"""Module providing graphs available from STRING.

References
----------
Please cite:

```bib
@article{szklarczyk2019string,
    title={STRING v11: protein--protein association networks with increased coverage, supporting functional discovery in genome-wide experimental datasets},
    author={Szklarczyk, Damian and Gable, Annika L and Lyon, David and Junge, Alexander and Wyder, Stefan and Huerta-Cepas, Jaime and Simonovic, Milan and Doncheva, Nadezhda T and Morris, John H and Bork, Peer and others},
    journal={Nucleic acids research},
    volume={47},
    number={D1},
    pages={D607--D613},
    year={2019},
    publisher={Oxford University Press}
}
```
"""
from ensmallen import Graph  # pylint: disable=import-error
from .graph_retrieval import RetrievedGraph

def SynechocystisSpPcc7509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC7509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc7509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPrasinopilosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces prasinopilosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPrasinopilosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoeciliaLatipinnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poecilia latipinna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoeciliaLatipinnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumAbscessusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAbscessusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonTcbr11e2g14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusInulinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusInulinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LampropediaHyalinaDsm16112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia hyalina DSM 16112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LampropediaHyalinaDsm16112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasDenitrificansDsm15123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans DSM 15123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrachymonasDenitrificansDsm15123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterCalcoaceticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter calcoaceticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCalcoaceticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CebusCapucinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cebus capucinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CebusCapucinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaHubeiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudozymaHubeiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumWg36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium WG36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumWg36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterInvisusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister invisus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterInvisusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumPolymorphumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum polymorphum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumPolymorphumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitoleransNbrc108937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans NBRC 108937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAmikacinitoleransNbrc108937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronolimnobiusInnermongolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronolimnobius innermongolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronolimnobiusInnermongolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaMasoucidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida masoucida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaMasoucidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpYr460(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr460", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosaetaHarundinacea6acEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea 6Ac Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosaetaHarundinacea6acEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13220cm2648(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_64_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm2648", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumMcbrellneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium mcbrellneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumMcbrellneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusIocasaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus iocasae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIocasaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeAr39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae AR39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeAr39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasMediaWs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas media WS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasMediaWs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFortisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fortis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioFortisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaSuimastitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia suimastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaSuimastitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesMccartyiCbdb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi CBDB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiCbdb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicronemaHongdechlorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomicronemaHongdechlorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusHarenaeDsm16969(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus harenae DSM 16969 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusHarenaeDsm16969", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTrypoxylicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus trypoxylicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusTrypoxylicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumGa0077525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumSg813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SG8_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSg813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedosphaeraParvulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedosphaeraParvulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAsterYellows(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma aster yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaAsterYellows", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineBacteriumAo1CCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return marine bacterium AO1-C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineBacteriumAo1CCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpFukuswis1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. FUKUSWIS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpFukuswis1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrispumAgresteEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum agreste Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumAgresteEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium6411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 64-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium6411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 1_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BiomphalariaGlabrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Biomphalaria glabrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BiomphalariaGlabrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaLutaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda lutaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaLutaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminobacterHydrogenoformansDsm2784Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans DSM 2784 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformansDsm2784Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasArenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas arenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasArenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSomerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas somerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSomerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaMembranifaciensNrrlY2026(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pichia membranifaciens NRRL Y-2026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PichiaMembranifaciensNrrlY2026", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPhyllostachyos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium phyllostachyos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPhyllostachyos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpKle1280Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. KLE1280 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpKle1280Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsbolusVerrucosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asbolus verrucosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsbolusVerrucosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterGallaeciensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter gallaeciensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterGallaeciensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelotrichaceaeBacteriumNk3d112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NK3D112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNk3d112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPseudopneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudopneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudopneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteScgcAb629i23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AB629I23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAb629i23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumMesophilumDsm19309Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum DSM 19309 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilumDsm19309Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergenciaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emergencia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmergenciaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CardiniumEndosymbiontCbtq1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cBtQ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCbtq1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusFulvus124b02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus 124B02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvus124b02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaSpMtp4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. MTP4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpMtp4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRhodolunaPlanktonicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodoluna planktonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodolunaPlanktonicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumFallax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFallax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumWanjuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium wanjuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumWanjuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaGinsengiterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengiterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengiterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFumigatusAf293Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Af293 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusFumigatusAf293Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusInulinusCasdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus CASD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusInulinusCasdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromohalobacterJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:115 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPectinilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pectinilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPectinilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodosporaAnserinaSMatCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina S mat+ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PodosporaAnserinaSMatCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusDucreyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus ducreyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusDucreyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSpb78Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SPB78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSpb78Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_43_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc1062Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC1062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc1062Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStoquefichusSpKle1796Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. KLE1796 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpKle1796Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAmericana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAmericana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnatzschineriaLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignatzschineria larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnatzschineriaLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13220cm27011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM27011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm27011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacillusKuerlensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacillus kuerlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacillusKuerlensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStreptomycesMassiliensisAp10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Streptomyces massiliensis AP10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStreptomycesMassiliensisAp10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_41_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg19ftcombo5516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG19FTCOMBO5516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg19ftcombo5516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaSpPamc20917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 20917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc20917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchangiumSpCbG35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archangium sp. Cb G35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchangiumSpCbG35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasZehnderiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumGw2011gwf24219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWF24219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwf24219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusYonginensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus yonginensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusYonginensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HodgkiniaCicadicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hodgkinia cicadicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HodgkiniaCicadicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho201full4349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO201FULL4349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho201full4349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRotaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rotai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRotaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvibaculumLavamentivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvibaculum lavamentivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvibaculumLavamentivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmadillidiumVulgareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armadillidium vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmadillidiumVulgareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpTcm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TCM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTcm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTremblayaPrincepsPcvalCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya princeps PCVAL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPrincepsPcvalCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumStylosanthisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium stylosanthis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumStylosanthisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa14423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA14423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa14423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettaeCvd059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae CVD059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusArlettaeCvd059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorrubiellaHemipterigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Torrubiella hemipterigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TorrubiellaHemipterigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotignumBalticumDsm7044(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotignum balticum DSM 7044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotignumBalticumDsm7044", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumMeliloti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium meliloti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMeliloti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpCnq490(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CNQ490 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCnq490", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp3211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp3211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TateyamariaOmphaliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria omphalii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TateyamariaOmphaliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasArsenicoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenicoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenicoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNantensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNantensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricanaCbs2517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana CBS 2517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaAfricanaCbs2517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKalixensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKalixensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumDsm525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum DSM525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumDsm525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumMultivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumMultivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag433(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:433 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag433", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusKodakarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus kodakarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusKodakarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemolyticusM21621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpNzgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. NZG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpNzgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusVoltae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus voltae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVoltae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAtlanticusDsm15807(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus DSM 15807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticusDsm15807", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCarbinoliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niastella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiastellaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloplanusNatansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloplanusNatansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMellis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMellis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesSp494a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 494a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp494a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BibersteiniaTrehalosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bibersteinia trehalosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BibersteiniaTrehalosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierellaPraeacutaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tissierella praeacuta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TissierellaPraeacutaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaDaqingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena daqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaDaqingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZinderiaInsecticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zinderia insecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZinderiaInsecticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesAbscessusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesAbscessusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiBc1401Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi BC1401 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiBc1401Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaPusillaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea pusilla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaPusillaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaEchinicomitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga echinicomitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEchinicomitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifoxyb1Full3916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYB1_FULL_39_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyb1Full3916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4534b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4534b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4534b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusSpUfo1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus sp. UFO1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelosinusSpUfo1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioParadoxusArh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus ARh 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxusArh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesDokdonensisFr1436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis FR1436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardioidesDokdonensisFr1436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasResinovoransDsm21078(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans DSM21078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransDsm21078", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorMorganiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor morganii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorMorganiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosalsumZhilinaeDsm4017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae DSM 4017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosalsumZhilinaeDsm4017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRossiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rossiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRossiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeomargaritaLithophoraAlchichicaD10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Alchichica-D10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GloeomargaritaLithophoraAlchichicaD10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesDentalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces dentalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDentalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactonifactorLongoviformisDsm17459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis DSM 17459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactonifactorLongoviformisDsm17459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterAzorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAsf356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAsf356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc3862(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3862 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3862", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifcsplowo201full6413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL6413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full6413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24387(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24387 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24387", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full3410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL3410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full3410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4122 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Henriciella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HenriciellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerriglobusRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TesticulariaCyperiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Testicularia cyperi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TesticulariaCyperiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumKashiwanohensePv202(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense PV20-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohensePv202", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrobacterAplysinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter aplysinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrobacterAplysinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJiangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaJiangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuganellaSpCf458Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF458 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf458Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasDaejeonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasDaejeonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GulbenkianiaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gulbenkiania indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GulbenkianiaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaKashmirensisW13003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis W13003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisW13003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumRifcsphigho201full6617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPHIGHO201FULL6617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsphigho201full6617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpS5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. S5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusSpS5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiosulfatibacterAminovoransDsm17477(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans DSM 17477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovoransDsm17477", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLentus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLentus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm16704Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM16704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm16704Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaPhaffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusMeridiei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus meridiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusMeridiei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaAmethystina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laccaria amethystina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaccariaAmethystina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaKristensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia kristensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaKristensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaHalifaxensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella halifaxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaHalifaxensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloplasmaContractileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloplasma contractile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloplasmaContractileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisNctc12261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis NCTC 12261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisNctc12261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesHordeovulnerisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hordeovulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHordeovulnerisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosporobacterMobilisDsm15930Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis DSM 15930 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilisDsm15930Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosococcusWatsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus watsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusWatsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusProteolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus proteolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusProteolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1No423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 No. 423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1No423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrothermarchaeotaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermarchaeota archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrothermarchaeotaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJceCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJceCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpHgh0039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HGH0039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHgh0039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusPlakortidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus plakortidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusPlakortidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusSpFs40622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus sp. FS40622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusSpFs40622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PortnoybacteriaBacteriumRbg13408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG13408 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg13408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSp1315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 13-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp1315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira terpstrae serovar Hualin str. LT 11-33 ATCC 700639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThiodiazotrophaEndolucinidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endolucinida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndolucinidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumPolymorphum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum polymorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumPolymorphum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPasteuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pasteurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPasteuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifoxyb1full4711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFOXYB1FULL4711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifoxyb1full4711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumOceanicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium oceanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOceanicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGaoshouyiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gaoshouyii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGaoshouyiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpBisph1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. Bisph1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpBisph1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpPamc26561(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. PAMC 26561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpPamc26561", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterDokdonensisDsw74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis DSW-74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensisDsw74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCatarrhalisBbh18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis BBH18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalisBbh18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs205(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs205", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheionarchaeaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7336Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7336 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7336Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpPamc26561Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. PAMC 26561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpPamc26561Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerodermaCitrinumFougAEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Foug A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SclerodermaCitrinumFougAEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusRusselliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus russellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusRusselliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonopterusAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monopterus albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonopterusAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasBacteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas bacteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasBacteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatisLmg20103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis LMG20103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisLmg20103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumLipoferum4bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum 4B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AzospirillumLipoferum4bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UstilagoHordeiUh48574Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Uh4857-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UstilagoHordeiUh48574Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiAtcc8739Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli ATCC8739 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiAtcc8739Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZhongshaniaAliphaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zhongshania aliphaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZhongshaniaAliphaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaNautarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella nautarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaNautarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaGranulomatisDsm19156Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis DSM 19156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MannheimiaGranulomatisDsm19156Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScophthalmusMaximusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scophthalmus maximus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScophthalmusMaximusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusWulumuqiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wulumuqiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWulumuqiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLutaoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lutaoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLutaoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ViridibacillusArenosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arenosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ViridibacillusArenosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_35_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae subsp. similipneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpScn7327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. SCN 73-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpScn7327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPactum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pactum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPactum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumDamselaeSubspDamselaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae subsp. damselae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumDamselaeSubspDamselaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPenetransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma penetrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPenetransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwa1377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA1377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa1377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylellaFastidiosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylella fastidiosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylellaFastidiosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag380Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag380Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpP2bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. P2b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpP2bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpRoot418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ViridibacillusArviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Viridibacillus arvi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ViridibacillusArviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParabrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabrevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallosphaeraHakonensisJcm8857Dsm7519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis JCM 8857 DSM 7519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensisJcm8857Dsm7519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg134322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_43_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsphigho212full6320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO212FULL6320 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho212full6320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumWalsbyiJ07hqw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumOxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexithrixDorotheaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flexithrix dorotheae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlexithrixDorotheaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensisKctc13613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus siamensis KCTC 13613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSiamensisKctc13613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpHot20860m813o14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813O14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813o14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterSpLeaf296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsplowo201full5118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO201FULL5118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo201full5118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSp99(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. 99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSp99", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioSalmonicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AliivibrioSalmonicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaSpKm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hippea sp. KM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HippeaSpKm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYC2_FULL_45_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumJosui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium josui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumJosui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTuricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesTuricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumCaseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumCaseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterSpAap82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraButanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera butanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraButanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaesserellaParasuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaesserella parasuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaesserellaParasuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSp609Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. 60_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSp609Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenobaculumSpY04aas1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. Y04AAS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpY04aas1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumChkci006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSalinaYim90010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis salina YIM 90010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisSalinaYim90010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusRubiinfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus rubiinfantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusRubiinfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluviicolaTaffensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola taffensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FluviicolaTaffensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesMethylutensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCoelicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces coelicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCoelicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwb24920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_49_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb24920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_54_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRbg134211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG134211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg134211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterLwoffiiNctc5866Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii NCTC 5866 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiNctc5866Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheropithecusGeladaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theropithecus gelada Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheropithecusGeladaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumGwc25713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc25713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusHermanniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hermanniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHermanniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBizertensisDsm18034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis DSM 18034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensisDsm18034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiophoraPuteana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coniophora puteana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ConiophoraPuteana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpPc13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. PC13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpPc13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpC04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. C04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpC04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSp142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPumilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pumilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPumilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAggregataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAggregataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwc14715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWC1_47_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwc14715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKullabergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kullabergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKullabergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoanaerobacterStomatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoanaerobacter stomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoanaerobacterStomatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinibacterTainanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinibacterTainanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsUnilateralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps unilateralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsUnilateralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJinanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jinanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaJinanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantCapraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant caprae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantCapraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotignumBalticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotignum balticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotignumBalticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiemerellaAnatipestifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riemerella anatipestifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiemerellaAnatipestifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumInhibens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium inhibens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumInhibens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TangfeifaniaDiversioriginumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tangfeifania diversioriginum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TangfeifaniaDiversioriginumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterVibrioidesCb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides CB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesCb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureobasidiumMelanogenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumDentium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium dentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumDentium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeauveriaBassianaD15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana D1-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaD15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpJf8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. JF8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpJf8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumGw2011gwd23842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWD23842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwd23842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumGw2011gwa14429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA14429 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa14429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinibacillusContaminansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusContaminansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumJannaschiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMytiliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mytili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMytiliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumRileyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium rileyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumRileyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg134610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg134610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaNativaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNativaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrinaliumEpipsammumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crinalium epipsammum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrinaliumEpipsammumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensSk114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens SK114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensSk114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpHel13355Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. Hel1_33_55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpHel13355Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RenibacteriumSalmoninarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Renibacterium salmoninarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RenibacteriumSalmoninarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaCompniacensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia compniacensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaCompniacensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwe23210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWE2_32_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwe23210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpR1200b2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. R1200B2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpR1200b2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPylori26695(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori 26695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPylori26695", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSp1485e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. 1485E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSp1485e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolinellaSuccinogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolinella succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolinellaSuccinogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumMultiglobuliferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum multiglobuliferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMultiglobuliferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterInsulaenigraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma auris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpAn1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. AN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpAn1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full5710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL5710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full5710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifcsplowo201full4626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GalerinaMarginataCbs33988Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Galerina marginata CBS 339.88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GalerinaMarginataCbs33988Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemolyticusM19501Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M19501 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM19501Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWesteberhardiaCardiocondylaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Westeberhardia cardiocondylae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWesteberhardiaCardiocondylaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumJcvitm6sc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium JCVITM6SC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumJcvitm6sc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpErmr104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. ERMR1:04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpErmr104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasHuabeiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas huabeiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasHuabeiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaSg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Sg graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698rsb12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta MAD698RSB12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698rsb12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumGuttoideum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum guttoideum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumGuttoideum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinovumAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinovum algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinovumAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterEnzymogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter enzymogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterEnzymogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTibeticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tibeticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTibeticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumNonalfalfae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verticillium nonalfalfae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerticilliumNonalfalfae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalaenopteraAcutorostrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag1193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumNrl2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium NRL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumNrl2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full5223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_52_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full5223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCanintestiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canintestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanintestiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSpNdb2meth4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. NDB2Meth4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpNdb2meth4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifoxyb1full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYB1FULL4614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyb1full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpErgs101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ERGS1:01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpErgs101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpRoot335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitomosoidesSigmodontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litomosoides sigmodontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitomosoidesSigmodontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRubensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium rubens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRubensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusPushchinoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus pushchinoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusPushchinoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiRu7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii RU7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiRu7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LottiaGigantea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lottia gigantea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LottiaGigantea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeokomagataeaThailandicaNbrc106555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica NBRC 106555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeokomagataeaThailandicaNbrc106555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobiformaLacisalsiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma lacisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobiformaLacisalsiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BursaphelenchusXylophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bursaphelenchus xylophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BursaphelenchusXylophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersicobacterSpJzb09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Persicobacter sp. JZB09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PersicobacterSpJzb09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgulaAerodenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOhsuiiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OHSUIII Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOhsuiiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa264110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_64_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa264110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaMojavensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila mojavensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DrosophilaMojavensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpJs666Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. JS666 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpJs666Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwe24214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE24214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe24214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeTagetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tagetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTagetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerorhabdusFurcosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerorhabdus furcosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerorhabdusFurcosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHarenaeNbrc108248Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia harenae NBRC 108248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaHarenaeNbrc108248Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPHIGHO2_02_FULL_52_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiLrivu41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi lrivu41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiLrivu41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobisporaSpAtccPta5024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. ATCC PTA-5024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpAtccPta5024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar86ClusterBacteriumSar86aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHarbinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHarbinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumApsheronumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium apsheronum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumApsheronumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpMadar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. MADAR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpMadar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubidusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubidus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubidusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpSr15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. SR1/5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpSr15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasAltamirensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas altamirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasAltamirensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpRac02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. RAC02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpRac02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm23732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasResinovoransNbrc106553Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans NBRC106553 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransNbrc106553Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBicirculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bicirculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBicirculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumChlororespiransDsm11544(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans DSM 11544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespiransDsm11544", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_12_FULL_43_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParameciumTetraureliaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paramecium tetraurelia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParameciumTetraureliaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaGrimesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia grimesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaGrimesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGa0074129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ga0074129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGa0074129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGlacieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium glaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGlacieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolycyclovoransAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polycyclovorans algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolycyclovoransAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcticibacterEurypsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter eurypsychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterEurypsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonariusItem5010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius ITEM 5010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusCarbonariusItem5010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaVespertilionisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malassezia vespertilionis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalasseziaVespertilionisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpHgh0039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HGH0039 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHgh0039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc5600(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5600 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5600", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSonorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sonorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSonorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusChristensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus christensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusChristensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpHr7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. HR7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpHr7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxSaidenbachensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax saidenbachensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxSaidenbachensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumKb13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium KB13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumKb13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCorrugataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas corrugata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCorrugataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumProteolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium proteolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProteolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag485(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag485", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusArsenicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus arsenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FictibacillusArsenicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterButzleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter butzleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterButzleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSp25b141Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 25B141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp25b141Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PetrimonasMucosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Petrimonas mucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PetrimonasMucosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp172e8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 172E8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp172e8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteriumSenegalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilibacteriumSenegalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhocaeicolaAbscessusCcug55929Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus CCUG 55929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessusCcug55929Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallionellaCapsiferriformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionella capsiferriformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellaCapsiferriformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HathewayaProteolyticaDsm3090Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica DSM 3090 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HathewayaProteolyticaDsm3090Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaDagmatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaDagmatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosumWal14673Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14673 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14673Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPhenolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas phenolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPhenolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalomonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiohalomonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiohalomonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HespelliaStercorisuisDsm15480Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis DSM 15480 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HespelliaStercorisuisDsm15480Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OoceraeaBiroiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ooceraea biroi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OoceraeaBiroiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalisediminibacteriumHaloalkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salisediminibacterium haloalkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalisediminibacteriumHaloalkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpOv259Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV259 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv259Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaHermsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hermsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaHermsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusCurtisiiAtcc43063Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC43063 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc43063Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumBv3ac1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium BV3Ac1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumBv3ac1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4281Fw2241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4281 (FW-2241) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4281Fw2241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag571Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag571Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumBuryatense5gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense 5G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatense5gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RudanellaLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rudanella lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RudanellaLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpP6a1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. P6A1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpP6a1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraSpCag700Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:700 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag700Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusIctaluriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ictaluri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIctaluriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViolaceoruber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violaceoruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolaceoruber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusKyotonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus kyotonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusKyotonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaStuartiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia stuartii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaStuartiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilalesBacteriumMbrsf5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium MBRSF5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumMbrsf5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsiellaDolichumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Absiella dolichum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbsiellaDolichumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxElongansAtccBaa1513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haloferax elongans ATCC BAA-1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaloferaxElongansAtccBaa1513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoaviumNbrc100491Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium NBRC 100491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterococcusPseudoaviumNbrc100491Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonadalesBacteriumRifoxya1full6910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium RIFOXYA1FULL6910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacteriumRifoxya1full6910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothrixThermoacetophilaPtCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila PT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophilaPtCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaOvis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dietzia maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DietziaMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsobaculumMelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Isobaculum melis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IsobaculumMelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMola455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MOLA455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMola455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf427Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf427 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf427Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoclostridiumDifficile630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile 630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficile630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSalifodinaeDsm8989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halococcus salifodinae DSM 8989 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalococcusSalifodinaeDsm8989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaNodosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia nodosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaNodosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaCaldifontisAzm44c09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis AZM44c09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermotogaCaldifontisAzm44c09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpAb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGenavenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium genavense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGenavenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwb1471Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWB1471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwb1471Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaCoubleaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia coubleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaCoubleaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerroglobusPlacidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferroglobus placidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerroglobusPlacidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrilusPlanipennisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrilus planipennis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrilusPlanipennisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwd24019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWD2_40_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwd24019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaLactamicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria lactamica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaLactamicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaAlbida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumPo82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Po82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPo82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LinumUsitatissimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Linum usitatissimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LinumUsitatissimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasIngrahamiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ingrahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromonasIngrahamiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaSpinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora spinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaSpinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFicariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia ficaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaFicariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcusAnaerobius653lEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius 653L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobius653lEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiodiazotrophaEndolucinidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endolucinida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndolucinidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_49_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoanaerobacterStomatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoanaerobacter stomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoanaerobacterStomatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaBurhodogranarieaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia burhodogranariea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaBurhodogranarieaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumisMeloEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cucumis melo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CucumisMeloEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesUtahensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesUtahensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaOchraceaF0287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea F0287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaF0287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLm7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LM7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLm7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraSpB5022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira sp. B5-022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSpB5022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcalesBacterium7313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomyceteKsu1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return planctomycete KSU1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlanctomyceteKsu1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChromiireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chromiireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChromiireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpMt41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. MT41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpMt41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpCag257Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:257 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag257Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12SubstrMg1655Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. MG1655 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrMg1655Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiDsm29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei DSM 29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiDsm29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumCongolenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium congolense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumCongolenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumChkci006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusMicrocarpus441Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus 441 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PisolithusMicrocarpus441Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterEnclensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter enclensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterEnclensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxya1Full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYA1_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxya1Full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylothermaceaeBacteriaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteriaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViolaceoruberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violaceoruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolaceoruberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthromitusSpSfbmousenl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseNL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousenl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumSubglacialeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumSubglacialeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusArctosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ursus arctos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrsusArctosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacteriumLuteolumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium luteolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumLuteolumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumCellulolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellulolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellulolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpongiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpongiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaSpIbvhs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpJcb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. JCB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpJcb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MooreaProducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moorea producens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MooreaProducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HippeaSpKm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hippea sp. KM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HippeaSpKm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_52_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMacleodii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas macleodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMacleodii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterValericigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter valericigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterValericigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpCcbau05631Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. CCBAU05631 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumSpCcbau05631Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo201full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL4510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicosporidiumSpAtcc50920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicosporidium sp. ATCC 50920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicosporidiumSpAtcc50920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag964Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:964 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag964Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaphniaPulexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daphnia pulex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaphniaPulexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AotusNancymaaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aotus nancymaae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AotusNancymaaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumTcs56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobisporangiumUltimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Globisporangium ultimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlobisporangiumUltimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedClostridiumSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiumSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbus8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24668(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_46_68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24668", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacearchaeotaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacearchaeota archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacearchaeotaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpMebic08052(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. MEBiC08052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSpMebic08052", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPseudogenitalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudogenitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudogenitalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaMycoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mycoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMycoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MizuhopectenYessoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mizuhopecten yessoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MizuhopectenYessoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterRodentium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterRodentium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full4115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAeronauticumDsm10349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum DSM 10349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticumDsm10349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscobolusImmersusRn42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ascobolus immersus RN42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AscobolusImmersusRn42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaJiangningensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga jiangningensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaJiangningensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpEr4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. ER4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpEr4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHeteromorphus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusHeteromorphus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaNavojoaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila navojoa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaNavojoaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterTroitsensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter troitsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterTroitsensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpOk626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. ok626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpOk626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesDirusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles dirus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesDirusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOv322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OV322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOv322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumRubiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rubi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumRubiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPLOWO2_01_FULL_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaRadiotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRadiotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSpDsm46786Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46786Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DissulfuribacterThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dissulfuribacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DissulfuribacterThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacillusLacisalsiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus lacisalsi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusLacisalsiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoflavimicrobiumDichotomicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoflavimicrobium dichotomicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoflavimicrobiumDichotomicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PestalotiopsisFiciW1061Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici W106-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PestalotiopsisFiciW1061Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacillusFlagellatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusFlagellatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaRickettsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia rickettsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaRickettsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumVanbaaleniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vanbaalenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVanbaaleniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumXenophagumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium xenophagum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumXenophagumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivicanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivicanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldisericumSpCg2303611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum sp. CG2_30_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldisericumSpCg2303611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_41_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmobacterNectariphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter nectariphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmobacterNectariphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterGottschalkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter gottschalkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterGottschalkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBouvetii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bouvetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBouvetii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCuracoiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces curacoi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCuracoiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_36_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaAnanassaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila ananassae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaAnanassaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBifidumPrl2010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum PRL2010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumPrl2010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4315bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4315b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4315bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterocephalusGlaberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heterocephalus glaber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeterocephalusGlaberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusDamnosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus damnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusDamnosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedAcidilobusSpCisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. CIS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpCisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterShowaeCc57c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CC57C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCc57c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineococcusRadiotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kineococcus radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KineococcusRadiotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAcridumCqma102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum CQMa 102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAcridumCqma102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BellilineaCaldifistulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bellilinea caldifistulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BellilineaCaldifistulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSalinitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PristionchusPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pristionchus pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PristionchusPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL4515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixEikelboomii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix eikelboomii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiothrixEikelboomii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaStercorariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla stercoraria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaStercorariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUrhb0009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. URHB0009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUrhb0009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumPhox21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium Phox-21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumPhox21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa14423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA14423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa14423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpBh72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. BH72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpBh72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoolittleaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doolittlea endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoolittleaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplosphaeraColitermitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Diplosphaera colitermitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DiplosphaeraColitermitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioSpN1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio sp. N1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioSpN1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaLutimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria lutimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaLutimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusOxalaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusOxalaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumGorillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGorillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGraevenitziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces graevenitzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGraevenitziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSp05ny08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 05NY08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp05ny08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterValericigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter valericigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterValericigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxNanhaiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax nanhaiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxNanhaiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGastricusPs3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus PS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGastricusPs3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaGlobuliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina globuliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaGlobuliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanisphaeraPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanisphaera psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanisphaeraPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonauticusSubmarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus submarinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSubmarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaCandida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaCandida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_45_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml980116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML98-0116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml980116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFloridensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaFloridensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpBmg111209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG111209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg111209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilumDsm21637Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum DSM 21637 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilumDsm21637Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpRoot444d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root444D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot444d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJensenii272chnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 272CHN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii272chnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AptenodytesForsteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aptenodytes forsteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AptenodytesForsteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13817 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusResistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus resistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusResistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacaDankookensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca dankookensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaDankookensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumPullulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwa24010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA24010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa24010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC2_34_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandaracinusAmylolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sandaracinus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SandaracinusAmylolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpClo3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. CLO-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpClo3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAlgidusDsm15638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus algidus DSM 15638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlgidusDsm15638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlutamicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glutamicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlutamicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisNcppb382(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis NCPPB382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisNcppb382", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumRubrisubalbicansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinidiaChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinidia chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinidiaChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho212full4219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpUrhb0009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. URHB0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUrhb0009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOligofermentansDsm15707Lmg22743(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans DSM 15707 LMG 22743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOligofermentansDsm15707Lmg22743", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusUzoniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus uzoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusUzoniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaSp5ratimar09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 5RATIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp5ratimar09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiccibacterTuricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter turicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SiccibacterTuricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRibeironisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ribeironis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRibeironisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_12_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MnemiopsisLeidyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mnemiopsis leidyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MnemiopsisLeidyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPiraticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piratica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiraticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_37_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaConchaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria conchae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaConchaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FragariaVescaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fragaria vesca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FragariaVescaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwa24315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWA2_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwa24315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CystobacterFerrugineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cystobacter ferrugineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CystobacterFerrugineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosphaeraAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosphaera aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosphaeraAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermusFervidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermus fervidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermusFervidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumLsjc7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium LSJC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumLsjc7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_02_FULL_45_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaZhangzhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaZhangzhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuganellaSpCf458(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF458 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf458", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidicaulisMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidicaulis marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidicaulisMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FasciolaGiganticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fasciola gigantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FasciolaGiganticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpRs40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinocyclocheilusGrahami(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus grahami graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusGrahami", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydialesBacterium3826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiales bacterium 38-26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydialesBacterium3826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumHum1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylothermaceaeBacteriaB42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria B42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteriaB42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasMalthaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas malthae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMalthaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaBovoculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovoculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovoculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwf1525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF1525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf1525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag582(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag582", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFlorumDsm22689Jcm16035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum DSM 22689 JCM 16035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFlorumDsm22689Jcm16035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaSpAtcc55076(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea sp. ATCC 55076 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaSpAtcc55076", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistetesBacteriumJgi0000079d21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synergistetes bacterium JGI 0000079D21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynergistetesBacteriumJgi0000079d21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiameyensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niameyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusNiameyensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwe24236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_42_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe24236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu37d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU37D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu37d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhizobiumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpSd626rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. SD626R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpSd626rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltosporidiumTvaerminnensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium tvaerminnensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumTvaerminnensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAminophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aminophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAminophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumOryziradicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryziradicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryziradicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAnticariensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas anticariensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasAnticariensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml130454(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML130454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml130454", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGasicomitatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gasicomitatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGasicomitatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndomicrobiumProavitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endomicrobium proavitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndomicrobiumProavitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniborusSpDw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus sp. DW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusSpDw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpM41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpM41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaSpJ72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrinema sp. J72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSpJ72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24817 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimicrobiumPachnodaeJcm13526Nbrc107786(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae JCM 13526 NBRC 107786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodaeJcm13526Nbrc107786", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaCohaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lewinella cohaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LewinellaCohaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpR43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. R43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpR43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichomalopsisSarcophagae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichomalopsis sarcophagae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichomalopsisSarcophagae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 41-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdvenellaKashmirensisWt001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis WT001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisWt001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedArchaeonA07hb70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HB70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hb70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YuhushiellaDesertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yuhushiella deserti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YuhushiellaDesertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpTpbh4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. TPBH4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpTpbh4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpUnc380mfsha31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. unc380mfsha3.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpUnc380mfsha31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaConcitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia concitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaConcitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpMs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. MS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpMs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GulosibacterMolinativoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gulosibacter molinativorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GulosibacterMolinativoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRifcsphigho212full389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPHIGHO212FULL389 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsphigho212full389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiiEuryarchaeoteCgEpi1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marine Group III euryarchaeote CG-Epi1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiiEuryarchaeoteCgEpi1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSp1nls2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 1NLS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AfipiaSp1nls2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLuciferensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus luciferensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLuciferensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPeroris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus peroris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPeroris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OncorhynchusMykiss(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oncorhynchus mykiss graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OncorhynchusMykiss", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBiavatiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium biavatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBiavatiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumTodarodis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum todarodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumTodarodis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMacacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus macacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMacacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAlbensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella albensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAlbensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpNcr5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. NCR5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpNcr5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCaribbeanicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio caribbeanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioCaribbeanicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraPardusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Panthera pardus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantheraPardusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag403Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag403Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TakifuguRubripes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Takifugu rubripes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TakifuguRubripes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobrachiumCelereCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobrachium celere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermobrachiumCelereCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full4412bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL4412b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full4412bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteroidesVaginaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilibacteroides vaginae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilibacteroidesVaginaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSp113p3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. 113P3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSp113p3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpCny236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. CNY236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpCny236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSakei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sakei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSakei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCaprae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCaprae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonauticusSp384375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. 38_4375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSp384375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasBalearicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas balearica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimonasBalearicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacteralesBacterium6714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium 67-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacterium6714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumGw2011gwf24219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWF24219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwf24219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumGypseum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microsporum gypseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrosporumGypseum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaShahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella shahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaShahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaSpCf118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. CF118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpCf118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumSpUnkmgs17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum sp. UNKMGS17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumSpUnkmgs17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticolaF0411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola F0411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaHisticolaF0411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGalatheaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium galatheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGalatheaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Veblenbacteria bacterium RIFOXYC2_FULL_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPropionicifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSpCetp13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. CETP13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpCetp13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellalesBacteriumRifcsphigho212full3511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3511 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensPf01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Pf01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensPf01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm2381Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm2381Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaAcetivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUlceransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulcerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlceransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOleovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oleovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOleovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelopsittacusUndulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melopsittacus undulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelopsittacusUndulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EudoraeaAdriaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eudoraea adriatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EudoraeaAdriaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusBolidensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus bolidensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsenicicoccusBolidensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrarchaeotaArchaeonCg1025115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025115 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusPersicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prunus persica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrunusPersicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaYl17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila YL17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaYl17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitoleransNbrc108937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans NBRC 108937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAmikacinitoleransNbrc108937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaceaeBacteriumNi1060Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium NI1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacteriumNi1060Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumF0431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium F0431 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumF0431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaCaliforniensisDsm14826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis DSM 14826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensisDsm14826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HespelliaStercorisuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HespelliaStercorisuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaZeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaZeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasRuthenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas ruthenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRuthenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRenniniDsm20253(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rennini DSM 20253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRenniniDsm20253", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraBriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira briensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraBriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa254124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_54_124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa254124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiscirickettsiaLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBiflexaSerovarPatocStrainPatoc1ParisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira biflexa serovar Patoc strain Patoc 1 (Paris) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBiflexaSerovarPatocStrainPatoc1ParisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillochlorisTrichoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillochloris trichoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillochlorisTrichoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSp6626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. 6626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSp6626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PundamiliaNyererei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pundamilia nyererei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PundamiliaNyererei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterToluenoxydansJcm15764Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans JCM 15764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacterToluenoxydansJcm15764Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFOXYA2_FULL_45_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasMontiporaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAntarcticusDsm21422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter antarcticus DSM 21422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MaribacterAntarcticusDsm21422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterPhenylpyruvicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter phenylpyruvicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPhenylpyruvicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf180(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf180", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforegulaConservatrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulforegula conservatrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulforegulaConservatrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaSpMc24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. Mc24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSpMc24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumNrl2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium NRL2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumNrl2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicropelagosThuwalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micropelagos thuwalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicropelagosThuwalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_35_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterKookiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kookii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKookiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylosporangiumAurantiacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dactylosporangium aurantiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DactylosporangiumAurantiacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExidiaGlandulosaHhb12029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exidia glandulosa HHB12029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExidiaGlandulosaHhb12029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23272(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23272", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLentocellum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lentocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLentocellum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaHalifaxensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella halifaxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaHalifaxensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterLectusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algibacter lectus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgibacterLectusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridioidesDifficile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides difficile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesDifficile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaGrammica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylaria grammica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylariaGrammica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxya1full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYA1FULL4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxya1full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceicoccusNaphthovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus naphthovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusNaphthovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KrasilnikoviellaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Krasilnikoviella flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KrasilnikoviellaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSalamaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica salamae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaSalamaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusOpacusB4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusOpacusB4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMaricopensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus maricopensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMaricopensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHalophyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora halophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHalophyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag590(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag590", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwd26328Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWD2_63_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwd26328Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StigmatellaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stigmatella aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StigmatellaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpQd031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. qd031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSpQd031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSojaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferSojaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnh099(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh099", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisSpNies3709Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3709 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3709Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumFunditumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium funditum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumFunditumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesocestoidesCortiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesocestoides corti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesocestoidesCortiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmobacterNectariphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter nectariphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmobacterNectariphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpLeaf160Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf160 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf160Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70737Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70737 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70737Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPolarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia polaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPolarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpFp211j200Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FP211J200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFp211j200Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0701(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0701", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibacteriumElongatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseibacterium elongatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseibacteriumElongatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuniculiplasmaDivulgatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cuniculiplasma divulgatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CuniculiplasmaDivulgatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EvansiaMuelleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Evansia muelleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EvansiaMuelleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusOpacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus opacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusOpacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpRoot608(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot608", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGanghwense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium ganghwense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGanghwense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusSolisalsiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus solisalsi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FictibacillusSolisalsiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilvimarinusChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErpetoichthysCalabaricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erpetoichthys calabaricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErpetoichthysCalabaricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasWolfeiSubspMethylbutyratica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei subsp. methylbutyratica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiSubspMethylbutyratica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinispirillumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinispirillum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinispirillumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiaControversa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tilletia controversa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TilletiaControversa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodolunaLacicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna lacicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodolunaLacicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKefiranofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiranofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiranofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAtexabd23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ATexABD23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAtexabd23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelobacterAcetylenicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter acetylenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelobacterAcetylenicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpSat1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SAT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSat1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpadix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas spadix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpadix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArdenticatenaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ardenticatena maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArdenticatenaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PneumocystisMurinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis murina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PneumocystisMurinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_44_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusTerranovensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAzotoformansLmg9581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus azotoformans LMG 9581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAzotoformansLmg9581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHemicellulosilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumThermoalcaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] thermoalcaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumThermoalcaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorusNotabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Morus notabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MorusNotabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTerpenotabidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium terpenotabidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTerpenotabidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaceaeBacteriumHun156Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium HUN156 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumHun156Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaryochlorisMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acaryochloris marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcaryochlorisMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVulneris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium vulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumVulneris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacterium4484702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_70.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliopsisZonataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliopsisZonataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnncaliiaAlgeraePra339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anncaliia algerae PRA339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnncaliiaAlgeraePra339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasAquimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromonasAquimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TarsiusSyrichtaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tarsius syrichta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TarsiusSyrichtaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KuenenbacteriaBacteriumCg2303924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium CG2303924 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumCg2303924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAquilaeDsm44791Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae DSM 44791 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAquilaeDsm44791Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumUreilyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium ureilyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumUreilyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensDb11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens Db11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensDb11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaWillistoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila willistoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaWillistoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalapricumSalinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halapricum salinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalapricumSalinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxiiCbs732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii CBS 732 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxiiCbs732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasAquimarinaAtccBaa1526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina ATCC BAA-1526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychromonasAquimarinaAtccBaa1526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaladaptatusSpR4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus sp. R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusSpR4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusAzygosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus azygosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopusAzygosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_38_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterPelagiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPelagiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterToluenoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterToluenoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDaejeonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDaejeonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacteralesBacteriumFibro01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacterales bacterium Fibro_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacteralesBacteriumFibro01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpermophilusDauricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spermophilus dauricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpermophilusDauricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo201full6025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL6025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full6025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IlyobacterPolytropus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ilyobacter polytropus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IlyobacterPolytropus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBorstelensisAk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis AK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensisAk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollimonasSpOk412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyprinodonVariegatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyprinodon variegatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyprinodonVariegatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpBr18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Br18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpBr18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumKocuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum kocurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumKocuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo201full5215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL5215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full5215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosynnemaMirumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema mirum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaMirumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniborusSpDw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus sp. DW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusSpDw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb243495d8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_495D8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243495d8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LitomosoidesSigmodontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litomosoides sigmodontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitomosoidesSigmodontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSalivariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus salivarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSalivariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag786Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag786Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusSaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRifcsphigho212full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPHIGHO212FULL4510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsphigho212full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrennerbacteriaBacteriumRifoxyd1full4116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brennerbacteria bacterium RIFOXYD1FULL4116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrennerbacteriaBacteriumRifoxyd1full4116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterOboediens174bp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens 174Bp2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterOboediens174bp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrucibulumLaeve(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crucibulum laeve graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrucibulumLaeve", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpJ142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. J14-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpJ142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaSubspSalmonicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. salmonicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspSalmonicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd2full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD2FULL4114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd2full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArsenophonusLipoptenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus lipoptenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusLipoptenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonisporaThiosulfatigenesDsm11270Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes DSM 11270 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenesDsm11270Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDubius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter dubius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDubius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251961sch5331710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251961SCH5331710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251961sch5331710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho212full4422b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4422b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4422b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyunsoonleellaJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyunsoonleella jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyunsoonleellaJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisFw213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis FW213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisFw213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasHydrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasHydrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumHoustonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium houstonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHoustonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCelluloflavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces celluloflavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCelluloflavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VignaRadiata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vigna radiata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VignaRadiata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutimaribacterSaemankumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutimaribacter saemankumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutimaribacterSaemankumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisalinibacterKiritimatiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldisalinibacter kiritimatiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldisalinibacterKiritimatiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUliginosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium uliginosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumUliginosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeggiatoaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPHIGHO2_12_FULL_38_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrothermarchaeotaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermarchaeota archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrothermarchaeotaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetakosakoniaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterThalassicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidibacterThalassicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpSoil766(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil766 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil766", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusNctc2665Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus NCTC 2665 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusNctc2665Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpLycopersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptothrixCholodniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptothrix cholodnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptothrixCholodniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpK24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. K24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpK24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpMm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. MM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiCsThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CS Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCsThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacterium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoahuilensisP1143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis p1.1.43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCoahuilensisP1143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full6025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL6025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full6025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumDtu027(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium DTU027 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumDtu027", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg166630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_16_66_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg166630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNfr12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPamc26605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosarcinaFibrataAmlC10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata AML-C10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaFibrataAmlC10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumWasabiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium wasabiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumWasabiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpOv259(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV259 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv259", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpS6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpS6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumNamibiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumNamibiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumAutotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum autotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumAutotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_72_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHeilmanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHeilmanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsphigho202full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL4114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaCaldifontisAzm44c09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis AZM44c09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermotogaCaldifontisAzm44c09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpScn6821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SCN 68-21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpScn6821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxoplasmaGondii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Toxoplasma gondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ToxoplasmaGondii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusStrTiberiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus str. Tiberius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusStrTiberiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumOlb18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium OLB18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumOlb18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaUliginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella uliginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaUliginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumThermoresistibileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium thermoresistibile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumThermoresistibileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho212full4113bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO212FULL4113b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho212full4113bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CharadriusVociferusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Charadrius vociferus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CharadriusVociferusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterForsetiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter forsetii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterForsetiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19041 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAnaemiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia anaemiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAnaemiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaBannensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bannensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBannensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusSomnusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus somnus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSomnusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigidarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothiobacillusSpXi15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. XI15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpXi15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApinorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apinorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApinorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecomicrobiumHirschiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prosthecomicrobium hirschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProsthecomicrobiumHirschiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesSpShpl62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogranumGelatinilyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halogranum gelatinilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalogranumGelatinilyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:227 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaGrandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria grandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpMaepy2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MAEPY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMaepy2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpJcbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. JCB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpJcbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliivibrioSalmonicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio salmonicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AliivibrioSalmonicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_49_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMesonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mesonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMesonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillaceaeBacteriumBrhc57Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillaceae bacterium BRHc57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillaceaeBacteriumBrhc57Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpDlviii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DLVIII graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDlviii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpS32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. S3-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpS32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParastagonosporaNodorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParastagonosporaNodorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAggregata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAggregata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiPomona(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Pomona graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiPomona", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumPga8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium pGA-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumPga8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumG186arCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum G186AR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumG186arCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4716bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4716b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4716bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBroomii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira broomii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBroomii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpRoot1480d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root1480D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot1480d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphilaNbrc108938Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila NBRC 108938 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphilaNbrc108938Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMarmotaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marmotae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarmotaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAurantiacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KapabacteriaThiocyanatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kapabacteria thiocyanatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KapabacteriaThiocyanatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusHalodenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus halodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusHalodenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSegetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium segetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSegetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_01_FULL_48_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonRbg19ftcombo5621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO5621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo5621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg163611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_36_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg163611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaHypogeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfohalovibrioReitneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalovibrio reitneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfohalovibrioReitneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpEnrichmentCultureCloneC5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment culture clone C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichmentCultureCloneC5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenobaculumSpY04aas1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. Y04AAS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpY04aas1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumSpOccitanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium sp. occitanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSpOccitanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalarchaeumAcidiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halarchaeum acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalarchaeumAcidiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumCg2303430(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_34_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303430", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpRoot65(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot65", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophilaDsm15071(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiohalospira halophila DSM 15071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiohalospiraHalophilaDsm15071", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpLeaf126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Leaf126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpLeaf126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusBoritoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusBoritoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Babesia equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BabesiaEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasHofstadii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasHofstadii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRit328Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. RIT328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRit328Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimiaSpSk013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimia sp. SK013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimiaSpSk013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpZ31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. Z-31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpZ31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasUshuaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas ushuaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasUshuaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthellaSpCag368Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag368Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRaffinosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus raffinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRaffinosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpPr090111t3t6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PR090111T3T6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPr090111t3t6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfBathymodiolus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaParisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Paris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaParisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep2538(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2538 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2538", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat26652Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-26652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat26652Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheileriaAnnulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theileria annulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheileriaAnnulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaSpBsc39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga sp. BSC39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaSpBsc39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisDnlkv3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis dnLKV3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisDnlkv3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovoraNrrlY12698(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Babjeviella inositovora NRRL Y-12698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BabjeviellaInositovoraNrrlY12698", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaSolani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSolani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolectaIrregularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neolecta irregularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeolectaIrregularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbus8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPseudobrasiliensisNbrc108224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis NBRC 108224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensisNbrc108224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFlexusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus flexus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFlexusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantheraPardus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Panthera pardus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantheraPardus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaRhizosphera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia rhizosphera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaRhizosphera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk1080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK1080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk1080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipomycesStarkeyiNrrlY11557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi NRRL Y-11557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LipomycesStarkeyiNrrlY11557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpAb3007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. AB3007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpAb3007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumGwa2528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_52_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa2528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolani123eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani 123E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolani123eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EthanoligenensHarbinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ethanoligenens harbinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EthanoligenensHarbinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxCitrulliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax citrulli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCitrulliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopirellulaEuropaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenuloplanesJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenuloplanes japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenuloplanesJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpGws1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. GWS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpGws1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpC6a8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. C6A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpC6a8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloactinosynnemaAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumCentrolobii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium centrolobii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCentrolobii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiSubspMethylbutyraticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei subsp. methylbutyratica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiSubspMethylbutyraticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusAmargosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus amargosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAmargosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_01_FULL_48_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpA12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. A12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpA12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFermentumIfo3956Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum IFO3956 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFermentumIfo3956Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorAmbiguusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucor ambiguus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucorAmbiguusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinocladiellaMackenzieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhinocladiellaMackenzieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpYbl2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YBL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYbl2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusDonghaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus donghaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusDonghaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnh287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PezolomaEricae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pezoloma ericae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PezolomaEricae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSaerimneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaerimneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumVariabileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum variabile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumVariabileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPedisStrTA4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema pedis str. T A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TreponemaPedisStrTA4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivalisAtcc33277Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis ATCC33277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisAtcc33277Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumTimonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum timonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VaribaculumTimonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas noxia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasNoxiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPHIGHO2_12_FULL_38_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaDokdonensisDs3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis DS-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensisDs3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkaliphilusMetalliredigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus metalliredigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusMetalliredigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpDg25a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu030Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU030 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu030Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonRbg135212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_52_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg135212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloferulaStellata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloferula stellata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloferulaStellata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumWsm2304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum WSM2304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumWsm2304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliglaciei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliglaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliglaciei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisF0319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis F0319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisF0319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumFreireiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium freirei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumFreireiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistophilusSomni2336(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Histophilus somni 2336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HistophilusSomni2336", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMarimammalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarimammalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpAt1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. AT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAt1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxGinsengi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux ginsengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxGinsengi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyseterCatodonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Physeter catodon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhyseterCatodonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabilithrixLuteolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labilithrix luteola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabilithrixLuteolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImmundisolibacterCernigliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Immundisolibacter cernigliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ImmundisolibacterCernigliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCrispatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crispatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrispatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpCrb92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-9-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaSaulgeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania saulgeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaSaulgeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNiastensisDsm21313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Massilia niastensis DSM 21313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MassiliaNiastensisDsm21313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full6019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL6019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full6019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimicrobiumSacchariphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrimicrobium sacchariphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrimicrobiumSacchariphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialosimplexSpHf37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialosimplex sp. HF37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialosimplexSpHf37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumEmbrapense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium embrapense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumEmbrapense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntestinimonasMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoMelanesiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho melanesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoMelanesiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCoryniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasChlororaphisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas chlororaphis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasChlororaphisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColobusAngolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colobus angolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColobusAngolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCc53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CC53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCc53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeon13140cm3386(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon 13_1_40CM_3_38_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeon13140cm3386", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtochlamydiaAmoebophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia amoebophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaAmoebophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaSpImcc20628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. IMCC20628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpImcc20628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19037Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19037 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19037Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbidiferaxSpOv413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Albidiferax sp. OV413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlbidiferaxSpOv413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumPhenoxybenzoativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium phenoxybenzoativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumPhenoxybenzoativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AstyanaxMexicanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Astyanax mexicanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AstyanaxMexicanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMultihospitium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium multihospitium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMultihospitium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaInnocuaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria innocua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaInnocuaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp166amftsuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 166amftsu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSp166amftsuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot264Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot264Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseolineaSerpens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseolinea serpens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseolineaSerpens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhlebiopsisGigantea110611Cr56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea 11061_1 CR5-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhlebiopsisGigantea110611Cr56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParalimentariusDsm19674(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius DSM 19674 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParalimentariusDsm19674", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpBsw11iv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BSW11IV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBsw11iv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterNanhaiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nanhaiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNanhaiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaSpUtamx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumBacl6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NumidumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Numidum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NumidumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisEthanolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis ethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanofollisEthanolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuncoHyemalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Junco hyemalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JuncoHyemalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaParkeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia parkeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaParkeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusPhoceensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus phoceensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprococcusPhoceensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serendipita indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerendipitaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusParviboronicapiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_12_FULL_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterCurvatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterCurvatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillalesBacteriumScgcAaa298n10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillales bacterium SCGC AAA298N10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillalesBacteriumScgcAaa298n10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMegateriumQmB1551Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium QM B1551 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumQmB1551Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg2304652(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_46_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2304652", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaGrammicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylaria grammica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylariaGrammicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1999(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1999", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAcidiproducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidiproducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusGordonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus gordonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusGordonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumLinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum linum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumLinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumSm2331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium SM23_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumSm2331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorhizobiumGalegaeBvOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaNaganishiiCbs8797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii CBS 8797 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaNaganishiiCbs8797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwc24220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC24220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc24220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoeciliaLatipinnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poecilia latipinna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoeciliaLatipinnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllofrancisellaGuangzhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allofrancisella guangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllofrancisellaGuangzhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaOklahomensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia oklahomensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaOklahomensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumColombiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium colombiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumColombiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumNurukiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium nuruki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumNurukiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumV9d3004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium V9D3004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumV9d3004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpCaviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. caviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpCaviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaDispersa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea dispersa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaDispersa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumAutotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumAutotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DonghicolaEburneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Donghicola eburneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DonghicolaEburneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaHofmanniiPcc7110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmannii PCC 7110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ScytonemaHofmanniiPcc7110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFuscovaginaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fuscovaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFuscovaginaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrahymenaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrahymenaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_36_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPurpeofuscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpeofuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesPurpeofuscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaPneumophilaSubspFraseriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. fraseri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspFraseriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full4914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL4914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full4914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesTogonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides togonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesTogonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSaguiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter saguini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSaguiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlumeriaGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blumeria graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlumeriaGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PicoidesPubescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Picoides pubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PicoidesPubescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp2a57ct2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 2A57CT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSp2a57ct2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FermentimonasCaenicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fermentimonas caenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FermentimonasCaenicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpRadiciscucumerinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. radiciscucumerinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpRadiciscucumerinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KockovaellaImperatae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kockovaella imperatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KockovaellaImperatae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpYr412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. YR412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpYr412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCyclitrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cyclitrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioCyclitrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa25713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_57_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansPlanktonicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27231(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27231", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchmidhempeliaBombiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schmidhempelia bombi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchmidhempeliaBombiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasHussainii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas hussainii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHussainii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsphigho212full4911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL4911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full4911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpLeaf201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimiduiaAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Simiduia agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SimiduiaAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumVitaeruminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium vitaeruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVitaeruminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpRcc307(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RCC307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRcc307", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf172Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf172 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf172Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaParaffinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia paraffinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaParaffinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatusBairdiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus bairdii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeromyscusManiculatusBairdiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpCcs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. CCS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpCcs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansPlanktonicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArhodomonasAquaeoleiDsm8974Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei DSM 8974 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArhodomonasAquaeoleiDsm8974Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEpsl27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EPSL27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEpsl27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaecibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caecibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaecibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpJa33ab(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA33Ab graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa33ab", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterPneumotropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter pneumotropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterPneumotropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumSg841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisZeicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris zeicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BipolarisZeicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreeseniaAngusta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Andreesenia angusta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AndreeseniaAngusta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesertifilumSpIppasb1220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desertifilum sp. IPPASB1220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesertifilumSpIppasb1220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitiniphilusShinanonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1388 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaFaecalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaFaecalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheileriaParvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theileria parva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheileriaParvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesFCircinelloides1006phlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides 1006PhL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloides1006phlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumConfluentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium confluentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumConfluentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumGeofontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium geofontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumGeofontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGyllenbergiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gyllenbergii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGyllenbergiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc7214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaArboriphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora arboriphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaArboriphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusHauseriAtcc700826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Proteus hauseri ATCC 700826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProteusHauseriAtcc700826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlyciniphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glyciniphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlyciniphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuncoHyemalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Junco hyemalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JuncoHyemalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaArthritidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arthritidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArthritidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrigoribacteriumSpLeaf415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full588Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL588 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full588Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaihuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taihuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaihuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MolaMolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mola mola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MolaMolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasWolfei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpUcdthuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. UCDTHU Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpUcdthuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag877(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag877", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpSk140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpSk140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesStipitatusAtcc10500Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus ATCC 10500 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TalaromycesStipitatusAtcc10500Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsmarc1296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosporangiumSpNrrlb3428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinosporangium sp. NRRLB3428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinosporangiumSpNrrlb3428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusChondroitinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus chondroitinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusChondroitinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumSpCaciam14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. CACIAM14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpCaciam14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaSerotypeA2Bovine(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica serotype A2 BOVINE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaSerotypeA2Bovine", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscoideaRubescensDsm1968Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascoidea rubescens DSM 1968 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AscoideaRubescensDsm1968Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwa23836Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA23836 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa23836Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaPickettiiDtp0602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii DTP0602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettiiDtp0602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSalinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium salinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSalinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumAgresteCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum agreste Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumAgresteCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudothermotogaLettingaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga lettingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaLettingaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumKht7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KHT7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKht7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumCg1023744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfatarculusSandiegensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatarculus sandiegensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatarculusSandiegensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpNsubEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. Nsub Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpNsubEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSp12014mblmicdivCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. 12014MBLMicDiv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterSp12014mblmicdivCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumFreirei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium freirei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumFreirei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRhizogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rhizogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRhizogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterCitreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter citreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterCitreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaGrayi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria grayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrayi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaF1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida F1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaF1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScalinduaBrodaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scalindua brodae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ScalinduaBrodaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterTjernbergiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tjernbergiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTjernbergiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerticilliumDahliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verticillium dahliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerticilliumDahliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaMuralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jiangella muralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JiangellaMuralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaPurpeofuscaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora purpeofusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaPurpeofuscaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPHIGHO2_02_FULL_43_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexithrixDorotheaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flexithrix dorotheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlexithrixDorotheaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermococcusThermolithotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus thermolithotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusThermolithotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GolovinomycesMagnicellulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces magnicellulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesMagnicellulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumDakarenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium dakarense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDakarenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasJejuensisNbrc106434(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis NBRC 106434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolaromonasJejuensisNbrc106434", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocKimchiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc kimchii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocKimchiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwc26444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWC2_64_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwc26444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRileyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium rileyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumRileyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1264(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1264", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaDefragrans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella defragrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaDefragrans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRbg166422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RBG_16_64_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRbg166422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1742Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1742 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1742Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenticepsClupeoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Denticeps clupeoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DenticepsClupeoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusHydrogenoformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus hydrogenoformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusHydrogenoformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRubrobruneaNbrc15275Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea NBRC 15275 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRubrobruneaNbrc15275Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliiglaciecolaLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliiglaciecola lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliiglaciecolaLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpNrrlb16309Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. NRRLB16309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpNrrlb16309Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumMd308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaSpOralTaxon928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemella sp. oral taxon 928 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemellaSpOralTaxon928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphusCoralli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amorphus coralli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmorphusCoralli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCfn42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CFN42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCfn42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonadalesBacterium6970(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 69-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6970", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSulfidigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sulfidigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSulfidigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidilobusSaccharovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidilobus saccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidilobusSaccharovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAmericanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter americanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAmericanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterWandonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter wandonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterWandonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAziziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus azizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAziziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrinaliumEpipsammumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crinalium epipsammum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrinaliumEpipsammumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorarchaeotaArchaeonAb25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon AB25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonAb25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrisporobacterOthiniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter othiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterOthiniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwf24317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF24317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf24317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa24319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_43_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OleibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oleibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OleibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGas113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium GAS113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGas113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasStagni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas stagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseomonasStagni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc25546Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_55_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc25546Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaTurkmenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena turkmenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaTurkmenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar92BacteriumBacl16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesCaccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesCaccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFormicaceticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium formicaceticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFormicaceticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanopusillusAcidilobiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanopusillus acidilobi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanopusillusAcidilobiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinifilumFragileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinifilum fragile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinifilumFragileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLeaf127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MurdochiellaVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisSpHl87(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HL87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHl87", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag552Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag552Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SandarakinorhabdusSpAap62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus sp. AAP62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusSpAap62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiophoraBrassicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodiophora brassicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiophoraBrassicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_12_FULL_43_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfipiaBirgiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia birgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaBirgiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacterium6626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 66-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg135211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_52_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaArginini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arginini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArginini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSynoviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma synoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSynoviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumOleivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOleivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterSpLeaf380Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. Leaf380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpLeaf380Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaEndophyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma endophyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaEndophyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSp73bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. 73B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSp73bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FortieaContortaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fortiea contorta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FortieaContortaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumViciae248Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 248 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae248Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpUnc305mfcol52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. UNC305MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUnc305mfcol52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh8109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusHalocryophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus halocryophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusHalocryophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctopusBimaculoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Octopus bimaculoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OctopusBimaculoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaSagamiharensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella sagamiharensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaSagamiharensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PuniceicoccalesBacteriumVerruco01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterHamburgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter hamburgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrobacterHamburgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaMalayi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brugia malayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrugiaMalayi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRamulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ramulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRamulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium durum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full497Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full497Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesGambiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles gambiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesGambiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Candida] auris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaAuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaSpEs058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. ES.058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StappiaSpEs058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterTowneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter towneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTowneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00274Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00274 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00274Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumSpCcfee5018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium sp. CCFEE 5018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumSpCcfee5018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_49_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusWakoensisJcm9140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus wakoensis JCM 9140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusWakoensisJcm9140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBl8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BL8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBl8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpMwyl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MWYL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMwyl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaDubliniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida dubliniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaDubliniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaGriseolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora griseola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaGriseolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrophominaPhaseolina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacrophominaPhaseolina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthocomusHoazinEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opisthocomus hoazin Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpisthocomusHoazinEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu072(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu072", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCannabisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioglobusSpRedseas12b1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus sp. REDSEAS12B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSpRedseas12b1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricibacterSpH121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sp. H121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSpH121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetitomaculumRuminisDsm5522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis DSM 5522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetitomaculumRuminisDsm5522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag451(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag451", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalimicrobiumAerophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium aerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumAerophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaoultellaOrnithinolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Raoultella ornithinolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RaoultellaOrnithinolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumSubspPolymorphumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. polymorphum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspPolymorphumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Facklamia hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FacklamiaHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusMethylotrophus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus methylotrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusMethylotrophus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichomitusSqualens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dichomitus squalens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DichomitusSqualens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlomeribacterGigasporarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glomeribacter gigasporarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlomeribacterGigasporarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFioriniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFioriniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasRivuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas rivuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasRivuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApisCeranaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apis cerana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApisCeranaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicolaFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidicola ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidicolaFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoclosmatiumGlobosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizoclosmatium globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizoclosmatiumGlobosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucispirillumSchaedleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucispirillum schaedleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucispirillumSchaedleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopropionibacteriumPropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudopropionibacterium propionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudopropionibacteriumPropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsphigho212full4816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO212FULL4816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho212full4816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaTenuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaTenuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusMetalliredigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus metalliredigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusMetalliredigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpBh211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. BH-2-1-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpBh211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpGcs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. GCS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpGcs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumCg104938(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_49_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104938", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a519a13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_519A13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a519a13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumAethiopicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium aethiopicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAethiopicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaGonorrhoeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_33_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumDehalogenansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dehalogenans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDehalogenansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesCryophilusOy26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus OY26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilusOy26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJs623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JS623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpJs623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisZeicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris zeicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BipolarisZeicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LodderomycesElongisporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LodderomycesElongisporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumBrachiatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium brachiatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumBrachiatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraInopinata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira inopinata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraInopinata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusSpicilegusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mus spicilegus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusSpicilegusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpFsw0699Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. FSW06-99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFsw0699Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicavibrioAeruginosavorusArl13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus ARL13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusArl13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpGm21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GM21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpGm21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosimicrobiumCellulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAethiopicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aethiopicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAethiopicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharimonasAalborgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharimonas aalborgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharimonasAalborgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumUsda6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusMinorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus minor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusMinorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HanseniasporaOsmophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora osmophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaOsmophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidisJam81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JAM81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJam81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacterium13140cm46819Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium 13_1_40CM_4_68_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacterium13140cm46819Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerXanaduensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopiger xanaduensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopigerXanaduensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSpRifcsplowo202full4514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. RIFCSPLOWO202FULL4514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpRifcsplowo202full4514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpLtsp885Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP885 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp885Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumHch1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium HCH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumHch1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraSojaeStrainP6497Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae strain P6497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraSojaeStrainP6497Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. enterica serovar Typhimurium str. LT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpNyagatareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Nyagatare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasSpNyagatareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasFuttsuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas futtsuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimonasFuttsuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVinicolorAmOr11026Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor AM-OR11-026 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizopogonVinicolorAmOr11026Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusPalustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPalustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodalislikeEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sodalislike endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SodalislikeEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Schekmanbacteria bacterium RIFCSPLOWO2_12_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosimplexCarlsbadenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halosimplex carlsbadense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalosimplexCarlsbadenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAquaticusDsm21051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus DSM 21051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAquaticusDsm21051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot568(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot568", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaOvisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoluteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoluteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseoluteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh7805(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7805 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7805", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicola5aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola 5A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicola5aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrodictiumDelaneyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium delaneyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumDelaneyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumCg2304152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium CG2304152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumCg2304152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAcridumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium acridum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAcridumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrisporobacterGlycolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter glycolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterGlycolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomonasIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusApis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacaseiAtcc334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei ATCC 334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParacaseiAtcc334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidicolaFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidicola ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidicolaFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumGw2011gwc24417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC24417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc24417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusEpiphyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus epiphyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEpiphyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibacteriumElongatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseibacterium elongatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseibacteriumElongatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeduiniMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beduini massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeduiniMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedosphaeraParvulaEllin514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Ellin514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PedosphaeraParvulaEllin514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeDcc43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae DCC43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeDcc43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusCcmp1375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus CCMP1375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusCcmp1375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisMaydisC5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis C5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BipolarisMaydisC5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCaspiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium caspium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCaspiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminobacterAminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter aminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminobacterAminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensPf01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Pf01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensPf01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PachysolenTannophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PachysolenTannophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterKumamotonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter kumamotonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterKumamotonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumCg1023735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG1_02_37_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg1023735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full4211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL4211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full4211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmborellaTrichopodaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amborella trichopoda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmborellaTrichopodaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlammeovirgaSpMy04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. MY04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpMy04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpStbin4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeotomaLepidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neotoma lepida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeotomaLepidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonIso4h5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon ISO4H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonIso4h5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesAtroroseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces atroroseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAtroroseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalilimnicolaEhrlichiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalilimnicola ehrlichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalilimnicolaEhrlichiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaCtuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ctu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCtuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPneumoniaeLpcoln(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae LPCoLN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniaeLpcoln", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp172e8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 172E8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp172e8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfDrosophilaSimulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaSimulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacteriumSpPamc21357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinibacterium sp. PAMC 21357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinibacteriumSpPamc21357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisGlossinidiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sodalis glossinidius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SodalisGlossinidiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaSpMarseillep2844Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holdemania sp. MarseilleP2844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaSpMarseillep2844Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusParauberisNcfd2020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis NCFD2020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisNcfd2020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasUreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas ureae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasUreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSaburreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesSalmoniphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides salmoniphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSalmoniphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusSediminisNbrc103570(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis NBRC 103570 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmphibacillusSediminisNbrc103570", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumHiltneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrobacterXylanophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter xylanophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrobacterXylanophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaTucsonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella tucsonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaTucsonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacteraceaeBacteriumGwc25311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_53_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf391(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf391 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf391", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubritaleaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubritaleaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPorciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 CBMW_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpCn3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CN3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCn3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaMelanogaster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila melanogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaMelanogaster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterFreundiiCfnih1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter freundii CFNIH1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFreundiiCfnih1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaCoxensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea coxensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NonomuraeaCoxensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SericytochromatiaBacteriumS15bmn24cbmw12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24CBMW_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24cbmw12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRubinfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rubinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRubinfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusDabanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus dabanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusDabanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TateyamariaSpAngs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria sp. ANGS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TateyamariaSpAngs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaGottschalkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml96a049Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML96A049 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml96a049Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiMaff303099Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti MAFF303099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiMaff303099Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRaac3Tm71Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RAAC3_TM7_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRaac3Tm71Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaSoesokkakensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita soesokkakensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSoesokkakensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSulfonivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sulfonivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSulfonivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSaburreumDsm3986Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum DSM3986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumDsm3986Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusLactolyticusS7113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus S7113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusS7113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4235Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4235 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4235Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NereidaIgnava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nereida ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NereidaIgnava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPantholopisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pantholopis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPantholopisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LongilineaArvoryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Longilinea arvoryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LongilineaArvoryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_49_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilumDsm21637Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum DSM 21637 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilumDsm21637Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesThermoautotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermoautotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermoautotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgulaAerodenitrificansDsm15089Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans DSM 15089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificansDsm15089Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseoflavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoflavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraSpAngvp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGVp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngvp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasSpCnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas sp. CN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasSpCnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsphigho201full5815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL5815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full5815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotiiLm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii LM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridioidesMangenotiiLm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpCra2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. CRA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpCra2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwc246850(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWC2_46_850 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwc246850", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGracilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGracilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Grimontia indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GrimontiaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrinomonasMethylaliphatogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrinomonas methylaliphatogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrinomonasMethylaliphatogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr460Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR460 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr460Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesEpiroticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles epiroticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesEpiroticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraKueneniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira kuenenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraKueneniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CentipedaPeriodontiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Centipeda periodontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CentipedaPeriodontiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellalesBacteriumRifcsphigho212full3714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasMethanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas methanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasMethanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrospermopsisRaciborskiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermopsis raciborskii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CylindrospermopsisRaciborskiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpP5210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. P5210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpP5210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumLymphophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoglobusAcetivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAcetivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSharmensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sharmensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSharmensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPiezotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella piezotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPiezotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasBoliviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas boliviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasBoliviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigidariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenibacterAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasSpHgc4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. HGC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpHgc4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusMucosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus mucosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusMucosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumBrhc20a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium BRHc20a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumBrhc20a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpF0436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpRoot935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpRac06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. RAC06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpRac06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusThermophilusHb8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusSpJlt9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus sp. JLT9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusSpJlt9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf2890Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2890 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2890Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasNasturtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas nasturtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasNasturtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusFulvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MyxococcusFulvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpTgly2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TGLY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTgly2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaceaeBacterium457259Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetaceae bacterium 4572_59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaceaeBacterium457259Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaChaffeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia chaffeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaChaffeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumSpF0437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. F0437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpF0437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumGwa15114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium GWA1_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumGwa15114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacillusAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBauzanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas bauzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBauzanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethylopumilusTuricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusTuricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasFlavigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas flavigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFlavigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumGw2011gwa24010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA24010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa24010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6677Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6677 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6677Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusZeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusSpOralTaxon190Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus sp. oral taxon 190 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArsenicicoccusSpOralTaxon190Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumDtu037Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium DTU037 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumDtu037Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiumMinutumPei191Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Pei191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutumPei191Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusFerusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusFerusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_37_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaPelophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina pelophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaPelophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaLuteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLuteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSulciaMuelleriGwssEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri GWSS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriGwssEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumGibsoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum gibsoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumGibsoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusAquatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus aquatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusAquatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAntibioticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces antibioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAntibioticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerProfundusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipiger profundus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipigerProfundusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterPhosphatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter phosphatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterPhosphatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiolapillusBrandeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiolapillus brandeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiolapillusBrandeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus tindarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolobusTindariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusAureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus aureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutisporaThermophilaDsm19022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lutispora thermophila DSM 19022 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LutisporaThermophilaDsm19022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFructicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFructicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumCg23050142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium CG2_30_50_142 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCg23050142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMarthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria marthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaMarthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlutamicibacterHalophytocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter halophytocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterHalophytocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusVoltaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus voltae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVoltaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk1057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK1057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk1057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeHs11286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae HS11286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeHs11286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KineosphaeraLimosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kineosphaera limosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KineosphaeraLimosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPneumoniaeLpcolnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae LPCoLN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniaeLpcolnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaSpCcfee5036(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. CCFEE 5036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpCcfee5036", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRileyiRcef4871Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium rileyi RCEF 4871 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRileyiRcef4871Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc2458Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC2458 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc2458Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHokkaidonensisJcm18461Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis JCM 18461 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensisJcm18461Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChauvoei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chauvoei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChauvoei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBacteroidesPeriocalifornicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus [Bacteroides] periocalifornicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBacteroidesPeriocalifornicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaSpW5cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. W5C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpW5cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenarthrobacterNicotinovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter nicotinovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterNicotinovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFaecichinchillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides faecichinchillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFaecichinchillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumOligotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium oligotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumOligotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaTurfanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria turfanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaTurfanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaKristinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rothia kristinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RothiaKristinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisAtcc35037(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC35037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc35037", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaPneumotropicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella pneumotropica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaPneumotropicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumPennivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium pennivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumPennivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesStipitatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TalaromycesStipitatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReinekeaBlandensisMed297(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Reinekea blandensis MED297 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ReinekeaBlandensisMed297", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOdorifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus odorifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOdorifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAurantiacusDsm18675Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus DSM 18675 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAurantiacusDsm18675Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpYr531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpF0581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckii2038Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii 2038 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckii2038Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_59_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusElongatusDsm2908(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus DSM 2908 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusElongatusDsm2908", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlesiocystisPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plesiocystis pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlesiocystisPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarthrobacterSiccitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter siccitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSiccitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinimonasAmylolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinimonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinimonasAmylolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcmicro4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGwa1418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GWA1418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGwa1418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaedaleaQuercinaL15889Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Daedalea quercina L-15889 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DaedaleaQuercinaL15889Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSuccinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus succinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSuccinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricellaOtitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Turicella otitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TuricellaOtitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluoribacterDumoffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter dumoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FluoribacterDumoffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSimiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSimiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ObscuribacterPhosphatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Obscuribacter phosphatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ObscuribacterPhosphatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumHum1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria rhizophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaRhizophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHuangheensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas huangheensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasHuangheensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacterium13120cm5428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_1_20CM_54_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13120cm5428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpTsl51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. TSL5-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpTsl51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaRobiniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea robiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaRobiniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaSpDsm29012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. DSM 29012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpDsm29012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpJ56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAlkalicaDsm8900Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica DSM 8900 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalicaDsm8900Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonJ07hb67(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HB67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hb67", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg23041165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG23041165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg23041165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJ37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJ37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumVulgareY25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Y25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgareY25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpPm2p129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. PM2P129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpPm2p129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiaeEquisimilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae equisimilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeEquisimilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiosporiumApollinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coniosporium apollinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConiosporiumApollinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MiscellaneousCrenarchaeotaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeotaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpKctc13219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] sp. KCTC 13219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpKctc13219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a518o7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518O7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518o7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp3andimar09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 3ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp3andimar09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpLeaf326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. Leaf326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLeaf326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusJensenii272chnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 272CHN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii272chnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBalearicaDsm6083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas balearica DSM 6083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBalearicaDsm6083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusHansupusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus hansupus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcusHansupusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumPrunaredenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium prunaredense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPrunaredenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaSpUsdaarsusmarc1261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia sp. USDAARSUSMARC1261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSpUsdaarsusmarc1261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaBarthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza barthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaBarthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaNelsoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nelsoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNelsoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe23640Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE2_36_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe23640Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGa0077523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpC105kso13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C105KSO13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC105kso13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf24014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_40_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumLuteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumLuteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaRuckeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia ruckeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaRuckeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusSpC1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sp. C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSpC1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_42_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimaricolaHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasDonghaensisDsm18148Ho3R19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis DSM 18148 HO3-R19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArenimonasDonghaensisDsm18148Ho3R19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiK96243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei K96243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiK96243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpLc2012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. lc2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpLc2012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumXueshanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xueshanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXueshanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpAntb3c2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. ANTB3C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAntb3c2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumRhodesiaeJs60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae JS60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeJs60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasAcidaminiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas acidaminiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasAcidaminiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPneumoniaeFhEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae FH Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeFhEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixMariniflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix mariniflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixMariniflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMidichloriaMitochondriiIricvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Midichloria mitochondrii IricVA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMidichloriaMitochondriiIricvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaBccCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola BCc Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBccCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicosporidiumSpAtcc50920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicosporidium sp. ATCC 50920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicosporidiumSpAtcc50920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerruconisGallopavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verruconis gallopava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerruconisGallopavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SarcophilusHarrisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sarcophilus harrisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SarcophilusHarrisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniphilumAcetatigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum acetatigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumAcetatigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPhagedenisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema phagedenis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPhagedenisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumSaheli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium saheli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSaheli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlkylphenolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumBbd199114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium BBD 1991-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumBbd199114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioSpN1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio sp. N1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioSpN1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPneumoniaeM129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae M129 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeM129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermusProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodothermusProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomycesCerevisiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces cerevisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesCerevisiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOzensisDsm23829Jcm17196Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis DSM 23829 JCM 17196 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOzensisDsm23829Jcm17196Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcidianusCopahuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acidianus copahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcidianusCopahuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpLeaf53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Leaf53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpLeaf53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpG5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpG5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharicrinisFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharicrinis fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharicrinisFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraStrobiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara strobi) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraStrobiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterGyllenbergiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gyllenbergii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGyllenbergiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusUreasiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureasiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreasiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaAmethystinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laccaria amethystina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaccariaAmethystinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumYanoikuyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium yanoikuyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumYanoikuyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaHyalinaDsm16112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia hyalina DSM 16112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LampropediaHyalinaDsm16112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_50_9b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacteriumHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterPontiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pontiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPontiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HomoSapiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Homo sapiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HomoSapiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpYr266Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR266 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr266Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimonasChungwhensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinimonas chungwhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinimonasChungwhensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisPinicolaFp58527Ss1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola FP-58527 SS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FomitopsisPinicolaFp58527Ss1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesDavawensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces davawensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesDavawensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesSpDsm45892Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45892 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45892Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxBorkumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax borkumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxBorkumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasCryotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas cryotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCryotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSpMed134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. MED134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpMed134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotignumPropionicumDsm1682Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum DSM 1682 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerotignumPropionicumDsm1682Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetalesBacteriumActino01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltonellaDefensaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hamiltonella defensa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HamiltonellaDefensaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasExtremaustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas extremaustralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasExtremaustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapaverSomniferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Papaver somniferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PapaverSomniferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaStercoreaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella stercorea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaStercoreaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHumireducensNbrc106098Dsm45392Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens NBRC 106098 DSM 45392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducensNbrc106098Dsm45392Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermovibrioAmmonificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermovibrio ammonificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermovibrioAmmonificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapitellaTeletaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capitella teleta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapitellaTeletaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesSpTfc3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. TFC3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpTfc3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusCatalpae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus catalpae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCatalpae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumImitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium imitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumImitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr80Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr80Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterNorwichensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter norwichensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterNorwichensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRifcsphigho201full4414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPHIGHO201FULL4414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsphigho201full4414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxParadoxus110bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus 110B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VariovoraxParadoxus110bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuciliaCuprina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lucilia cuprina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuciliaCuprina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27231Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27231Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterShowaeCsunswcdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CSUNSWCD Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCsunswcdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusButanolivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus butanolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusButanolivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TubulinosemaRatisbonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tubulinosema ratisbonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TubulinosemaRatisbonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniellaLuteolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaLuteolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosopumilusKoreensisAr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopumilus koreensis AR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopumilusKoreensisAr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasFrigidaquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas frigidaquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasFrigidaquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaCoronariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marssonina coronariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarssoninaCoronariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassiosiraOceanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira oceanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThalassiosiraOceanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisLiminatansDsm4140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis liminatans DSM 4140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanofollisLiminatansDsm4140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia puris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaPurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrellaSpEs10322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrella sp. ES10-3-2-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrellaSpEs10322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeri3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeri3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusIainarchaeumAndersoniiScgcAaa011E11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Iainarchaeum andersonii SCGC AAA011-E11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusIainarchaeumAndersoniiScgcAaa011E11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_52_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag254(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:254 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag254", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpLeaf51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumEndosymbiontOfPedicinusBadiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus badii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusBadiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJls(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JLS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJls", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBaroniaeDsm16972Jcm13447Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella baroniae DSM 16972 JCM 13447 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBaroniaeDsm16972Jcm13447Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaLonarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga lonarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaLonarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpEur3222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. EUR3222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpEur3222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ModestobacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SymbiobacteriumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SymbiobacteriumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasZinciduransB6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zincidurans B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasZinciduransB6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpF0356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. F0356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpF0356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaOvipneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovipneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvipneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenophonusEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arsenophonus endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArsenophonusEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumM3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium M3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumM3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharophagusDegradans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharophagus degradans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharophagusDegradans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaKunkeliiCr23x(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii CR2-3x graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaKunkeliiCr23x", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag354Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag354Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OwenweeksiaHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Owenweeksia hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OwenweeksiaHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaPortivictoriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella portivictoriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaPortivictoriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaAlbertiiKf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii KF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiKf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMelaninogenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella melaninogenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMelaninogenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaCanadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaCanadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidiaBacterium4341Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium 43-41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacterium4341Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogeaDsm11164Nbrc106472Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea DSM 11164 NBRC 106472 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudothermotogaHypogeaDsm11164Nbrc106472Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptosphaeriaMaculansJn3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans JN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculansJn3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAccolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium accolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAccolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricellaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumTrichothecenolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium trichothecenolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTrichothecenolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDoosanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium doosanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDoosanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelianthusAnnuusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helianthus annuus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelianthusAnnuusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRibeironisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ribeironis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRibeironisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioAlginolyticus40bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus 40B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticus40bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHemicellulosilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaminobacterSalicylatoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter salicylatoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterSalicylatoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifoxyc2full3525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFOXYC2FULL3525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifoxyc2full3525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCasseliflavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus casseliflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterococcusCasseliflavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumCoriense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum coriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCoriense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisJsc3bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris JSC-3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisJsc3bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusDevriesei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus devriesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDevriesei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCapricolumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCapricolumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 40-19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharolyticumWm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum WM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumWm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil750Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil750 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil750Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphothecaResinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amorphotheca resinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmorphothecaResinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaShandongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia shandongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaShandongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylicusOleusabulumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus oleusabulum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusOleusabulumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimaricolaHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwr3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWR3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwr3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraAquaemixtae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquaemixtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquaemixtae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpNsp222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpNsp222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminobacterSpJ41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. J41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpJ41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterMorbiferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter morbifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconobacterMorbiferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobilibacteriumTimonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mobilibacterium timonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MobilibacteriumTimonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwa23836Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA23836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa23836Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusObesiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusObesiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuriculariopsisAmpla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Auriculariopsis ampla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AuriculariopsisAmpla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpBmg111209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG111209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg111209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKribbensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kribbensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusKribbensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterRarusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter rarus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRarusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrococcusJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumAlpha01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Alpha_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumAlpha01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb1446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB1_44_6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb1446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwa14424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWA1_44_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwa14424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumBovisDsm19482(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis DSM 19482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumBovisDsm19482", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag508Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:508 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag508Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full5016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL5016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full5016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpSgbin2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantMicrotiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant microti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantMicrotiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHtcc5015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC5015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc5015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1092Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1092 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1092Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPbh53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PBH53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPbh53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumMedpeswcelEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium MedPESWcel Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumMedpeswcelEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaGraminisWp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula graminis WP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodotorulaGraminisWp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusEquuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus equuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusEquuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_42_49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArhodomonasAquaeoleiDsm8974(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei DSM 8974 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArhodomonasAquaeoleiDsm8974", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho202full3814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO202FULL3814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho202full3814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOralisAtcc33269Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis ATCC33269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisAtcc33269Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumLithotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum lithotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumLithotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSp6526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 65-26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFructicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFructicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusCellicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus cellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusCellicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo2024111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO2024111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo2024111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumCv2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium cv2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCv2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSpb78Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SPB78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSpb78Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumTrifoliiWsm2304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii WSM2304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiWsm2304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full6819Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6819 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6819Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraSpSoil756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera sp. Soil756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraSpSoil756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasutterellaExcrementihominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parasutterella excrementihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParasutterellaExcrementihominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag341Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:341 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag341Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAviariusSubspAraffinosusDsm20653(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius subsp. araffinosus DSM 20653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAviariusSubspAraffinosusDsm20653", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSp1nls2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 1NLS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AfipiaSp1nls2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpCf385Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF385 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf385Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaTropicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinispora tropica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisporaTropicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMiyunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia miyunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaMiyunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParachlamydiaAcanthamoebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaAcanthamoebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVelezensisYaub9601y2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis YAUB9601Y2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisYaub9601y2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusDaeguensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus daeguensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusDaeguensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRapiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rapi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRapiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SymbiobacteriumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacterium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SymbiobacteriumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumSpOralTaxon193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. oral taxon 193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumSpOralTaxon193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RouxiellaChamberiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella chamberiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RouxiellaChamberiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisNctc12261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis NCTC 12261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisNctc12261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpUrha0033Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. URHA0033 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUrha0033Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas testosteroni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasTestosteroni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OttowiaThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterSpA7aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. A7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpA7aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensBurtonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens burtonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensBurtonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensis0850475(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoeensis 085-0475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoeensis0850475", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumGriseofulvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium griseofulvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumGriseofulvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumIncanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum incanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumIncanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBeveridgeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus beveridgei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusBeveridgeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisSpHl87Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HL87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHl87Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusZopfiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusZopfiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CinnamomumMicranthumFKanehirae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum f. kanehirae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CinnamomumMicranthumFKanehirae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAurantiacusDsm18675(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus DSM 18675 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAurantiacusDsm18675", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumPentaromativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium pentaromativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumPentaromativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRoot381Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root381 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot381Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaBccEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola BCc Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBccEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasEncheleiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas encheleia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasEncheleiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPacaenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pacaense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPacaenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensisKr140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis KR-140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DeinococcusHopiensisKr140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumImcc26256(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26256 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26256", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwa13921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa044d11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA044D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa044d11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterRectusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter rectus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterRectusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusAlimentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusAlimentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelleaBalneolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hellea balneolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelleaBalneolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSpCf118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. CF118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpCf118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifcsplowo201full4811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPLOWO201FULL4811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsplowo201full4811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0602 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBoissieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter boissieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBoissieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerriphaselusAmnicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus amnicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusAmnicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwd23811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD23811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd23811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasProtegens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas protegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProtegens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumCellulolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellulolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellulolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofustisGlycolicusDsm9705Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus DSM 9705 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicusDsm9705Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTestacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia testacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaTestacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraMultiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira multiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraMultiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpTnd4ek4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. TND4EK4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpTnd4ek4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHomopropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium homopropionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHomopropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRbg133914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RBG_13_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRbg133914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaPassalidarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpathasporaPassalidarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusMumeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prunus mume Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrunusMumeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAzotifigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAzotifigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaNeofelifaecisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia neofelifaecis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaNeofelifaecisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSpAgr2158(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. AGR2158 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpAgr2158", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaBrassicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma brassicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaBrassicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_39_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacteriumJdfr48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumFossorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium fossor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumFossorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionicicellaSuperfundiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionicicella superfundia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NectriaHaematococcaMpvi77134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Nectria] haematococca mpVI 77-13-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NectriaHaematococcaMpvi77134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaHelgolandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia helgolandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaHelgolandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesHadrusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes hadrus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesHadrusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterCibinongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterCibinongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesChartreusisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces chartreusis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesChartreusisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomycesKudriavzeviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzeviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaCheerisanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora cheerisanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KitasatosporaCheerisanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltonellaDefensaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hamiltonella defensa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HamiltonellaDefensaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD12_FULL_33_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaStercoreaCag629Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea CAG:629 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaStercoreaCag629Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls149Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls149Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwf13135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWF13135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwf13135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolentinusLepideusHhb14362Ss1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neolentinus lepideus HHB14362 ss-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeolentinusLepideusHhb14362Ss1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioZosterae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioZosterae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaSpMarseillep2844(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holdemania sp. MarseilleP2844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaSpMarseillep2844", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonInterdigitaleMr816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale MR816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichophytonInterdigitaleMr816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TomitellaBiformata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tomitella biformata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TomitellaBiformata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYD1_FULL_46_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KtedonobacterRacemifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter racemifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterRacemifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArcachonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arcachonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArcachonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MailhellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mailhella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MailhellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPedisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema pedis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPedisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterobasidionIrregulareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeterobasidionIrregulareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobotulusGlycolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobotulus glycolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophobotulusGlycolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpAa23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. AA23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpAa23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaJiangsuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia jiangsuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaJiangsuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminiphilusCircumscriptusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminiphilus circumscriptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminiphilusCircumscriptusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusParabrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus parabrevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusParabrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenustampullaEchinocandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Venustampulla echinocandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VenustampullaEchinocandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioEthanolgignensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetivibrio ethanolgignens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetivibrioEthanolgignensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeobacterSpS60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. S60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpS60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisBaekryungensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis baekryungensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisBaekryungensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetococcusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetococcus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetococcusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumPendensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum pendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermofilumPendensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag724Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:724 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag724Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KineosphaeraLimosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kineosphaera limosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KineosphaeraLimosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaSolaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma solani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaSolaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmmonsiaSpCac2015aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia sp. CAC-2015a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaSpCac2015aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagneticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEquinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEquinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSwingsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium swingsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSwingsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumGw2011Gwa14161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium GW2011_GWA1_41_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumGw2011Gwa14161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpLc11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LC11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLc11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSp6526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 65-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSka58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SKA58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSka58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MixiaOsmundaeIam14324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae IAM 14324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MixiaOsmundaeIam14324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetanaerobacteriumElongatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetanaerobacterium elongatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetanaerobacteriumElongatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaAtypicaAcs049vsch6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica ACS049VSch6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaAcs049vsch6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterTemperatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter temperatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterTemperatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisSubspCapsiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. capsici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspCapsiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdiutrixIntracellularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adiutrix intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdiutrixIntracellularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YooniaVestfoldensisDsm16212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis DSM 16212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisDsm16212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL3811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaBacilliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Knoellia flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KnoelliaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp9mfcol31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 9MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp9mfcol31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisBenzoatilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis benzoatilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBenzoatilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinimicrobiumMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElephantulusEdwardiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Elephantulus edwardii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ElephantulusEdwardiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumCg1024737(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium CG1024737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumCg1024737", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumGenosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium genosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumGenosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPyridomyceticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pyridomyceticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPyridomyceticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMassiliodielmoenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium massiliodielmoense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMassiliodielmoenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseochromogenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EchinicolaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echinicola pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EchinicolaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaOdoriferaDsm4582Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia odorifera DSM 4582 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaOdoriferaDsm4582Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusStrMit9303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. MIT 9303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrMit9303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpGd11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GD11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpGd11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_50_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulansExf150Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans EXF-150 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumPullulansExf150Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpizellomycesPunctatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpizellomycesPunctatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumPhsc20c1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium PHSC20C1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumPhsc20c1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrysSpWjw(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrys sp. WJW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrysSpWjw", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterSpHtcc2649(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. HTCC2649 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpHtcc2649", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMindensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMindensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegaseliaScalaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megaselia scalaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegaseliaScalaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSobrinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSobrinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesAtroparvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles atroparvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesAtroparvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRadiopugnansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces radiopugnans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRadiopugnansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaHydrolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola hydrolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaHydrolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaMazeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina mazei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaMazeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpBa92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusPoinariiG6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii G6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusPoinariiG6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSocompensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSocompensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaBrassicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma brassicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaBrassicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasutterellaExcrementihominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parasutterella excrementihominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParasutterellaExcrementihominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenatarsenatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacterium3818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 38-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium3818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSp31yCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 31Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp31yCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusAcidilacticiDsm20284Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici DSM20284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PediococcusAcidilacticiDsm20284Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium72143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 72-143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium72143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAmbofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces ambofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAmbofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitiniphilusShinanonensisDsm23277(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis DSM 23277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensisDsm23277", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspLactaridiLmg23825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lactaridi LMG 23825 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLactaridiLmg23825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacterium4128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 41-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterWuianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter wuianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterWuianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4416 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpLc5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. LC5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLc5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsidiaRepensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Absidia repens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbsidiaRepensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EncephalitozoonCuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisBiprosthecumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis biprosthecum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBiprosthecumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumRbg136414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumEmbrapenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium embrapense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumEmbrapenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4516Fw969Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4516 (FW-969) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4516Fw969Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpsilonproteobacteriaBacteriumTcs49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epsilonproteobacteria bacterium tcs-49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpsilonproteobacteriaBacteriumTcs49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PomaceaCanaliculataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pomacea canaliculata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PomaceaCanaliculataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeramiaOrbicularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaeramia orbicularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaeramiaOrbicularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4718 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGsubCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Gsub Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGsubCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumRifoxyb1full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPhocae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPhocae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilaChrysaetosChrysaetos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquila chrysaetos chrysaetos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquilaChrysaetosChrysaetos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusCleftensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus cleftensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCleftensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterTerrenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter terrenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterTerrenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNucleicultrixAmoebiphilaFs5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nucleicultrix amoebiphila FS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNucleicultrixAmoebiphilaFs5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiSerovarHardjoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Hardjo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarHardjoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2304418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMacrosporangiidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus macrosporangiidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMacrosporangiidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringens13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringens13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSuwonensis111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis 111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensis111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1416 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusEhimensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusEhimensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisBalhimycinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis balhimycina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBalhimycinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaprevotellaClaraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella clara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaClaraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumRifcsphigho201full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO201FULL4114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho201full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumS714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumFlavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumFlavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpathasporaSpJa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora sp. JA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpathasporaSpJa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromonasArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSp770b2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. 770b2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSp770b2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArdenticatenaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ardenticatena maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArdenticatenaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpUsmaa24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. USMAA2-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpUsmaa24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematocidaSp1Ertm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nematocida sp. 1 ERTm2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NematocidaSp1Ertm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag202Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag202Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NecropsobacterRosorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter rosorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterRosorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFermentansM64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans M64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFermentansM64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaLacunataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lacunata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLacunataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCanadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusTrichosporiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus trichosporium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosinusTrichosporiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraSpCag484(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag484", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporobacterMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SharpeaAzabuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sharpea azabuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SharpeaAzabuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHorneckiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horneckiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHorneckiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumBarkeri2011R4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium barkeri 2011-R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeri2011R4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimihaloglobusSulfuriphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limihaloglobus sulfuriphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimihaloglobusSulfuriphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumBarnesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum barnesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumBarnesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonB261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRudis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter rudis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRudis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis6119v5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 6119V5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis6119v5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplorickettsiaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumMacuxiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium macuxiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMacuxiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSpRitpifEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. RITPIf Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSpRitpifEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusSpGba12924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus sp. GBA129-24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusSpGba12924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg136414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full4611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSalivarius57i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius 57I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSalivarius57i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusSpG3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpG3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpPk(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. PK graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpPk", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterButzleriEd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri ED1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriEd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaObeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia obeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaObeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusJl18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus JL-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusJl18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptosporangiumAmethystogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium amethystogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumAmethystogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumSubglacialeExf2481Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale EXF-2481 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumSubglacialeExf2481Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterLuteusImvB3098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter luteus IMV-B-3098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacterLuteusImvB3098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaCardiffensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia cardiffensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaCardiffensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpFuku2iso50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Fuku2ISO50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFuku2iso50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSandarakinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sandarakinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSandarakinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpP2s70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. P2S70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpP2s70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaMinasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia minasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMinasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTelluritireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas telluritireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTelluritireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusEapokensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus eapokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusEapokensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaTaiwanensisDsm12281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis DSM 12281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensisDsm12281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesOdoratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPolaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPolaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiversisporaEpigaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diversispora epigaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiversisporaEpigaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonBrna1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon BRNA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonBrna1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbus7Dsm20455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7  DSM 20455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7Dsm20455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaBronchialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella bronchialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaBronchialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDichloromethanomonasElyunquensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dichloromethanomonas elyunquensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDichloromethanomonasElyunquensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumKocuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum kocurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumKocuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusAcididuransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acididurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcididuransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IctidomysTridecemlineatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ictidomys tridecemlineatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IctidomysTridecemlineatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaCitreaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora citrea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCitreaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcococcusSueciensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus sueciensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelcococcusSueciensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysiphePulchraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe pulchra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysiphePulchraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaHaematobiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma haematobium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaHaematobiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCns606(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNS606 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCns606", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasBadiaDsm17552Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonas badia DSM 17552 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonasBadiaDsm17552Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterTritici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter tritici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RathayibacterTritici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrrhodermaNoxium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrrhoderma noxium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrrhodermaNoxium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Bacterium2013ark19i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Ark19i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013ark19i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZeaMays(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zea mays graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZeaMays", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesHelcogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides helcogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesHelcogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0801Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0801 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0801Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxMediterraneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mediterranei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMediterraneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaPruniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma pruni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaPruniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiabellaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niabella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiabellaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpYcrl4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. YCRL4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpYcrl4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag341(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:341 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag341", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviibacterAbscessusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caviibacter abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaviibacterAbscessusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterocephalusGlaberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heterocephalus glaber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeterocephalusGlaberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumC6a11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C6A11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC6a11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonRbg16369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon RBG_16_36_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonRbg16369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaNodosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia nodosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaNodosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp174mfsha11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 174MFSha1.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp174mfsha11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp32owEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32OW Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32owEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillisiaBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Millisia brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MillisiaBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusMaripaludisC7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpAls9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. ALS9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpAls9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaBarthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza barthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaBarthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpPcc7105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 7105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaOralisAtcc51147(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kingella oralis ATCC 51147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KingellaOralisAtcc51147", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSilesiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus silesiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSilesiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusAurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterPolytrichastri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter polytrichastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPolytrichastri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TindalliaMagadiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tindallia magadiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TindalliaMagadiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpEs333Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ES3-33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEs333Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAquistagniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus aquistagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAquistagniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anabaena variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnabaenaVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpOralTaxon212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpPbts1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. PBTS 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpPbts1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLemurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium lemurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLemurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithobacteriumRhinotrachealeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithobacterium rhinotracheale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithobacteriumRhinotrachealeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophilaceaeBacteriumCg10262390Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophilaceae bacterium CG1_02_62_390 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophilaceaeBacteriumCg10262390Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwb1558Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWB1_55_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwb1558Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaAzotonutriciumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema azotonutricium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaAzotonutriciumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaSpUtamx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpDd3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. DD3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpDd3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenophonusLipoptenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus lipoptenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusLipoptenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpPamc28756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. PAMC 28756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpPamc28756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitibacterSpBrhc19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter sp. BRHc19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterSpBrhc19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpYik11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. YIK11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpYik11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FangiaHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fangia hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FangiaHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusObesiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusObesiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumOlb16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium OLB16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumOlb16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaRocourtiaeFslF6920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria rocourtiae FSL F6-920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaRocourtiaeFslF6920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaPluranimaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella pluranimalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPluranimaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutisporaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutispora thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutisporaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFormicaceticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium formicaceticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFormicaceticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeCc1557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumGryphiswaldenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum gryphiswaldense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumGryphiswaldenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusTropaeoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus tropaeoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FructobacillusTropaeoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpAgr2160Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. AGR2160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpAgr2160Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpRaccoon60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. Raccoon60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpRaccoon60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStreptomycesMassiliensisAp10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Streptomyces massiliensis AP10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStreptomycesMassiliensisAp10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf23869Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_38_69 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf23869Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminicolaSpYik13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminicola sp. YIK13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminicolaSpYik13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BatrachochytriumDendrobatidisJel423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JEL423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJel423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterOlleyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter olleyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOlleyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpOrs3359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaHaradaeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia haradaeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaHaradaeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaFaecigallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea faecigallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaFaecigallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisMurinaB123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina B123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PneumocystisMurinaB123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ItalianCloverPhyllodyPhytoplasmaStrMa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Italian clover phyllody phytoplasma str. MA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ItalianCloverPhyllodyPhytoplasmaStrMa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeocallimastixCaliforniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neocallimastix californiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeocallimastixCaliforniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalonomonasRubraDsm5091(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Malonomonas rubra DSM 5091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MalonomonasRubraDsm5091", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMongolienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium mongoliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMongolienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCgr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CGR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCgr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAlkanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia alkanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaAlkanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumGwa27023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_70_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSirexaaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SirexAAE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSirexaaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedMegasphaeraSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Megasphaera sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedMegasphaeraSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlkylphenoliaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenoliaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpAap53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. AAP53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpAap53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaRustigianiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia rustigianii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRustigianiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_41_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusFaeciumNrrlb2354Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium NRRLB2354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumNrrlb2354Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifcsphigho212full6320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO212FULL6320 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho212full6320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCochleariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cochlearium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCochleariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAlbicans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida albicans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaAlbicans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpOk626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. ok626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpOk626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhenoliruptrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenoliruptrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenoliruptrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesMinimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles minimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesMinimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiphophorusMaculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus maculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XiphophorusMaculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumStercorarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium stercorarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumStercorarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElephantulusEdwardiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Elephantulus edwardii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ElephantulusEdwardiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HenriciellaLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Henriciella litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HenriciellaLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaEllipticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia elliptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaEllipticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSpAe122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. AE122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasSpAe122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianus3p3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus 3P3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianus3p3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VignaAngularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vigna angularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VignaAngularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndozoicomonasNumazuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas numazuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasNumazuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandicaDsm15978Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica DSM 15978 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandicaDsm15978Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LibanicoccusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Libanicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LibanicoccusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasPhyllosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas phyllosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasPhyllosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BermanellaMarisrubri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bermanella marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BermanellaMarisrubri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumScgcAaa160i06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA160I06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa160i06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatibacillumAlkenivoransDsm16219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans DSM 16219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransDsm16219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpLeaf78(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf78", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAquistagni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus aquistagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAquistagni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumCynomolgiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium cynomolgi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumCynomolgiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBroomiiSerovarHurstbridgeStr5399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira broomii serovar Hurstbridge str. 5399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBroomiiSerovarHurstbridgeStr5399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumDrakeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium drakei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumDrakeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRac05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. RAC05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRac05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSaheliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium saheli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSaheliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMelonisTyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis TY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMelonisTyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasSpNyagatare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Nyagatare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasSpNyagatare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaGeojensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia geojensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaGeojensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJceEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJceEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwf235184Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_35_184 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf235184Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho212full4412bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO212FULL4412b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho212full4412bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobaculumAquaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobaculum aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobaculumAquaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AncylobacterRudongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ancylobacter rudongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AncylobacterRudongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpRac01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. RAC01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRac01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc512e3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-2E3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc512e3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosocosmicusExaquareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus exaquare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusExaquareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusIbericusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus ibericus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusIbericusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpM(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpM", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllobaculumStercoricanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allobaculum stercoricanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllobaculumStercoricanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterWoluwensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter woluwensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterWoluwensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobisporangiumUltimumDaomBr144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Globisporangium ultimum DAOM BR144 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlobisporangiumUltimumDaomBr144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofusicoccumParvumUcrnp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum UCRNP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeofusicoccumParvumUcrnp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaGraminisWp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula graminis WP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodotorulaGraminisWp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KyrpidiaTusciaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kyrpidia tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KyrpidiaTusciaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpR4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaSpR4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusSubspFetusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. fetus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspFetusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedMethanoculleusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Methanoculleus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedMethanoculleusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaWenyonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaWenyonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaMallotivora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia mallotivora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaMallotivora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaOlearia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga olearia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KosmotogaOlearia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulibacterBethesdensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulibacter bethesdensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulibacterBethesdensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGraevenitzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces graevenitzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGraevenitzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpLtsp849Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP849 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp849Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaSubspMultocidaStrPm70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida str. Pm70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaStrPm70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumFb2012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium FB2012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumFb2012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCoralliilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio coralliilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioCoralliilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteinernemaCarpocapsaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Steinernema carpocapsae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SteinernemaCarpocapsaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaPm70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida Pm70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaPm70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaCibariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella cibaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaCibariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiO157H7StrSakaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157:H7 str. Sakai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157H7StrSakaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquaspirillumSerpensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum serpens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSerpensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaPetrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga petrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaPetrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeeksellaSpFf8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Weeksella sp. FF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WeeksellaSpFf8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibroporiaRadiculosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibroporia radiculosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibroporiaRadiculosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaPopuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niastella populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiastellaPopuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelioribacterRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melioribacter roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelioribacterRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp24mn13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 24MN13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp24mn13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulansExf150Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans EXF-150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumPullulansExf150Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCip102129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP102129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCip102129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUberisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus uberis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUberisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminispirochaetaSmaragdinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta smaragdinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaSmaragdinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilaginoideaVirens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ustilaginoidea virens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UstilaginoideaVirens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAsiaticusPsy62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus psy62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusPsy62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopelagiusInordinatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopelagius inordinatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopelagiusInordinatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSp6113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 61-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenarthrobacterNicotinovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter nicotinovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterNicotinovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full4013bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL4013b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full4013bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionisporaVibrioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionispora vibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionisporaVibrioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPHIGHO2_02_FULL_43_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaceaeBacteriumIbvucb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYeochonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yeochonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYeochonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaScatoligenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella scatoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaScatoligenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpKordi100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf2429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf2429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaWelshimeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria welshimeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaWelshimeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumSaponariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum saponariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSaponariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSpSd62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. SD62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpSd62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaBlattaeCbs6284Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae CBS 6284 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaBlattaeCbs6284Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasTaxiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas taxi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTaxiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParadoxumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium paradoxum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumParadoxumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterUrsingiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter ursingii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterUrsingiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc2489(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_48_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc2489", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSprentiaeWsm5005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae WSM5005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiaeWsm5005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta Mad698R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaPolarisLmg21857(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris LMG 21857 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParaglaciecolaPolarisLmg21857", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumVitaeruminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium vitaeruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVitaeruminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierelliaBacteriumKa00581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tissierellia bacterium KA00581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TissierelliaBacteriumKa00581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNbrc110611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 110611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc110611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavisolibacterTropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterTropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho202full3917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL3917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full3917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAgalactiaeLmg14747Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae LMG14747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeLmg14747Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParastagonosporaNodorumSn15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum SN15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParastagonosporaNodorumSn15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoelleriellaLiberaRcef2490Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moelleriella libera RCEF 2490 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoelleriellaLiberaRcef2490Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaRubripromontoriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula rubripromontorii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaRubripromontoriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NelumboNucifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nelumbo nucifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NelumboNucifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalsirhodobacterSpAlg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falsirhodobacter sp. alg1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalsirhodobacterSpAlg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasProfundimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas profundimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasProfundimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo212full4426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO212FULL4426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo212full4426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4510cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4510c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4510cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPituitosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPituitosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymomonasMobilisAtcc10988(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ATCC10988 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZymomonasMobilisAtcc10988", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonIso4h5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon ISO4H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonIso4h5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifoxyd12full6137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFOXYD12FULL6137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifoxyd12full6137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumCg2304417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG2304417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg2304417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumKujiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum kujiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumKujiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraTigrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Panthera tigris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantheraTigrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaSechelliaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila sechellia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSechelliaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpYr568(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. YR568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpYr568", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlimentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlimentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusAcidilacticiDsm20284(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici DSM20284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PediococcusAcidilacticiDsm20284", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterAlginicilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algibacter alginicilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAlginicilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBaumannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_58_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 63-57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacterRiflensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacter riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacterRiflensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpRitpieCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. RITPIe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpRitpieCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaKururiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpA12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpA12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumMalmoense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium malmoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMalmoense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobacterThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobacter thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenobacterThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa300d14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA300D14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa300d14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SlackiaHeliotrinireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Slackia heliotrinireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SlackiaHeliotrinireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBeijerinckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium beijerinckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBeijerinckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMmlr14010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplorickettsiaMassiliensis20b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis 20B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensis20b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaLimnaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gillisia limnaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GillisiaLimnaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumRedseas34b6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS34B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas34b6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CommensalibacterIntestiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterIntestiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaOklahomensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia oklahomensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaOklahomensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViolaceoruberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violaceoruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolaceoruberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumViciaeGb30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae GB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciaeGb30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAkl19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCaviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCaviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusIndolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus indolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusIndolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumViridifuturiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium viridifuturi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumViridifuturiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWaltersii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella waltersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaWaltersii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumArizonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium arizonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumArizonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusPuniceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus puniceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPuniceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheionarchaeaArchaeonDg701Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon DG-70-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeonDg701Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCohnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus cohnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCohnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4922bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4922b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4922bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSolincolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium solincola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSolincolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesPhaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myroides phaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyroidesPhaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegilopsTauschii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aegilops tauschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AegilopsTauschii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9401234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9401234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9401234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSobrinusDsm20742Atcc33478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus DSM 20742 ATCC 33478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSobrinusDsm20742Atcc33478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full3717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3717 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOdoratitofuiDsm19909Jcm15043(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui DSM 19909 JCM 15043 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofuiDsm19909Jcm15043", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumNyuble8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NYUBLE8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNyuble8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DothistromaSeptosporumNze10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dothistroma septosporum NZE10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DothistromaSeptosporumNze10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTerpenotabidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium terpenotabidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTerpenotabidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumFc4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium FC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumFc4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumMedacidig3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHimb083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumUrocaniciphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium urocaniciphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUrocaniciphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaSpNcppb569Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. NCPPB569 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpNcppb569Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMesoamericanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium mesoamericanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMesoamericanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasSpCn(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas sp. CN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasSpCn", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumMacuxienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium macuxiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMacuxienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSp9143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesTangfeifaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces tangfeifanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTangfeifaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaSativaIndicaGroup(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Group graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaIndicaGroup", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpLeaf334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRhamnosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rhamnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRhamnosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PteropusVampyrusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pteropus vampyrus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PteropusVampyrusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisPrasinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis prasina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPrasinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesParvulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces parvulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesParvulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6676Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6676 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6676Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrenochaetaSpDs3say3aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrenochaeta sp. DS3sAY3a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrenochaetaSpDs3say3aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag343(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag343", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 41-46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LampropediaHyalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia hyalina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LampropediaHyalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacunisphaeraLimnophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacunisphaera limnophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacunisphaeraLimnophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RasamsoniaEmersoniiCbs39364Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii CBS 393.64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RasamsoniaEmersoniiCbs39364Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PvcGroupBacteriumExBugulaNeritinaAb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return PVC group bacterium (ex Bugula neritina AB1) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PvcGroupBacteriumExBugulaNeritinaAb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyalangiumMinutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyalangium minutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyalangiumMinutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpTb23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. TB23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpTb23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterCaenitepidiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter caenitepidi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterCaenitepidiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMendocinaYmpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina ymp Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaYmpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaMiroungaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Facklamia miroungae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FacklamiaMiroungaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpSrsw22016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. SRSW22016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpSrsw22016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQueenslandensisAustNh15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis AUST/NH15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaQueenslandensisAustNh15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPsittaci6bc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 6BC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci6bc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBlattaOrientalisStrTarazonaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. (Blatta orientalis) str. Tarazona Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBlattaOrientalisStrTarazonaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusParasanguinisAtcc903Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis ATCC903 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisAtcc903Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg164224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_42_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMaceacherniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella maceachernii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaMaceacherniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb241528o2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241528O2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528o2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumHimb55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasUenonis603Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis 603 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonis603Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaTularensisSchus4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis SCHUS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisSchus4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMannitolivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus mannitolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMannitolivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg134915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg165211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_52_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg165211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MustelaPutorius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mustela putorius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MustelaPutorius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaBalticaOs155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella baltica OS155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBalticaOs155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSpCag977Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. CAG:977 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSpCag977Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpKp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. Kp2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpKp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacterStenotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacter stenotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobacterStenotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYD1_FULL_47_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterEnclensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter enclensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterEnclensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23066Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23066 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23066Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWeiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira weilii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWeiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgareSubspVulgareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare subsp. vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HordeumVulgareSubspVulgareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifoxya2full3321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL3321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full3321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusParviboronicapiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PteropusVampyrusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pteropus vampyrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PteropusVampyrusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAciduriciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidurici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAciduriciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaHarenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia harenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaHarenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonJdfr11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon JdFR-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonJdfr11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquincolaTertiaricarbonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquincola tertiaricarbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquincolaTertiaricarbonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMucilaginosus3016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus 3016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosus3016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpKordi52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSabulitectumSilens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sabulitectum silens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSabulitectumSilens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaCohaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lewinella cohaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LewinellaCohaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaHaemolyticaSerotypeA2BovineEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica serotype A2 BOVINE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaSerotypeA2BovineEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumImcc26256Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26256 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26256Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphiprionPerculaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion percula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphiprionPerculaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip562(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP56.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip562", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaOroxyli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia oroxyli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaOroxyli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumFrediiHh103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii HH103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiHh103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGenitaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma genitalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGenitaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrdosporaColligata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ordospora colligata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrdosporaColligata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrysSpWjwEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrys sp. WJW Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrysSpWjwEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 47-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp3131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 3_1_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaColumbinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma columbinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaColumbinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumS5a14a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S5A14a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS5a14a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusBourgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusBourgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaStr5aAcyrthosiphonPisumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola str. 5A (Acyrthosiphon pisum) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaStr5aAcyrthosiphonPisumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickenellaMelleaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickenella mellea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickenellaMelleaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxCitrulliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax citrulli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCitrulliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24535Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_45_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24535Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSabulitectumSilensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sabulitectum silens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSabulitectumSilensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatelliglobosisporaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catelliglobosispora koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatelliglobosisporaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpAe3005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. AE3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpAe3005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwd23614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWD23614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwd23614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifoxyb12full5810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB12FULL5810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb12full5810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasponiaAndersonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parasponia andersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParasponiaAndersonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp32352Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32352 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32352Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCereusAtcc14579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus ATCC 14579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusAtcc14579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMangrovisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mangrovisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMangrovisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMultiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf407Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf407Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaetbulibacterSaemankumensisDsm17032Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis DSM 17032 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensisDsm17032Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesPercursusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces percursus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomycesPercursusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VavraiaCulicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vavraia culicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VavraiaCulicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfobacillusAcidophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPLOWO2_01_FULL_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpTs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. TS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpTs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSzegedienseO12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense O-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylocaldumSzegedienseO12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumVeterumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium veterum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumVeterumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlexanderiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alexanderi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlexanderiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimwelliaBlattaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimwellia blattae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimwelliaBlattaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Raymondbacteria bacterium RIFOXYC2_FULL_50_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RudaeaCellulosilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rudaea cellulosilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RudaeaCellulosilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Bacterium2013ark19iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Ark19i Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013ark19iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecropsobacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUrhb0044Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHB0044 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhb0044Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesWuyuanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wuyuanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWuyuanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifoxyb1full4423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPr090111t3t6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PR090111T3T6A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPr090111t3t6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CavenderiaFasciculataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CavenderiaFasciculataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusSanguinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sanguinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusSanguinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAcrylicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio acrylicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAcrylicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaQuintanaRm11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana RM-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaQuintanaRm11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpF0437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. F0437 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpF0437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypoxylonSpCi4aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CI-4A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCi4aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_15b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloactinosynnemaIranicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaIranicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpBjedd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. Bjedd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpBjedd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiveispirillumIrakense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niveispirillum irakense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiveispirillumIrakense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumRifcsplowo201full5028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPLOWO201FULL5028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsplowo201full5028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa2829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-2829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa2829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitromicrobiumBathyomarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium bathyomarinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitromicrobiumBathyomarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaAffCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia aff. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaAffCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasNitroreducensTx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens TX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensTx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobaculumHydrogeniformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumHydrogeniformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat18019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_38_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaShandongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora shandongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaShandongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNbrc110611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 110611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc110611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCoryneforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium coryneforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCoryneforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroogloeocystisSiderophila52SC1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila 5.2 s.c.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophila52SC1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4354Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4354Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrioBacteriovorusTiberius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus Tiberius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusTiberius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquiDsm15833Jcm10991Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equi DSM 15833 JCM 10991 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusEquiDsm15833Jcm10991Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolymorphumGilvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polymorphum gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolymorphumGilvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRbg167010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_16_70_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg167010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaGamsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma gamsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaGamsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonScgcAaa282k18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA282K18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa282k18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaMorbirosei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tatumella morbirosei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TatumellaMorbirosei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterMathranii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathranii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumArenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumArenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterGelidistatuariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter gelidistatuariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SanguibacterGelidistatuariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaRobiniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea robiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaRobiniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophoarchaeumCaldarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum caldarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumCaldarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensBurtonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens burtonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensBurtonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichophytonRubrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton rubrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichophytonRubrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr78Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr78Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumGonidiaformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium gonidiaformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumGonidiaformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSpTwe2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. TWE2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpTwe2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGuangdongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guangdongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuangdongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnthophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea anthophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnthophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporocytophagaMyxococcoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporocytophaga myxococcoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporocytophagaMyxococcoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoffeaCanephora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coffea canephora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoffeaCanephora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpSfb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothelomycesThermophilusAtcc42464Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus ATCC 42464 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilusAtcc42464Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusStolonifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus stolonifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopusStolonifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpAp23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. AP23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAp23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaTardaAtcc15947(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda ATCC15947 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EdwardsiellaTardaAtcc15947", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonRubrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichophytonRubrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZonotrichiaAlbicollis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zonotrichia albicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZonotrichiaAlbicollis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraNanhaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacaBermudensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca bermudensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PelagibacaBermudensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevilineaSaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levilinea saccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevilineaSaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumScgcAaa298d23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA298D23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa298d23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GabonibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gabonibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GabonibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaGinsengiterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengiterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengiterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm18996(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 18996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm18996", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium6e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 6E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium6e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMacleodiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaylandiaZebraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maylandia zebra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaylandiaZebraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalinemaSpCaciamEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciamEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpHgb0015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. HGB0015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpHgb0015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeganemaPerideroedesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Meganema perideroedes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MeganemaPerideroedesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFOXYC2_FULL_35_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoraliomargaritaSpCag312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita sp. CAG:312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaSpCag312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedClostridiaBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridia bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiaBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSaburreumF0468(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum F0468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumF0468", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisMacrogoltabidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis macrogoltabida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisMacrogoltabidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSzegediense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSzegediense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4354(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4354", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterosteliumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heterostelium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeterosteliumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKle1755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KLE1755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKle1755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetosphaeriaTurcica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Setosphaeria turcica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SetosphaeriaTurcica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpYi23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. YI23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpYi23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpS62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S-6-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfovibrioSalsuginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioSalsuginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Morchella conica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MorchellaConicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuaniaAlbidiflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruania albidiflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuaniaAlbidiflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquisalimonasAsiatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquisalimonas asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquisalimonasAsiatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusSpJcm18860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus sp. JCM 18860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusSpJcm18860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulforhopalusSingaporensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulforhopalus singaporensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulforhopalusSingaporensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortieraAleyrodidarumBtBHrs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum BT-B-HRs graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumBtBHrs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpAm1d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. AM1D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpAm1d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHyovaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilvimarinusChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopirellulaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolitaleaCanadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solitalea canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolitaleaCanadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorSpAld01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloramator sp. ALD01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloramatorSpAld01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UliginosibacteriumGangwonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uliginosibacterium gangwonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UliginosibacteriumGangwonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusCastenholziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus castenholzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusCastenholziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumArachidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arachidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArachidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpeibonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces speibonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpeibonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusDevorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus devorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusDevorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSepticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium septicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSepticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSchleiferiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus schleiferi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSchleiferiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella bongori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaBongoriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniphilumSpEbm39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum sp. EBM-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSpEbm39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCoprostanoligenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium coprostanoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCoprostanoligenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MooreaProducensPal815081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens PAL-8-15-08-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MooreaProducensPal815081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Streptococcus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Streptococcus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasAuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas auensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolumonasAuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusHorikoshii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus horikoshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusHorikoshii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0429 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioSpJc8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. JC8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpJc8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTasmaniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tasmaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTasmaniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVietnamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVietnamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaphniaMagnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daphnia magna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaphniaMagnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpMjr8396c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. MJR8396C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpMjr8396c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpM143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumGw2011gwe23830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWE23830 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwe23830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumHuakuiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaMesophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaMesophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumTsurumiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium tsurumiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumTsurumiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DongiaSpUrhe0060Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dongia sp. URHE0060 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DongiaSpUrhe0060Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSpFsc1006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. FSC1006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpFsc1006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodoplanesSinuspersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoplanes sinuspersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoplanesSinuspersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterMishustinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter mishustinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterMishustinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoaLoaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loa loa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoaLoaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisSubspTessellarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. tessellarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspTessellarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumAquatileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumAquatileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpMed121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MED121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMed121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaAlgaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella algae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAlgaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumRbg13429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RBG13429 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRbg13429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycetocolaMiduiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola miduiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycetocolaMiduiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp303mfcol52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 303MFCol52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp303mfcol52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethermicoccusShengliensisDsm18856Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis DSM 18856 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethermicoccusShengliensisDsm18856Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumItalicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium italicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumItalicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSalinitoleransStrHayward0363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans str. Hayward 0363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitoleransStrHayward0363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_43_15b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlareaLozoyensisAtcc20868(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis ATCC 20868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlareaLozoyensisAtcc20868", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAltamirensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia altamirensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAltamirensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitiporiaMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitiporia mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FomitiporiaMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniomycesEndolithicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces endolithicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesEndolithicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhinocladiellaMackenzieiCbs65093Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei CBS 650.93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhinocladiellaMackenzieiCbs65093Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpMedpeswcelEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. MedPESWcel Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpMedpeswcelEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolytica101Dsm11237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidocella aminolytica 101 DSM 11237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidocellaAminolytica101Dsm11237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobacillusDevoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus devorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusDevoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSoliNbrc100801(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas soli NBRC 100801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSoliNbrc100801", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalocynthiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halocynthiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalocynthiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaTemerariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia temeraria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTemerariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0442Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0442 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0442Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRiesiaPediculischaeffi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pediculischaeffi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPediculischaeffi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eremococcus coleocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EremococcusColeocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumMinutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium minutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumMinutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhydraLutrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enhydra lutris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnhydraLutrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusOshimai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus oshimai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusOshimai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaHinzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella hinzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaHinzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9400853(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9400853 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9400853", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpBmg536Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. BMG5.36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpBmg536Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpDvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. DV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpDvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VenustampullaEchinocandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Venustampulla echinocandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VenustampullaEchinocandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGlycinifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus glycinifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGlycinifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium verticillioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumVerticillioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusDesertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusDesertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaBombi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaBombi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraElsdenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera elsdenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraElsdenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipiger marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipigerMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Streptomyces albus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "StreptomycesAlbusAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr3BacteriumGw2011gwf23518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium GW2011GWF23518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3BacteriumGw2011gwf23518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumHveragerdenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hveragerdense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHveragerdenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHBB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnserCygnoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anser cygnoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnserCygnoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopilaAestuariiDsm18488Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii DSM 18488 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfopilaAestuariiDsm18488Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidipiscisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidipiscis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidipiscisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumMarisDsm6286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum maris DSM 6286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumMarisDsm6286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonHepatopenaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon hepatopenaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonHepatopenaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerovibrioLipolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio lipolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioLipolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTsri0107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterTandoii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tandoii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTandoii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchangiumGephyra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archangium gephyra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchangiumGephyra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylothermusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpRifcsphigho212full6519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. RIFCSPHIGHO212FULL6519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRifcsphigho212full6519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCgr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CGR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCgr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MustelaPutoriusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mustela putorius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MustelaPutoriusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBorgpeterseniiSerovarHardjo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Hardjo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarHardjo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DactylellinaHaptotyla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DactylellinaHaptotyla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumSg824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium SG8_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumSg824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaOroxyliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia oroxyli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaOroxyliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusSzentirmaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaSpF366(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. F36-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpF366", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumGraminearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium graminearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumGraminearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcromyrmexEchinatior(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acromyrmex echinatior graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcromyrmexEchinatior", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicoccusSagamiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicoccus sagamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicoccusSagamiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillaceaeBacteriumAsp1002a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillaceae bacterium ASP10-02a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillaceaeBacteriumAsp1002a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpLeaf326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. Leaf326 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLeaf326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium vaginae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumVaginaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpDmeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDmeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnobacterSpMed105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. MED105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpMed105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110055Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110055Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermaniaPiniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Skermania piniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SkermaniaPiniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaSpTg14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. TG14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpTg14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithiiAtcc35061(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii ATCC35061 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithiiAtcc35061", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesDenticolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces denticolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDenticolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpJahEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JAH Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJahEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusFerrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSuccinicans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium succinicans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuccinicans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistliaConsotensisUsba355Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tistlia consotensis USBA 355 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TistliaConsotensisUsba355Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaAcetivoransC2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans C2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivoransC2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMacauensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus macauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusMacauensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumTegetincolaDsm22377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola DSM 22377 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincolaDsm22377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaBrevipalpisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina brevipalpis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaBrevipalpisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0263Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpF0263Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrocarboniphagaDaqingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga daqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaDaqingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinatimonasSpCag777(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas sp. CAG:777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasSpCag777", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinimicrobiumPekingenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium pekingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumPekingenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenderiaElectrophagaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenderia electrophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenderiaElectrophagaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSinduriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sinduriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSinduriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPapuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella papuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPapuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacteriaceaeBacteriumLsjc7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium LSJC7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumLsjc7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 29_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpCb01531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. CB01531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpCb01531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFxj1172Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. FXJ1.172 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFxj1172Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtomycesLactucaedebilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Protomyces lactucaedebilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProtomycesLactucaedebilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaSubspAchromogenesAs03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. achromogenes AS03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspAchromogenesAs03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterCastelli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter castelli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCastelli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterSphagniphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sphagniphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSphagniphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterOrnithocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ornithocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterOrnithocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelonoidisAbingdonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelonoidis abingdonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelonoidisAbingdonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaChilensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella chilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaChilensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_02_FULL_43_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisB6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis B6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisB6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_01_FULL_44_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrionalesBacteriumGwa2659Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrionales bacterium GWA2_65_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrionalesBacteriumGwa2659Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrophominaPhaseolinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacrophominaPhaseolinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnchocercaFlexuosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca flexuosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OnchocercaFlexuosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumAzorenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium azorense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumAzorenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpKh3b4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. KH3B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpKh3b4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusOleiagriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus oleiagri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusOleiagriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterMarburgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacillusKushneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinibacillus kushneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinibacillusKushneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaSp1andimar09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 1ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp1andimar09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpIcm42b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. ICM42b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpIcm42b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumNodosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium nodosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumNodosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovenusAranensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halovenus aranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalovenusAranensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGerencseriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGerencseriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae168(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae168", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RenibacteriumSalmoninarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Renibacterium salmoninarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RenibacteriumSalmoninarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_58_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterBeijingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterBeijingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisH37rvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Rv Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37rvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusEllipticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusEllipticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterDaecheongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraJaponicaT1X7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica T1-X7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJaponicaT1X7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalovivaxRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halovivax ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalovivaxRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpRoot710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaTurbans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia turbans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTurbans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1285Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1285 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1285Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeospirillumFulvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum fulvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumFulvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdhaeribacterAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adhaeribacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdhaeribacterAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicatellaBalaenopteraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella balaenopterae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaBalaenopteraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CytophagaHutchinsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga hutchinsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CytophagaHutchinsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EptesicusFuscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eptesicus fuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EptesicusFuscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaPhocaeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella phocaeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaPhocaeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpRs01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. RS01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpRs01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumB14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium B14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumB14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumChkci002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium CHKCI002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumChkci002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeijerinckiaMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SistotremastrumSuecicumHhb10207Ss3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum HHB10207 ss-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumSuecicumHhb10207Ss3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidipropionibacteriumAcidipropioniciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium acidipropionici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumAcidipropioniciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanomonosporaSphaericaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planomonospora sphaerica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanomonosporaSphaericaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumLssobCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium LSSOB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumLssobCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPLOWO2_01_FULL_48_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesEuropaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesEuropaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacterKriegiiDsm6294Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii DSM 6294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanobacterKriegiiDsm6294Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccusIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBogoriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bogoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusBogoriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaAlgae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa algae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaAlgae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRamulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ramulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRamulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumGwa24611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWA2_46_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwa24611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TinamusGuttatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tinamus guttatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TinamusGuttatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGracilibacteriaBacteriumCg10238174Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gracilibacteria bacterium CG1_02_38_174 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGracilibacteriaBacteriumCg10238174Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumExpansumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium expansum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumExpansumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterGlucosidilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter glucosidilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterGlucosidilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannizziaGypseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nannizzia gypsea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NannizziaGypseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacterium4920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium 49_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacterium4920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudanabaenaSpPcc7367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC7367 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc7367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EzakiellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ezakiella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EzakiellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrauserellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prauserella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrauserellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf25735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_57_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwc14710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWC14710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwc14710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_42_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumSpMj126nf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium sp. MJ126NF4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumSpMj126nf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKunkeeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kunkeei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKunkeeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterBeijingensisDsm21582(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis DSM 21582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DyadobacterBeijingensisDsm21582", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CongregibacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Congregibacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CongregibacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathymodiolusAzoricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathymodiolusAzoricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaEhrenbergii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga ehrenbergii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEhrenbergii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumKlh11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium KLH11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumKlh11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GynuellaSunshinyiiYc6258Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii YC6258 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GynuellaSunshinyiiYc6258Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusYoungiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus youngiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusYoungiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DichelobacterNodosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dichelobacter nodosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DichelobacterNodosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKribbensisDsm17871Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kribbensis DSM 17871 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusKribbensisDsm17871Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaZoogloeoidesAtcc25935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides ATCC 25935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DuganellaZoogloeoidesAtcc25935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusMalaysiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus malaysiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusMalaysiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaFrisia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea frisia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaFrisia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusHeterorhabditisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus heterorhabditis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusHeterorhabditisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumViciaeGb30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae GB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciaeGb30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusJurassicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusJurassicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpPbts1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. PBTS 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpPbts1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwh4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaAlbidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6319 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesPosadasiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides posadasii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesPosadasiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisS2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis S2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisS2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenarthrobacterAurescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter aurescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterAurescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpAtcc6931Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. ATCC6931 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpAtcc6931Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmanitaMuscariaKoideBx008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amanita muscaria Koide BX008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmanitaMuscariaKoideBx008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasCellaseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasCellaseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira vanthielii serovar Holland str. Waz Holland ATCC 700522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureobasidiumNamibiaeCbs14797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae CBS 147.97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumNamibiaeCbs14797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminispirochaetaBajacaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta bajacaliforniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaBajacaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsphigho201full4822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPHIGHO201FULL4822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsphigho201full4822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaculaSpRifoxya12full4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. RIFOXYA12FULL4616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpRifoxya12full4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4515Fw2607(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4515 (FW-2607) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4515Fw2607", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsphigho202Full4518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPHIGHO2_02_FULL_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsphigho202Full4518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumImmobileAtcc35973Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile (ATCC 35973) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobileAtcc35973Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpNfr01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. NFR01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpNfr01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaDejecticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KwoniellaDejecticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraShabanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera shabanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraShabanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusFujiensisJcm16395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis JCM 16395 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusFujiensisJcm16395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquicursoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equicursoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquicursoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFischeriNrrl181Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fischeri NRRL 181 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusFischeriNrrl181Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrospiraNitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesLutziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesLutziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalicatenaFissicatenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena fissicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaFissicatenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CobetiaCrustatorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cobetia crustatorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CobetiaCrustatorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaYamanashiensisNbrc100130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis NBRC 100130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaYamanashiensisNbrc100130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDiolivoransDsm14421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans DSM 14421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDiolivoransDsm14421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AustwickiaChelonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Austwickia chelonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AustwickiaChelonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSp21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. 21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSp21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorientalisSpIm1011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis sp. IM1011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorientalisSpIm1011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBroomiiSerovarHurstbridgeStr5399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira broomii serovar Hurstbridge str. 5399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBroomiiSerovarHurstbridgeStr5399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaSpCba1230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sp. CBA1230 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSpCba1230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpinosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium spinosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpinosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBrasiliensisJcm12178Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis JCM 12178 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensisJcm12178Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEbm40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium EBM-40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumEbm40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAdolescentisAtcc15703Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis ATCC 15703 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentisAtcc15703Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgaricusBisporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agaricus bisporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgaricusBisporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenovulumAgarivoransDs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans DS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransDs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriovoraxSpMedpeswdeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. MedPESWde Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpMedpeswdeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEdwardsbacteriaBacteriumGwe25412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Edwardsbacteria bacterium GWE2_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusEdwardsbacteriaBacteriumGwe25412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio piger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpLeaf405Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf405 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf405Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_12_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19046Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM19046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJcm19046Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAdolescentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaCastelliiCbs4309Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii CBS 4309 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaCastelliiCbs4309Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina palpalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaPalpalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJinanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jinanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaJinanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumOncopeltii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium oncopeltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumOncopeltii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShuttleworthiaSpMsx8b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia sp. MSX8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShuttleworthiaSpMsx8b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillisiaBrevisNbrc105863Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Millisia brevis NBRC 105863 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MillisiaBrevisNbrc105863Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLup30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LUP30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLup30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho202full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL3613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccusLuminyensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag632Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:632 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag632Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermofilumAdornatus1505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum adornatus 1505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermofilumAdornatus1505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorAmbiguusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucor ambiguus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucorAmbiguusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45543Cns863(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 CNS-863 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543Cns863", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSubtileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium subtile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSubtileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtelocyanobacteriumThalassaAloha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa ALOHA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaAloha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc23210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC23210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc23210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk1080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK1080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk1080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaSolaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya solani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaSolaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAsf502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsf502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMarimammaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marimammalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarimammaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAkagiiDsm12554(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium akagii DSM 12554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAkagiiDsm12554", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPhocaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus phocaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPhocaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiBacteriumNicil2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium NICIL-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumNicil2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf67Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf67Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpD27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. D27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpD27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUnc279mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC279MFTsu5.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc279mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSpG11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. G11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpG11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagnetobacteriumCasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magnetobacterium casensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagnetobacteriumCasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasGotlandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas gotlandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasGotlandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBiflexa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira biflexa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBiflexa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaPutidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia putida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaPutidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumLividumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium lividum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JanthinobacteriumLividumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpSg55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. SG55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpSg55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpTw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. TW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpTw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaZobelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina zobellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaZobelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterCryptus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter cryptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterCryptus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterSpHtcc2649Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. HTCC2649 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpHtcc2649Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpLycopersici4287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici 4287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersici4287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeJd6301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae JD6301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeJd6301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaCanadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia canadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaCanadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYD1_FULL_41_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusMirabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteus mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteusMirabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaTurfanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria turfanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaTurfanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumSpEnrichmentCultureCloneC5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment culture clone C5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichmentCultureCloneC5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgarivoransAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNtMorphotype(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nt morphotype graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNtMorphotype", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumCanarienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium canariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCanarienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaAvicenniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora avicenniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAvicenniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabelaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Babela massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BabelaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSrs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SRS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSrs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RufibacterRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RufibacterRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaVersiformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrinema versiforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrinemaVersiformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpHun007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. HUN007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpHun007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpFuku2iso50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Fuku2ISO50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFuku2iso50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinotignumSchaalii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum schaalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinotignumSchaalii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCherryCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cherry Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCherryCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumParaconglomeratumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium paraconglomeratum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumParaconglomeratumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaArgentinensisDsm12282Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis DSM 12282 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaloarculaArgentinensisDsm12282Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSp197a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sp. 197A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalococcusSp197a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnobacterSpCaciam66h1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. CACIAM 66H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpCaciam66h1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensSpHeli66Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens sp. HelI66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensSpHeli66Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_42_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgathobaculumDesmolansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agathobaculum desmolans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgathobaculumDesmolansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumEstertheticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium estertheticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumEstertheticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaTuricataeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia turicatae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaTuricataeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterAalborgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterAalborgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisTropicalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis tropicalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisTropicalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusCoxii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus coxii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusCoxii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AedesAlbopictusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aedes albopictus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AedesAlbopictusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDevriesei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus devriesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDevriesei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumJeddahenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeddahense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeddahenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaLijiangensisNbrc108240(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis NBRC 108240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaLijiangensisNbrc108240", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScyliorhinusTorazame(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scyliorhinus torazame graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScyliorhinusTorazame", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_02_35_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumRifcsphigho201full5025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFCSPHIGHO201FULL5025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifcsphigho201full5025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifcsplowo2123612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFCSPLOWO2_12_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifcsplowo2123612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalocapsaSpMl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiohalocapsa sp. ML1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiohalocapsaSpMl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EisenibacterElegansDsm3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eisenibacter elegans DSM 3317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EisenibacterElegansDsm3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 142 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAtlanticusDsm15807Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus DSM 15807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticusDsm15807Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSp9mfcol31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 9MFCol31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp9mfcol31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraAtramentariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura atramentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraAtramentariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioQuintilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio quintilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioQuintilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpAp49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YarrowiaLipolyticaClib122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica CLIB122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YarrowiaLipolyticaClib122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaPseudomalleiK96243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei K96243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiK96243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusLaumondii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus laumondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLaumondii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumBacl6Mag120910Bin40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 MAG-120910-bin40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Mag120910Bin40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHodgkiniaCicadicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hodgkinia cicadicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHodgkiniaCicadicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoagulans36d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 36D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans36d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaVerecundumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma verecundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaVerecundumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumResistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium resistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumResistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifcsplowo212full459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPLOWO212FULL459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsplowo212full459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosocosmicusOleophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus oleophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusOleophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVarsoviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces varsoviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVarsoviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumNcimb41171Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum NCIMB41171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumNcimb41171Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNxc14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NXC14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNxc14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpHb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. HB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpHb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumPygmaeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium pygmaeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPygmaeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRbg19ftcombo5311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG19FTCOMBO5311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg19ftcombo5311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeblenbacteriaBacteriumRifoxyc2full4211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veblenbacteria bacterium RIFOXYC2FULL4211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeblenbacteriaBacteriumRifoxyc2full4211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DenitrobacteriumDetoxificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Denitrobacterium detoxificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DenitrobacteriumDetoxificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaPsittaci6bcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 6BC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci6bcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DothistromaSeptosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dothistroma septosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DothistromaSeptosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUberisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus uberis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUberisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNasuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNasuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag486(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag486", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesRadicidentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces radicidentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRadicidentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMarthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria marthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaMarthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSeohaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter seohaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSeohaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCanadense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canadense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanadense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holdemania massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaRohdeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia rohdei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaRohdeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaAusteni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina austeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaAusteni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusThailandensisDsm22698Jcm13996Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis DSM 22698 JCM 13996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusThailandensisDsm22698Jcm13996Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialophoraAttaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialophora attae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAttaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpP1xp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P1XP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP1xp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSpA11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpA11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumGw2011gwa15015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium GW2011GWA15015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumGw2011gwa15015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaSpIstkb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. ISTKB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpIstkb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaMultimorphosaCbs102226Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa CBS 102226 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosaCbs102226Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerstersiaGyiorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kerstersia gyiorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KerstersiaGyiorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaHominisCcug36813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis CCUG 36813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FacklamiaHominisCcug36813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpPbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. PBA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpPbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGleumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gleum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGleumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixEspanaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix espanaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixEspanaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHyointestinalisSubspHyointestinalisLmg9260(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis subsp. hyointestinalis LMG 9260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalisSubspHyointestinalisLmg9260", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_12_FULL_45_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraMegakarya(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora megakarya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraMegakarya", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSp6146afaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 6146AFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp6146afaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterCryptusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter cryptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterCryptusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosulfidibacterTakaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MartelellaEndophyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Martelella endophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MartelellaEndophyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumOculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium oculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeonectriaDitissima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neonectria ditissima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeonectriaDitissima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbmousejapan(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseJapan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousejapan", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseatelesDepolymeransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseateles depolymerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseatelesDepolymeransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat25496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-25496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat25496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumIranicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIranicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinifilumFragileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinifilum fragile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinifilumFragileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MogibacteriumSpCm50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mogibacterium sp. CM50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MogibacteriumSpCm50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PowellomycesHirtusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Powellomyces hirtus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PowellomycesHirtusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumVincentii3136a2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 3136A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii3136a2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCurvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter curvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCurvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasReinhardtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas reinhardtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasReinhardtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumPacificumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum pacificum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumPacificumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusLimi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusLimi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaceaeBacteriumPhil7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPersicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPersicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasTaetrolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taetrolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaetrolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMarseillep2986(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium MarseilleP2986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMarseillep2986", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpongiicolaDsm21749Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola DSM 21749 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysobacterSpongiicolaDsm21749Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBaumanniiBjab07104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii BJAB07104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiBjab07104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusLugdunensisHku0901Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis HKU0901 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisHku0901Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusThailandensisDsm22698Jcm13996(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis DSM 22698 JCM 13996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusThailandensisDsm22698Jcm13996", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAntibioticophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus antibioticophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAntibioticophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetitomaculumRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetitomaculumRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidiprofundiDsm19306Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi DSM 19306 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundiDsm19306Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DielmaFastidiosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dielma fastidiosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DielmaFastidiosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRhodochrous(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodochrous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodochrous", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KtedonobacterRacemiferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter racemifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterRacemiferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMendocinaNk01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina NK01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaNk01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpCcge1001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatitaleaSpBrhc12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea sp. BRHc12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaSpBrhc12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipheNecator(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe necator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipheNecator", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9403326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9403326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9403326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpC9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. C9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpC9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpongiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpongiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacterium4572128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 4572_128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4572128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiensFb03509an(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens FB03509AN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensFb03509an", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaZimbabwensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella zimbabwensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaZimbabwensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVelezensisTrigocor1448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis TrigoCor1448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisTrigocor1448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. salamae serovar 56:z10:e,n,x str. 1369-73 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematobacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpDs20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. DS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpDs20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumK1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium K1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumK1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrothermaeBacteriumJdfr72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermae bacterium JdFR72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrothermaeBacteriumJdfr72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoHordeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ustilago hordei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UstilagoHordeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpPamc25486Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAMC 25486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpPamc25486Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaSpD27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. D27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaSpD27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumAbikonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium abikonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumAbikonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisAlkaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaPaludivivens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella paludivivens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPaludivivens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonBrna1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon BRNA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonBrna1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaShimofusensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaShimofusensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesStercorirosoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercorirosoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesStercorirosoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiEuryarchaeote(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeote", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IctalurusPunctatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ictalurus punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IctalurusPunctatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaBronchiseptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchiseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BordetellaBronchiseptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSp5720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 57_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp5720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HamiltosporidiumTvaerminnensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium tvaerminnensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumTvaerminnensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaThermarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga thermarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaThermarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilis168Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis 168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilis168Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteusHauseriAtcc700826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus hauseri ATCC 700826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProteusHauseriAtcc700826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYD1_FULL_52_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaSp2812bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 2812B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp2812bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSporothermoduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sporothermodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSporothermoduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumScn6820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium SCN 68-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumScn6820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasMediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas media Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasMediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAntH11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant H11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpAntH11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusTc41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius Tc41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusTc41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumTusciaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumTusciaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpAu22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaTimonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia timonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaTimonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPHIGHO2_01_FULL_48_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumFumariolicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum fumariolicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumFumariolicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSandarakinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sandarakinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSandarakinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPontisDsm8475(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pontis DSM 8475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPontisDsm8475", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterArenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterArenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfallasAlcoholivoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas alcoholivorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfallasAlcoholivoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaMorsitansMorsitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glossina morsitans morsitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlossinaMorsitansMorsitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpRoot485(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot485", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluviicolaTaffensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola taffensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FluviicolaTaffensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHordeiDsm19519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hordei DSM 19519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHordeiDsm19519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionNc10BacteriumRifcsplowo202full6622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium RIFCSPLOWO202FULL6622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumRifcsplowo202full6622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GalbibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Galbibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GalbibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusResistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus resistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusResistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMatruchotiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium matruchotii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMatruchotiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaOvisStrMichigan(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovis str. Michigan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaOvisStrMichigan", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacterAutotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter autotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthobacterAutotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiulongibacterSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jiulongibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JiulongibacterSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFurukawaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas furukawaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFurukawaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMarmoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus marmoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMarmoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKrulwichiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus krulwichiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusKrulwichiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MeiothermusTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesJenseniiJcm1364Nbrc14755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides jensenii JCM 1364 NBRC 14755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardioidesJenseniiJcm1364Nbrc14755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusWentiiDto134e9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus wentii DTO 134E9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusWentiiDto134e9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpH7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. H7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpH7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUreolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUreolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumTepidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum tepidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumTepidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJeojienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jeojiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusJeojienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaSpCcfee5036Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. CCFEE 5036 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpCcfee5036Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassomonasActiniarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas actiniarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasActiniarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium4484113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4484_113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium4484113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporisoriumReilianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium reilianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporisoriumReilianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterSpYe315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. YE315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpYe315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrosmanniaClavigera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Grosmannia clavigera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GrosmanniaClavigera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVeterana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia veterana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaVeterana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasNaejangsanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas naejangsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNaejangsanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSojae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSojae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumGw2011gwc24017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumRifcsphigho212full3622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium RIFCSPHIGHO212FULL3622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumRifcsphigho212full3622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacificibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacificibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacificibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterHiberniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter hiberniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHiberniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamormyropsKingsleyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paramormyrops kingsleyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParamormyropsKingsleyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaSordidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Valsa sordida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ValsaSordidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph3623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 3623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph3623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillerozymaFarinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Millerozyma farinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MillerozymaFarinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpYr527Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. YR527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpYr527Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200250816sch5313054b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200250816SCH5313054b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200250816sch5313054b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRu3701Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ru370.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu3701Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyc2full3521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMaritimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio maritimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMaritimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaSaharensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora saharensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaSaharensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocaceaeBacteriumR53105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostocaceae bacterium R-53105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocaceaeBacteriumR53105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusGilardiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusGilardiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidifarinaeDsm19394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae DSM 19394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinaeDsm19394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirillosporaAlbidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirillospora albida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirillosporaAlbidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromonasArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusNovalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus novalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusNovalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfPedicinusBadiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus badii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusBadiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSulciaMuelleriSmdsem(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri SMDSEM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriSmdsem", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_55_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaymondbacteriaBacteriumRifoxyc2full5021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Raymondbacteria bacterium RIFOXYC2FULL5021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RaymondbacteriaBacteriumRifoxyc2full5021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaIniectaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia iniecta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaIniectaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiBl21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli BL21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiBl21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCystitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesResistomycificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces resistomycificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesResistomycificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipotesVexillifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lipotes vexillifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LipotesVexillifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesVulgatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides vulgatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesVulgatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_02_FULL_48_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAnisopliaeBrip53293Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae BRIP 53293 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliaeBrip53293Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiAnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi Ana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiAnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZinderiaInsecticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zinderia insecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZinderiaInsecticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermicanusAegyptius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermicanus aegyptius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermicanusAegyptius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaBronchialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia bronchialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaBronchialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraFaineiSerovarHurstbridgeStrBut6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira fainei serovar Hurstbridge str. BUT 6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraFaineiSerovarHurstbridgeStrBut6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumFaeciumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium faecium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumFaeciumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchangiumSpCbG35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archangium sp. Cb G35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchangiumSpCbG35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaGlobisporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina globispora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaGlobisporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusAsymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus asymbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAsymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NicotianaSylvestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana sylvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NicotianaSylvestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoplanesSpZ2yc6860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoplanes sp. Z2YC6860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoplanesSpZ2yc6860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumYad3003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YAD3003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYad3003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDendritiformisC454Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis C454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformisC454Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterShowaeRm3277(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae RM3277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeRm3277", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaMontaniterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma montaniterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaMontaniterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LingulaAnatinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lingula anatina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LingulaAnatinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumPcc7702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium PCC7702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumPcc7702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumProfundumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium profundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumProfundumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogulbenkianiaSpMai1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. MAI-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpMai1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCirculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus circulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCirculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBirtlesiiIbs325Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii IBS 325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaBirtlesiiIbs325Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumFortuitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fortuitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFortuitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraMultiparaAtcc19207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara ATCC19207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaAtcc19207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimicrobiumSacchariphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrimicrobium sacchariphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrimicrobiumSacchariphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpTw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. TW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpTw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosartoryaFischeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neosartorya fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeosartoryaFischeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaYuzhufengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia yuzhufengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaYuzhufengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAlginolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioAlginolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumUasb124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpartansiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium spartansii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpartansiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHtcc2148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpSyk6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. SYK6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpSyk6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaodelphaxStriatellusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laodelphax striatellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaodelphaxStriatellusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsplowo201full4327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterChlorophenolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter chlorophenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterChlorophenolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZymaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus zymae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusZymaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhinopithecusBietiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus bieti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusBietiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpCg2304434Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. CG2_30_44_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpCg2304434Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusGlucosetrophus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus glucosetrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylovorusGlucosetrophus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpScn6718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SCN 67-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpScn6718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusFleurettii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus fleurettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusFleurettii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubinisphaeraBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubinisphaera brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubinisphaeraBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansAtcc10379Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans ATCC10379 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansAtcc10379Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenibacterAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllofrancisellaGuangzhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allofrancisella guangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllofrancisellaGuangzhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZobelliaUliginosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zobellia uliginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZobelliaUliginosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiMandapamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi mandapamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiMandapamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag762Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:762 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag762Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaLonarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaLonarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumRobustumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium robustum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumRobustumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaSechelliaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila sechellia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSechelliaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_38_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumPalustreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumPalustreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZimmermannellaBifidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella bifida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaBifidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpizellomycesPunctatusDaomBr117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus DAOM BR117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpizellomycesPunctatusDaomBr117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuisYs72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis YS72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisYs72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMendocinaYmp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina ymp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaYmp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaSpUtamx2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCapricolumSubspCapripneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum subsp. capripneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaCapricolumSubspCapripneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg165418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_54_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpragueaLophii42110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spraguea lophii 42_110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpragueaLophii42110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaGingivalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga gingivalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGingivalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGwf16617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWF1_66_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwf16617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavicepsPurpurea201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea 20.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClavicepsPurpurea201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCelluloflavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces celluloflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCelluloflavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrivivaxBenzoatilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax benzoatilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxBenzoatilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumLarrymooreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymooreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusTengchongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusTengchongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumCauenseR2a7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cauense R2A-7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumCauenseR2a7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeotrichumCandidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geotrichum candidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeotrichumCandidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMola455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MOLA455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMola455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZeaMaysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zea mays Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZeaMaysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaSpCag878(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma sp. CAG:878 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaSpCag878", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BermanellaMarisrubriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bermanella marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BermanellaMarisrubriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp37maEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 37MA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSp37maEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusTibetensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus tibetensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusTibetensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpH1aiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. H1ai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpH1aiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSalivariusUcc118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius UCC118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSalivariusUcc118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesStephensiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles stephensi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesStephensiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaHellenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella hellenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaHellenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgarivoransAlbusMkt106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans albus MKT 106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgarivoransAlbusMkt106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_70_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumTardaugensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium tardaugens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumTardaugensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaDasiensisCbs10888Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea dasiensis CBS 10888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachanceaDasiensisCbs10888Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterConcisusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter concisus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterConcisusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full4016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAveniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas aveniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAveniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6247Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6247Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaOsloensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella osloensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOsloensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4328Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4328 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4328Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSpCcge1002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. CCGE1002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpCcge1002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetoanaerobiumSticklandii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetoanaerobium sticklandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetoanaerobiumSticklandii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaPassalidarumNrrlY27907(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum NRRL Y-27907 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpathasporaPassalidarumNrrlY27907", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginaePb189t14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae PB189T14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaePb189t14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaMarisrubriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarisrubriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaFijiensisCirad86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis CIRAD86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensisCirad86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil764(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil764", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumResinovorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium resinovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumResinovorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IlyobacterPolytropusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ilyobacter polytropus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IlyobacterPolytropusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc078h07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC078H07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc078h07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaGlatheiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glathei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlatheiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulochytriumProtostelioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulochytrium protostelioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulochytriumProtostelioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4035 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpCg232(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG23_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg232", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpBsw20308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. Bsw20308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpBsw20308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiochaetaPulveracea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta pulveracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaPulveracea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHengshuiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hengshuiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHengshuiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldimicrobiumThiodismutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldimicrobium thiodismutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldimicrobiumThiodismutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApisCeranaCeranaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Apis cerana cerana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ApisCeranaCeranaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatirhabdiumButyrativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpNuni2hmbin003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumAap65Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap65Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot494Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot494Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusWulumuqiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus wulumuqiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusWulumuqiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisXCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis X Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisXCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBgi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bgi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBgi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloglycomycesAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloglycomyces albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloglycomycesAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumAStrAtcc3502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A str. ATCC 3502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAStrAtcc3502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb243498i20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_498I20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243498i20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSulfurreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sulfurreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterSulfurreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumUrhd0088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpFw1012bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. FW1012B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpFw1012bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaSpNg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella sp. NG2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilliamellaSpNg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamponotusFloridanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Camponotus floridanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CamponotusFloridanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoagulans26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfacinumInfernumDsm9756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum infernum DSM 9756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumInfernumDsm9756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaSchinkiiDsm10518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia schinkii DSM 10518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlautiaSchinkiiDsm10518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CesiribacterAndamanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cesiribacter andamanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CesiribacterAndamanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCamelliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCamelliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusStearothermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus stearothermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusStearothermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Andersenbacteria bacterium RIFCSPHIGHO2_01_FULL_46_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MangrovimonasYunxiaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas yunxiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasYunxiaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaZeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Runella zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RunellaZeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumEligensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium eligens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumEligensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElysiaChloroticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elysia chlorotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElysiaChloroticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc2387Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC2387 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc2387Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KetogulonicigeniumRobustumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium robustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumRobustumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OvisAries(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ovis aries graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OvisAries", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full3615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasPusillaCcmp1545(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla CCMP1545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicromonasPusillaCcmp1545", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpTth04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TTH0-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTth04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeauveriaBassianaArsef2860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana ARSEF 2860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaArsef2860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RozellaAllomycisCsf55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rozella allomycis CSF55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RozellaAllomycisCsf55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPobuzihiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pobuzihii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPobuzihiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumGp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaplasmaMarginaleStCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale St. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleStCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasIlicicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas ilicicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasIlicicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumA37t11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium A37T11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumA37t11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CephalotusFollicularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cephalotus follicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CephalotusFollicularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusPanacihumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus panacihumi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusPanacihumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorBesciiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor bescii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorBesciiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwf26230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWF2_62_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwf26230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaphorinaCitriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diaphorina citri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiaphorinaCitriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24218Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24218Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpOv700Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv700Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiophoraBrassicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodiophora brassicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiophoraBrassicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BudviciaAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Budvicia aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BudviciaAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpL21syrab(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. L21SyrAB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpL21syrab", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGerencseriaeDsm6844Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae DSM 6844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGerencseriaeDsm6844Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_50_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpTs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. TS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpTs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomonosporaCurvata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermomonospora curvata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermomonosporaCurvata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa24015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa24015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterPetaseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PustulibacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pustulibacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PustulibacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfTrabutinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSpMit975078Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. MIT975078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpMit975078Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusJensenii1153chnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 1153CHN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii1153chnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBarengoltziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterChironomiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chironomi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChironomiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpRs01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. RS01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpRs01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpPamc20917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 20917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc20917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaSympodialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malassezia sympodialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalasseziaSympodialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSpRoot187(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora sp. Root187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSpRoot187", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumBrhc25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium BRHc25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumBrhc25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporangiumAurantiacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporangium aurantiacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptosporangiumAurantiacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephaloticoccusCapnophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus capnophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusCapnophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumScgcAaa164e04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA164E04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa164e04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag309Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag309Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterLipolyticusSm19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus SM19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusSm19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpTc228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tc2-28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTc228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLowiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lowii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLowiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCitriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCitriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCyclitrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cyclitrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioCyclitrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMegateriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina megaterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMegateriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpW8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_52_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyopneumoniaeJ(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniaeJ", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcetothermiaBacteriumJdfr48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag268Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag268Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full6019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL6019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full6019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusMetallidurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus metallidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusMetallidurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpKms(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KMS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKms", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacteraceaeBacteriumCg1023614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacteraceae bacterium CG1_02_36_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacteraceaeBacteriumCg1023614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFabifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fabifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFabifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TremblayaPhenacolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya phenacola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TremblayaPhenacolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumMucogenicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mucogenicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMucogenicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscochytaRabiei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ascochyta rabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AscochytaRabiei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 46-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsphigho202full5411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumSpScadcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. SCADC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpScadcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacterium3153Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 3153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium3153Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumBrisbanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brisbanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrisbanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaAlkaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alkaliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlkaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminicoccusRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geminicoccus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeminicoccusRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasFragariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas fragariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFragariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterThalassicusDsm15285(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus DSM 15285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TepidibacterThalassicusDsm15285", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanococcusAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanococcus atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanococcusAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusCaldusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonariusItem5010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius ITEM 5010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusCarbonariusItem5010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumAcetoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum acetoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAcetoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4393(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4393", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansA8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansA8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeggiatoaLeptomitoformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa leptomitoformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaLeptomitoformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterThereiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter thereius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterThereiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium etli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumEtli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRifamycinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rifamycinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRifamycinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_40_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumCg10244142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG1_02_44_142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg10244142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumFrediiUsda257Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii USDA257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiUsda257Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaSpCba1127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula sp. CBA1127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaSpCba1127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaSerotypeA2BovineCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica serotype A2 BOVINE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaSerotypeA2BovineCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumE1BontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum E1 BoNT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumE1BontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeobacteroidesBs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides BS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesBs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumViciae3841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 3841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae3841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaSpCag257(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag257", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriRch2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri RCH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriRch2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButtiauxellaAgrestisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella agrestis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaAgrestisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterHoylei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter hoylei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterHoylei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaDokdonensisDs3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis DS-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensisDs3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibaculumBaratangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutibaculum baratangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutibaculumBaratangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpLsaoaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. LSAOA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpLsaoaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSibiricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sibiricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSibiricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumAap65(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap65", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaPlymuthicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia plymuthica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaPlymuthicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoruegeriaSabulilitorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sabulilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSabulilitorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrabacterSp28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. 28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSp28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaMorsitansMorsitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glossina morsitans morsitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlossinaMorsitansMorsitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumRbg13429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RBG13429 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRbg13429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaMassilioguelmaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia massilioguelmaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaMassilioguelmaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlegusellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olegusella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlegusellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesMerdaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides merdae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMerdaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerminephrobacterEiseniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verminephrobacter eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerminephrobacterEiseniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusOrientis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus orientis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusOrientis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpCf125(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf125", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpUcdkl21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNageliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNageliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StereumHirsutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stereum hirsutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StereumHirsutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterGuillouiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter guillouiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGuillouiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusParalvinellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus paralvinellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusParalvinellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27245Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27245 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27245Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full6316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL6316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full6316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumParafortuitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium parafortuitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumParafortuitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterAsburiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter asburiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterAsburiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpHmsc064e01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC064E01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc064e01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlesiomonasShigelloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plesiomonas shigelloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlesiomonasShigelloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpGib2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. GIB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpGib2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaSpTg14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. TG14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpTg14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyorhinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusAmylolentusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptococcusAmylolentusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_16b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumTepidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium tepidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumTepidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusTaiwanensisDsm18679Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis DSM 18679 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensisDsm18679Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumVincentiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaSpCfcc13594(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella sp. CFCC 13594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaSpCfcc13594", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumGwa27023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_70_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusOlitorius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corchorus olitorius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorchorusOlitorius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParoeduraPictaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paroedura picta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParoeduraPictaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterOralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HuchoHuchoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hucho hucho Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HuchoHuchoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumUasb340Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB340 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb340Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSp5039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. 50-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSp5039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCurvatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurvatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterMicraerophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister micraerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterMicraerophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaArgentinensisDsm12282(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis DSM 12282 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaloarculaArgentinensisDsm12282", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGeorgiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces georgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGeorgiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSasangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sasangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSasangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaCompniacensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia compniacensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaCompniacensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200210029sch5224772(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200210029SCH5224772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200210029sch5224772", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumLarrymooreiAf310Atcc51759Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei AF3.10 ATCC 51759 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymooreiAf310Atcc51759Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaSpSwk7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula sp. SWK7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaSpSwk7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa26018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa26018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriDsm1131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri DSM1131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDsm1131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpBgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSalivae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella salivae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSalivae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaObeumA2162Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blautia obeum A2-162 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlautiaObeumA2162Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNomiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nomius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusNomiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpArr65Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ARR65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpArr65Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusKribbensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus kribbensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusKribbensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSulphureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sulphureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSulphureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumThoenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium thoenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumThoenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFarraginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarraginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysiogenesArsenatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chrysiogenes arsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChrysiogenesArsenatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumAlbertimagniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium albertimagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumAlbertimagniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSp25mfcol41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. 25mfcol4.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSp25mfcol41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterXylosoxidansA8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansA8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpartansii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium spartansii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpartansii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumGracileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium gracile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobiumGracileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp11mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 11MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp11mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IchthyophthiriusMultifiliisStrainG5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis strain G5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliisStrainG5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpErg5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ERG5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpErg5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpizellomycesPunctatusDaomBr117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus DAOM BR117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpizellomycesPunctatusDaomBr117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumHirsutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gossypium hirsutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GossypiumHirsutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogranumSalariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halogranum salarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalogranumSalariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPellirubrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrinema pellirubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrinemaPellirubrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaGonorrhoeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niastella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiastellaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumCrithidii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium crithidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumCrithidii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisMinervaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis minervae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisMinervaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpLm4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. LM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLm4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FuerstiaMarisgermanicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fuerstia marisgermanicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FuerstiaMarisgermanicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolymorphaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpSk20926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. SK20926 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpSk20926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAlkenifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alkenifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlkenifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveraAscorbataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera ascorbata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KluyveraAscorbataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeovibrioSpL21acebes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geovibrio sp. L21AceBES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeovibrioSpL21acebes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaM42548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica M42548 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaM42548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpAsf360Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. ASF360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpAsf360Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillaceaeBacteriumGas479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium GAS479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumGas479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPLOWO2_12_FULL_35_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PicoidesPubescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Picoides pubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PicoidesPubescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaPusilla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaPusilla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillaceaeBacteriumAsp1002aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillaceae bacterium ASP10-02a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillaceaeBacteriumAsp1002aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerendipitaVermiferaMaff305830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serendipita vermifera MAFF 305830 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerendipitaVermiferaMaff305830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PachysolenTannophilusNrrlY2460(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus NRRL Y-2460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PachysolenTannophilusNrrlY2460", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAsf502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsf502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimaricolaCinnabarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola cinnabarinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaCinnabarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterSpDg15c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG15C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg15c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteipulveratusMongoliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus mongoliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusMongoliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasMacacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasMacacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaChrysanthemiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya chrysanthemi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaChrysanthemiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacterium1109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium 1109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacterium1109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSediminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSediminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaAtlantaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella atlantae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaAtlantaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 39-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusCoprophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCoprophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaBissettiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia bissettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaBissettiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChristensenellaMinuta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenella minuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMinuta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenibacterElegansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eisenibacter elegans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EisenibacterElegansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalis13sdw01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis 13SDW01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalis13sdw01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0425Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0425Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanotheceSpAtcc51142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. ATCC51142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpAtcc51142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasSpJm171Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. JM171 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJm171Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpC8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetohalobiumArabaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetohalobium arabaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetohalobiumArabaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg19ftcombo6530Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO6530 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo6530Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPseudoalcaligenesCect5344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes CECT5344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesCect5344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExserohilumTurcicaEt28a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exserohilum turcica Et28A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExserohilumTurcicaEt28a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YamadazymaTenuisAtcc10573Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis ATCC 10573 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YamadazymaTenuisAtcc10573Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosMutus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bos mutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BosMutus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwb24136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWB24136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwb24136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhynchosporiumCommuneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhynchosporium commune Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhynchosporiumCommuneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5424 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc6406Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC6406 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc6406Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusScotoductusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus scotoductus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusScotoductusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCoronafaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumCg2304152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium CG2_30_41_52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumCg2304152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaTriticina11BbbdRace1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia triticina 1-1 BBBD Race 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PucciniaTriticina11BbbdRace1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesIleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ilei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlbimonasPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Albimonas pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlbimonasPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaceaeBacterium4572322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_32.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium4572322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg10247685Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG10247685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg10247685Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpOhsuiiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OHSUIII Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOhsuiiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasXianhensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xianhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasXianhensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSunkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sunkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSunkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1468Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1468Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterSpMhb5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. MHB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpMhb5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumYoeliiYoeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium yoelii yoelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumYoeliiYoeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumGenitalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium genitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGenitalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxya12full5229(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA12FULL5229 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya12full5229", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaFormosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poecilia formosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoeciliaFormosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorusNotabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Morus notabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MorusNotabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolanumLycopersicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solanum lycopersicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolanumLycopersicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerothrixDaxensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerothrix daxensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermanaerothrixDaxensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumXanthumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xanthum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXanthumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacinutrixHimadriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix himadriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixHimadriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpLc3010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LC3010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLc3010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpAp50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensisDokdo023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis DOKDO 023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensisDokdo023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGa0074129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ga0074129 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGa0074129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapilioXuthusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Papilio xuthus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PapilioXuthusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasVirosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas virosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasVirosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoldemaniaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holdemania massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesProvencensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesProvencensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacterium4572123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalonomonasRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malonomonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalonomonasRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumCg1026336Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_63_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1026336Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium659Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium659Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBivia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bivia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBivia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TindalliaMagadiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tindallia magadiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TindalliaMagadiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiolineaDisciformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiolinea disciformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiolineaDisciformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_47_48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumThermosaccharolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium thermosaccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumThermosaccharolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCh12i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CH12i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCh12i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwf13410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF13410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf13410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminicoccusRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geminicoccus roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeminicoccusRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumChiriqhuchaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium chiriqhucha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumChiriqhuchaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCrudilactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium crudilactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCrudilactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLuciferensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus luciferensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLuciferensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_52_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full5216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusTepidamans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus tepidamans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusTepidamans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AvibacteriumParagallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo212full599Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO212FULL599 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo212full599Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumGwb25436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_54_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb25436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNoviomagense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium noviomagense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNoviomagense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwe24236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_42_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe24236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiastellaYeongjuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niastella yeongjuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiastellaYeongjuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_02_FULL_39_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalleroniaMarisminoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Palleronia marisminoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PalleroniaMarisminoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumGw2011Od13428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium GW2011_OD1_34_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumGw2011Od13428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfHeteropsyllaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaDiuraphisNoxia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Diuraphis noxia) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaDiuraphisNoxia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PerlucidibacaPiscinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca piscinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaPiscinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusThioreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus thioreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusThioreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpN418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. N418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioSpN418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioSpOa2007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. OA-2007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpOa2007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaProteamaculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia proteamaculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaProteamaculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAnimalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus animalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAnimalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumZag111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium Zag111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumZag111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_38_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium5246Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 52_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium5246Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaAnsorpiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella ansorpii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaAnsorpiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusMucosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusMucosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidimonasBauzanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candidimonas bauzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidimonasBauzanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc4bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLepromatosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lepromatosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLepromatosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpNfr01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. NFR01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpNfr01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VogesellaSpEbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogesella sp. EB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogesellaSpEbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxValerianellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax valerianellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxValerianellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaSpEs058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. ES.058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StappiaSpEs058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpV450(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. V450 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpV450", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioVulgarisMiyazaki(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Miyazaki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisMiyazaki", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonsdaleaPopuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaPopuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_38_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeumEquitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium3146faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3146FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3146faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSchoenbuchensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpHk06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. HK-06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpHk06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesBarnesiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides barnesiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesBarnesiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisMinervaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis minervae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisMinervaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusNematophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus nematophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusNematophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusHnlc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetascardoviaCricetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metascardovia criceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetascardoviaCricetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaParvirubraYit11816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella parvirubra YIT 11816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SutterellaParvirubraYit11816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSaliperosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saliperosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaliperosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPiscinaleCena21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nostoc piscinale CENA21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NostocPiscinaleCena21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaSiciliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4016bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4016b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4016bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_02_FULL_42_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumImcc26134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium IMCC26134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumImcc26134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterDaecheongensisDsm21074(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis DSM 21074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensisDsm21074", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaliobacillusRyukyuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus ryukyuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusRyukyuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiusGelatinovorusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius gelatinovorus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusGelatinovorusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlareaLozoyensisAtcc20868Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis ATCC 20868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlareaLozoyensisAtcc20868Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaUniformisNbrc13702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia uniformis NBRC 13702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaUniformisNbrc13702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaQuinlivaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella quinlivanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuinlivaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4825 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaShayeganii871Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria shayeganii 871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaShayeganii871Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusApachensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus apachensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusApachensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaHofmanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70273(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70273 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70273", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaKoehlerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella koehlerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaKoehlerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaErythraeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora erythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaErythraeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifoxyd1full5236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYD1FULL5236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyd1full5236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisGanjiahuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis ganjiahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisGanjiahuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaGeestiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella geestiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaGeestiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrincolaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumGw2011gwa14161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium GW2011GWA14161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumGw2011gwa14161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumCallitrichosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium callitrichos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCallitrichosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumJdfr77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FraserbacteriaBacteriumRbg16559Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fraserbacteria bacterium RBG16559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FraserbacteriaBacteriumRbg16559Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusKawachiiIfo4308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii IFO 4308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusKawachiiIfo4308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpVk13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. VK13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpVk13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaMurisAs145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia muris AS145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EhrlichiaMurisAs145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCecorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus cecorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCecorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303346Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_33_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303346Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumJkg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium JKG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumJkg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycisphaeraeBacteriumSm2330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaerae bacterium SM23_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraeBacteriumSm2330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaFlabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella flabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaFlabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSpW15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis sp. W15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSpW15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxIsoporaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax isoporae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxIsoporaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRutilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rutilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRutilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterAerophilusDsm13606(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus DSM 13606 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HymenobacterAerophilusDsm13606", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full509bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL509b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full509bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusAsaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumCarotovorumPc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum PC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumPc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrabulsiellaGuamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella guamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrabulsiellaGuamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillumSpUnkmgs17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum sp. UNKMGS17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumSpUnkmgs17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasRuthenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas ruthenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRuthenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRifamyciniDsm43936Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini DSM 43936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRifamyciniDsm43936Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwe24063(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24063", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumPseudogrignonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum pseudogrignonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumPseudogrignonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSpVcm10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. VCM10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpVcm10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliifodinibiusRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliifodinibius roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliifodinibiusRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenophilusAzovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenophilus azovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenophilusAzovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolicicoccusSubflavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amycolicicoccus subflavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmycolicicoccusSubflavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxKonjaciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax konjaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxKonjaciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilaceaeBacteriumUrhb0062Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0062Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb245a519a13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_519A13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a519a13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpCag439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:439 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinorNm305(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor NM305 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinorNm305", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSpGwe1629Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. GWE1_62_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpGwe1629Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PygoscelisAdeliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pygoscelis adeliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PygoscelisAdeliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpD14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpD14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOk095Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OK095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOk095Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls350Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS350 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls350Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSpMctg156(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. MCTG156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpMctg156", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusAutotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusAutotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRbg163710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_16_37_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg163710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCalidoustus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus calidoustus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusCalidoustus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBombicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bombicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBombicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthobacterSoliDsm19599Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli DSM 19599 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoliDsm19599Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166443Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166443Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KtedonobacterSp13120cm45311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter sp. 13_1_20CM_4_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterSp13120cm45311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg135212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_52_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg135212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaSpSjp92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. SJP92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpSjp92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumRifoxyd12full368(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYD12FULL368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyd12full368", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpH1aiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. H1ai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpH1aiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpLycopersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGa0077544Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077544 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077544Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRv15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. RV15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRv15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterLignolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter lignolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLignolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpGw103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. GW103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpGw103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSp513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. 5.13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSp513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polytolypa hystricis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolytolypaHystricis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpJkg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. JKG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpJkg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPyruviciproducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pyruviciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPyruviciproducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumRifoxyb1full3315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium RIFOXYB1FULL3315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumRifoxyb1full3315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpPdc64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. PDC64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpPdc64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaCanimorsus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canimorsus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanimorsus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidimonasTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidimonasTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumPlexicaudatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium plexicaudatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPlexicaudatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaHypogeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga hypogea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermotogaHypogeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DechloromonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DechloromonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AstyanaxMexicanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Astyanax mexicanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AstyanaxMexicanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatelliglobosisporaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catelliglobosispora koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatelliglobosisporaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWaltersiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella waltersii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaWaltersiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicolaPhilippinesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Philippines Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynesporaCassiicolaPhilippinesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaSpielmanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella spielmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaSpielmanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneatrixAlpicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Balneatrix alpica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BalneatrixAlpicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaGlaucaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaGlaucaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenarcanumBioreactoricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenarcanum bioreactoricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenarcanumBioreactoricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumGwf16617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWF1_66_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwf16617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumJicamae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium jicamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJicamae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicropelagosThuwalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micropelagos thuwalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicropelagosThuwalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterVinaykumariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter vinaykumarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterVinaykumariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GonapodyaProliferaJel478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gonapodya prolifera JEL478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GonapodyaProliferaJel478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSaudimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter saudimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSaudimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpMan2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. MAN2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpMan2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GimesiaMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gimesia maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GimesiaMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumDentiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium dentium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumDentiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumThermocellumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium thermocellum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumThermocellumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutisporaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutispora thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutisporaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPelagibacterSpHimb1321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. HIMB1321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpHimb1321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpYr577(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. YR577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpYr577", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaLitorea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yoonia litorea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YooniaLitorea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSp7101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. 7101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSp7101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwe14915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE14915 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe14915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TypebSymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return TypeB symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TypebSymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNl5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nl5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNl5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsJavanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps javanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CordycepsJavanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaStriiformisFSpTriticiPst78Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia striiformis f. sp. tritici PST-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PucciniaStriiformisFSpTriticiPst78Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenovulumMaritimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum maritimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenovulumMaritimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlackburnbacteriaBacteriumRifcsphigho212full4113b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO212FULL4113b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho212full4113b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc8051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC8051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc8051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCetorumMit995656Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT995656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit995656Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaTolypothrichoidesVb61278Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides VB-61278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoidesVb61278Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionicicellaSuperfundia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionicicella superfundia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpEr16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. ER1/6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpEr16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaAviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella avium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaAviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisSpSb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacterialesBacteriumAlc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium ALC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumAlc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvissimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvissimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFulvissimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmotaMarmotaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marmota marmota Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarmotaMarmotaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpUnc23mfcrub11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC23MFCrub11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc23mfcrub11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaDenticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema denticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaDenticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSolani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSolani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansHk1651Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans HK1651 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansHk1651Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpCag52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSuccinatiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister succinatiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterSuccinatiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusArsenicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus arsenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FictibacillusArsenicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumSaccharolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium saccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSaccharolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CruoricaptorIgnavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cruoricaptor ignavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CruoricaptorIgnavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraPelophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira pelophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraPelophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriaceaeBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacteriaceae bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriaceaeBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGwa1418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GWA1418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGwa1418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransDsm16219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans DSM 16219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransDsm16219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRifcsplowo201full4332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPLOWO201FULL4332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsplowo201full4332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Morchella conica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MorchellaConicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMoravicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella moravica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaMoravicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWA2_43_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTyphi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia typhi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaTyphi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOtakiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus otakiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOtakiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeronosporaEffusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peronospora effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeronosporaEffusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacteraceaeBacterium4484166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacteraceae bacterium 4484_166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacteraceaeBacterium4484166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaFradiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria fradiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaFradiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaeciumC68Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium C68 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumC68Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAlbumArsef1941(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium album ARSEF 1941 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAlbumArsef1941", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAtroolivaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atroolivaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAtroolivaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoplanusPetrolearius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus petrolearius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusPetrolearius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter concisus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterConcisusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhodospiraHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraSpJc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. JC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpJc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaBoydiiCdc308394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella boydii CDC 3083-94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShigellaBoydiiCdc308394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumRifcsplowo212full3712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumYl45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium YL45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumYl45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacterFloricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacter floricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacterFloricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcidifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium acidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumAcidifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSubtile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium subtile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSubtile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsConfragosaRcef1005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps confragosa RCEF 1005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CordycepsConfragosaRcef1005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumRivuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium rivuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumRivuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaNoatunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Francisella noatunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrancisellaNoatunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpLc2012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. lc2012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpLc2012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAminophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KangiellaAquimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kangiella aquimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KangiellaAquimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAsaccharolyticaNbrc15499Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica NBRC 15499 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolyticaNbrc15499Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidisRp62aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis RP62A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisRp62aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterSpLpb0138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter sp. LPB0138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutibacterSpLpb0138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacillusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdvenellaKashmirensisW13003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis W13003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisW13003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYB1_FULL_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaLacustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaLacustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMetschnikovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio metschnikovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMetschnikovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusMarisnigriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus marisnigri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusMarisnigriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscirickettsiaSalmonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia salmonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaSalmonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb1437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_43_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb1437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CheloniaMydas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelonia mydas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CheloniaMydas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaColwellianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella colwelliana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaColwellianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwb1448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWB1448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwb1448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculischaeffiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculischaeffi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculischaeffiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCapricolumSubspCapripneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum subsp. capripneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaCapricolumSubspCapripneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiochaetaLigniariaNrrl30616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria NRRL 30616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ConiochaetaLigniariaNrrl30616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumOgunienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum oguniense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumOgunienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSp2b12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. 2B12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DickeyaSp2b12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanohalarchaeumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanohalarchaeum thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanohalarchaeumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumGa0074140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium Ga0074140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGa0074140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCarnosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus carnosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCarnosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLentocellumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lentocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLentocellumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrischellaPerraraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frischella perrara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrischellaPerraraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full3511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL3511 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full3511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobicatellaSulfidifaciensDsm15739Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens DSM 15739 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciensDsm15739Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocurvibacterAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvibacter africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvibacterAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaAlbidocapillataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albidocapillata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbidocapillataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterInhibensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter inhibens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterInhibensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSpHeli6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. HelI6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpHeli6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp6529Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6529Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpT28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. T28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpT28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesProvencensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesProvencensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxJadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax jadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxJadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwf24413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWF2_44_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwf24413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaribacterHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laribacter hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaribacterHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpPsnih2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviibacterAbscessusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caviibacter abscessus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaviibacterAbscessusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSpEbm43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta sp. EBM-43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaSpEbm43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpB6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpB6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaMellicolaCbs63366Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia mellicola CBS 633.66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WallemiaMellicolaCbs63366Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumRifoxyc2full3612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC2FULL3612 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc2full3612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaSpImcc20628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. IMCC20628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpImcc20628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmoebophilusSp3638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus sp. 3638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusSp3638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMendocinaYmpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina ymp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaYmpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaFlocculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaFlocculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiPam55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii PAM55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiPam55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerdimonasFaecisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Merdimonas faecis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MerdimonasFaecisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPraedii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus praedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPraedii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerroglobusPlacidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferroglobus placidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerroglobusPlacidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZavarzinellaFormosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zavarzinella formosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZavarzinellaFormosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImtechellaHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Imtechella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ImtechellaHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg136020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG136020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg136020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharogumiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharogumia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharogumiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaBatsensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola batsensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaBatsensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasSenticiiDsm18821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas senticii DSM 18821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FerrimonasSenticiiDsm18821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3903(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3903 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3903", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrennerbacteriaBacteriumRifoxyd1full4116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brennerbacteria bacterium RIFOXYD1FULL4116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrennerbacteriaBacteriumRifoxyd1full4116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSepticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium septicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSepticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonIplasma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Iplasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonIplasma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerProfundusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipiger profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipigerProfundusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCibiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cibi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCibiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpMa2016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. MA2016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpMa2016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaNanhaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanicolaNanhaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnditaleaAndensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anditalea andensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnditaleaAndensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusParaburkholderiaKirkiiUzhbot1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Paraburkholderia kirkii UZHbot1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusParaburkholderiaKirkiiUzhbot1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricellaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraYanagawaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira yanagawae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraYanagawaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumSg824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium SG8_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumSg824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_59_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGoldsteiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeurosporaCrassaOr74aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa OR74A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeurosporaCrassaOr74aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPhyllosphaerae52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae 52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaerae52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzimaplasmaSpHr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Izimaplasma sp. HR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IzimaplasmaSpHr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensIpla20019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens IPLA20019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensIpla20019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniphilumSaccharofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum saccharofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSaccharofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPaludisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter paludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPaludisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobaculumTepidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum tepidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumTepidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCg10264396Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CG1_02_64_396 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCg10264396Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAurantiacumDsm6208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum DSM 6208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacumDsm6208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFarraginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarraginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoflavonifractorSpMarseillep3106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor sp. MarseilleP3106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorSpMarseillep3106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpUnc345mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. UNC345MFTsu5.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUnc345mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgicolaSagamiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algicola sagamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgicolaSagamiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnisphaeraAggregansDsm17230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans DSM 17230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IgnisphaeraAggregansDsm17230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag567Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:567 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag567Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LautropiaSpScn6989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lautropia sp. SCN 69-89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LautropiaSpScn6989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJhl3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaQuateirensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella quateirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuateirensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpRoot381Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot381Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaSpPamc21821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 21821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc21821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcoidesVulcani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesVulcani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RugamonasRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rugamonas rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RugamonasRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpNp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. NP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NesterenkoniaSpNp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterKivuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter kivui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterKivuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacterium6920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 69-20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium6920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaPopuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niastella populi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiastellaPopuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbmousejapanEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseJapan Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousejapanEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwc23922(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWC23922 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwc23922", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctopusBimaculoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Octopus bimaculoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OctopusBimaculoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromohalobacterSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporisoriumReilianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium reilianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporisoriumReilianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMmg1121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoaciditogaLauensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoaciditoga lauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoaciditogaLauensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Gemella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Gemella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaLettingae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga lettingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermotogaLettingae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSp519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. 51_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSp519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_49_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaChahannaoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpicheri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus spicheri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpicheri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasAdhaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas adhaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAdhaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaWorsleiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella worsleiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaWorsleiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOdinarchaeotaArchaeonLcb4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Odinarchaeota archaeon LCB_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOdinarchaeotaArchaeonLcb4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpPcc9228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 9228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc9228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGaetbulicolaGung47Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Gung47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicolaGung47Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusNeoformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptococcusNeoformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusMetalliduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus metallidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusMetalliduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaFrigidimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella frigidimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFrigidimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumAsf500(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ASF500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumAsf500", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpAmp6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. amp6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CupriavidusSpAmp6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBingmayongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bingmayongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusBingmayongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterocytozoonBieneusiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesKebangsaanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kebangsaanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKebangsaanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterSpPpn85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter sp. Ppn85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterSpPpn85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumCetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium ceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumCetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusThermoglucosidasiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermoglucosidasius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusThermoglucosidasiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaRohdei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia rohdei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaRohdei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaLimnaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gillisia limnaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GillisiaLimnaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumPmmr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium PMMR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumPmmr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusLarvaeSubspLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae subsp. larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusLarvaeSubspLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHel13378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel1_33_78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel13378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpQssc122bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. QSSC1-22B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpQssc122bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumMelanogenumCbs110374Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum CBS 110374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenumCbs110374Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterPhenanthrenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter phenanthrenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterPhenanthrenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumRifoxyc2full3521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumCg2304142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_41_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2304142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaChauliocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaChauliocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpHixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. HIX Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpHixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeophyllumTrabeumAtcc11539(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum ATCC 11539 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GloeophyllumTrabeumAtcc11539", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaDagmatisAtcc43325Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis ATCC 43325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaDagmatisAtcc43325Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoplanesSpZ2yc6860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoplanes sp. Z2YC6860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoplanesSpZ2yc6860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs1612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS1612 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs1612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumUndaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium undae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumUndaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasWolfeiGoettingenCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Goettingen Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiGoettingenCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermothielavioidesTerrestrisNrrl8126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris NRRL 8126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestrisNrrl8126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HebelomaCylindrosporumH7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum h7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HebelomaCylindrosporumH7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumCg2305937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_59_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2305937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArsenophilumNbrc109478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum NBRC 109478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilumNbrc109478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterConcretionisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter concretionis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterConcretionisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobiumAcetethylicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobium acetethylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobiumAcetethylicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusFijiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterCelerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter celer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterCelerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpYr583(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. YR583 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpYr583", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpH20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovibacillusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novibacillus thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovibacillusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusFlocculiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus flocculiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichococcusFlocculiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlcaliphilum20z(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum 20Z graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilum20z", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaMattheei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mattheei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMattheei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasReinhardtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas reinhardtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasReinhardtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpCf136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofustisGlycolicusDsm9705Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus DSM 9705 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicusDsm9705Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphilophusCitrinellusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphilophus citrinellus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphilophusCitrinellusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CobetiaSpUcd24cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cobetia sp. UCD-24C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CobetiaSpUcd24cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptonychotesWeddellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptonychotes weddellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptonychotesWeddellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusLacustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusShapirobacteriaBacteriumCg2303520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium CG2_30_35_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumCg2303520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaMansoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mansoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMansoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaSympodialisAtcc42132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Malassezia sympodialis ATCC 42132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MalasseziaSympodialisAtcc42132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpCcbau05631(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. CCBAU05631 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumSpCcbau05631", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillaGorillaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gorilla gorilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GorillaGorillaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusMetalliduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus metallidurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusMetalliduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSp3363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. 3363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalothrixSp3363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaHaemolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga haemolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaHaemolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalodenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusChromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus chromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusChromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeotheceVerrucosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece verrucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeotheceVerrucosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaDejecticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KwoniellaDejecticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuricaudaAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRaac3Tm71Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RAAC3_TM7_1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRaac3Tm71Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSpSo1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. SO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumSpSo1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliocybeSulcata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heliocybe sulcata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeliocybeSulcata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocebusMurinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microcebus murinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrocebusMurinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUrha0014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. URHA0014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUrha0014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioInopinatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumUrhd0088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpX2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. X2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpX2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSpYim77859Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. YIM77859 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpYim77859Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusMarinonascensNbrc14363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens NBRC 14363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusMarinonascensNbrc14363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichosporonAsahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichosporon asahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichosporonAsahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaEndophyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma endophyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaEndophyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumKbs89(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs89", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferribacteralesBacteriumDeferri01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deferribacterales bacterium Deferri_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeferribacteralesBacteriumDeferri01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantMicrotiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant microti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantMicrotiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nosema ceranae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NosemaCeranaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasOryzaePxo99aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae PXO99A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePxo99aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimonasCellulosilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylanimonas cellulosilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylanimonasCellulosilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusAutotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus autotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusAutotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviitogaTunisiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Defluviitoga tunisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DefluviitogaTunisiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneatrixAlpica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Balneatrix alpica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BalneatrixAlpica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavovariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavovariabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavovariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaLiquefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia liquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaLiquefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrucellaAbortusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brucella abortus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrucellaAbortusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSasangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sasangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSasangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp1andimar09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 1ANDIMAR09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp1andimar09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocoliticaLc20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica LC20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocoliticaLc20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobaculumGomorrenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobaculum gomorrense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobaculumGomorrenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumViciae3841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 3841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae3841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSpCaAtcc33047Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. CA ATCC 33047 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpCaAtcc33047Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacteriumCsp16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium CSP16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumCsp16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterAlbidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter albidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconobacterAlbidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolimonasVariicoloris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solimonas variicoloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolimonasVariicoloris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaVariansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria varians Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaVariansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpXt11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. XT11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpXt11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSalivariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSalivariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxobacterPfennigiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oxobacter pfennigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OxobacterPfennigiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniellaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumVentriculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ventriculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumVentriculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpF0412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. F0412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpF0412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusSpCag542(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:542 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag542", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H050 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActibacteriumAtlanticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium atlanticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumAtlanticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedClostridiaBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridia bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiaBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumLychnidisDioicaeP1a1LamoleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum lychnidis-dioicae p1A1 Lamole Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisDioicaeP1a1LamoleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacteriaceaeBacteriumLsjc7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium LSJC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumLsjc7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcalesBacterium6820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium 68-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacterium6820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg1023112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1023112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1023112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg134613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG134613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg134613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTuberumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tuberum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTuberumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptosphaeriaMaculansJn3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans JN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculansJn3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMerionisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus merionis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMerionisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasHussainiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas hussainii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHussainiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpScn6119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. SCN 61-19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpScn6119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusAlkaliphilusDsm16010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus DSM 16010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilusDsm16010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifoxyb1full5435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYB1FULL5435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyb1full5435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuriculariopsisAmplaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Auriculariopsis ampla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AuriculariopsisAmplaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumY4iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Y4I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumY4iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterOboediens174bp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens 174Bp2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterOboediens174bp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColobusAngolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colobus angolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColobusAngolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk1057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK1057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk1057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopococcusTabaci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopococcus tabaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopococcusTabaci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StachybotrysChlorohalonataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwc14715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWC1_47_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwc14715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesDirus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles dirus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesDirus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb02923Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02923 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02923Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumLarrymooreiAf310Atcc51759(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei AF3.10 ATCC 51759 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymooreiAf310Atcc51759", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCarneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia carnea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaCarneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGuangdongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guangdongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuangdongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphriteaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphritea atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphriteaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacteriumLuteolum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium luteolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumLuteolum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInterrogansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira interrogans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInterrogansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematospirillumJordaniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haematospirillum jordaniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaematospirillumJordaniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpAsf360Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. ASF360 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpAsf360Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumGwb25626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium GWB2_56_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumGwb25626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaMultimorphosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiXiangfangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei xiangfangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiXiangfangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLc300(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LC300 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLc300", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full4412bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL4412b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full4412bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpNrrls836Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. NRRLS836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpNrrls836Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimicrobiumFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobium ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiumFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSpHl35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. HL35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpHl35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocAzollaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc azollae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocAzollaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaMorsitansMorsitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina morsitans morsitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlossinaMorsitansMorsitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasPanacihumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas panacihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasPanacihumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysochlorisAsiaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysochloris asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChrysochlorisAsiaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofundulusThermosubterraneusDsm16057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus DSM 16057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneusDsm16057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusSpA2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. A-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpA2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf469Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf469 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf469Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpEp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. EP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpEp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpKk4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKk4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniphilumAcetatigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum acetatigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumAcetatigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaccariaBicolorS238nH82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Laccaria bicolor S238N-H82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LaccariaBicolorS238nH82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaMeridionalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza meridionalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaMeridionalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTuaregi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus tuaregi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusTuaregi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesIndistinctusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes indistinctus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesIndistinctusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNiastensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia niastensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaNiastensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdyssellaThessalonicensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Odyssella thessalonicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OdyssellaThessalonicensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium4423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 44-23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium4423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSputorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSputorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrahymenaThermophilaSb210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila SB210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrahymenaThermophilaSb210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpJl475(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. JL475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpJl475", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHtcc2083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium czechense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumCzechenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo201full4732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL4732 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full4732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumXinjiangenseDsm19287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense DSM 19287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangenseDsm19287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGalbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces galbus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGalbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1024989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_49_89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1024989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg165811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_58_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TardiphagaSpOk245Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga sp. OK245 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TardiphagaSpOk245Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaMansoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mansoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMansoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelonobacterOrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelonobacter oris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelonobacterOrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StegodyphusMimosarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stegodyphus mimosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StegodyphusMimosarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerriglobusRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerriglobusRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp3524zxxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 3524ZXX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp3524zxxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAle19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BernardetiaLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bernardetia litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BernardetiaLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydocellaSpUlo1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carboxydocella sp. ULO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarboxydocellaSpUlo1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta Mad698R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColinusVirginianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colinus virginianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColinusVirginianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterCurvatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter curvatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCurvatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterSuareziiNbrc16159Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii NBRC 16159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SanguibacterSuareziiNbrc16159Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfococcusOleovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus oleovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusOleovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaPahangi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brugia pahangi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrugiaPahangi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpEc08061901(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. EC080619-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpEc08061901", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumCymbalariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EremotheciumCymbalariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpSr15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. SR1/5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpSr15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumStercorariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium stercorarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumStercorariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumRbg19ftcombo5817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO5817 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo5817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StemphyliumLycopersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stemphylium lycopersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StemphyliumLycopersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumM102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium M102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumM102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaJaponicaA8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaA8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSpVcm10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. VCM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpVcm10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalieaceaeBacteriumImcc3088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halieaceae bacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalieaceaeBacteriumImcc3088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaGrimshawiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila grimshawi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGrimshawiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OdobenusRosmarusDivergensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus divergens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OdobenusRosmarusDivergensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSputorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSputorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSpCp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. CP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpCp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_01_FULL_45_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonBa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FimbriimonasGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fimbriimonas ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FimbriimonasGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpRoot81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Root81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpRoot81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorellaSorokinianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorella sorokiniana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorellaSorokinianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaGrayiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria grayi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrayiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInterrogansSerovarLaiStr56601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira interrogans serovar Lai str. 56601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInterrogansSerovarLaiStr56601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumBrhc36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium BRHc36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumBrhc36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full4222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL4222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full4222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosovibrioSpNv6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio sp. Nv6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioSpNv6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaKingaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kingella kingae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KingellaKingaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaEburneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora eburnea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaEburneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag563Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag563Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAnaemiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia anaemiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAnaemiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumMedpeswsndg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHygroscopicusSubspHygroscopicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus subsp. hygroscopicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusSubspHygroscopicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRenniniDsm20253Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rennini DSM 20253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRenniniDsm20253Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhizobiumPelagicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhizobium pelagicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhizobiumPelagicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOligofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOligofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium4484113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4484_113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium4484113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae MGH 78578 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumOlb17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium OLB17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumOlb17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacteriumJdfr52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrucellaMelitensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brucella melitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrucellaMelitensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoenicibacterCongonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phoenicibacter congonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhoenicibacterCongonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumCitreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium citreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumCitreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa2377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA2377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa2377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterGlacincolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter glacincola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterGlacincolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sciscionella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SciscionellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiemerellaColumbipharyngisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbipharyngis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbipharyngisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf407(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf407", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaWadsworthiiDsm21896Atcc33877Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella wadsworthii DSM 21896 ATCC 33877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaWadsworthiiDsm21896Atcc33877Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpH133(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. H133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSpH133", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAespoeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aespoeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAespoeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YangiaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yangia pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YangiaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLuteolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas luteola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasLuteolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpEpsl25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. EpSL25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEpsl25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpIcm42bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. ICM42b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpIcm42bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumDenitrificansAtcc51888Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans ATCC51888 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificansAtcc51888Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloactinosynnemaSpL07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema sp. L-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaSpL07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaSpielmanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia spielmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaSpielmanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSalsiciusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter salsicius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSalsiciusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSg611l(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SG61-1L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSg611l", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiochaetaLigniariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaLigniariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSpCag826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApinorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apinorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApinorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesMassiliensisB84634Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis B84634 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisB84634Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusJensenii1153chnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 1153CHN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii1153chnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCf080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfacinumHydrothermaleDsm13146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale DSM 13146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermaleDsm13146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAndreraoultiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus andreraoultii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAndreraoultiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSediminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusSediminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaHigoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia higoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaHigoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcalesBacteriumSg838(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium SG8_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacteriumSg838", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomicrobiaArchaeonJdfr19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon JdFR-19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonJdfr19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaSchlechtendaliaChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Schlechtendalia chinensis) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSchlechtendaliaChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMalicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Valsa malicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ValsaMalicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TeredinibacterTurneraeT7902(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7902 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7902", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermocisternusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermocisternus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermocisternusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpJpy347(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JPY347 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpJpy347", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusThermodenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus thermodenitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusThermodenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpIs79a3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Is79A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpIs79a3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibacaCalidilacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseibaca calidilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseibacaCalidilacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReichenbachiellaFaecimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaFaecimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSelenitireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSelenitireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpHtcc7211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HTCC7211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHtcc7211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FermentibacterDaniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fermentibacter daniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FermentibacterDaniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSpCag144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:144 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrenneriaSpEnid312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brenneria sp. EniD312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrenneriaSpEnid312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpHensoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. hensonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHensoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumUrinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum urinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumUrinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD1_FULL_39_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSteyniiIbt23096(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus steynii IBT 23096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusSteyniiIbt23096", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusTinctoriusMarx270(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Marx 270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PisolithusTinctoriusMarx270", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSaltansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter saltans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PedobacterSaltansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5421b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5421b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5421b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpDabal43bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. DABAL43B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpDabal43bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMikellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mikella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMikellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSericea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sericea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSericea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeAtcc13047Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae ATCC13047 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeAtcc13047Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaMegaterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina megaterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMegaterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_44_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterWiegeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter wiegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterWiegeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSalsicius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter salsicius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSalsicius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpiralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella spiralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpiralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpMbr210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. MBR 210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocSpMbr210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpH83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. H83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpH83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolycyclovoransAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polycyclovorans algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolycyclovoransAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcusLuteusNctc2665(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus NCTC 2665 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusNctc2665", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaylyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baylyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaylyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFlocculareAtcc27399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare ATCC 27399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFlocculareAtcc27399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesHordeovulneris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hordeovulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHordeovulneris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylumTricornutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasArgentinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas argentinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasArgentinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxoplasmaGondiiVegCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii VEG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ToxoplasmaGondiiVegCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferShofinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer shofinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferShofinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpS6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. S6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpS6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinithermusHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinithermus hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinithermusHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyprinodonVariegatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyprinodon variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyprinodonVariegatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumRifcsphigho202full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPHIGHO202FULL3913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsphigho202full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPhaffiiGs115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Komagataella phaffii GS115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPhaffiiGs115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSpAk22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. AK22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSpAk22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmilianiaHuxleyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emiliania huxleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmilianiaHuxleyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia symbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaTobetsuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella tobetsuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaTobetsuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumBaccatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capsicum baccatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapsicumBaccatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusGilardiiCr3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii CR3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CupriavidusGilardiiCr3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe23928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_39_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe23928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaHydrogenitoleransDsm16785Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans DSM 16785 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitoleransDsm16785Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_39_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaHeveanensisBcc8398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis BCC8398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KwoniellaHeveanensisBcc8398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag177Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:177 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag177Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg165611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_56_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 33-17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCellulosilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cellulosilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCellulosilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpS6spd3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S6Spd3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS6spd3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_39_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillisiaBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Millisia brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MillisiaBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIhumii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIhumii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterSakazakiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter sakazakii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CronobacterSakazakiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumBacl1Mag120820Bin45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 MAG-120820-bin45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1Mag120820Bin45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrabacterSpSoil810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Soil810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpSoil810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpYbe204Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. YBE204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpYbe204Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusChampanellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusChampanellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJiangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusJiangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumJilantaienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium jilantaiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumJilantaienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterThalassicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidibacterThalassicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSzegedienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSzegedienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpHv1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Hv1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpHv1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasJeddahensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jeddahensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJeddahensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegetibacterKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Segetibacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SegetibacterKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinus1366Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus 1366 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinus1366Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisListeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisListeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusLutrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus lutrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VagococcusLutrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo202full6764Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL6764 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full6764Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaBryophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bryophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBryophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumMaltaromaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium maltaromaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMaltaromaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRs9917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmobacterMegateriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter megaterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmobacterMegateriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeovisonVisonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neovison vison Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeovisonVisonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaLituseburensisDsm797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis DSM 797 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensisDsm797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KallipygaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KallipygaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacterArenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThalassobacterArenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterGlacincola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter glacincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterGlacincola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioFibrisolvensDsm3071Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens DSM 3071 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensDsm3071Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PterulaGracilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pterula gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PterulaGracilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynoglossusSemilaevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cynoglossus semilaevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CynoglossusSemilaevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasMethanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas methanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasMethanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacterium4920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasBoliviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas boliviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasBoliviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PromicromonosporaKroppenstedtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Promicromonospora kroppenstedtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PromicromonosporaKroppenstedtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifcsphigho201full5110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL5110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full5110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacearchaeotaArchaeonRbg133326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacearchaeota archaeon RBG_13_33_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacearchaeotaArchaeonRbg133326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag472Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag472Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpPamc26617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaGlabrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida glabrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaGlabrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsoniaIntracellularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lawsonia intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LawsoniaIntracellularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiovulumSpEs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiovulum sp. ES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiovulumSpEs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwh4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpZym1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. ZYM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpZym1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeBacterium457278Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium457278Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaArizonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arizonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaArizonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaObtusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holospora obtusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HolosporaObtusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusPeptidifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumJsc12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium JSC12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumJsc12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYr295Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr295Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaValaisianaTom4006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana Tom4006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaTom4006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WesteberhardiaCardiocondylaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Westeberhardia cardiocondylae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WesteberhardiaCardiocondylaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp2621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRbg165712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RBG_16_57_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRbg165712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumGallicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerostipesSp494aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 494a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp494aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpBmg536Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. BMG5.36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpBmg536Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusKyotonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus kyotonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusKyotonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumLitoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium litorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLitoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpCf149Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CF149 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpCf149Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetomicrobiumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConchiformibiusKuhniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius kuhniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusKuhniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWmmb714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasHydrophilaAtcc7966Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila ATCC7966 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaAtcc7966Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaBirgiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia birgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaBirgiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirschiaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hirschia baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HirschiaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmittiumMegazygosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smittium megazygosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmittiumMegazygosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanococcusAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanococcus atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanococcusAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumThermophilumVarThermophilumDsm1495Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum var. thermophilum DSM 1495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumThermophilumVarThermophilumDsm1495Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrarchaeotaArchaeonCg1025541Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025541 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025541Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwa2319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_31_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa2319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopseudomonasPalustrisDx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris DX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisDx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumMola455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MOLA455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMola455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 41-46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMaritimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMaritimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolosicoccusPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dolosicoccus paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DolosicoccusPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNeonataleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium neonatale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNeonataleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph298Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 298 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph298Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopogonVinicolorAmOr11026(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor AM-OR11-026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizopogonVinicolorAmOr11026", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaInopinata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scardovia inopinata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScardoviaInopinata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full3914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL3914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full3914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovigenitalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovigenitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovigenitalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaAcetivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTuccetiDsm20183Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti DSM 20183 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTuccetiDsm20183Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LishizheniaTianjinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lishizhenia tianjinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LishizheniaTianjinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumKlh11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium KLH11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumKlh11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiCeIsolateThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CE isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCeIsolateThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacterium13220cm2648Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM2648 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm2648Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp21311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2131.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpLeaf363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Leaf363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLeaf363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BizioniaEchiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bizionia echini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BizioniaEchiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonRbg16369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon RBG16369 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonRbg16369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeraceosorusGuamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus guamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusGuamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg16439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesIhumiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes ihumii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesIhumiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3812b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3812b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3812b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraCrunogenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira crunogena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraCrunogenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontStrainEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont strain Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontStrainEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicrobiumZhouii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium zhouii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumZhouii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpKg01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KG01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKg01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaBifidaNbrc103089Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] bifida NBRC 103089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaBifidaNbrc103089Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasNumazuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas numazuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasNumazuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeobacterKilaueensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter kilaueensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeobacterKilaueensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwf1518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_51_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCanadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniaeHk85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae HK 85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusPittmaniaeHk85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaSpPp2459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. PP2-459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpPp2459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaNigra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora nigra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaNigra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTianmuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tianmuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTianmuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrodictiumDelaneyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium delaneyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumDelaneyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumTardaugensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium tardaugens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumTardaugensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophorhabdusAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophorhabdus aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophorhabdusAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaValaisianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella valaisiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaValaisianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachanceaDasiensisCbs10888(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea dasiensis CBS 10888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachanceaDasiensisCbs10888", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumCg10237114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_37_114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg10237114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisNigoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis nigoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisNigoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaSpScgcAb629i23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota sp. SCGC AB629I23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaSpScgcAb629i23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermaerobacterSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpP5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. P5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpP5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177NandIiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177/Nand II Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177NandIiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSp2kl3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerovibrioAcidaminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio acidaminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioAcidaminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasGilardii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas gilardii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseomonasGilardii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root420 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumGoodiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium goodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGoodiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpEs010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. ES.010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpEs010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiumFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobium ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiumFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusZanclesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus zancles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusZanclesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriKos6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri KOS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriKos6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpOralTaxon807Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. oral taxon 807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OlsenellaSpOralTaxon807Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorKristjanssoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor kristjanssonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorKristjanssoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpAcam123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ACAM123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAcam123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSalinaYim90010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis salina YIM 90010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisSalinaYim90010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaFormicigeneransAtcc27755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans ATCC27755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigeneransAtcc27755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypoxylonSpCi4a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CI-4A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCi4a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpCua673Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CUA-673 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCua673Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSpTm1035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. TM1035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseovariusSpTm1035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCoralliilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio coralliilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioCoralliilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBplanEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPLAN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBplanEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminobacterHydrogenoformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLpu83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LPU83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpLpu83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacteraceaeBacteriumCg1023614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacteraceae bacterium CG1_02_36_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacteraceaeBacteriumCg1023614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemofelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemofelis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemofelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh80548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH80548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh80548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTeleogrylli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Erwinia] teleogrylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTeleogrylli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasArcisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas arcis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasArcisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusVeneficus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus veneficus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusVeneficus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAquivivusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter aquivivus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterAquivivusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScleropagesFormosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scleropages formosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScleropagesFormosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumBeijerinckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolobusPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrincolaLacisaponensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola lacisaponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrincolaLacisaponensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumUlvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium ulvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumUlvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterLatericiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter latericius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenibacterLatericiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusPelagius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusPelagius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterGeojensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter geojensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGeojensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSubtropicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium subtropicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSubtropicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpRac03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. RAC03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpRac03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaculaToluolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaToluolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusPetroleariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus petrolearius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusPetroleariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosocomiicoccusAmpullaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nosocomiicoccus ampullae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NosocomiicoccusAmpullaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioides7600Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides 7600 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumVerticillioides7600Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MikellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mikella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MikellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctobacteriumSuccinatutens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium succinatutens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSuccinatutens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusAdriaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus adriaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusAdriaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSp348mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. 348MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSp348mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpentinomonasRaichei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas raichei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasRaichei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermococcusOkinawensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus okinawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusOkinawensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesPombe972hEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe 972h- Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombe972hEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumGw2011gwf24332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWF24332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwf24332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaminobacterManganicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter manganicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterManganicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaGrandensisFslF60971Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria grandensis FSL F6-0971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaGrandensisFslF60971Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythiumIwayamai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pythium iwayamai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PythiumIwayamai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4718 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysemysPictaBelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta bellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChrysemysPictaBelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorientalisSpIm1011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis sp. IM1011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorientalisSpIm1011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CylindrospermumStagnaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermum stagnale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CylindrospermumStagnaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm3535Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_53_5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm3535Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraParasiticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora parasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraParasiticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacterium4128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 41-28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL3919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSp499(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp499", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrigopsHabroptilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strigops habroptila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrigopsHabroptilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaphrinaDeformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taphrina deformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaphrinaDeformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteroidesSaopaulenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides saopaulense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSaopaulenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolichospermumCircinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dolichospermum circinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DolichospermumCircinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumBrisbanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brisbanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrisbanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesThermolilacinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermolilacinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermolilacinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PersephonellaSpKm09lau8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. KM09Lau8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpKm09lau8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpW9775Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. W9775 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpW9775Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeB728a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae B728a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeB728a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho202full3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO202FULL3919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho202full3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinocyclocheilusAnshuiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus anshuiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusAnshuiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaVermifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serendipita vermifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerendipitaVermifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLondiniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella londiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaLondiniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterArseniciresistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter arseniciresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterArseniciresistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaGinsengisegetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga ginsengisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaGinsengisegetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaceaeBacteriumPmp191fEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium PMP191F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumPmp191fEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaYuzhufengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia yuzhufengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaYuzhufengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenulisporaAcidiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenulispora acidiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenulisporaAcidiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumNodulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium nodulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumNodulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifcsplowo202full4814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO202FULL4814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo202full4814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPLOWO2_01_FULL_45_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCrudilactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium crudilactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCrudilactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansAtcc11563(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans ATCC11563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansAtcc11563", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorallococcusSpCag1435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus sp. CAG:1435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorallococcusSpCag1435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumMor1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Mor1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumMor1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMandeliiPd30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii PD30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandeliiPd30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumDolichumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium dolichum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDolichumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaLuteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma luteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLuteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaCoronataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capronia coronata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaproniaCoronataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTsri0107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4518Fw2643Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4518 (FW-2643) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4518Fw2643Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOtakiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus otakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOtakiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtheneCunicularia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Athene cunicularia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtheneCunicularia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_38_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_39_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacterialesBacteriumUtchb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteriales bacterium UTCHB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacterialesBacteriumUtchb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraMesophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraMesophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaeBacteriumDg1235Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobiae bacterium DG1235 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaeBacteriumDg1235Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevirhabdusPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevirhabdus pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevirhabdusPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaPersicina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia persicina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPersicina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLongbeachaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella longbeachae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaLongbeachaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LatesCalcariferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lates calcarifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LatesCalcariferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumCg2303729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium CG2_30_37_29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumCg2303729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7SakaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Sakai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7SakaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. 28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraSp28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpPamc26640Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PAMC 26640 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPamc26640Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaViolaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella violacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaViolaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogeaDsm11164Nbrc106472Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea DSM 11164 NBRC 106472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudothermotogaHypogeaDsm11164Nbrc106472Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHlucco07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0430Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0430 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpF0430Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfobacillusAcidophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumImcc3088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium IMCC3088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumImcc3088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGrimmiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia grimmiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaGrimmiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColi536(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli 536 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColi536", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPlatycodiJcm25414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi JCM 25414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiJcm25414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetovibrioBlakemorei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetovibrio blakemorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetovibrioBlakemorei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumCg2303729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium CG2303729 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumCg2303729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRoot154(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot154", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladusLaminosusUu774Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus UU774 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MastigocladusLaminosusUu774Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumUlceransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumUlceransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterPiechaudiiAtcc43553Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii ATCC43553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiAtcc43553Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobutyricumHalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobutyricum hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobutyricumHalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaOleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea olei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaOleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParalimentariusDsm19674Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius DSM 19674 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParalimentariusDsm19674Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobiusVpi4330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius VPI4330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobiusVpi4330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusSpLeaf369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. Leaf369 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpLeaf369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraHakonensisJcm8857Dsm7519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis JCM 8857 DSM 7519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensisJcm8857Dsm7519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Belnapia rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BelnapiaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumM181Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium M181 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumM181Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumKocuriiJcm14978Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum kocurii JCM 14978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumKocuriiJcm14978Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag245Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag245Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwb11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorickettsiaSp179522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sp. 179522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSp179522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDesulfopertinaxCoweniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfopertinax cowenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfopertinaxCoweniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesDaqusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces daqus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesDaqusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioKanaloaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio kanaloae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioKanaloaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumCg1023744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLatescibacterAnaerobiusScgcAaa252E07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Latescibacter anaerobius SCGC AAA252-E07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLatescibacterAnaerobiusScgcAaa252E07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilunaSpImcc13023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. IMCC13023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpImcc13023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaMalonica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa malonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporomusaMalonica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf2429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf2429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSinuspersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sinuspersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSinuspersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CosenzaeaMyxofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemominutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemominutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemominutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusFerrooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus ferrooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusFerrooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil774Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil774Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusBvHnlc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenimonasThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenimonas thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenimonasThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSp31syn3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 31syn3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp31syn3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tectomicrobia bacterium RIFCSPLOWO2_02_FULL_70_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMagnumDsm2767Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium magnum DSM 2767 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMagnumDsm2767Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumCsp14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium CSP1-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumCsp14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho202full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL4114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSaburreumF0468Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum F0468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumF0468Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxNanhaiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxNanhaiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiAbcpw111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei ABCPW111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiAbcpw111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpGa6a2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. Ga6A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpGa6a2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_46_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaBelliiRml369c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii RML369C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiRml369c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpTgly2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TGLY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTgly2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaMonacensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia monacensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaMonacensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterPhosphatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter phosphatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterPhosphatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHygroscopicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCoccineaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trametes coccinea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrametesCoccineaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacaMethylaminivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibaca methylaminivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacaMethylaminivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpRoot81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Root81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpRoot81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycetaceaeBacteriumMp11305Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomycetaceae bacterium MP113-05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycetaceaeBacteriumMp11305Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpA9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. A9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpA9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumTwa4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TWA4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTwa4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusParaburkholderiaKirkiiUzhbot1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Paraburkholderia kirkii UZHbot1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusParaburkholderiaKirkiiUzhbot1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrauserellaRugosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prauserella rugosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrauserellaRugosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaBryophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bryophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBryophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMedpeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MedPE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMedpeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalalkalibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halalkalibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalalkalibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaPleuritidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pleuritidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPleuritidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospirillumFerriphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesSpLeaf222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Leaf222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpLeaf222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonBa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaOakridgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella oakridgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaOakridgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo212full6140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwf24415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWF24415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwf24415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallionellalesBacteriumGwa25518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_55_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa25518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistliaConsotensisUsba355Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tistlia consotensis USBA 355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TistliaConsotensisUsba355Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumOxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarcicellaHirudinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudarcicella hirudinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudarcicellaHirudinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicronemaHongdechlorisC2206(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris C2206 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomicronemaHongdechlorisC2206", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpBjgmmb45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. BJGMMB45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpBjgmmb45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilunaSpImcc13023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. IMCC13023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpImcc13023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UstilaginoideaVirensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ustilaginoidea virens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UstilaginoideaVirensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSanfranciscensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sanfranciscensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSanfranciscensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaSucciniciproducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia succiniciproducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSucciniciproducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumCpb6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium CPB6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCpb6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeBacterium16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium 16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacterium16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp351mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 351MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp351mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo212full6819Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6819 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6819Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpNfr15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFasciculatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fasciculatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumFasciculatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteri10023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri 10023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteri10023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GrosmanniaClavigeraKw1407(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera kw1407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GrosmanniaClavigeraKw1407", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicavibrioAeruginosavorusEpbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus EPB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusEpbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterArboriphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo2023512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_02_35_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo2023512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBrassicacearumSubspBrassicacearumNfm421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum subsp. brassicacearum NFM421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearumSubspBrassicacearumNfm421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasAsaccharolyticaNbrc15499Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica NBRC 15499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolyticaNbrc15499Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag594Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag594Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPeoriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus peoriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPeoriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumMelanogenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfatatorAutotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator autotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAutotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpErv7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ERV7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpErv7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumDecipiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium decipiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumDecipiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumSg839Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg839Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpUrhd0069Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHD0069 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrhd0069Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria fleischmannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaFleischmanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPyloriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pylori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPyloriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusParacuniculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paracuniculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParacuniculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaInulinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia inulinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaInulinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpF0370(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0370 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0370", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwb1378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloversatilisUniversalisEhg5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis EHg5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisEhg5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaAldovaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia aldovae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaAldovaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpMarseillep2426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. MarseilleP2426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpMarseillep2426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumOleivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oleivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOleivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNcu2d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCu2D-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNcu2d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasInfelixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas infelix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasInfelixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GulosibacterMolinativoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gulosibacter molinativorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GulosibacterMolinativoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTetaniE88Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetani E88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTetaniE88Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProcaviaCapensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Procavia capensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProcaviaCapensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCereusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCereusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGingeriNcppb3146Lmg5327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri NCPPB 3146 LMG 5327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasGingeriNcppb3146Lmg5327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionisporaSp2237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionispora sp. 2/2-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionisporaSp2237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthocheilonemaViteaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acanthocheilonema viteae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcanthocheilonemaViteaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUrinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus urinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUrinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaitozymaPodzolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saitozyma podzolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaitozymaPodzolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpCs1gbmeth3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1GBMeth3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1gbmeth3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_12_FULL_48_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpAr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. AR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitrosopumilusSpAr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaCaldarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema caldarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaCaldarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpNo7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpNo7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacterium13220cm6814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 13_2_20CM_68_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium13220cm6814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaHubeiensisSy62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis SY62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudozymaHubeiensisSy62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTenderiaElectrophagaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tenderia electrophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTenderiaElectrophagaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusThermophilusHb27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaShakespeareiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella shakespearei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaShakespeareiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHelveticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHelveticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumFlavigenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium flavigenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFlavigenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaSolidipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armillaria solidipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmillariaSolidipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp7243faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 7243FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp7243faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusPhosphorivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus phosphorivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FictibacillusPhosphorivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumChoanaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium choanae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumChoanaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumRubi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rubi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumRubi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterMusarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter musarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterMusarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL4515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpH83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. H83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpH83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NisaeaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nisaea denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NisaeaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacaMethylaminivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibaca methylaminivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacaMethylaminivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu053Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu053Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho201full5431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVietnamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vietnamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVietnamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacillusLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaoerskoviaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraoerskovia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaoerskoviaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoplasmaTermitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoplasma termitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoplasmaTermitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasSpFcs9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. FCS-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpFcs9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllobaculumStercoricanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allobaculum stercoricanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllobaculumStercoricanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvularculaOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumGw2011gwc24417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC24417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc24417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full5223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL5223 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full5223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaAtrilutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella atrilutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaAtrilutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu032Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU032 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu032Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumCyclohexanicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium cyclohexanicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumCyclohexanicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterVinaykumarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter vinaykumarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterVinaykumarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaShimofusensisNbrc100134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis NBRC 100134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaShimofusensisNbrc100134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLz4w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Lz4W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpLz4w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumAsp1004aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium ASP10-04a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumAsp1004aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnobacteriumBovisDsm14045Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis DSM 14045 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnobacteriumBovisDsm14045Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethermicoccusShengliensisDsm18856(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis DSM 18856 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethermicoccusShengliensisDsm18856", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensDsm10105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens DSM10105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensDsm10105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpCal575(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. CAL575 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpCal575", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpA47Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. A47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpA47Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD1_FULL_39_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusParasiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusParasiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixRhusiopathiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix rhusiopathiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixRhusiopathiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesOdoratimimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratimimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratimimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpMt41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. MT41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpMt41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa1377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_37_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa1377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaAcuminataSubspMalaccensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata subsp. malaccensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MusaAcuminataSubspMalaccensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypothrixSpPcc7601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix sp. PCC 7601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolypothrixSpPcc7601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterTandoiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tandoii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTandoiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraSpMccc1a02491Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A02491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a02491Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosotenuisCloacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis cloacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisCloacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSaskatchewanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium saskatchewanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSaskatchewanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AustwickiaChelonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Austwickia chelonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AustwickiaChelonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaTrachomatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CavenderiaFasciculataSh3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata SH3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CavenderiaFasciculataSh3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPastoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Komagataella pastoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPastoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium5039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 50-39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium5039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumAquatileDsm21506Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile DSM 21506 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumAquatileDsm21506Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisZeicola26R13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola 26-R-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BipolarisZeicola26R13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3610bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3610b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3610bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBogoriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bogoriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusBogoriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpG2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpG2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidiaBacteriumSm23282(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoidia bacterium SM23_28_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidiaBacteriumSm23282", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHel133143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. Hel1_33_143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpHel133143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumVincentii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCantharicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma cantharicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCantharicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAap1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCylindrosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaphaeosphaeriaSporulosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraphaeosphaeria sporulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaphaeosphaeriaSporulosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlenkiaTaihuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klenkia taihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlenkiaTaihuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiritimatiellaGlycovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kiritimatiella glycovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KiritimatiellaGlycovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPrimitiaZas2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumNiveocremeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcococcusKunziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus kunzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelcococcusKunziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOrisasiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisasini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisasiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaAlgicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordia algicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiaAlgicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaTenuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaTenuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioMagneticusRs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus RS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusRs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpEprs66(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EpRS66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEprs66", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWeiliiSerovarRanarumStrIcft(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira weilii serovar Ranarum str. ICFT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWeiliiSerovarRanarumStrIcft", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSilageiJcm19001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus silagei JCM 19001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSilageiJcm19001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasSpBrl61Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas sp. BRL61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TolumonasSpBrl61Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NakamurellaMultipartita(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella multipartita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NakamurellaMultipartita", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlutamicibacterSp0426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter sp. 0426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterSp0426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlcaligenesNbrc14159Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes NBRC14159 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenesNbrc14159Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeHs11286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae HS11286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeHs11286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaegleriaGruberiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Naegleria gruberi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NaegleriaGruberiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0430(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0430 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpF0430", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaAlgaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella algae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAlgaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusMaliNbrc102425(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali NBRC 102425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusMaliNbrc102425", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelftiaAcidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Delftia acidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DelftiaAcidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcaryochlorisMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acaryochloris marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcaryochlorisMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterSegnis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter segnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSegnis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaInsecticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia insecticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaInsecticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParauberis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parauberis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParauberis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaAnsorpiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella ansorpii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaAnsorpiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium czechense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumCzechenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls149Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS149 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls149Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumCommuneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumCommuneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaVacciniiNbrc15922Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vaccinii NBRC 15922 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaVacciniiNbrc15922Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusMaripaludisC7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusPinatubonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pinatubonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPinatubonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisUniversalisEhg5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis EHg5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisEhg5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyc2full3412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYC2FULL3412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyc2full3412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PocilloporaDamicornisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pocillopora damicornis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PocilloporaDamicornisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalieaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haliea rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalieaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt318(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCnt318", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpCmf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpCmf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicractiniumConductrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micractinium conductrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicractiniumConductrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSp7101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. 7101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSp7101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusThermoglucosidasiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermoglucosidasius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusThermoglucosidasiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MollicutesBacteriumHr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpMit975078(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. MIT975078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpMit975078", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisKctc3167Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis KCTC3167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisKctc3167Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaHofmannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIndolis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium indolis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIndolis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacterFastidiosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacter fastidiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoprobacterFastidiosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiaeAtcc27957Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae ATCC27957 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeAtcc27957Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaTrevisaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia trevisanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaTrevisaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPutrefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella putrefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPutrefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaFuscipesFuscipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glossina fuscipes fuscipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlossinaFuscipesFuscipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WheatBlueEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wheat blue Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WheatBlueEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaXylanovoransDsm12503Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans DSM 12503 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovoransDsm12503Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumCryptumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium cryptum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumCryptumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumIndicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium indicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumIndicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusHermanniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hermanniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHermanniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelleaBalneolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hellea balneolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelleaBalneolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacterFormigenesOxcc13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes OXCC13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesOxcc13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterTrogontumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter trogontum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTrogontumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumOxidotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium oxidotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumOxidotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisKunsanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis kunsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisKunsanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliifodinibiusRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliifodinibius roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliifodinibiusRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSteckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium steckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSteckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaAcetivoransC2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans C2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivoransC2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumSinecaudumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium sinecaudum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EremotheciumSinecaudumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumJohnsoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium johnsoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumJohnsoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSyntrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter syntrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSyntrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeifsoniaSp109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full6025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL6025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full6025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpNsub(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. Nsub graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpNsub", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_12_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumLacusprofundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lacusprofundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLacusprofundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSordidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sordidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSordidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpLs16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. LS16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLs16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSediminumDsm21906Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sediminum DSM 21906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSediminumDsm21906Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCongonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides congonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCongonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAcridumCqma102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum CQMa 102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAcridumCqma102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella haemolysans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaHaemolysansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorDanieliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor danielii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorDanieliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_42_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12747610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274761.0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScabrisporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabrisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabrisporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpWsm2230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WSM2230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWsm2230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpM240Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. M240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpM240Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GillisiaSpJm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. JM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpJm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSenegalimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AurantimonasSpLeaf443Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. Leaf443 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSpLeaf443Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoemansiaReversaNrrl1564(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coemansia reversa NRRL 1564 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoemansiaReversaNrrl1564", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterGlucosidilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter glucosidilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterGlucosidilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusSpBg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHsism1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HSISM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpHsism1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpMarseille(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. Marseille graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpMarseille", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho202full4012bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO202FULL4012b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho202full4012bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEi5cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EI5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEi5cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasTerrigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerrigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaToletanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia toletana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaToletanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LyngbyaSpPcc8106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lyngbya sp. PCC8106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LyngbyaSpPcc8106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc04h06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC04H06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc04h06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilifactorAlocisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Filifactor alocis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FilifactorAlocisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpAmp6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. amp6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CupriavidusSpAmp6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpKbs0721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KBS0721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKbs0721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuis22083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 22083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuis22083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaVirilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila virilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaVirilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwd23827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWD2_38_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwd23827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraJadiniiNrrlY1542Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii NRRL Y-1542 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyberlindneraJadiniiNrrlY1542Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonJdfr11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon JdFR-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonJdfr11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalibacteriumQingdaonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium qingdaonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumQingdaonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumMercanteiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium mercantei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMercanteiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumWg36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium WG36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumWg36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatesCalcarifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lates calcarifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LatesCalcarifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr7277Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR7277 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr7277Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFuscansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fuscans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasFuscansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrmitellaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Urmitella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrmitellaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpYcrl4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. YCRL4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpYcrl4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNuni2hmbin003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortieraAleyrodidarumBtbhrs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum BTBHRs graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumBtbhrs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSpSg02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. SG02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpSg02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RufibacterRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpHmsc071c03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC071C03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc071c03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiMethylbutyraticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei methylbutyratica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiMethylbutyraticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanohalarchaeumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanohalarchaeum thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanohalarchaeumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPeli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas peli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPeli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRbg133615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_36_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg133615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusKukulkanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus kukulkanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusKukulkanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPHIGHO2_01_FULL_65_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_46_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterGinsenosidimutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ginsenosidimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterGinsenosidimutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpLnhc252b00Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNHC252B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnhc252b00Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchwartziaSuccinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchwartziaSuccinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumPhenoxybenzoativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium phenoxybenzoativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumPhenoxybenzoativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaPelagiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Henriciella pelagia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HenriciellaPelagiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IchthyophthiriusMultifiliisStrainG5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis strain G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliisStrainG5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusLacrimalisDsm7455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis DSM 7455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalisDsm7455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlycinophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glycinophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumGlycinophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSmegmatisJs623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis JS623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisJs623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNovofumigatusIbt16806Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus IBT 16806 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusNovofumigatusIbt16806Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumPuteiDsm12395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei DSM 12395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumPuteiDsm12395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotodesmusKatoptronEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus katoptron Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusKatoptronEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumNitrativoransNl23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans NL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativoransNl23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutibacterProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutibacterProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanifilumFulgidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planifilum fulgidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanifilumFulgidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsSpCamponotisaundersiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotisaundersi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotisaundersiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosotenuisUzonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis uzonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisUzonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumFreireiPrf81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium freirei PRF 81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumFreireiPrf81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OtolemurGarnettiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Otolemur garnettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OtolemurGarnettiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaBillingiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia billingiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaBillingiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_48_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusPrevotiiDsm20548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii DSM20548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiDsm20548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaWallisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea wallisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaWallisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNomius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nomius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusNomius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusArachidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus arachidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusArachidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLeaf58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumOxidoreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium oxidoreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumOxidoreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lindowbacteria bacterium RIFCSPLOWO2_12_FULL_62_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6247(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6247", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterorhabdusCaecimuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus caecimuris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusCaecimuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpT32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. T32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpT32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiariaAnomala(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tilletiaria anomala graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TilletiariaAnomala", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12Mg1655Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 MG1655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12Mg1655Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPropionicifaciensDsm19291Jcm14649Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens DSM 19291 JCM 14649 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciensDsm19291Jcm14649Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumTolulyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum tolulyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AromatoleumTolulyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpPm2p129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. PM2P129 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpPm2p129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumTropicale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum tropicale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumTropicale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp31y(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 31Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp31y", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpImcc9063(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. IMCC9063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpImcc9063", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesDerwentensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes derwentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesDerwentensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRumoiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rumoiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioRumoiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwc23926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_39_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc23926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCapricolumSubspCapripneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum subsp. capripneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaCapricolumSubspCapripneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeckwithbacteriaBacteriumRifcsphigho212full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RIFCSPHIGHO212FULL4717 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRifcsphigho212full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacterium4484171Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484171Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumNitrogenifigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium nitrogenifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumNitrogenifigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillerozymaFarinosaCbs7064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa CBS 7064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MillerozymaFarinosaCbs7064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonadaceaeBacteriumBrhc29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium BRHc29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumBrhc29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpA12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpA12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlobicatellaSulfidifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPhleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium phlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPhleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNk4a144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A144 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMuelleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMuelleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMalefermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus malefermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMalefermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCremoricolorataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cremoricolorata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCremoricolorataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumOraleDsm12838Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale DSM 12838 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumOraleDsm12838Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoluteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoluteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseoluteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1995(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1995", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SoleaferreaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Soleaferrea massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SoleaferreaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PercaFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Perca flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PercaFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL3919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumLlatzerenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium llatzerense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLlatzerenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAnisopliaeBrip53293Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae BRIP 53293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliaeBrip53293Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusIntermedius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIntermedius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPerolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus perolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPerolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliterellaAtlanticaCena595Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliterella atlantica CENA595 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AliterellaAtlanticaCena595Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSaanichensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tatumella saanichensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TatumellaSaanichensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaMollaretiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia mollaretii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaMollaretiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwc14710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWC14710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwc14710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterDelicatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter delicatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurvibacterDelicatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutisporaThermophilaDsm19022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lutispora thermophila DSM 19022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LutisporaThermophilaDsm19022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full487(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL487 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full487", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicocarpusGriseusUamh5409(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicocarpus griseus UAMH5409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicocarpusGriseusUamh5409", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharolobusSolfataricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharolobus solfataricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharolobusSolfataricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIec1808(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IEC1808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIec1808", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSpiritensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella spiritensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSpiritensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaP74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila P74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaP74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSpT436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. T436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpT436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpKbs0703Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. KBS0703 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpKbs0703Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAbyssalisTar001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis TAR-001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalisTar001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumCsp16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium CSP16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumCsp16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumCg2303616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG2_30_36_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg2303616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumOphioglossoidesCbs100239Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides CBS 100239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoidesCbs100239Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaCinnabarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Loktanella cinnabarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LoktanellaCinnabarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaucusCarotaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daucus carota Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaucusCarotaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisZeicola26R13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola 26-R-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BipolarisZeicola26R13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpinosispora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosispora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpTw10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. TW10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnsiferSpTw10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpF0418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp5ratimar09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 5RATIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp5ratimar09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeAr39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae AR39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeAr39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrifoliumPratenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trifolium pratense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrifoliumPratenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaPickettiiDtp0602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii DTP0602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettiiDtp0602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsMilitarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps militaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CordycepsMilitarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvoviolaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fulvoviolaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFulvoviolaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf24131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_41_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PercaFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Perca flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PercaFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumGw2011Gwa14610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium GW2011_GWA1_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumGw2011Gwa14610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpEb01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. EB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpEb01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlpinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alpinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlpinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf2479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF2479 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf2479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraTerpenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera terpenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraTerpenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacibacteriumNormanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacterium normanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacibacteriumNormanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpAcs4054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho212full4519bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO212FULL4519b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho212full4519bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifoxyd2full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD2FULL4114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd2full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaPneumotropica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella pneumotropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaPneumotropica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesDistasonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides distasonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesDistasonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNtMorphotypeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nt morphotype Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNtMorphotypeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAdolescentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg135024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_50_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg135024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpDd12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumPavilionensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium pavilionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumPavilionensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpOv219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OV219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOv219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwb14719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWB14719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwb14719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisKc583Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis KC583 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisKc583Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomagnumIshizawai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomagnum ishizawai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomagnumIshizawai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusGnavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gnavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGnavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterTropicalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterTropicalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonadalesBacteriumGa0077559(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077559", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermokryptusMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermokryptus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermokryptusMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisa53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisA53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisa53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumGa0077559Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077559 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077559Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSp20gpm1509mEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. 20GPM1509m Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSp20gpm1509mEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAbscessusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia abscessus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAbscessusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacaMethylaminivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibaca methylaminivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacaMethylaminivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterInsulaenigraeNctc12927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae NCTC 12927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigraeNctc12927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLentusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lentus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLentusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSp9135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobotrysOligosporaAtcc24927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora ATCC 24927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobotrysOligosporaAtcc24927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaNativa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNativa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwf24113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWF2_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwf24113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpPacm27299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. PACM 27299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpPacm27299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamadaeaTsunoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hamadaea tsunoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HamadaeaTsunoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsialesBacteriumExBugulaNeritinaAb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsialesBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritaleaMyrionectae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maritalea myrionectae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaritaleaMyrionectae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumStraminisolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlagellimonasEckloniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas eckloniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasEckloniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLutrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lutrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLutrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpWsm2230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WSM2230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWsm2230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusHaemoperoxidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus haemoperoxidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHaemoperoxidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesMethylutensMm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens MM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutensMm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyncephalastrumRacemosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syncephalastrum racemosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyncephalastrumRacemosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudohongiellaActicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella acticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaActicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_43_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosumFd172Ss1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum FD-172 SS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosumFd172Ss1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhlebiaCentrifugaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phlebia centrifuga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhlebiaCentrifugaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumValentinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium valentinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumValentinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho201full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAquaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium aquaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAquaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylonaHeveaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylona heveae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylonaHeveaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParusMajorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parus major Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParusMajorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumResistensNbrc103078(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium resistens NBRC 103078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumResistensNbrc103078", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetaceaeBacteriumBa112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetaceae bacterium BA112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycetaceaeBacteriumBa112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecropsobacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpLpb0137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LPB0137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLpb0137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumGa0077535Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium Ga0077535 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGa0077535Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SlackiaPiriformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Slackia piriformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SlackiaPiriformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPHIGHO2_02_FULL_52_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaCepaciaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cepacia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCepaciaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5411bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5411b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5411bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBiviaDnf00188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia DNF00188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaDnf00188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpOralTaxon847Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 847 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon847Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPLOWO2_12_FULL_35_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanibacillusModesticaldusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulcanibacillus modesticaldus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulcanibacillusModesticaldusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraFainei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira fainei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraFainei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraAustraliensisBen110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Ben110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensisBen110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusAneurinilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus aneurinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusAneurinilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMohniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mohnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMohniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyosteliumDiscoideumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium discoideum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumDiscoideumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSp112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 1_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpMi1205Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. MI1205 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpMi1205Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaClarridgeiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella clarridgeiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaClarridgeiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm1253(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1253", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24668Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24668 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24668Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaArvensicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga arvensicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaArvensicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DraconibacteriumSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaProfundaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga profunda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaProfundaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4332bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4332b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4332bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpSoil750(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil750 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil750", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionicicellaSuperfundiaDsm22317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionicicella superfundia DSM 22317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundiaDsm22317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpPamc22219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. PAMC22219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpPamc22219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpTca20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. TCA20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpTca20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJ37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJ37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolymyxaSc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa SC2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaSc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PundamiliaNyerereiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pundamilia nyererei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PundamiliaNyerereiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSenmaizukeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TulasnellaCalosporaMut4182Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tulasnella calospora MUT 4182 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TulasnellaCalosporaMut4182Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioAscidiaceicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio ascidiaceicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAscidiaceicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferacaceaeArchaeonB1Br10E2g22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon B1-Br10_E2g22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeonB1Br10E2g22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumCoryneformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium coryneforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCoryneformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnicellularCyanobacteriumSu2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium SU2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UnicellularCyanobacteriumSu2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterSuarezii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSuarezii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpSm9913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. SM9913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpSm9913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMacerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMacerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaVelesianaGillSymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Solemya velesiana gill symbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SolemyaVelesianaGillSymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niabella aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiabellaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAnt303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ant303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAnt303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaGlabrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida glabrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaGlabrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterAzorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDigitatumPhi26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum PHI26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliumDigitatumPhi26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapillibacterCinnamivoransDsm12816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans DSM 12816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PapillibacterCinnamivoransDsm12816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NodulariaSpumigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nodularia spumigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NodulariaSpumigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpiritivorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium spiritivorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpiritivorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrateuriaAurantiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frateuria aurantia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrateuriaAurantiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacteriumLuteolumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium luteolum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumLuteolumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HumibacillusSpDsm29435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Humibacillus sp. DSM 29435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HumibacillusSpDsm29435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPLOWO2_01_FULL_43_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilalesBacteriumLsucc0135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium LSUCC0135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumLsucc0135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenophonusTriatominarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus triatominarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusTriatominarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CastorCanadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Castor canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CastorCanadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpL250(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L250 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpL250", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLigniniphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ligniniphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLigniniphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaSpDsm29012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. DSM 29012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpDsm29012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubidibacterLacunae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubidibacter lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubidibacterLacunae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPalustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioPalustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaRiboflavinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia riboflavina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaRiboflavinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloprevotellaTanneraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella tannerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaTanneraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CognatiyooniaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsplowo212full5310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_02_FULL_51_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumScatologenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scatologenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScatologenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpY57Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Y57 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpY57Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferAgarilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAgarilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBifermentansDsm20003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans DSM 20003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBifermentansDsm20003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium6579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-79 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSp6rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. 6R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSp6rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumNebraskenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium nebraskense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNebraskenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ManihotEsculentaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Manihot esculenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ManihotEsculentaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumSteckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium steckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSteckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpA16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. A16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpA16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrusXBretschneideriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrus x bretschneideri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyrusXBretschneideriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunoko(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunoko", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKyorinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kyorinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKyorinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpNfacc26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. NFACC26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpNfacc26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaFlavescensNrl30031h210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens NRL30031H210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensNrl30031h210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrientiaChutoStrDubaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Orientia chuto str. Dubai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OrientiaChutoStrDubaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumXbb1006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB1006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb1006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumAzadirachtae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium azadirachtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAzadirachtae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciens007cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens 007c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciens007cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGlacialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlacialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumDtu059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicellaActignisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicella actignis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicellaActignisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MailhellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mailhella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MailhellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterMustelaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter mustelae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMustelaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumXenopiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium xenopi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumXenopiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumCongolenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium congolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumCongolenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosynechococcusElongatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus elongatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusElongatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisNctc12261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis NCTC 12261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisNctc12261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FortieaContorta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fortiea contorta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FortieaContorta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRifcsphigho201full6931Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. RIFCSPHIGHO201FULL6931 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRifcsphigho201full6931Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag545Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:545 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag545Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpSt04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. ST04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpSt04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParameciumTetraurelia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paramecium tetraurelia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParameciumTetraurelia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndozoicomonasMontiporae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLentusNbrc16444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lentus NBRC 16444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusLentusNbrc16444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_57_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpOralTaxon920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12747566(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274756.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747566", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusAminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus aminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumXenophagum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium xenophagum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumXenophagum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaSolani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaSolani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_12_FULL_38_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRu36dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU36D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu36dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbidosporaCretacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora cretacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaCretacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOryziterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oryziterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusOryziterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymomonasMobilisZm4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ZM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisZm4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaGlobisporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina globispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaGlobisporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenobacterLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenobacterLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaledivibacterHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maledivibacter halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaledivibacterHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 37-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumArbustiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium arbusti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArbustiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HepatoplasmaCrinochetorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hepatoplasma crinochetorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HepatoplasmaCrinochetorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGhanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGhanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC2_FULL_36_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumCellobioparumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellobioparum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellobioparumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpCag409Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. CAG:409 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpCag409Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseochromogenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeonScgcAaa471b05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon SCGC AAA471B05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeonScgcAaa471b05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnh287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH287 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFukatsuiaSymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fukatsuia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFukatsuiaSymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpSk643Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpSk643Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermobacterSpCat2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter sp. CaT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterSpCat2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaAerogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella aerogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaAerogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCrudilactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium crudilactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCrudilactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc074e01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC074E01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc074e01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumHtcc2255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium HTCC2255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumHtcc2255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMucosaeLm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae LM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMucosaeLm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPanipatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas panipatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPanipatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaCostaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga costaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaCostaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumCsp14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium CSP1-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumCsp14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaPseudospiralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella pseudospiralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPseudospiralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaLanzarotensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachancea lanzarotensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachanceaLanzarotensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig2bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc7217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCatenulatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium catenulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumCatenulatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumPapyrosolvensDsm2782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens DSM 2782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensDsm2782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaHospitaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia hospita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaHospitaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidibacterFormicigenesDsm15518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes DSM 15518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TepidibacterFormicigenesDsm15518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaOneidensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella oneidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaOneidensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfospiraJoergenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfospira joergensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfospiraJoergenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb1446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB1_44_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb1446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusLactisCremorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis cremoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisCremorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuribaculumIntestinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muribaculum intestinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuribaculumIntestinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumTrifoliiCb782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii CB782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiCb782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesantisbacteriaBacteriumCg2304021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG2304021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg2304021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumValvarumF0432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum F0432 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CardiobacteriumValvarumF0432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDidelphis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus didelphis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDidelphis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterobasidionIrregulareTc321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare TC 32-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HeterobasidionIrregulareTc321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeeksellaVirosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weeksella virosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeeksellaVirosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRifcsplowo202full7116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RIFCSPLOWO202FULL7116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRifcsplowo202full7116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHeckeshornenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heckeshornense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeckeshornenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilomicrobiumInsigne(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Filomicrobium insigne graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FilomicrobiumInsigne", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisAd2017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis AD2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisAd2017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusCcmp1375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus CCMP1375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusCcmp1375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaSp5064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 50_64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp5064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovibrioSalinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovibrio salinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovibrioSalinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisAtcc49296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC49296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc49296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasBennonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas bennonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasBennonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaLoihiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina loihiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaLoihiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabilibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabilibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusReuszeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus reuszeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusReuszeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaSpY9602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rahnella sp. Y9602 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RahnellaSpY9602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalioglobusJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalioglobusJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumOleivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOleivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsphigho201full6320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL6320 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full6320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusTrichosporium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus trichosporium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosinusTrichosporium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpNsp21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP2.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpNsp21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JoostellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Joostella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JoostellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGinsengihumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ginsengihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGinsengihumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMargulisbacteriaBacteriumGwd239127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWD2_39_127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwd239127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_12_FULL_38_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFonticolaAuap2cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola AUAP2C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaAuap2cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPuniceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium puniceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPuniceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasAsaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasAsaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenesCect7868(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio aerogenes CECT 7868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioAerogenesCect7868", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpHl111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. HL-111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpHl111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeolentinusLepideusHhb14362Ss1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neolentinus lepideus HHB14362 ss-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeolentinusLepideusHhb14362Ss1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwc12715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC1_27_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc12715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctopirusHydrillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus hydrillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusHydrillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaCincinnatiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella cincinnatiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaCincinnatiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaAtlantae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella atlantae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaAtlantae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PomaceaCanaliculata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pomacea canaliculata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PomaceaCanaliculata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc074e01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC074E01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc074e01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpE463Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. E463 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpE463Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPolynesiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium polynesiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolynesiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViridochromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridochromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumBavaricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAlbilineans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas albilineans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAlbilineans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSediminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sediminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSediminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexCornetziCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex cornetzi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexCornetziCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiberibacterAfricanusPtsapsyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liberibacter africanus PTSAPSY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiberibacterAfricanusPtsapsyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusAcidocaldariusSusaz(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius SUSAZ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusSusaz", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OligotrophaCarboxidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oligotropha carboxidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OligotrophaCarboxidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KorarchaeumCryptofilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Korarchaeum cryptofilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KorarchaeumCryptofilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaminobacterSalicylatoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter salicylatoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterSalicylatoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlkylphenolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AvibacteriumParagallinarum72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterWoliniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterWoliniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas testosteroni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasTestosteroniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesCerinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces cerinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesCerinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumAgarivoransDs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans DS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransDs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleispiraAntarcticaRb8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oleispira antarctica RB-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OleispiraAntarcticaRb8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimenticolaSelenatireducensDsm17993Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens DSM 17993 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducensDsm17993Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpongiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpongiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterNecessariusAsymbioticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius asymbioticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusAsymbioticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasByunsanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas byunsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasByunsanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpH133Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. H133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSpH133Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodococcusSpAk35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus sp. AK35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiorhodococcusSpAk35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaEndosymbiontOfAmblyommaAmericanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont of Amblyomma americanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiontOfAmblyommaAmericanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo201full4810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO201FULL4810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo201full4810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenarchaeotaArchaeon13140cm35210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpPsnih1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumYuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium yurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumYuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpPh1c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. PH1c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpPh1c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisUniversalisFam5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis FAM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisFam5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMelainabacteriaBacteriumGwf23715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWF2_37_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwf23715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporichthyaPolymorphaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporichthya polymorpha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporichthyaPolymorphaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaVariansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria varians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaVariansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpP5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. P5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpP5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoniaMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesonia mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoniaMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovibacterSpMfb070(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter sp. MFB070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MangrovibacterSpMfb070", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpZg627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. ZG627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpZg627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiobacterAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dethiobacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DethiobacterAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLz4wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Lz4W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpLz4wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterAerogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter aerogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAerogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpF0581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusToleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius tolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusToleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumBohemicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium bohemicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumBohemicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollichthysLucidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collichthys lucidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollichthysLucidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitromicrobiumBathyomarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium bathyomarinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitromicrobiumBathyomarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHydrogenedentesBacteriumCg1024214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrogenedentes bacterium CG1_02_42_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrogenedentesBacteriumCg1024214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumPaludisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium paludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumPaludisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBovis914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis 914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovis914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraSpSoil756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera sp. Soil756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraSpSoil756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusCallidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus callidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusCallidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoculleusHoronobensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus horonobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusHoronobensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaAtrinaeC38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kocuria atrinae C3-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KocuriaAtrinaeC38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSpA13l(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. A13L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpA13l", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSalifodinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus salifodinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusSalifodinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaPsychrerythraeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumRifcsphigho201full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO201FULL4114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho201full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterMediterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter mediterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMediterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSpJc4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. JC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpJc4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaGb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida GB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaGb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho201full3819(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3819 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3819", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenustampullaEchinocandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Venustampulla echinocandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VenustampullaEchinocandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPsychrerythraea34h(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea 34H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraea34h", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisSaalfeldensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis saalfeldensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSaalfeldensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13120cm25314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_20CM_2_53_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13120cm25314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SucciniclasticumRuminisDsm9236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis DSM 9236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SucciniclasticumRuminisDsm9236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho202full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO202FULL4712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho202full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusHalodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacillusHalodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinellusMicaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprinellus micaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprinellusMicaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CharadriusVociferus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Charadrius vociferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CharadriusVociferus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusAlbusJl83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus JL83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbusJl83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacteraceaeBacteriumGwc25844Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_58_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25844Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisNattoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis natto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisNattoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumKroppenstedtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKroppenstedtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZosteraMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zostera marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZosteraMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpIbun(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. IBUN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpIbun", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsphigho202full4513b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO202FULL4513b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho202full4513b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpJcc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. JCC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpJcc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumXylanophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium xylanophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumXylanophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonsdaleaBritannica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea britannica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaBritannica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyperthermusButylicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyperthermus butylicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyperthermusButylicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpLeaf291(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Leaf291 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpLeaf291", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesClavuligerusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces clavuligerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesClavuligerusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaTaeniospiralisNbrc102512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis NBRC 102512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralisNbrc102512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NafulsellaTurpanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nafulsella turpanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NafulsellaTurpanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumPhox21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium Phox-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumPhox21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSuaedaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia suaedae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSuaedaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastacembelusArmatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mastacembelus armatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MastacembelusArmatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedosphaeraParvulaEllin514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Ellin514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PedosphaeraParvulaEllin514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat14578Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-14578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat14578Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGlycerinitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces glycerinitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGlycerinitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TeredinibacterTurneraeT7901Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7901 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7901Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFloricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus floricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFloricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumAquaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAquaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioExovorus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio exovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioExovorus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUlceransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlceransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh5701(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 5701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SynechococcusSpWh5701", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPalustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio palustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioPalustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisTessellariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis tessellarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisTessellariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusOryzaeRib40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae RIB40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusOryzaeRib40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterInsolitusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter insolitus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterInsolitusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPiscicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piscicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiscicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterMrazii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter mrazii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMrazii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumJoshi001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium JOSHI001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumJoshi001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RouxiellaBadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella badensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RouxiellaBadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaCinerea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCinerea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThiodiazotrophaEndoloripes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endoloripes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndoloripes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpBl107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. BL107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpBl107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachypodiumDistachyonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachypodium distachyon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachypodiumDistachyonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallaecimonasXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaMarinistellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria marinistellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaMarinistellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumSalamandrivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium salamandrivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumSalamandrivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterSp4636Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. 46_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSp4636Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantisSk1076Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK1076 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk1076Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraLicerasiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira licerasiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraLicerasiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraElsdeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera elsdenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraElsdeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpNctc13003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. NCTC 13003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpNctc13003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarimonasRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonas rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinarimonasRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterPsychrotoleransDsm18569(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans DSM 18569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HymenobacterPsychrotoleransDsm18569", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJs623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JS623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpJs623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaArgentinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaArgentinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaHispanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula hispanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaHispanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumBacl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterRoseosalivariusDsm11622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius DSM 11622 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivariusDsm11622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaGlyceriniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moorella glycerini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoorellaGlyceriniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYr528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongyloidesRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumCg1024331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG1_02_43_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg1024331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarinimicrobiaBacteriumCg1024814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marinimicrobia bacterium CG1_02_48_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarinimicrobiaBacteriumCg1024814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAdolescentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematocidaDisplodere(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nematocida displodere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NematocidaDisplodere", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaMytiliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia mytili Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaMytiliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopedobacterSaltansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudopedobacter saltans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudopedobacterSaltansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1199Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1199 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1199Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseomonasRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermusFervidusDsm2088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanothermus fervidus DSM 2088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanothermusFervidusDsm2088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaMorsitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina morsitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaMorsitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4226Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4226 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4226Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuricataSuricattaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Suricata suricatta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuricataSuricattaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5329(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5329 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5329", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSelenitireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSelenitireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCrk1wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK1W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk1wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlsr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALSr1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlsr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabilithrixLuteola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labilithrix luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabilithrixLuteola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPHIGHO2_01_FULL_57_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KordiaJejudonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordia jejudonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiaJejudonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldivirgaSpMu80Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga sp. MU80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaSpMu80Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_49_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PavoCristatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pavo cristatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PavoCristatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full509b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL509b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full509b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_39_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaLimiDsm17137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Devosia limi DSM 17137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DevosiaLimiDsm17137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBereziniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bereziniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBereziniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrogenedentesBacteriumCg1024214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrogenedentes bacterium CG1_02_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrogenedentesBacteriumCg1024214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusSpHmsc06h08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sp. HMSC06H08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusSpHmsc06h08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensSbw25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens SBW25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensSbw25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusPoinariiG6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii G6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusPoinariiG6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSp499Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp499Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaBacteriumBal38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BAL38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBal38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSp10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. 10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSp10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf25735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_57_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraAustraliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae232Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 232 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae232Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpLm4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. LM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLm4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivirgaEhrenbergiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga ehrenbergii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEhrenbergiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasGilardiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas gilardii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseomonasGilardiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag274Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag274Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaRocourtiaeFslF6920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria rocourtiae FSL F6-920 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaRocourtiaeFslF6920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBereziniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bereziniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBereziniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPiezophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piezophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPiezophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterAcetylenicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter acetylenicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelobacterAcetylenicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpBcu110501Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BCU110501 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBcu110501Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSp428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 42_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaSp428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumLitorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumLitorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatlockiaMicdadei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tatlockia micdadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TatlockiaMicdadei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaeOryzicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae oryzicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaeOryzicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisTaihuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis taihuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisTaihuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseobacterDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosphaeraSpWgk6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera sp. WGK6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraSpWgk6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAvermitilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avermitilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvermitilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseibacaCalidilacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseibaca calidilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseibacaCalidilacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoplanesSinuspersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoplanes sinuspersici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoplanesSinuspersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumOtitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOtitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaTeleogrylliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Erwinia] teleogrylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTeleogrylliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumKbs96Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs96Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUrhc0008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHC0008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrhc0008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KutzneriaSp744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria sp. 744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KutzneriaSp744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp32133(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3213.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32133", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaGrenadensisNbrc108939Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia grenadensis NBRC 108939 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaGrenadensisNbrc108939Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusElongatusPcc6301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC6301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc6301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpKctc13219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] sp. KCTC 13219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpKctc13219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCholeraeO1Biovar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 biovar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO1Biovar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc7375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTerrigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerrigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumGw2011gwa24310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWA24310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwa24310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusPacaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus pacaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusPacaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusStilesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus stilesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusStilesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpA45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. A45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpA45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermacetogeniumPhaeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermacetogenium phaeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermacetogeniumPhaeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LebetimonasSpJs170(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lebetimonas sp. JS170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LebetimonasSpJs170", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTestaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia testacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaTestaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioSpBr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. BR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpBr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterPseudethanolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter pseudethanolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterPseudethanolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpTf25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tf2-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTf25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApisCerana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apis cerana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApisCerana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumFreireiPrf81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium freirei PRF 81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumFreireiPrf81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumRifcsphigho201full5025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFCSPHIGHO201FULL5025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifcsphigho201full5025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpIbvss2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium7064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 70-64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium7064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpH14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerochaetaGlobosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta globosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaGlobosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopumilusPlanktonicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus planktonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusPlanktonicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAngustum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium angustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumAngustum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PvcGroupBacteriumExBugulaNeritinaAb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return PVC group bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PvcGroupBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusSp8g7msg3316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 8G7MSG3316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp8g7msg3316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaRettgeriDsm1131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri DSM1131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDsm1131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAlkaliantarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas alkaliantarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasAlkaliantarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasMossiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas mossii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMossiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenibacteriumSpCag290Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenibacterium sp. CAG:290 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenibacteriumSpCag290Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaSolaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma solani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSolaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumSp5120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. 51_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSp5120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110052Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110052Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesHarbinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces harbinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycomycesHarbinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaGrahamii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella grahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaGrahamii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumProfundumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium profundum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumProfundumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpEr16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. ER1/6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpEr16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077545Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077545 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077545Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaApis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaApis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusTinctoriusMarx270Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Marx 270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PisolithusTinctoriusMarx270Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleomorphomonasKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PleomorphomonasKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacterium13220cm5510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_2_20CM_55_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13220cm5510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaludibacteriumYongneupenseDsm18731Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense DSM 18731 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupenseDsm18731Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSp6146afaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 6146AFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp6146afaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CenarchaeumSymbiosumACluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosumACluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ModuliflexusFlocculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moduliflexus flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ModuliflexusFlocculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg1024390Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_43_90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1024390Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaSainthelensiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella sainthelensi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSainthelensiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg136212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_62_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioglobusSingularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus singularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSingularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidesmisPriestleyiAna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi Ana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiAna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoahuilensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCoahuilensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpRd272Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Rd 27.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpRd272Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusKaustophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus kaustophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusKaustophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpDme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaAlimentaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dietzia alimentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DietziaAlimentaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpGwf24489Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. GWF2_44_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpGwf24489Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterNataicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter nataicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterNataicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasGeothermicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas geothermicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGeothermicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumNamibiaeCbs14797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae CBS 147.97 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumNamibiaeCbs14797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoclostridiumPhytofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phytofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhytofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraMethylohalidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterHarbinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter harbinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHarbinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermococcusOkinawensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus okinawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusOkinawensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasMariniglutinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas mariniglutinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasMariniglutinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumPh28bin88Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium PH28bin88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumPh28bin88Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedOscillibacterSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Oscillibacter sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedOscillibacterSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumYsb2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSB2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsb2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpR575Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. R57-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpR575Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPutidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema putidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPutidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FischerellaSpPcc9339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusAlbusJl83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus JL83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbusJl83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpFsw0699Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. FSW06-99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFsw0699Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RamlibacterTataouinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter tataouinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RamlibacterTataouinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb1437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_43_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb1437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm3983(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM3983 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm3983", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisSpHl87Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HL87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHl87Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_39_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella bongori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaBongori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeNbb3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae NBB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeNbb3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full5016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL5016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full5016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCloacimonetesBacterium457255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Cloacimonetes bacterium 4572_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCloacimonetesBacterium457255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpNbs1129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NBS 11-29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNbs1129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb14412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB14412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb14412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohongiellaSpirulinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella spirulinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaSpirulinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo2025612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_56_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo2025612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PriciaAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pricia antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PriciaAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeomicrobiumSpJcm19038(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19038", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolibacillusSilvestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solibacillus silvestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolibacillusSilvestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusErythropolisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus erythropolis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusErythropolisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSpNsp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaChauliocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaChauliocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpFxanac1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FxanaC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpFxanac1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumWalsbyiJ07hqw2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaSoesokkakensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita soesokkakensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSoesokkakensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteigerwaltiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella steigerwaltii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteigerwaltiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCompetibacterDenitrificansRunAD11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Competibacter denitrificans Run_A_D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCompetibacterDenitrificansRunAD11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LihuaxuellaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lihuaxuella thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LihuaxuellaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumGwa24615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium GWA2_46_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumGwa24615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporocytophagaMyxococcoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporocytophaga myxococcoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporocytophagaMyxococcoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubidusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubidus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubidusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusPenaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus penaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VagococcusPenaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaPachydermatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malassezia pachydermatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalasseziaPachydermatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaFrigiditurrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella frigiditurris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaFrigiditurrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacterium351910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium 351910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacterium351910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KapabacteriaThiocyanatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kapabacteria thiocyanatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KapabacteriaThiocyanatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1023846Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_38_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1023846Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpC1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. C-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpC1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteribacillusBidgolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus bidgolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusBidgolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NaumovozymaCastelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma castellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaCastelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGa0074134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0074134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0074134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGwa2509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GWA2_50_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGwa2509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisPinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FomitopsisPinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpYbl2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YBL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYbl2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidiprofundiDsm19306(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi DSM 19306 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundiDsm19306", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraChlorobenzoica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera chlorobenzoica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraChlorobenzoica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGanghwenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium ganghwense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGanghwenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_44_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdeonellaSakaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ideonella sakaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdeonellaSakaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuodenibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duodenibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuodenibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_70_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumDg23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium DG_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumDg23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasCommunisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas communis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCommunisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LampropediaHyalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia hyalina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LampropediaHyalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraMoscoviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira moscoviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraMoscoviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpMl96Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ML96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMl96Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararheinheimeraTexasensisDsm17496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis DSM 17496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensisDsm17496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosalibacterSpMarseillep3206(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. MarseilleP3206 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerosalibacterSpMarseillep3206", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUnc41mfs5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC41MFS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc41mfs5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSepticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium septicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSepticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterCastelliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter castelli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCastelliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa13330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraVanthieliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira vanthielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraVanthieliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpWg5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. WG5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpWg5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpM41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpM41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter syzygii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSyzygiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_46_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_54_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacteriumYongneupenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumA52c2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium A52C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumA52c2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfBathymodiolusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusHalocryophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus halocryophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusHalocryophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaRuestringensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda ruestringensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaRuestringensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCanorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas canoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCanorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaHelminthoecaStrOregonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca str. Oregon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoecaStrOregonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFragilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fragilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFragilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurihydrogenibiumAzorense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium azorense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumAzorense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseofilumReptotaeniumAo1A(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium AO1-A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseofilumReptotaeniumAo1A", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonasAcidaminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonas acidaminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacimonasAcidaminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioScophthalmi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio scophthalmi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioScophthalmi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LibanicoccusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Libanicoccus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LibanicoccusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlixibacterBellariivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prolixibacter bellariivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProlixibacterBellariivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpCm6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. CM6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpCm6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumDehalogenansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dehalogenans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDehalogenansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumUasb270Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacterium UASB270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriumUasb270Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumQ1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Q-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumQ1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaCaroliniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brocadia caroliniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrocadiaCaroliniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumCalidifontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum calidifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumCalidifontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatishimiaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cognatishimia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CognatishimiaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm8964Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM8964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm8964Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsPolyrhachisfurcata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachisfurcata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisfurcata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalleroniaMarisminorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Palleronia marisminoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PalleroniaMarisminorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TogniniaMinimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Togninia minima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TogniniaMinimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxHaastiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apteryx haastii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApteryxHaastiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaChitinilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia chitinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaChitinilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaLutimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria lutimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaLutimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiellaMagnetica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella magnetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaMagnetica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusGelatini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus gelatini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FictibacillusGelatini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumNctc2916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum NCTC2916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumNctc2916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KriegellaAquimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kriegella aquimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KriegellaAquimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumOceanosedimentumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium oceanosedimentum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumOceanosedimentumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeckwithbacteriaBacteriumCg1024737Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium CG1024737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumCg1024737Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusSpPamc21323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus sp. PAMC21323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusSpPamc21323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OenococcusOeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus oeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OenococcusOeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJhl9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacillusPsychroduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychroduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosaPls229Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa PLS229 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosaPls229Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCichoriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cichorii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCichoriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFuscans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fuscans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasFuscans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpB6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpB6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisElegansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis elegans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisElegansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAgalactiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuculusCanorusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cuculus canorus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CuculusCanorusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaPelophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina pelophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaPelophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdaphobacillusLindanitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edaphobacillus lindanitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdaphobacillusLindanitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpUrha0002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHA0002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrha0002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumCulicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smittium culicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmittiumCulicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpNo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpNo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil766Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil766 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil766Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpongiicolaDsm21749(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola DSM 21749 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysobacterSpongiicolaDsm21749", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaApsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola APS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaApsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPatagoniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus patagoniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPatagoniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusVulcanalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus vulcanalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusVulcanalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusMicrocarpusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PisolithusMicrocarpusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBl8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BL8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBl8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasViscosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasViscosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMelonisTyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis TY Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMelonisTyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSalyersiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salyersiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalyersiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumBarchaimiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium barchaimii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumBarchaimiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogranumSalariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halogranum salarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalogranumSalariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosarcinaFibrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaFibrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSpJc230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. JC230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpJc230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwc12715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC1_27_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc12715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumB14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium B14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumB14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumMelilotiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium meliloti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMelilotiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobbsiaAndropogonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Robbsia andropogonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RobbsiaAndropogonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiellaIsopodorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella isopodorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaIsopodorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_34_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaParadisiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya paradisiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaParadisiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GalerinaMarginataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Galerina marginata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GalerinaMarginataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAesculapiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium aesculapii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAesculapiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterSpAtcc31444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. ATCC31444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpAtcc31444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NisaeaDenitrificansDsm18348Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nisaea denitrificans DSM 18348 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NisaeaDenitrificansDsm18348Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaDiversumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma diversum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaDiversumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD1_FULL_56_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanoperedensNitroreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoperedens nitroreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoperedensNitroreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusPahariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mus pahari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusPahariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariprofundusMicogutta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus micogutta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MariprofundusMicogutta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumCsp18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CSP1-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCsp18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeishmaniaBraziliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leishmania braziliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaBraziliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusBicirculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bicirculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBicirculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_02_FULL_43_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TalaromycesIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromassilibacillusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetohalobiumArabaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetohalobium arabaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetohalobiumArabaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHammesiiDsm16381(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii DSM 16381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHammesiiDsm16381", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag192Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:192 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag192Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibroporiaRadiculosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibroporia radiculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibroporiaRadiculosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LitoreibacterJanthinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter janthinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterJanthinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterVinaykumariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter vinaykumarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterVinaykumariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasMucosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas mucosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseomonasMucosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProsekiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas prosekii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProsekiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoSp1063Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho sp. 1063 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoSp1063Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumWce2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa288g21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288G21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288g21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasRivuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas rivuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasRivuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HungateiclostridiumStraminisolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnserBrachyrhynchusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anser brachyrhynchus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnserBrachyrhynchusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaDispersaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea dispersa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaDispersaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpCl6colCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. cl6col Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCl6colCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumHydatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hydatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHydatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusHerbariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus herbarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHerbariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusHaemoglobinophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus haemoglobinophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusHaemoglobinophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocMesenteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc mesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocMesenteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpHiyo8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Hiyo8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHiyo8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumL41aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium L41A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumL41aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSp22iis11z7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. 22IIS11z7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSp22iis11z7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3924 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaPolarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria polaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaPolarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesProvencensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes provencensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesProvencensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlkylphenolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_47_48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DolichospermumCircinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dolichospermum circinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DolichospermumCircinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAsbs410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASBs410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsbs410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYeochonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yeochonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYeochonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumEndosymbiontOfPedicinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusLutimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius lutimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusLutimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTenaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium tenax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTenaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusSpMilost2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. MilosT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpMilost2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLentusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLentusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GregarinaNiphandrodesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gregarina niphandrodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GregarinaNiphandrodesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moritella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoritellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumRaimondii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gossypium raimondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GossypiumRaimondii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSimiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSimiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCcmmd2014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CCMMD2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCcmmd2014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumAsf500Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ASF500 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumAsf500Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMerdaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium merdae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMerdaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LichtheimiaCorymbiferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LichtheimiaCorymbiferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxBoronicumulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax boronicumulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxBoronicumulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaOsloensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella osloensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOsloensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaEffusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaEffusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophobacterSpDg60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter sp. DG_60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterSpDg60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuis05zyh33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 05ZYH33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis05zyh33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSpMarseillep3519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. MarseilleP3519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpMarseillep3519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAndreraoultii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus andreraoultii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAndreraoultii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpLm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. LM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycetalesBacteriumActino01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliiroseovariusCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterMarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter marensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterMarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumGw2011gwa24314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA24314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa24314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumReducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum reducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumReducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterFreundii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter freundii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterFreundii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusChliarophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus chliarophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusChliarophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterVenetianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter venetianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterVenetianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAbscessusNbrc100374Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia abscessus NBRC 100374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAbscessusNbrc100374Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporocytophagaMyxococcoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporocytophaga myxococcoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporocytophagaMyxococcoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAsiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus asini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAsiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMacacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter macacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMacacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMaculosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella maculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMaculosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAlbaNbrc108234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia alba NBRC 108234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAlbaNbrc108234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077540Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077540 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077540Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat22090Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-22090 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat22090Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumGwa1448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium GWA1_44_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumGwa1448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSiciliaeC2jEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae C2J Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliaeC2jEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TangfeifaniaDiversioriginum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tangfeifania diversioriginum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TangfeifaniaDiversioriginum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraSojaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora sojae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraSojaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfatibacterAminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumGwa2349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWA2_34_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwa2349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasSpScn70307Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas sp. SCN 70-307 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasSpScn70307Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioSpJcm19048(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio sp. JCM 19048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioSpJcm19048", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_39_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumHqm9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium HQM9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumHqm9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterWinghamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter winghamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterWinghamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theileria equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheileriaEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumScatologenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scatologenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScatologenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMaddingleyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Maddingley Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMaddingleyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacterFormigenesOxcc13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes OXCC13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesOxcc13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpM412017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpM412017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesFLusitanicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPsychrosaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus psychrosaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPsychrosaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusCremeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus cremeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusCremeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHimastatinicusAtcc53653Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus ATCC 53653 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicusAtcc53653Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraAustraliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudopodocesHumilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudopodoces humilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudopodocesHumilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpYr266(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr266", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorumFunduliformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum funduliforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumFunduliformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HahellaGanghwensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hahella ganghwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HahellaGanghwensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium4461Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4461Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusPortucalensisFdf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis FDF-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensisFdf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickenellaMelleaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickenella mellea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickenellaMelleaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TupaiaChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tupaia chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TupaiaChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPropionicifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaK279aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia K279a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaK279aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermaceaeBacteriumRaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium RA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumRaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LepidothrixCoronataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lepidothrix coronata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LepidothrixCoronataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoclavibacterHelvolusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter helvolus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterHelvolusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_02_FULL_45_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaceaeBacteriumFsla50281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaIsraelensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella israelensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaIsraelensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriDsm1131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri DSM1131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDsm1131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaboniaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gabonia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GaboniaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuxenochlorellaProtothecoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Auxenochlorella protothecoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AuxenochlorellaProtothecoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocSpPcc7107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo201full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL4510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FodinicurvataSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusSpPamc21323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus sp. PAMC21323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusSpPamc21323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingorhabdusSpM41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus sp. M41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusSpM41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg10243210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG10243210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg10243210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTeresFTeres01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres f. teres 0-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTeresFTeres01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpWcd2001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD2001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd2001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumAap38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterCitreusLama915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter citreus LAMA 915 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErythrobacterCitreusLama915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaTyrosinosolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella tyrosinosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaTyrosinosolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassolituusOleivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassolituus oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassolituusOleivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevyellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levyella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevyellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaBarkeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_41_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrosporumCanisCbs113480(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microsporum canis CBS 113480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrosporumCanisCbs113480", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterYeojuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter yeojuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterYeojuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacteriumPelagiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium pelagium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPelagiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpJpy347Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JPY347 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpJpy347Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_52_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaHydrogenotrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia hydrogenotrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaHydrogenotrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaCasuarinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia casuarinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaCasuarinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioGalatheaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio galatheae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioGalatheaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccalesArchaeonRumenM2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon RumEn M2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeonRumenM2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusJurassicusNbrc107829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus NBRC 107829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusJurassicusNbrc107829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGorillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGorillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLehensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lehensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLehensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu036(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu036", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusFerrophilusDsm13482(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus DSM 13482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilusDsm13482", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumFlavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium flavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumFlavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaLacuscaerulensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria lacuscaerulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaLacuscaerulensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaCoronataVarAvenaeFSpAvenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia coronata var. avenae f. sp. avenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PucciniaCoronataVarAvenaeFSpAvenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndobugulaSertulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endobugula sertula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndobugulaSertulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslh70737(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70737", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiBerkhoffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii berkhoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiBerkhoffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc13712bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC13712b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc13712bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasSynergisticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas synergistica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSynergisticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_44_22b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusMarisflavi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMarisflavi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliscomenobacterHydrossisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haliscomenobacter hydrossis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaliscomenobacterHydrossisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyseterCatodonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Physeter catodon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhyseterCatodonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpUrha0002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHA0002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrha0002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJdm601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JDM601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJdm601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumCg10237114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_37_114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg10237114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistalesBacterium5881(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 58_81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5881", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifoxya2full329(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFOXYA2FULL329 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifoxya2full329", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaPickettii12jEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12J Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12jEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriJ99(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori J99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriJ99", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwd23219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpA49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. A49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpA49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusMediterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaprevotellaClaraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella clara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaClaraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterVadi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter vadi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterVadi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaceaeBacterium457278Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium457278Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolymorphumGilvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polymorphum gilvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolymorphumGilvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDaliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus daliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusDaliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGuanduensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces guanduensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGuanduensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesIndistinctus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes indistinctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesIndistinctus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumSpPcc7702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. PCC7702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpPcc7702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_44_22b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpA37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. A37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpA37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisRemaneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis remanei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisRemaneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaE681Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa E681 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaE681Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaStuartiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia stuartii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaStuartiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HesseltinellaVesiculosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hesseltinella vesiculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HesseltinellaVesiculosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScopuliridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scopuliridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScopuliridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaCasuarinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia casuarinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaCasuarinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaSpCag105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferShofinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer shofinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferShofinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesMangenotiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCincinnatiensisDsm19608Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis DSM 19608 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioCincinnatiensisDsm19608Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp7136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 71-36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FinegoldiaMagnaAtcc29328Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC29328 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc29328Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterMisakiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter misakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FabibacterMisakiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromatiumPalustre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromatium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromatiumPalustre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium2146faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 2146FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium2146faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp1nla3e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 1NLA3E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSp1nla3e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucunaPruriens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucuna pruriens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucunaPruriens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_44_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpS6262Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S6-262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpS6262Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusAmyloliquefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus amyloliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusAmyloliquefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpJsc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. JSC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpJsc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVariegatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces variegatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVariegatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpH3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpH3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMaliNbrc102425Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali NBRC 102425 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusMaliNbrc102425Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusMahiiDsm5219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii DSM 5219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusMahiiDsm5219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavisporaLusitaniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClavisporaLusitaniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiemerellaColumbinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaThermophilaTm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila TM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaThermophilaTm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaetbulibacterSaemankumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PavoCristatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pavo cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PavoCristatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalimicrobiumFlavidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium flavidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumFlavidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwf23876Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF23876 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf23876Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterSpRedseas28b5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. REDSEAS28B5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpRedseas28b5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumGw2011gwc24417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC24417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc24417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumSubrubescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium subrubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSubrubescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylicusOleusabulum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus oleusabulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusOleusabulum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusSpMm3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus sp. MM3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusSpMm3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio aerogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioAerogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo2024111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO2024111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo2024111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumNalgiovenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nalgiovense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNalgiovenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacrostomumLignanoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macrostomum lignano Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacrostomumLignanoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumShinjukuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shinjukuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShinjukuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKitasatonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kitasatonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKitasatonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumCg23041165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_41_165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg23041165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyoglomusTurgidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus turgidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusTurgidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpAls9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. ALS9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpAls9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpOralTaxon110StrF0139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. oral taxon 110 str. F0139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParvimonasSpOralTaxon110StrF0139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpSoapLake7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Lake #7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpSoapLake7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusSpJcm18860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus sp. JCM 18860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusSpJcm18860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisSpGbs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis sp. GBS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisSpGbs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMmlr14010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DokdonellaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterDaltoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter daltonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterDaltoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConidiobolusCoronatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConidiobolusCoronatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaEchiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bizionia echini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BizioniaEchiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaCetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaCetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusRuberCbs135680Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ruber CBS 135680 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusRuberCbs135680Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumHalophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium halophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumHalophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenedentesBacteriumJgi0000039j10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium JGI 0000039J10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumJgi0000039j10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopumilusTuricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusTuricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOryzisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaAlcalifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTubingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusTubingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusPropionicusDsm2032Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus DSM 2032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicusDsm2032Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaEchinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella echinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GramellaEchinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumJgi0000039d08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium JGI 0000039D08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumJgi0000039d08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf186Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf186 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf186Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpinaciaOleracea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spinacia oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpinaciaOleracea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaProfusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella profusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProfusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSpEp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. EP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpEp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CohnellaSp6021052837(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cohnella sp. 6021052837 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CohnellaSp6021052837", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasAtrocyanea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas atrocyanea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinomonasAtrocyanea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonariusItem5010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius ITEM 5010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusCarbonariusItem5010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesDoreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides dorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesDoreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyronemaOmphalodesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyronema omphalodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyronemaOmphalodesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium4081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 40-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpYr568Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. YR568 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpYr568Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhanerochaeteCarnosaHhb10118Sp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa HHB-10118-sp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosaHhb10118Sp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaucusCarotaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daucus carota Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaucusCarotaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPeliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas peli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPeliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZootermopsisNevadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zootermopsis nevadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZootermopsisNevadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinicolaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echinicola pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EchinicolaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLicheniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus licheniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLicheniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaSpitsbergenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma spitsbergense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSpitsbergenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagirhabdusAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagirhabdus alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagirhabdusAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumQ1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Q-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumQ1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzoarcusSpCib(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. CIB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpCib", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusSpSdbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sp. SDB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSpSdbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaApsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola APS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaApsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmittiumMegazygosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smittium megazygosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmittiumMegazygosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrococcusJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumGw2011gwa13716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWA13716 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwa13716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisciDsm44792Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci DSM 44792 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisciDsm44792Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPLOWO2_12_FULL_35_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsplowo212Full3511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HespelliaStercorisuisDsm15480(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis DSM 15480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HespelliaStercorisuisDsm15480", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasElodeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas elodea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasElodeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumNk3b98Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium NK3B98 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumNk3b98Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicavibrioAeruginosavorusArl13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus ARL13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusArl13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSucicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sucicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSucicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusCaballusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Equus caballus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EquusCaballusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpSjsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. SJS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpSjsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumGondwanenseDsm13020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense DSM 13020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanenseDsm13020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSpTwe2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. TWE2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpTwe2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpL(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpL", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LomentosporaProlificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lomentospora prolificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LomentosporaProlificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1025541Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_55_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025541Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaCruziStrainClBrenerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi strain CL Brener Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaCruziStrainClBrenerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpJcm18900Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. JCM18900 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpJcm18900Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusPhoenicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus phoenicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPhoenicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusPiezotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus piezotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPiezotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusYayanosiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus yayanosii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusYayanosiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesUrogenitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnicoccusHospitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus hospitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusHospitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumAqs3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium AqS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumAqs3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloranaerobacterAzorensisH53214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis H53214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensisH53214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaLecithinolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema lecithinolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaLecithinolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaRapa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brassica rapa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrassicaRapa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynoglossusSemilaevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cynoglossus semilaevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CynoglossusSemilaevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumAlbertimagni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium albertimagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumAlbertimagni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacterStenotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacter stenotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobacterStenotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratiruptorTergarcus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorTergarcus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLoiseleuriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus loiseleuriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLoiseleuriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full4732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL4732 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full4732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusColumbaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus columbae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusColumbaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniomycesEndolithicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces endolithicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesEndolithicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisRsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StanieriaCyanosphaeraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stanieria cyanosphaera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StanieriaCyanosphaeraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaportheAmpelina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe ampelina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiaportheAmpelina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaGallicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armillaria gallica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmillariaGallicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu084(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU084 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu084", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg104938Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_49_38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104938Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumYrb3002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YRB3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYrb3002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PichiaKudriavzeviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pichia kudriavzevii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PichiaKudriavzeviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaCaldifontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaCaldifontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeromyxobacterSpRbg166914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. RBG_16_69_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpRbg166914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMorhuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella morhuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMorhuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaBombicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella bombicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilliamellaBombicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaSphaeroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporomusaSphaeroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhlebiopsisGiganteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhlebiopsisGiganteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumScgcAaa027g08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027G08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027g08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa1377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA1377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa1377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofervidusAuxilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofervidus auxilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofervidusAuxilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaCaliforniensisDsm14826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis DSM 14826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensisDsm14826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaLuteola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaLuteola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSirexaaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SirexAAE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSirexaaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasFungiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas fungiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasFungiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUlceribovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulceribovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlceribovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumBlastocrithidiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium blastocrithidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumBlastocrithidiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSaelicesensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora saelicesensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSaelicesensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasFimiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas fimi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFimiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumRifcsphigho201full5431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5431 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaStewartiiSubspStewartiiDc283Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii subsp. stewartii DC283 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantoeaStewartiiSubspStewartiiDc283Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonTcbr11e2g8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasAquimarinaAtccBaa1526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina ATCC BAA-1526 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychromonasAquimarinaAtccBaa1526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkiellaAquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella aquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaAquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioSp1s175Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio sp. 1S175 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliivibrioSp1s175Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRifamycinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rifamycinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRifamycinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpHgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFructivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fructivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFructivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusLimicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoplanus limicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoplanusLimicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesRadicidentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces radicidentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRadicidentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribiusSalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribius salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribiusSalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLongumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLongumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumGwa15235(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA1_52_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa15235", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwe23210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWE2_32_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwe23210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg16439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_43_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChoanephoraCucurbitarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Choanephora cucurbitarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChoanephoraCucurbitarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesLimnophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces limnophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesLimnophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumFrisingenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum frisingense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumFrisingenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlumeriaGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blumeria graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlumeriaGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusVulcaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus vulcani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolobusVulcaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitibacterAlkalitoleransDsm16504(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans DSM 16504 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitoleransDsm16504", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusDelemarCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus delemar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopusDelemarCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsplowo201full4733b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4733b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4733b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixSchenckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix schenckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporothrixSchenckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisGanjiahuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis ganjiahuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisGanjiahuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaSpDg1229Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. DG1229 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpDg1229Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaSphaeroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporomusaSphaeroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensPf5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Pf5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensPf5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPseudofirmusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudofirmus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudofirmusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TateyamariaOmphalii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria omphalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TateyamariaOmphalii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSuccinicansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium succinicans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuccinicansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsplowo202full4337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO202FULL4337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo202full4337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RippkaeaOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rippkaea orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RippkaeaOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnimonasNigrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnimonas nigrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnimonasNigrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaSordidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia sordidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaSordidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrincolaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrincolaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo2124711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo2124711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterCibarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCibarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusUrinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaRufipogonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza rufipogon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaRufipogonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumAlbumDsm18261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium album DSM 18261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumAlbumDsm18261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonascusPurpureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monascus purpureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonascusPurpureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSwezeyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus swezeyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSwezeyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAsteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia asteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAsteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusElgiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus elgii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusElgiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRv15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. RV15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRv15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacterium34128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium 34_128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacterium34128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobotulusGlycolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobotulus glycolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophobotulusGlycolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag386Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag386Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesVulgatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides vulgatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesVulgatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAsf356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAsf356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumCpb6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium CPB6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCpb6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeurosporaCrassaOr74a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa OR74A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeurosporaCrassaOr74a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumDolichum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium dolichum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDolichum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMaceacherniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella maceachernii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaMaceacherniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5420 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium1747faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 1747FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium1747faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpBhbn044(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BHBN044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSpBhbn044", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium2w06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 2W06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium2w06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesMissouriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes missouriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesMissouriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachymonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaArboriphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora arboriphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaArboriphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsFumosoroseaArsef2679Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea ARSEF 2679 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CordycepsFumosoroseaArsef2679Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudacidovoraxIntermediusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax intermedius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxIntermediusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3837(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3837 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3837", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZimmermannellaBifidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella bifida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaBifidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCatarrhalisBbh18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis BBH18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalisBbh18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusFerrivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full4010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminobacterAmylophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminobacter amylophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminobacterAmylophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPinihumiDsm23905Jcm16419(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi DSM 23905 JCM 16419 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPinihumiDsm23905Jcm16419", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_02_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensIpla20019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens IPLA20019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensIpla20019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph899Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH899 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph899Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusTundraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus tundrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusTundraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPanipatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas panipatensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPanipatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariimicrobiumKwangyangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aestuariimicrobium kwangyangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AestuariimicrobiumKwangyangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAdety(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AdeTY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAdety", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LagierellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lagierella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LagierellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterSuareziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSuareziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPneumoniaeR6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae R6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeR6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaUmbonataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella umbonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUmbonataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusEllipticusCbs70779Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus CBS 707.79 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusEllipticusCbs70779Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosalibacterSpNd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. ND1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerosalibacterSpNd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TilletiopsisWashingtonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tilletiopsis washingtonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TilletiopsisWashingtonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZimmermannellaFaecalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella faecalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaFaecalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumKh2t8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium KH2T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumKh2t8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCholeraeO1BiovarCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 biovar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO1BiovarCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAmericanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAmericanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaAureaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa aurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAureaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TermitomycesSpJ132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Termitomyces sp. J132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TermitomycesSpJ132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCoraliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio coralii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCoraliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobacillusSpC254Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus sp. C254 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusSpC254Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hortaea werneckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HortaeaWerneckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLk11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLk11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcamd2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceaniovalibusGuishaninsulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceaniovalibus guishaninsula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceaniovalibusGuishaninsulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalariasFasciatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salarias fasciatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalariasFasciatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpBrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. BR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpBrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifoxyb1full5435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYB1FULL5435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyb1full5435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidipiscisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidipiscis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidipiscisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpOralTaxon431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. oral taxon 431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpOralTaxon431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpJhl9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraRoreri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora roreri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraRoreri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVulnerisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium vulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumVulnerisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasDiminutaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasDiminutaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAntri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus antri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAntri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumAmbiguum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidium ambiguum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidiumAmbiguum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLegalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio legallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLegalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFutsaiiJcm17355Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii JCM 17355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFutsaiiJcm17355Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BhargavaeaCecembensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea cecembensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaCecembensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRac07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. RAC07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRac07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliterellaAtlanticaCena595(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aliterella atlantica CENA595 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AliterellaAtlanticaCena595", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRbg163710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_16_37_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg163710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfolunaSpongiiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfoluna spongiiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfolunaSpongiiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiochaetaPulveraceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta pulveracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaPulveraceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaporthiopsisPoaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_54_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCincinnatiensisDsm19608(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis DSM 19608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioCincinnatiensisDsm19608", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPeliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas peli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPeliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNereis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nereis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioNereis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobacterSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobacter subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobacterSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedPoseidonialesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Poseidoniales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedPoseidonialesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpUnccl20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. UNCCL20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpUnccl20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumPaludicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPaludicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaPoulsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma poulsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaPoulsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPoribacteriaBacteriumWga3g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Poribacteria bacterium WGA-3G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPoribacteriaBacteriumWga3g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaSebiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia sebi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WallemiaSebiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimentisphaeraCyanobacteriorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera cyanobacteriorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraCyanobacteriorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaCaeniNbrc101664Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella caeni NBRC 101664 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CastellaniellaCaeniNbrc101664Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorBasaltis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor basaltis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratireductorBasaltis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaPratensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agreia pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgreiaPratensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteusVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteus vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteusVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcticibacterEurypsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter eurypsychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterEurypsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPertussis18323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis 18323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussis18323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr3Bacterium4484211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium 4484_211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3Bacterium4484211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacillusSpOk028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetitomaculumRuminisDsm5522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis DSM 5522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetitomaculumRuminisDsm5522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannocystisExedens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nannocystis exedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NannocystisExedens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterUraniireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterUraniireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterAzorensisH53214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis H53214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensisH53214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HirschiaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hirschia baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HirschiaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpR1ns10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. R1NS10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpR1ns10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumReducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum reducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumReducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeonectriaDitissimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neonectria ditissima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeonectriaDitissimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSenmaizukeiDsm21775Nbrc103853(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei DSM 21775 NBRC 103853 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukeiDsm21775Nbrc103853", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegilopsTauschiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aegilops tauschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AegilopsTauschiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGaoshouyii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gaoshouyii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGaoshouyii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrombidiumDelienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrombidium deliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrombidiumDelienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaMtcc5279Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida MTCC5279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaMtcc5279Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMosselii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mosselii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMosselii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavusDsm17758Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus concavus DSM 17758 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusConcavusDsm17758Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterFulvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter fulvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterFulvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GynuellaSunshinyiiYc6258Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii YC6258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GynuellaSunshinyiiYc6258Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusSubspFetus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. fetus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspFetus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyoglomusThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPallidulaDsm14239Acam615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola pallidula DSM 14239 ACAM 615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPallidulaDsm14239Acam615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaCt18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Salmonella enterica CT18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaCt18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyalangiumMinutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyalangium minutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyalangiumMinutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterCorallicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter corallicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterCorallicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumRbg13429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RBG_13_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRbg13429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp37ma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 37MA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSp37ma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24218(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24218", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaMorganiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Morganella morganii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MorganellaMorganiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucusCbs51665Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus glaucus CBS 516.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusGlaucusCbs51665Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSpOr53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. OR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSpOr53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSp63713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. 63-713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSp63713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalothiobacillusNeapolitanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus neapolitanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusNeapolitanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemetriaTerragenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demetria terragena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemetriaTerragenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaRuckeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia ruckeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaRuckeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOy3wo11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OY3WO11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOy3wo11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumTenueEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidium tenue Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidiumTenueEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCoprophilusNbrc100603Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus NBRC 100603 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusCoprophilusNbrc100603Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMikamii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mikamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaMikamii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnanasComosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ananas comosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnanasComosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PopulusAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Populus alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PopulusAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulciaMuelleriSmdsemCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri SMDSEM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriSmdsemCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPLOWO2_02_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutusTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opitutus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpitutusTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilvensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silvensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilvensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpCf444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. CF444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpCf444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterSpMhb5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. MHB5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpMhb5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoluteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseoluteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseoluteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeinonellaPeptonophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Seinonella peptonophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SeinonellaPeptonophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtribacteriaBacteriumCg2303313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium CG2_30_33_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumCg2303313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium verticillioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumVerticillioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHomeothermusArabinoxylanisolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Homeothermus arabinoxylanisolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHomeothermusArabinoxylanisolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusManliponensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus manliponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusManliponensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa26018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa26018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalarsenatibacterSilvermaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halarsenatibacter silvermanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalarsenatibacterSilvermaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSp197aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sp. 197A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalococcusSp197aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcaceaeBacteriumW5053Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium W5053 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumW5053Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenitireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenitireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterJiangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaludibacterJiangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumEscambienseDsm10707Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense DSM 10707 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambienseDsm10707Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSanguinicancriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sanguinicancri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSanguinicancriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumGwa24615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium GWA24615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumGwa24615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumImmobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpMed193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. MED193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpMed193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMelainabacteriaBacteriumGwa2349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWA2_34_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwa2349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptosphaeriaMaculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpLeaf148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot604Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root604 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot604Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE3198Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3198 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3198Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaVirensGv298Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Gv29-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaVirensGv298Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPecorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPecorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudozymaHubeiensisSy62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis SY62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudozymaHubeiensisSy62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaIntestini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilliamellaIntestini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterGlycinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter glycinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterGlycinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioSp1s175Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio sp. 1S175 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliivibrioSp1s175Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophilia5bai2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia 5BAI2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophilia5bai2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobaculumLitoreumDsm18839Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum DSM 18839 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreumDsm18839Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaGeojedonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivita geojedonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivitaGeojedonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumGw2011gwa25212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GW2011GWA25212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGw2011gwa25212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaElegansE1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Holospora elegans E1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HolosporaElegansE1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpR2019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. R2019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpR2019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa24416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA24416 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa24416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAlkalica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGlobisporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces globisporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlobisporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHungaricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hungaricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHungaricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumGenomosp3StrCfbp6623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. 3 str. CFBP 6623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumGenomosp3StrCfbp6623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaSeiffertiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsmarc1261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSanxanigenensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanxanigenens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanxanigenensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaGrandensisFslF60971Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria grandensis FSL F6-0971 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaGrandensisFslF60971Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag65(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag65", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusShizuokensisNbrc103103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis NBRC 103103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensisNbrc103103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaIslandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula islandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaIslandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogeometricumBorinquense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum borinquense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumBorinquense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusClavatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus clavatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusClavatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumMaritimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum maritimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMaritimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaBerlinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema berlinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaBerlinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumH143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaParisiiErtm3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nematocida parisii ERTm3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NematocidaParisiiErtm3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomicrobiumOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinomicrobium oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinomicrobiumOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSambucusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sambucus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSambucusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortieraAleyrodidarumBtBHrsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum BT-B-HRs Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumBtBHrsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRbg166213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_62_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot495Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot495Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaBannensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bannensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBannensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminispirochaetaBajacaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta bajacaliforniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaBajacaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSegetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium segetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSegetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMontana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas montana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMontana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVenenatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium venenatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumVenenatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_54_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NipponiaNippon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nipponia nippon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NipponiaNippon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpCo6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus sp. CO-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusSpCo6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaVersiformeJcm10478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natrinema versiforme JCM 10478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatrinemaVersiformeJcm10478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGallinarumDsm18171Jcm13658Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum DSM 18171 JCM 13658 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesGallinarumDsm18171Jcm13658Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaLutaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda lutaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaLutaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaDentiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dentiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDentiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosalsumZhilinaeDsm4017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae DSM 4017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosalsumZhilinaeDsm4017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnteractinococcusHelveticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enteractinococcus helveticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnteractinococcusHelveticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp11649854Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164985.4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649854Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium6626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 66-26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTerreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus terreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusTerreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Bacterium3363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium 336/3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Bacterium3363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaBruceiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma brucei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaBruceiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaC102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa C102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaC102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumLeptumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium leptum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLeptumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaAcidipaludisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia acidipaludis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAcidipaludisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVermiculataNbrc100427Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vermiculata NBRC 100427 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaVermiculataNbrc100427Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaPalleronii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaPalleronii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChiloSuppressalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chilo suppressalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChiloSuppressalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosocosmicusOleophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus oleophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusOleophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenitrovibrioAcetiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Denitrovibrio acetiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DenitrovibrioAcetiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaEquiStrainWaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Theileria equi strain WA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TheileriaEquiStrainWaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasVariicolorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solimonas variicoloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolimonasVariicolorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGeothermarchaeotaArchaeonJdfr13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Geothermarchaeota archaeon JdFR-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGeothermarchaeotaArchaeonJdfr13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusDonghaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusDonghaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylella fastidiosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylellaFastidiosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRoot154Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root154 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot154Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumKnowlesiStrainHCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi strain H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesiStrainHCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaHelicoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma helicoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaHelicoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc512e3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-2E3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc512e3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmobacterAquatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter aquatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmobacterAquatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE3251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PygoscelisAdeliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pygoscelis adeliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PygoscelisAdeliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium GW2011_GWA1_40_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterNectarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nectaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNectarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_36_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNovocastrenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium novocastrense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNovocastrenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisSpBbd199110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. BBD 1991-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpBbd199110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo212full6540Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6540 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6540Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacaSpPts2502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca sp. PTS2502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaSpPts2502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerracidiphilusGabretensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terracidiphilus gabretensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerracidiphilusGabretensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanotheceSpCcy0110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. CCY0110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpCcy0110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAnthracisStrAmesAncestorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis str. Ames Ancestor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisStrAmesAncestorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumLentocellum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum lentocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumLentocellum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutypaLataUcrel1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata UCREL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EutypaLataUcrel1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallinaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCsp11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon CSP1-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCsp11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterLapidarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter lapidarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterLapidarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHalophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum halophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHalophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DothistromaSeptosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dothistroma septosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DothistromaSeptosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOy3wo11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OY3WO11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOy3wo11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylonaHeveaeTc161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xylona heveae TC161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XylonaHeveaeTc161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSedlakiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sedlakii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSedlakiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusDepauperatusCbs7841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus CBS 7841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptococcusDepauperatusCbs7841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPseudoalcaligenesKf707(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes KF707 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesKf707", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CnuibacterPhyscomitrellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cnuibacter physcomitrellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CnuibacterPhyscomitrellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaArabinofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida arabinofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaArabinofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpJha26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPhytoplasmaAurantifoliaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma aurantifolia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaAurantifoliaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTransvalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia transvalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaTransvalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumNeutrophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum neutrophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumNeutrophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaAldovae67083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae 670-83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaAldovae67083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrypanosomaBrucei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma brucei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaBrucei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeongeupiaSpUsm3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeongeupia sp. USM3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeongeupiaSpUsm3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisC6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsphigho201full5513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO201FULL5513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho201full5513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCoronafaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionisporaVibrioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionispora vibrioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionisporaVibrioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaNiabensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga niabensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaNiabensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionTm6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRhodesiaeNbb3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae NBB3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeNbb3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifcsplowo201full3912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO201FULL3912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo201full3912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraHakonensisJcm8857Dsm7519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis JCM 8857 DSM 7519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensisJcm8857Dsm7519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntestinimonasButyriciproducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas butyriciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasButyriciproducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrifolaFrondosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Grifola frondosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GrifolaFrondosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlercreutziaEquolifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlercreutzia equolifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlercreutziaEquolifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonchuraStriataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lonchura striata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LonchuraStriataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalyomorphaHalysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halyomorpha halys Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalyomorphaHalysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaeBacteriumDg1235(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobiae bacterium DG1235 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaeBacteriumDg1235", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VolvoxCarteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Volvox carteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VolvoxCarteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasTaeanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas taeanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasTaeanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYC2_FULL_43_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisAmesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Ames Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisAmesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa076p09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpTomcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. TomC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpTomcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwe132154(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWE1_32_154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwe132154", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaLupini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLupini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusLacisalsiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus lacisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusLacisalsiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaFijiensisCirad86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis CIRAD86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensisCirad86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumGw2011gwf23566Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWF23566 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwf23566Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSubantarcticusLmg24377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus LMG 24377 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticusLmg24377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnc496mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC496MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc496mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaHaliotisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shewanella haliotis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShewanellaHaliotisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirestonebacteriaBacteriumRifoxyc2full3967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYC2FULL3967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxyc2full3967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBataviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bataviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusBataviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodolunaPlanktonicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna planktonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodolunaPlanktonicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosinusCarboxydivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermosinus carboxydivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermosinusCarboxydivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumJlt2015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium JLT2015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumJlt2015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpBolea5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. BoleA5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpBolea5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusCelericrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus celericrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCelericrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RappaportIsraeliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rappaport israeli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RappaportIsraeliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaXenovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia xenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaXenovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDysgalactiaeEquisimilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae equisimilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeEquisimilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumCongolense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium congolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumCongolense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRbg164519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_16_45_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg164519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpOk091Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OK091 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOk091Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumFreireiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium freirei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumFreireiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp174mfsha11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 174MFSha1.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp174mfsha11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMageritenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mageritense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumMageritenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Raymondbacteria bacterium RIFOXYC2_FULL_50_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasPusillaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonas pusilla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonasPusillaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCapitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus capitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCapitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaeBacteriumRifcsplowo2123915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospinae bacterium RIFCSPLOWO2_12_39_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospinaeBacteriumRifcsplowo2123915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PicrophilusTorridusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Picrophilus torridus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PicrophilusTorridusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCommuneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium commune Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCommuneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnccl117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNCCL117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnccl117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeeksellaSpFf8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Weeksella sp. FF8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WeeksellaSpFf8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesFunestusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles funestus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesFunestusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumPh28bin88Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium PH28bin88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumPh28bin88Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumRifoxyb1Full5412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYB1_FULL_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyb1Full5412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4645(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4645 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4645", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiflebacteriaBacteriumGwc2508Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riflebacteria bacterium GWC2_50_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiflebacteriaBacteriumGwc2508Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpP1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. P1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpP1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRbg166411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_64_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfurarchaeumFormicicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfurarchaeum formicicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalodesulfurarchaeumFormicicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrococcusRivularisNies593Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis NIES-593 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrococcusRivularisNies593Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioLipolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio lipolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioLipolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusFuriosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus furiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusFuriosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag177(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:177 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag177", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpDm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. DM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpDm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiumSpLsa18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium sp. LSA18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumSpLsa18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinor202(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor 202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinor202", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilimonasLacunaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Filimonas lacunae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FilimonasLacunaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMusc93Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc93Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterNorwichensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter norwichensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterNorwichensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSpGwe1629(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. GWE1_62_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpGwe1629", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHemicellulosilyticusJcm9152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus JCM 9152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticusJcm9152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasFlavigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas flavigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFlavigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteriumSenegalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilibacterium senegalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilibacteriumSenegalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlterileibacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alterileibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlterileibacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUrhd0025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHD0025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhd0025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasStagniDsm19981Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas stagni DSM 19981 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseomonasStagniDsm19981Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LitoreibacterAscidiaceicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter ascidiaceicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAscidiaceicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCedrinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cedrina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCedrinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasSynergistica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas synergistica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSynergistica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusSpCag782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus sp. CAG:782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprococcusSpCag782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisIl1403Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis Il1403 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisIl1403Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwc23941Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC23941 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc23941Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterPhenanthrenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter phenanthrenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterPhenanthrenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterMelonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter melonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterMelonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumSpP6bsiiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum sp. P6BSIII Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumSpP6bsiiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOsloensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella osloensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOsloensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TidjanibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tidjanibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TidjanibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpS23321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. S23321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpS23321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriaSymbiontBfo2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOtCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOtCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacebacteriaBacteriumRifcsphigho201full4610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaM42548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica M42548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaM42548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HammondiaHammondiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hammondia hammondi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HammondiaHammondiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaRubripromontorii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula rubripromontorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaRubripromontorii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpEp60837Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. EP60837 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpEp60837Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaPekkanenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pekkanenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaPekkanenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumVincentiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaVaccimaxillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia vaccimaxillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaVaccimaxillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpCnt312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNT312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnt312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSullaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sullae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSullaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamadaeaTsunoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hamadaea tsunoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HamadaeaTsunoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBogoriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bogoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusBogoriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHdn1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HdN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHdn1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterXylosoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4520Fw2644(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4520 (FW-2644) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4520Fw2644", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodniusProlixusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodnius prolixus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodniusProlixusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosarcinaLacusLw14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina lacus LW14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaLacusLw14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumHiltneriN3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri N3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneriN3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteocatellaSphenisciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteocatella sphenisci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteocatellaSphenisciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrarchaeotaArchaeonCg1025115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_51_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedMethanoculleusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Methanoculleus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedMethanoculleusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcidisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acidisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcidisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VittaformaCorneaeAtcc50505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vittaforma corneae ATCC 50505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VittaformaCorneaeAtcc50505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHispalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hispalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHispalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesMccartyi195Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi 195 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyi195Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumRosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium rosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumRosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPLOWO2_01_FULL_45_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZinderiaInsecticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zinderia insecticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZinderiaInsecticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaAmylovora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia amylovora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaAmylovora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaSuimastitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia suimastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaSuimastitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpAs2mbin001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. AS2MBin001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpAs2mbin001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumHtcc2080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGwf25119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium GWF2_51_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGwf25119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomicrostromaGlucosiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomicrostroma glucosiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomicrostromaGlucosiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaligenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterSp24yea8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. 24YEA8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSp24yea8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaAerolataKacc11604Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Skermanella aerolata KACC 11604 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SkermanellaAerolataKacc11604Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiohalospira halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiohalospiraHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOkhensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus okhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusOkhensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_35_48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaFermentatiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachancea fermentati Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachanceaFermentatiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CadophoraSpDse1049Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cadophora sp. DSE1049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CadophoraSpDse1049Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumThalpophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDysgalactiaeAtcc27957(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae ATCC27957 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeAtcc27957", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa027j17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA027J17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa027j17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaF0287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea F0287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaF0287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferribacterDesulfuricans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deferribacter desulfuricans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeferribacterDesulfuricans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4218(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4218", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBataviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bataviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusBataviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactucaSativaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactuca sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactucaSativaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumTestudinorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium testudinoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTestudinorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteusVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteus vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteusVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensDb11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens Db11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensDb11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaParvumStrIndianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma parvum str. Indiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaParvumStrIndianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpGwf24489Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. GWF2_44_89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpGwf24489Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpMc2021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumFrediiNgr234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii NGR234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiNgr234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiochaetaLigniariaNrrl30616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria NRRL 30616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ConiochaetaLigniariaNrrl30616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTuricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesTuricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOrbiscindensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium orbiscindens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumOrbiscindensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysOligospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysOligospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasNaphthalenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas naphthalenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasNaphthalenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudacidovoraxSpRu35e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax sp. RU35E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxSpRu35e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolituusThermophilusDsm23256Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus DSM 23256 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporolituusThermophilusDsm23256Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerodermaCitrinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SclerodermaCitrinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeocallimastixCaliforniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neocallimastix californiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeocallimastixCaliforniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMagnum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium magnum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMagnum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusSpMv1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. MV1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusSpMv1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSp4557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 4557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp4557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedTermiteGroup1BacteriumPhylotypeRsD17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Rs-D17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeRsD17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetalesBacteriumSpiro05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoemansiaReversa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coemansia reversa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoemansiaReversa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_50_9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviramulusIchthyoenteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus ichthyoenteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusIchthyoenteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumXueshanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xueshanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXueshanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumE1BontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum E1 BoNT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumE1BontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasCellasea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasCellasea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacterLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_43_15b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyclobacteriumLianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium lianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumLianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaBooriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria booriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaBooriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovermiculusHalophilusDsm18834(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus DSM 18834 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilusDsm18834", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsphigho212full278Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL278 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full278Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyocaulusViviparusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dictyocaulus viviparus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DictyocaulusViviparusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasHofstadiiJcm17038(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii JCM 17038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasHofstadiiJcm17038", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferrisomaCaminiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deferrisoma camini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeferrisomaCaminiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GasterosteusAculeatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gasterosteus aculeatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GasterosteusAculeatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumRubrisubalbicansM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicansM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasPhaseoliPvDieffenbachiaeLmg695Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli pv. dieffenbachiae LMG 695 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasPhaseoliPvDieffenbachiaeLmg695Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioCosticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio costicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioCosticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumVariabile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium variabile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVariabile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygii9h2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter syzygii 9H-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterSyzygii9h2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NaumovozymaDairenensisCbs421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis CBS 421 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaDairenensisCbs421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpKm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumCg2304320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_43_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2304320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSpOk283(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK283 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk283", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusGelatiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus gelatini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FictibacillusGelatiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterSuareziiNbrc16159Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii NBRC 16159 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SanguibacterSuareziiNbrc16159Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf231(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf231", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumGwf1657(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium GWF1_65_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumGwf1657", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumWanjuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium wanjuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumWanjuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RamazzottiusVarieornatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ramazzottius varieornatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RamazzottiusVarieornatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaMannitolilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia mannitolilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaMannitolilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumPaludicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPaludicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBreveCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium breve Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBreveCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusMinor202Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor 202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinor202Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccalesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DactylellinaHaptotylaCbs20050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla CBS 200.50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DactylellinaHaptotylaCbs20050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymomonasMobilisAtcc10988Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ATCC10988 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZymomonasMobilisAtcc10988Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumisSativusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cucumis sativus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CucumisSativusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelesianaGillSymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Solemya velesiana gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SolemyaVelesianaGillSymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpCmr5c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CMR5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCmr5c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKribbensisDsm17871(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kribbensis DSM 17871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusKribbensisDsm17871", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaChahannaoensisJcm10990(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis JCM 10990 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensisJcm10990", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeotaArchaeonScgcAaa011G17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon SCGC AAA011-G17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeonScgcAaa011G17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaGeestianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella geestiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaGeestianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb1388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB1388 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb1388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6820 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumRhodesiaeJs60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae JS60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeJs60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsSpRao2017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps sp. RAO-2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CordycepsSpRao2017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaldieriaSulphurariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Galdieria sulphuraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GaldieriaSulphurariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAminophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio aminophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAminophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesOvatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ovatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOvatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaZhangzhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordia zhangzhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiaZhangzhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnatzschineriaLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignatzschineria larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnatzschineriaLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterGudaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter gudaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterGudaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNodensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nodensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNodensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifcsphigho202full4214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO202FULL4214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho202full4214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisAlexandriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis alexandrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisAlexandriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolineaTardivitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolinea tardivitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolineaTardivitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumKhcpx20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KHCPX20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKhcpx20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocFallaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc fallax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocFallaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwb13912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpP11g5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensisVarSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Camellia sinensis var. sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CamelliaSinensisVarSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterSpMm124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. MM124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpMm124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaUreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina ureae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaUreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaHolmesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella holmesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaHolmesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAmphilectiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina amphilecti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAmphilectiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_FULL_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMycoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mycoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMycoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasDiversaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas diversa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasDiversaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNd2006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium ND2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNd2006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatirosaKalamazoonesisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatirosa kalamazoonesis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatirosaKalamazoonesisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumFunkeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium funkei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumFunkeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivirgaCyanobacteriivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivirga cyanobacteriivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivirgaCyanobacteriivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpGwa24521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. GWA2_45_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpGwa24521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosiphoSp1063Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho sp. 1063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoSp1063Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumCg2304421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_44_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiHcIsolateThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HC isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHcIsolateThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaSp13gom1096mEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. 13GOM1096m Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSp13gom1096mEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilunaSpUbmaderosw2red(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. UBMaderosW2red graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpUbmaderosw2red", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaSp4g2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lewinella sp. 4G2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LewinellaSp4g2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaPolarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPolarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterToluenoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterToluenoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumEpidermidicanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium epidermidicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEpidermidicanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButtiauxellaFerragutiaeAtcc51602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae ATCC 51602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiaeAtcc51602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho201full4623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL4623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full4623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BibersteiniaTrehalosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bibersteinia trehalosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BibersteiniaTrehalosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobacterSpRoot29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpVpap30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. VPAP30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSpVpap30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaistia adipata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaistiaAdipataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcanobacteriumPhocaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumPhocaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumAo1cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium AO1C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumAo1cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 39-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp4g2div0659Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 4G2DIV0659 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp4g2div0659Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaLituseburensisDsm797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis DSM 797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensisDsm797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo212full4116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO212FULL4116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo212full4116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUmwwyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWWY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwwyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDendritiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpCnr923Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNR-923 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnr923Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumMesophilumDsm19309Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum DSM 19309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilumDsm19309Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HypsizygusMarmoreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hypsizygus marmoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HypsizygusMarmoreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumZavarziniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium zavarzinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumZavarziniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpHm582Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. HM58-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpHm582Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium688Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 68-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium688Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho202full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO202FULL4712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho202full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylothermusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuscaDomesticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Musca domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuscaDomesticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpRac01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. RAC01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRac01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanimonasSpGk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas sp. GK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSpGk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GonapodyaProliferaJel478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gonapodya prolifera JEL478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GonapodyaProliferaJel478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumNoncentrifugensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium noncentrifugens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumNoncentrifugensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumAAtcc3502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum A ATCC 3502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAAtcc3502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DerxiaGummosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Derxia gummosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DerxiaGummosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMarthiiFslS4120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria marthii FSL S4-120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaMarthiiFslS4120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaAgriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella agri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaAgriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlmg11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALMg11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlmg11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmataSpIil30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. IIL30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemmataSpIil30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharothrixSyringae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix syringae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSyringae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot685(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot685", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRenniniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rennini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRenniniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalarchaeumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalarchaeum thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalarchaeumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaBoryanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya boryana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaBoryanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusXenolissoclinumPacificiensisL6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xenolissoclinum pacificiensis L6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusXenolissoclinumPacificiensisL6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSingulareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium singulare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSingulareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteralesBacteriumRifoxyb1full6716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFOXYB1FULL6716 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifoxyb1full6716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumGwa15114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium GWA15114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumGwa15114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNeuiiBvs029a5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii BVS029A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiBvs029a5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterAnodireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter anodireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterAnodireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiPcNhvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PC NHV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPcNhvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBingmayongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bingmayongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusBingmayongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachipleistophoraHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trachipleistophora hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrachipleistophoraHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperellaBernardiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trueperella bernardiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrueperellaBernardiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpLkl04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. LKL04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLkl04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4716 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusElongatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusElongatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL3713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldiarchaeumSubterraneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldiarchaeum subterraneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldiarchaeumSubterraneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaHispanicaCri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hispanica CRI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaHispanicaCri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFo5176Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Fo5176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFo5176Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VogelbacteriaBacteriumRifoxyd1full4619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4619 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil736Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil736 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil736Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterTjernbergiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tjernbergiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTjernbergiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaimiriBoliviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saimiri boliviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaimiriBoliviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioInopinatusDsm10711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus DSM 10711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatusDsm10711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrisporobacterOthiniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter othiniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterOthiniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreniaMarismortui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orenia marismortui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OreniaMarismortui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusShacheensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shacheensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusShacheensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumGraminicolaM1001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola M1.001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGraminicolaM1001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalusDomesticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malus domestica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalusDomesticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24618(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24618 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24618", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephaloticoccusPrimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus primus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusPrimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHimb083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumPlexicaudatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium plexicaudatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPlexicaudatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterCeler(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter celer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterCeler", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisAtcc35310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis ATCC35310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisAtcc35310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPaucimobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas paucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPaucimobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpZxy2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ZXY-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpZxy2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GullanellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gullanella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GullanellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaStewartiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea stewartii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaStewartiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligotrophaCarboxidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oligotropha carboxidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OligotrophaCarboxidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacterium13220cm2628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium 13_2_20CM_2_62_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacterium13220cm2628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaParasiticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaParasiticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusSendaiensisNbrc100866Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis NBRC 100866 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensisNbrc100866Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndolissoclinumFaulkneriL5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4520Fw2644Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4520 (FW-2644) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4520Fw2644Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumHydrocarbonoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hydrocarbonoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHydrocarbonoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabisPvPhaseoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis pv. phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCannabisPvPhaseoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSenegalimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag1060Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag1060Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathymodiolusAzoricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathymodiolusAzoricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaAkCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ak Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAkCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasIlicicolaDsm19980Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas ilicicola DSM 19980 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasIlicicolaDsm19980Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMb2021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MB2021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMb2021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCapillatusDsm19910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus DSM 19910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCapillatusDsm19910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumLimigenitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium limigenitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLimigenitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumShinjukuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shinjukuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShinjukuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BermanellaMarisrubriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bermanella marisrubri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BermanellaMarisrubriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_42_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaineyellaAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Raineyella antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RaineyellaAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfococcusSp4484241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus sp. 4484_241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusSp4484241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpL77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. L77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpL77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusLuminescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus luminescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLuminescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHayakitensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hayakitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHayakitensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanizomenonFlosaquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aphanizomenon flosaquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AphanizomenonFlosaquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesStephensiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles stephensi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesStephensiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaPaludivivensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella paludivivens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPaludivivensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpAf1028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpAf1028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Giardia intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GiardiaIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAfermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium afermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAfermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrospiraPlatensisNies39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis NIES39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisNies39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasMediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas media Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasMediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumJaponicumIn8p8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum in8p8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumIn8p8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpinosisporaDsm44797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora DSM 44797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosisporaDsm44797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusOceanisediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oceanisediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusOceanisediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_38_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSeoulenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium seoulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSeoulenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSocompensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSocompensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaTardaAtcc15947Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda ATCC15947 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EdwardsiellaTardaAtcc15947Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpUrha0032Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0032 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0032Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full6316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL6316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full6316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElsinoeAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elsinoe australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElsinoeAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudophaeobacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistophilusSomni2336Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Histophilus somni 2336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HistophilusSomni2336Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp21mfcrub11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 21MFCrub1.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp21mfcrub11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyb1full3916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYB1FULL3916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyb1full3916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzonexusHydrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azonexus hydrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzonexusHydrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAbyssalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaTestudinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella testudinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaTestudinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccalesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaSpGbbuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riesia sp. GBBU Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiesiaSpGbbuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf2429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_42_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf2429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumLaevaniformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium laevaniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLaevaniformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRoot180Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root180 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot180Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeroformaArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaeroformaArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpPc0866Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. PC08-66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpPc0866Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumUtcfx2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VignaRadiataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vigna radiata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VignaRadiataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaPersimilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila persimilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPersimilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMassiliensis4401292Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis 4401292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesMassiliensis4401292Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusColeohominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coleohominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusColeohominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKisonensisF0435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis F0435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKisonensisF0435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRedseas12b4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS12B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas12b4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusPleuropneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCancerogenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCancerogenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpSk02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwc24418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWC2_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwc24418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaExalbida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia exalbida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaExalbida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpMs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpMs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHammesiiDsm16381Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii DSM 16381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHammesiiDsm16381Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumLuteolum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium luteolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumLuteolum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeribacillusPallidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeribacillus pallidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeribacillusPallidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaBelliiOsu85389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii OSU85389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiOsu85389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisNcppb382Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis NCPPB382 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisNcppb382Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCaviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCaviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogemmatisporaSpPm5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora sp. PM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermogemmatisporaSpPm5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumKujienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum kujiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumKujienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSpLeaf354Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. Leaf354 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSpLeaf354Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaBrunneaFSpMultigermtubiMbM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea f. sp. multigermtubi MB_m1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarssoninaBrunneaFSpMultigermtubiMbM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpMor2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. Mor2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpMor2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium3157faact1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3157FAACT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3157faact1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_12_FULL_41_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag1320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1320 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf198Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf198Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbiotrophiaDefectivaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Abiotrophia defectiva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbiotrophiaDefectivaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpFb24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. FB24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpFb24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSinopsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sinopsychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSinopsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar92BacteriumBacl16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpNb68(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb68", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumDesmolans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium desmolans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDesmolans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfUnidentifiedScalySnailIsolateMonjuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified scaly snail isolate Monju Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentifiedScalySnailIsolateMonjuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaDermatitidisNihUt8656Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis NIH/UT8656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExophialaDermatitidisNihUt8656Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinusNbrc15237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus NBRC 15237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusNbrc15237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalusDomestica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malus domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalusDomestica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusFamiliarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus familiaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CanisLupusFamiliarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphopichiaBurtoniiNrrlY1933(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii NRRL Y-1933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyphopichiaBurtoniiNrrlY1933", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisSpNies3708Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3708 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3708Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpR11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. R11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuegeriaSpR11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraLinaloolentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera linaloolentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraLinaloolentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumAd3010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AD3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAd3010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioFairfieldensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fairfieldensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFairfieldensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioVulgarisHildenborough(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Hildenborough graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisHildenborough", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabidopsisLyrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisLyrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCarneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia carnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaCarneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasPhyllosphaeraeFa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae FA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaeraeFa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCag1963641(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CAG:196_36_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCag1963641", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaricaPapayaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Carica papaya Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaricaPapayaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansNbrc15126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans NBRC15126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansNbrc15126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermosubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SteroidobacterDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Steroidobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SteroidobacterDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyphaciaMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syphacia muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyphaciaMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk307Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk307Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitibacterSpBrhc19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter sp. BRHc19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterSpBrhc19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilodermaCroceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piloderma croceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PilodermaCroceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo1OfFrankliniellaOccidentalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 of Frankliniella occidentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1OfFrankliniellaOccidentalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSusongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia susongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSusongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumSpPmmr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium sp. PMMR2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidobacteriumSpPmmr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenbacteriaBacteriumRbg167146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eisenbacteria bacterium RBG167146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EisenbacteriaBacteriumRbg167146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumPhocaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium phocae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumPhocaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GleimiaEuropaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gleimia europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GleimiaEuropaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaMegalochromosomataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia megalochromosomata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaMegalochromosomataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterBilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPeucetiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora peucetia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPeucetiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQuintanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella quintana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaQuintanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPullorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPullorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeoglobusAhangariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus ahangari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAhangariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosovibrioTenuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio tenuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioTenuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGraminicolaM1001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola M1.001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGraminicolaM1001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimonasTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ValsaMaliVarPyriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Valsa mali var. pyri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ValsaMaliVarPyriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaSp13gom1096mCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. 13GOM1096m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSp13gom1096mCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBpaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBpaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSpM107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. M107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSpM107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquigenerosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equigenerosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquigenerosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpMc138b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MC13-8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMc138b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSalmonicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia salmonicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSalmonicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNourseiAtcc11455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces noursei ATCC 11455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesNourseiAtcc11455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMexicanaNbrc108244Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mexicana NBRC 108244 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaMexicanaNbrc108244Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag545(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag545", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRuminisAtcc27782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis ATCC27782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRuminisAtcc27782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaAlkaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlkaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MameliellaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mameliella alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MameliellaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU064 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp6c8div0013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 6C8DIV0013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp6c8div0013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anabaena variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnabaenaVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TamlanaSedimentorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tamlana sedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TamlanaSedimentorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3926 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioAespoeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio aespoeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioAespoeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallaecimonasPentaromativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas pentaromativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasPentaromativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidiphilusMargaritiferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidiphilus margaritifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidiphilusMargaritiferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKirkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kirkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKirkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg134915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_49_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumRs24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium RS24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumRs24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho201full5513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO201FULL5513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho201full5513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumFlavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumFlavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpongiibacterMarinusDsm19753Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter marinus DSM 19753 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpongiibacterMarinusDsm19753Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Danaus plexippus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DanausPlexippus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaValaisianaVs116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana VS116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaVs116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg19ftcombo6530(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO6530 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo6530", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PirellulaStaleyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pirellula staleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PirellulaStaleyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronococcusOccultus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus occultus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronococcusOccultus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag770Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:770 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag770Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAlbicansSc5314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans SC5314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaAlbicansSc5314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumNematocidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium nematocida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumNematocidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MediterraneaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mediterranea massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MediterraneaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSpMd25a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. MD25a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpMd25a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMonteiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas monteilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMonteiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentinusTigrinusAlcf2ss16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lentinus tigrinus ALCF2SS1-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LentinusTigrinusAlcf2ss16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_37_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSolitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium solitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSolitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNdiopicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ndiopicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusNdiopicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulaeDsm17944Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides insulae DSM 17944 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardioidesInsulaeDsm17944Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwa13413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA13413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa13413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSp9145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. 9145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSp9145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaLalandiDorsalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Seriola lalandi dorsalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SeriolaLalandiDorsalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrackiellaOedipodis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brackiella oedipodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrackiellaOedipodis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhytofirmansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phytofirmans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhytofirmansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaGraminisFSpTriticiCrl75367003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis f. sp. tritici CRL 75-36-700-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PucciniaGraminisFSpTriticiCrl75367003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpDg25aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwc23922Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWC23922 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwc23922Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraLinaloolentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera linaloolentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraLinaloolentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPentosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pentosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPentosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisa53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisA53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisa53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpC448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. C448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpC448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AvibacteriumParagallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumCsp17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium CSP1-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumCsp17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnobacteriumBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnobacteriumBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPLOWO2_12_FULL_48_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilumDsm16684Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum DSM 16684 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilumDsm16684Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium6626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 66-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGje10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GJE10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGje10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumRbg163414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RBG_16_34_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRbg163414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLeaf262Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf262Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusHalodenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus halodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusHalodenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocellaPaludicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocella paludicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocellaPaludicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlkylphenolia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenolia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PongoAbelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pongo abelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PongoAbelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPatagoniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella patagoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPatagoniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHigoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia higoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaHigoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaAtriluteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella atrilutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaAtriluteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNasuiaDeltocephalinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nasuia deltocephalinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNasuiaDeltocephalinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginaeDsm15829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae DSM15829 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaeDsm15829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaFiliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holdemania filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaFiliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArhodomonasAquaeoleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArhodomonasAquaeoleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterDaqiaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daqiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaqiaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LichtheimiaCorymbiferaJmrcFsu9682Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera JMRC:FSU:9682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LichtheimiaCorymbiferaJmrcFsu9682Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensMarinusS108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens marinus S1-08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NonlabensMarinusS108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnochordaPilosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnochorda pilosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnochordaPilosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeratitisCapitataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ceratitis capitata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CeratitisCapitataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnchocercaFlexuosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca flexuosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OnchocercaFlexuosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChungbukenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chungbukense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChungbukenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiovulumSpEsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiovulum sp. ES Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiovulumSpEsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeptuniibacterPectenicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter pectenicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterPectenicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLavenduligriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lavenduligriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLavenduligriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag492(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:492 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag492", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParachlamydiaceaeBacteriumHst3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydiaceae bacterium HST3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaceaeBacteriumHst3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp103mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 103mf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSp103mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxya2full3621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA2FULL3621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya2full3621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaFuscaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella fusca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFuscaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspSpizizeniiTuB10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. spizizenii TU-B-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspSpizizeniiTuB10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusSpMucl43196Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus sp. MUCL 43196 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizophagusSpMucl43196Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlassbacteriaBacteriumRifcsplowo212full5811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glassbacteria bacterium RIFCSPLOWO212FULL5811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlassbacteriaBacteriumRifcsplowo212full5811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinispiraMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinispira mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinispiraMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpEur3222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. EUR3222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpEur3222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisSpHtcc2633Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HTCC2633 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHtcc2633Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrrellaDioscoreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orrella dioscoreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrrellaDioscoreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpHmsc065f10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC065F10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc065f10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChersina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora chersina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaChersina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRoot209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. Root209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRoot209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumHalorespiransDsm13726Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans DSM 13726 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespiransDsm13726Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAbyssalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina abyssalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAbyssalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobaculumLitoreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasCitreaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas citrea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasCitreaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinimicrobiumSpCnj824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium sp. CNJ-824 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumSpCnj824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPurpureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces purpureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPurpureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwe13228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWE1_32_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwe13228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumJejuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jejuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJejuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAraiiNbrc100433Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia araii NBRC 100433 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GordoniaAraiiNbrc100433Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpOk602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ok602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpOk602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUreolyticusRigs9880Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus RIGS 9880 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUreolyticusRigs9880Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumSpAf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4510cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4510c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4510cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelosinusPropionicusDsm13327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus propionicus DSM 13327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PelosinusPropionicusDsm13327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTerreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus terreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusTerreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanimonasSpGk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas sp. GK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSpGk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusTiberiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus Tiberius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusTiberiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquiflexumBalticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquiflexum balticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquiflexumBalticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusObscuribacterPhosphatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Obscuribacter phosphatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusObscuribacterPhosphatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwr3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWR3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwr3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferAgarilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAgarilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpUcdfrssp1630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. UCDFRSSP1630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSpUcdfrssp1630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_42_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesPubescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trametes pubescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrametesPubescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrackiellaOedipodisDsm13743Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brackiella oedipodis DSM 13743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrackiellaOedipodisDsm13743Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAlgidicarnis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium algidicarnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAlgidicarnis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCoyleae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium coyleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCoyleae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchwartziaSuccinivoransDsm10502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans DSM 10502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchwartziaSuccinivoransDsm10502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMarseillensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marseillensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarseillensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterTyphloniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter typhlonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTyphloniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaAzaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora azatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAzaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrunusYedoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prunus yedoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrunusYedoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusNctc2665Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus NCTC 2665 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusNctc2665Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCurvus52592Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter curvus 525.92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterCurvus52592Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpRw2a1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. RW2A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpRw2a1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAkagiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium akagii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAkagiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_45_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumNitrativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodococcusSpAk35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus sp. AK35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiorhodococcusSpAk35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeijerinckiaMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalobiumEvestigatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisB6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisB6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumFrediiUsda257(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii USDA257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiUsda257", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumCg2303944Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2303944 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2303944Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFrederiksbergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas frederiksbergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFrederiksbergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumOxalicum1142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum 114-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliumOxalicum1142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJinjuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas jinjuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJinjuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabidopsisLyrataSubspLyrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata subsp. lyrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArabidopsisLyrataSubspLyrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpHgb0020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HGB0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHgb0020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LautropiaMirabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lautropia mirabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LautropiaMirabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumGwa2349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWA2349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwa2349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpJccCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. JCC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpJccCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimicrobiumAcidiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimicrobium acidiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimicrobiumAcidiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DictyosteliumPurpureumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium purpureum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumPurpureumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUvarumCbs121591(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus uvarum CBS 121591 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusUvarumCbs121591", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbimonasDonghaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Albimonas donghaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlbimonasDonghaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacteriumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpYl58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. YL58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpYl58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaLoihicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella loihica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaLoihicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasDiminuta4704Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta 4704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasDiminuta4704Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotignumPropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumPropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrapeneCarolinaTriunguisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrapene carolina triunguis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TerrapeneCarolinaTriunguisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminibacterMediatlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SanguibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylellinaHaptotylaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DactylellinaHaptotylaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TumebacillusFlagellatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tumebacillus flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TumebacillusFlagellatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdoribacterLaneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter laneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OdoribacterLaneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenyingzhuangiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysFlagransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys flagrans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysFlagransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasIssachenkoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas issachenkonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasIssachenkoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfiporiaCocosMd104Ss10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolfiporia cocos MD-104 SS10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolfiporiaCocosMd104Ss10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxPacificusW115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus W11-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxPacificusW115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IzhakiellaCapsodisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella capsodis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaCapsodisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusSpKp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. Kp2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpKp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSeriolaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia seriolae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSeriolaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaSanctiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sancti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSanctiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JatrophaCurcasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jatropha curcas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JatrophaCurcasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdhazardiaAedisUsnm41457(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Edhazardia aedis USNM 41457 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EdhazardiaAedisUsnm41457", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiniumEndosymbiontCeper1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cEper1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCeper1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaHulunbeirensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaRapaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brassica rapa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrassicaRapaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHordeiDsm19519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hordei DSM 19519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHordeiDsm19519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaCellulosilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumFrisingenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum frisingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumFrisingenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludisphaeraBorealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paludisphaera borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaludisphaeraBorealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulciaMuelleriGwssEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri GWSS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriGwssEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraNanhaiensisE4078Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis E407-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensisE4078Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosporaCaninumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neospora caninum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeosporaCaninumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelusAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Struthio camelus australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StruthioCamelusAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasQingdaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas qingdaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasQingdaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaeraeDsm18581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae DSM 18581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioRhizosphaeraeDsm18581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpCm6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. CM6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpCm6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrospiraPlatensisYzCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis YZ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisYzCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumTumefaciensF2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens F2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensF2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobiusGelatinovorusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius gelatinovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusGelatinovorusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSpSb3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. SB3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpSb3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumScgcAaa300k03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA300K03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa300k03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hordeum vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HordeumVulgare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaSpJa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora sp. JA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpathasporaSpJa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliothisVirescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heliothis virescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeliothisVirescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMerionis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus merionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMerionis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMisionensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces misionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMisionensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterCurvatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCurvatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriTs44(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri TS44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriTs44", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSpJcm19060Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. JCM 19060 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpJcm19060Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaAfzeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella afzelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaAfzeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumEhc05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium EhC05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumEhc05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAvicenniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvicenniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110053Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110053Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MeiothermusTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumOryziradicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryziradicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryziradicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSibiricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sibiricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSibiricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar86ClusterBacteriumBacl1Mag120820Bin45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 MAG-120820-bin45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1Mag120820Bin45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticumS6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumS6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesObesiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes obesi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesObesiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumAaa252a02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium AAA252A02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumAaa252a02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumJohnsoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium johnsoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumJohnsoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumInsulareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum insulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumInsulareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumP6b14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6B14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6b14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterCertesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter certesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenibacterCertesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeeuwenhoekiellaSpMar2009132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. MAR2009132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpMar2009132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_70_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusPastoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus pastoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusPastoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusIbericusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ibericus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusIbericusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylothermusHellenicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus hellenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusHellenicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNfr07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelliellaPelovolcaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Belliella pelovolcani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BelliellaPelovolcaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_37_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAcidiscabiesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces acidiscabies Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAcidiscabiesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpNa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. NA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpNa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_49_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterLutiphocae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter lutiphocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterLutiphocae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumJcvitm6sc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium JCVITM6SC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumJcvitm6sc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaccharosporaIrregularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGigasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gigas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGigasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusGonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus gonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusGonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYk2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YK2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYk2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaSlithyformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Runella slithyformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RunellaSlithyformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpTnd4ek4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. TND4EK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpTnd4ek4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusIsoporaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus isoporae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusIsoporaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusAsinusAsinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Equus asinus asinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EquusAsinusAsinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpBal39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BAL39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBal39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho212full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO212FULL4311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho212full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicocarpusGriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicocarpus griseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicocarpusGriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogeometricumBorinquenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum borinquense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumBorinquenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3718 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFairfieldensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella fairfieldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaFairfieldensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAbawacabacteriaBacteriumRbg164210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Abawacabacteria bacterium RBG_16_42_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAbawacabacteriaBacteriumRbg164210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActibacteriumMucosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium mucosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumMucosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusUreilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus ureilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusUreilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuganellaZoogloeoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaZoogloeoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpNi22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. NI22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodovulumSpNi22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloferulaStellataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloferula stellata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloferulaStellataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumOrbiculareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaNasimurium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rothia nasimurium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RothiaNasimurium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpWsf3629Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. WSF 3629 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpWsf3629Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu036Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu036Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobacterPhocaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobacter phocae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobacterPhocaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumM102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium M102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumM102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAggregata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAggregata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full4219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaTardaAtcc15947Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Edwardsiella tarda ATCC15947 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EdwardsiellaTardaAtcc15947Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMelliferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma melliferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaMelliferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumHtcc2255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium HTCC2255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumHtcc2255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumQ1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Q-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumQ1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumImcc3088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumImcc3088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioSpMa26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MA2-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMa26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlleyaNamhaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olleya namhaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlleyaNamhaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurotusOstreatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PleurotusOstreatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosynnemaSpAli144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema sp. ALI-1.44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaSpAli144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSp1135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyd2full3916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYD2FULL3916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyd2full3916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUterequi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium uterequi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUterequi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasSpFbcdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FBCd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFbcdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDentasiniJcm15908Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentasini JCM 15908 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDentasiniJcm15908Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_34b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniaeHk85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae HK 85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusPittmaniaeHk85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpP2s70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. P2S70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpP2s70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpRoot133(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot133", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaAtcc43768Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea ATCC 43768 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaAtcc43768Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumParaoxydans77mftsu32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans 77MFTsu32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydans77mftsu32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArachidicoccusSpBs20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus sp. BS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusSpBs20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusManzaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidianus manzaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidianusManzaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoHordeiUh48574Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Uh4857-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UstilagoHordeiUh48574Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp233421i1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 233421I1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp233421i1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSp9140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. 9140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSp9140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpLw4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterButzleriRm4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri RM4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriRm4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZincidurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zincidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasZincidurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonesiaQuinghaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jonesia quinghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JonesiaQuinghaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpSt904Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. ST904 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpSt904Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumCiceriBiovar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri biovar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriBiovar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCfSaccharolyticumK10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cf. saccharolyticum K10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCfSaccharolyticumK10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacteriumJdfr48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndocarponPusillum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Endocarpon pusillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndocarponPusillum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsialesBacteriumAc37bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Ac37b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacteriumAc37bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumImcc26134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium IMCC26134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumImcc26134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesTsukubensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces tsukubensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTsukubensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSp197aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halococcus sp. 197A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalococcusSp197aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc13813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC1_38_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc13813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeon13140cm3386Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon 13_1_40CM_3_38_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeon13140cm3386Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpHb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. HB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpHb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeniophoraSpContCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peniophora sp. CONT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeniophoraSpContCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifoxyb2full4511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB2FULL4511 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb2full4511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaCepacia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cepacia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCepacia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumJeikeiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeikeium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeikeiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPallidulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola pallidula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPallidulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb241528n17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_528N17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528n17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesFarautiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles farauti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesFarautiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRifcsphigho202full4313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPHIGHO202FULL4313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsphigho202full4313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachipleistophoraHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trachipleistophora hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrachipleistophoraHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixRhusiopathiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix rhusiopathiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixRhusiopathiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesJeddahensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces jeddahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesJeddahensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSoliNbrc100801Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas soli NBRC 100801 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSoliNbrc100801Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho212full4412bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO212FULL4412b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho212full4412bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumMaltaromaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium maltaromaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMaltaromaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4027Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4027 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4027Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaSpheciospongiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora spheciospongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaSpheciospongiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg134613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_13_46_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg134613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalitaleaCylindroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyc2full3412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYC2FULL3412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyc2full3412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NectriaHaematococcaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nectria haematococca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NectriaHaematococcaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetragenococcusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDrentensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus drentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusDrentensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot472d3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root472D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot472d3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaAtcc43541Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia ATCC43541 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaAtcc43541Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag791Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:791 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag791Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGm21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GM21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpGm21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumCg1026018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium CG1_02_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumCg1026018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmorphothecaResinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amorphotheca resinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmorphothecaResinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk283Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK283 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk283Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cynara cardunculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CynaraCardunculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jacksonbacteria bacterium RIFOXYA2_FULL_43_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaMucilaginosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rothia mucilaginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RothiaMucilaginosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusEquiDsm15833Jcm10991(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equi DSM 15833 JCM 10991 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusEquiDsm15833Jcm10991", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumUreilyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium ureilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumUreilyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBovisM02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis m02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovisM02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastochlorisViridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastochloris viridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastochlorisViridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesJohnsoniiDsm18315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii DSM 18315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsoniiDsm18315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1203Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1203 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1203Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo202full4813bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL4813b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full4813bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacteraceaeBacteriumGwc25520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_55_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnccl117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNCCL117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnccl117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxya2Full4315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA2_FULL_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya2Full4315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_42_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaCitrea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora citrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCitrea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisAlexandriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis alexandrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisAlexandriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwc246850Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWC2_46_850 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwc246850Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSp1485eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. 1485E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSp1485eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusSpUfo1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus sp. UFO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelosinusSpUfo1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocoliticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaEnterocoliticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSpJc4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. JC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpJc4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumHalophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumHalophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaPennsylvanicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia pennsylvanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaPennsylvanicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterColi76339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli 76339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterColi76339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaOh4807Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida OH4807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaOh4807Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriCcug29243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri CCUG 29243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriCcug29243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_36_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr50345Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR50345 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr50345Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusHerbarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus herbarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHerbarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacterLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NoviherbaspirillumSpRoot189Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum sp. Root189 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumSpRoot189Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuromonasThiophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas thiophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasThiophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaAzureaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora azurea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaAzureaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraRoreriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora roreri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraRoreriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GanodermaSinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ganoderma sinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GanodermaSinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSpMa067296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. MA067296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpMa067296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusArctosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ursus arctos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrsusArctosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumCasei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumCasei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosakoniaCowaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia cowanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KosakoniaCowaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesDavawensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces davawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesDavawensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonsdaleaBritannicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea britannica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaBritannicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaIgnavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Facklamia ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FacklamiaIgnavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConchiformibiusSteedae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius steedae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusSteedae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumScatologenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scatologenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScatologenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasBromiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas bromi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasBromiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasiiAtcc12478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii ATCC12478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasiiAtcc12478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaWeaveriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria weaveri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWeaveriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParafilimonasTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parafilimonas terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParafilimonasTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantisSk970Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK970 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk970Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaMajorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leishmania major Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaMajorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophothermusLipocalidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus lipocalidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusLipocalidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumRifcsplowo212full3712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSpT3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. T3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpT3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSubsaxonicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium subsaxonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSubsaxonicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwb13613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb13613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaDonghaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina donghaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaDonghaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwa13716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWA1_37_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwa13716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumCg1023721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermaeBacteriumJdfr72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermae bacterium JdFR-72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermaeBacteriumJdfr72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_45_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPsittaci6bcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 6BC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci6bcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumSaccharolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium saccharolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSaccharolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNasuiaDeltocephalinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nasuia deltocephalinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNasuiaDeltocephalinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSp627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. 627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesSp627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumConspicuumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium conspicuum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumConspicuumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferSpZgt114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. ZGT114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpZgt114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusDamuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus damuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusDamuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryhalocaulisCaribicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryhalocaulis caribicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryhalocaulisCaribicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraRamorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora ramorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraRamorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPhocaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus phocaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPhocaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesocestoidesCorti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesocestoides corti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesocestoidesCorti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrellaSpEs10322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrella sp. ES10-3-2-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrellaSpEs10322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumIriomotense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium iriomotense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumIriomotense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3718 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaJaponicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaJaponicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterSpUcdthuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. UCDTHU Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpUcdthuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpFobrc9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpKh3b4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. KH3B4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpKh3b4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot404(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot404", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeyerozymaGuilliermondiiAtcc6260Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii ATCC 6260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondiiAtcc6260Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthamoebaCastellanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcanthamoebaCastellanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHuangheensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas huangheensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasHuangheensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisSpAc466(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC466 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc466", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpMc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisSpMc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorselliaAnophelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thorsellia anophelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThorselliaAnophelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParabrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabrevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303346Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_33_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303346Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluviicolaRiflensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FluviicolaRiflensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusCandidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus candidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusCandidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusWakoensisJcm9140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus wakoensis JCM 9140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusWakoensisJcm9140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColobusAngolensisPalliatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colobus angolensis palliatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColobusAngolensisPalliatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosiphoAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumBarkeri2011R4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium barkeri 2011-R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeri2011R4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumYim77505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium YIM77505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumYim77505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EgrettaGarzetta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Egretta garzetta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EgrettaGarzetta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaVerticillata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mortierella verticillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MortierellaVerticillata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSimilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus similis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSimilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg165418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_54_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaSp22iis11z7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. 22IIS11z7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSp22iis11z7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaSpDiamant(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Diamant graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpDiamant", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaHypoxylonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylaria hypoxylon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylariaHypoxylonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaStriiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puccinia striiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PucciniaStriiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag272Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag272Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaAbortusLlg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia abortus LLG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaAbortusLlg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliscomenobacterHydrossisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haliscomenobacter hydrossis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaliscomenobacterHydrossisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMum116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MUM 116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMum116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumCm5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium CM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumCm5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFlorumDsm22689Jcm16035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum DSM 22689 JCM 16035 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFlorumDsm22689Jcm16035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusDelemarRa99880(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar RA 99-880 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizopusDelemarRa99880", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumCg2303639Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG2_30_36_39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg2303639Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriA1501(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri A1501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriA1501", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpArh5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ARh5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpArh5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg166615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_66_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_53_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpB6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. B6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpB6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaUrealyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma urealyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaUrealyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaIowae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma iowae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaIowae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterDelicatusNbrc14919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter delicatus NBRC 14919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CurvibacterDelicatusNbrc14919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesFlavochromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavochromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpTg39aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TG39a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpTg39aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu030Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU030 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu030Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesImmunogenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides immunogenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesImmunogenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachymonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachymonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpEhn04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. EhN04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpEhn04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmilianiaHuxleyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emiliania huxleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmilianiaHuxleyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCapeferrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas capeferrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCapeferrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidibacillusFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidibacillus ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidibacillusFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciensFd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens FD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensFd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterNicotinovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nicotinovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterNicotinovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligellaUrethralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oligella urethralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OligellaUrethralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusArthromitusSpSfbTurkeyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arthromitus sp. SFB-turkey Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusArthromitusSpSfbTurkeyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusVanfongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus vanfongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusVanfongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSusongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia susongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSusongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumDesertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDesertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MahellaAustraliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mahella australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MahellaAustraliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VanderwaltozymaPolysporaDsm70294(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora DSM 70294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VanderwaltozymaPolysporaDsm70294", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhymatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phymatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhymatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSzechwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides szechwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSzechwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaSpLeaf244Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf244Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4625(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4625", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisPorriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botrytis porri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotrytisPorriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInadaiSerovarLymeStr10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira inadai serovar Lyme str. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInadaiSerovarLymeStr10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CavenderiaFasciculataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CavenderiaFasciculataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylicusMesodigestumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus mesodigestum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusMesodigestumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpWcc10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. WCC10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpWcc10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMarinumDsm44953Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium marinum DSM 44953 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumMarinumDsm44953Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfidibacterTakaiiAbi70s6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii ABI70S6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaiiAbi70s6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterCrescentusOr37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus OR37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusOr37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharolobusSolfataricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharolobus solfataricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharolobusSolfataricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NadsoniaFulvescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NadsoniaFulvescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaHaemulonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Candida] haemulonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaHaemulonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrochothrixCampestrisFslF61037(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix campestris FSL F6-1037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrochothrixCampestrisFslF61037", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaphrinaDeformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taphrina deformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaphrinaDeformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterColiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter coli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterColiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo202full6128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesIsraelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces israelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesIsraelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumScindensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scindens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScindensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SlackiaHeliotrinireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Slackia heliotrinireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SlackiaHeliotrinireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporisoriumReilianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporisorium reilianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporisoriumReilianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoxodontaAfricana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loxodonta africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoxodontaAfricana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiCj3symCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti CJ3sym Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiCj3symCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HippeaAlviniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hippea alviniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HippeaAlviniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJeoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jeonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJeoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaOakridgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella oakridgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaOakridgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisSubspCoryniformisCect5711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis subsp. coryniformis CECT 5711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisSubspCoryniformisCect5711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusZopfiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusZopfiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLongbeachae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella longbeachae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaLongbeachae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterBaekdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter baekdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterBaekdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumAap99Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap99Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTaylorii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella taylorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaTaylorii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterActiniarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpCf038Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. CF038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpCf038Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaApicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella apicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilliamellaApicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4393Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4393Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaSpUrhb0036Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. URHB0036 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpUrhb0036Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpKu2611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU2-6(11) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu2611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioJasicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio jasicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioJasicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPyridomyceticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pyridomyceticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPyridomyceticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusSpJchs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus sp. JCHS_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusSpJchs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasAlkaliantarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas alkaliantarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasAlkaliantarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwe132154Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWE1_32_154 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwe132154Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalosaccharovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halosaccharovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHalosaccharovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniaeJEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae J Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniaeJEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CriblamydiaSequanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Criblamydia sequanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CriblamydiaSequanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthellaSpYy7918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. YY7918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpYy7918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusFleurettiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus fleurettii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusFleurettiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSulfidophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sulfidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSulfidophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurellaAmilsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella amilsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAmilsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCongonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides congonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCongonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaPedrosoiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaLiquefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia liquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaLiquefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabisAlpina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arabis alpina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArabisAlpina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus oralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpPamc26554Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26554Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GregarinaNiphandrodesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gregarina niphandrodes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GregarinaNiphandrodesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobiArchaeonJdfr42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon JdFR-42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeonJdfr42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilis3112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis 3112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilis3112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterArilaitensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter arilaitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterArilaitensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumFlorentinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium florentinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFlorentinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraHibiscaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura hibisca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraHibiscaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaTularensisNovicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis novicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisNovicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaParvirubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sutterella parvirubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SutterellaParvirubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaBurnetiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coxiella burnetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoxiellaBurnetiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaBannensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bannensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBannensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAvidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium avidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAvidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotum397(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium nepotum 39/7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumNepotum397", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliicoccusPersicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliicoccus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliicoccusPersicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbimonasPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Albimonas pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlbimonasPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaRocourtiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria rocourtiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaRocourtiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo5817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_58_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo5817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsplowo212full4211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO212FULL4211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo212full4211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GopherusAgassizii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gopherus agassizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GopherusAgassizii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorselliaAnophelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thorsellia anophelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThorselliaAnophelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf343Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf343Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChthoniobacterFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chthoniobacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChthoniobacterFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumSalamandrivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium salamandrivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumSalamandrivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMste9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MSTE9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMste9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa2407bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA2407b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa2407bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_69_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixDisciformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix disciformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiothrixDisciformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTa06BacteriumDg24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium DG_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06BacteriumDg24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusKribbensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus kribbensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusKribbensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaceaeBacteriumPmp191f(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium PMP191F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumPmp191f", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13140cm2607(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_40CM_2_60_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13140cm2607", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCl2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Anaerolineaceae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Anaerolineaceae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAgnetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus agnetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAgnetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMohnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mohnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMohnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrococcusCaseolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus caseolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCaseolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCholeraeO1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "VibrioCholeraeO1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DechloromonasAgitata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas agitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAgitata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArachidicoccusRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTerreusNih2624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus NIH2624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusTerreusNih2624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterSpHl12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. HL-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpHl12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaMicrofususCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rikenella microfusus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RikenellaMicrofususCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalispirochaetaAmericanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta americana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAmericanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalusBaccataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malus baccata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalusBaccataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PneumocystisMurina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis murina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PneumocystisMurina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgaricusBisporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agaricus bisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgaricusBisporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPametensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pametensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPametensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpUrha0041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. URHA0041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpUrha0041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLz4wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Lz4W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpLz4wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaOneidensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella oneidensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaOneidensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisIgneusKol5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris igneus Kol 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisIgneusKol5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumHigginsianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puccinia graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PucciniaGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerribacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerribacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaOxytoca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella oxytoca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaOxytoca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansK601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans K601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansK601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAlienaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas aliena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAlienaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaXyliCynodontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli cynodontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCynodontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpBolea5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. BoleA5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpBolea5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaBrachyanthaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza brachyantha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaBrachyanthaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycetocolaMiduiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola miduiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycetocolaMiduiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterGhanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ghanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterGhanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusUvarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus uvarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusUvarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesiotobacterExalbescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesiotobacter exalbescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesiotobacterExalbescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoaurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoaurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoaurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioZosteraeDsm11974Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae DSM 11974 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioZosteraeDsm11974Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAtcc31555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ATCC31555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAtcc31555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13817 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumPuteiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumPuteiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSchindleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter schindleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSchindleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorallococcusCoralloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus coralloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorallococcusCoralloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansAtcc25259Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans ATCC25259 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansAtcc25259Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesLimnophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces limnophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesLimnophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaAnimalorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria animaloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaAnimalorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaSpPamc20917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 20917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc20917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrigoribacteriumSpLeaf164Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf164Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylariaHypoxylon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylaria hypoxylon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylariaHypoxylon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpAc3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. AC-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpAc3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpAsf519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. ASF519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesSpAsf519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpBmg51109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG51109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg51109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterAerophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterAerophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_12_FULL_60_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPasteuriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pasteuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPasteuriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanibaculumNanhaienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum nanhaiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumNanhaienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensis0850475Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoeensis 085-0475 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoeensis0850475Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensUlvanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens ulvanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensUlvanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPseudoporcinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudoporcinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudoporcinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpLig30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. lig30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpLig30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasStagniDsm19981(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas stagni DSM 19981 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseomonasStagniDsm19981", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf25010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_50_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf25010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusKimchiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus kimchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusKimchiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaGranulosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga granulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGranulosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAnimalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPinihumiDsm23905Jcm16419Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi DSM 23905 JCM 16419 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPinihumiDsm23905Jcm16419Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJ33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. J33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJ33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpLeaf26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Leaf26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpLeaf26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMt11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium mt11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMt11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaW619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida W619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaW619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumScgcAaa027k21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium SCGC AAA027K21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumScgcAaa027k21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_12_FULL_41_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetofabaAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetofaba australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetofabaAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium4423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 44-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium4423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpPamc28711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. PAMC 28711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpPamc28711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpMh3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. MH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpMh3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpNies3755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-3755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies3755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusMediterraneusDsm13871Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus DSM 13871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneusDsm13871Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophoarchaeumCaldariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum caldarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumCaldariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpDm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. DM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpDm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviitaleaPhaphyphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Defluviitalea phaphyphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DefluviitaleaPhaphyphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterPeloridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter peloridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPeloridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterSpLeaf185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonosporaCurvataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermomonospora curvata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermomonosporaCurvataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterEchinorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter echinorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterEchinorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6676Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6676 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6676Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusTc41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius Tc41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusTc41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterCorallicolaNbrc107790Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Janibacter corallicola NBRC 107790 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JanibacterCorallicolaNbrc107790Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumMercanteiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium mercantei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMercanteiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetraodonNigroviridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetraodon nigroviridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetraodonNigroviridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonAb25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon AB_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonAb25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumHydrothermale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum hydrothermale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumHydrothermale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag177Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:177 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag177Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSp113p3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. 113P3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSp113p3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPHIGHO2_02_FULL_52_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsphigho202Full5217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOryzihabitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzihabitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzihabitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaSchinkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia schinkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaSchinkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuhomycesTanzawaensisNrrlY17324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis NRRL Y-17324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensisNrrlY17324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:628 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxosarcinaSpGi1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxosarcina sp. GI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxosarcinaSpGi1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesToyocaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces toyocaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesToyocaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlumeriaGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blumeria graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlumeriaGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifoxyc2full479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYC2FULL479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyc2full479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChoiromycesVenosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Choiromyces venosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChoiromycesVenosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full4630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL4630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full4630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraLucentensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira lucentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraLucentensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaTriticina11BbbdRace1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Puccinia triticina 1-1 BBBD Race 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PucciniaTriticina11BbbdRace1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23827 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumCiceriCa181Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri ca181 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriCa181Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpRoot930Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root930 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot930Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpChd6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CHD6a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpChd6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaTabacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana tabacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NicotianaTabacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpBp7605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. Bp7605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpBp7605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEpsl27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EPSL27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEpsl27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_33_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasVirosaDsm23226Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas virosa DSM 23226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyricimonasVirosaDsm23226Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarboxydocellaSpUlo1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carboxydocella sp. ULO1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarboxydocellaSpUlo1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterStanieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter stanieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterStanieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo201full4421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO201FULL4421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo201full4421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraAraneosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaera araneosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraAraneosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCadaverisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cadaveris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCadaverisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParamicrosporidiumSaccamoebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paramicrosporidium saccamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParamicrosporidiumSaccamoebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaMeyeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia meyeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaMeyeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nosema ceranae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NosemaCeranaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyc1full3779Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYC1FULL3779 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyc1full3779Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_39_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27445Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27445 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27445Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpQxt31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. QXT-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpQxt31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigidimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLundenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium lundense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLundenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomarinaGelatinilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomarina gelatinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomarinaGelatinilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpLeaf160(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf160", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisciDsm44792Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci DSM 44792 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisciDsm44792Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioFibrisolvens164(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens 16/4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvens164", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp7016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 70-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo2024111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO2024111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo2024111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaBombycisCq1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nosema bombycis CQ1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NosemaBombycisCq1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf231Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf231 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf231Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStationisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium stationis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStationisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumPeriodonticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium periodonticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPeriodonticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiameybacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niameybacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiameybacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLjungdahliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ljungdahlii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLjungdahliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLuteocolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteocolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteocolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKansasiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaGrandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria grandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrosmanniaClavigeraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Grosmannia clavigera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GrosmanniaClavigeraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg166620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_66_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpBf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. BF4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSpBf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovoculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovoculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovoculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpAf1028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpAf1028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumSg841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg2304418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLappah95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpLappah95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohongiellaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorMitchellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloramator mitchellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloramatorMitchellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitrellaBrassicaformisCcmp3155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis CCMP3155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VitrellaBrassicaformisCcmp3155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_63_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParaplantarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paraplantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParaplantarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInterrogansSerovarLaiStr56601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira interrogans serovar Lai str. 56601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInterrogansSerovarLaiStr56601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterAtrinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter atrinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterAtrinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLnhc252b00Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNHC252B00 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnhc252b00Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaGerundensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia gerundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaGerundensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloracidobacteriumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodomicrobiumVannieliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium vannielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumVannieliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpAt9b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. At9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpAt9b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaElarraichensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solemya elarraichensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolemyaElarraichensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalisaetaLonga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salisaeta longa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalisaetaLonga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNbrc109706Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 109706 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc109706Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MogibacteriumSpCm50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mogibacterium sp. CM50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MogibacteriumSpCm50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis2F0392Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 F0392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2F0392Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlammeovirgaSpMy04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. MY04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpMy04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumGwa24115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_41_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa24115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasThermotoleransDsm14292Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans DSM 14292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasThermotoleransDsm14292Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotodesmusKatoptron(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus katoptron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusKatoptron", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioMarinisediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinivibrionaceaeBacteriumWg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrionaceae bacterium WG-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrionaceaeBacteriumWg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusEapokensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus eapokensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusEapokensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpWcd3002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD3002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd3002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasKorlensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas korlensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasKorlensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD1_FULL_56_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusFerrophilusDsm13482Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus DSM 13482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilusDsm13482Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpCag435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamsiaSp1135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwd24214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD24214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd24214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesEgde(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes EGDe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesEgde", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZhouiaAmylolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zhouia amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZhouiaAmylolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixSoehngeniiGp6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii GP6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanothrixSoehngeniiGp6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSediminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus sediminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusSediminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpMccc1a10513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MCCC1A10513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSpMccc1a10513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TessaracoccusFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifcsphigho201full5110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL5110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full5110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24711b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_47_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24711b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFlocculareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFlocculareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceispirillumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puniceispirillum marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PuniceispirillumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaBettyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella bettyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaBettyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdinarchaeotaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Odinarchaeota archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OdinarchaeotaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanaeolusCyanescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Panaeolus cyanescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PanaeolusCyanescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendroctonusPonderosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dendroctonus ponderosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DendroctonusPonderosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalioglobusPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalioglobusPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EffusibacillusPohliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Effusibacillus pohliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EffusibacillusPohliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaHoutenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica houtenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaHoutenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpLeaf69Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf69 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf69Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJejuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jejuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJejuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa264110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_64_110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa264110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpQh12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. QH-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpQh12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetraodonNigroviridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetraodon nigroviridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetraodonNigroviridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSatsumensisDsm16230Jcm12392Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis DSM 16230 JCM 12392 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSatsumensisDsm16230Jcm12392Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterTyphlonius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter typhlonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTyphlonius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiSerovarPomonaStr200901868Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Pomona str. 200901868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarPomonaStr200901868Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IxodesScapularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ixodes scapularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IxodesScapularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusHalodenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus halodenitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusHalodenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484702 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelissococcusPlutoniusAtcc35311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Melissococcus plutonius ATCC 35311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MelissococcusPlutoniusAtcc35311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaLupiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lupini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLupiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosocomiicoccusSpNp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus sp. NP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NosocomiicoccusSpNp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BarnesiellaViscericolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella viscericola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaViscericolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerophagaThermohalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerophaga thermohalophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerophagaThermohalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VitrellaBrassicaformisCcmp3155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis CCMP3155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VitrellaBrassicaformisCcmp3155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfallasGibsoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas gibsoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGibsoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSoleaferreaMassiliensisAp7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Soleaferrea massiliensis AP7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSoleaferreaMassiliensisAp7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumM12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLegalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio legallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLegalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpErv7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ERV7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpErv7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiHcThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HC Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHcThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesOdoratimimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratimimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratimimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAmblyommatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaAsiaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba asiatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaAsiaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumNoncentrifugensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium noncentrifugens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumNoncentrifugensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpErvv1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. ErVv1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpErvv1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopertinaxCowenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfopertinax cowenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfopertinaxCowenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineosporiaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kineosporia aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KineosporiaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMuralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMuralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumChlorochromatii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium chlorochromatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumChlorochromatii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTransvalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia transvalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaTransvalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBifermentansDsm20003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans DSM 20003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBifermentansDsm20003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAssamensisDsm18201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis DSM 18201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAssamensisDsm18201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasCompostiDsm21721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas composti DSM 21721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonasCompostiDsm21721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaSpT6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo212full6140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumOraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumOraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaBrunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella brunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaBrunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSubrutilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces subrutilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSubrutilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevinemaAndersoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevinema andersonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevinemaAndersoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaRhizoxinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia rhizoxinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaRhizoxinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KandleriaVitulina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kandleria vitulina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KandleriaVitulina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpCubenseRace4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_51_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumLeiognathiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifoxyb1full4324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYB1FULL4324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyb1full4324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBeijingensisNbrc16342(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia beijingensis NBRC 16342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaBeijingensisNbrc16342", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLitoralisDsm11393Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis DSM 11393 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralisDsm11393Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaEburnea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora eburnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaEburnea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRbg133615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG133615 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg133615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdobenusRosmarusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Odobenus rosmarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OdobenusRosmarusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumVivaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium vivax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumVivaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenothrixSpD3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenothrix sp. D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenothrixSpD3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMonteiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas monteilii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMonteiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota group-6 archaeon AD8-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaTyrosinoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga tyrosinoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaTyrosinoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetomicrobiumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSoudanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas soudanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSoudanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumNeutrophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum neutrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumNeutrophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpLeaf131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatiglansAniliniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatiglansAniliniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCoyleaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium coyleae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCoyleaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyosynoviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyosynoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyosynoviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminobacterHydrogenoformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaSp4g2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lewinella sp. 4G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LewinellaSp4g2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterOskolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter oskolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RathayibacterOskolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumSpPsu2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium sp. PSU-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSpPsu2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomonasBhubaneswarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas bhubaneswarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomonasBhubaneswarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpArh5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ARh5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpArh5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPorci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb00455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB00455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb00455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumVacuolatumDsm3385Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum DSM 3385 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatumDsm3385Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVelezensisTrigocor1448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis TrigoCor1448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisTrigocor1448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAnimalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAnimalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusWakoensisJcm9140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus wakoensis JCM 9140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusWakoensisJcm9140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaOdoriferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia odorifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaOdoriferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBovieniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus bovienii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBovieniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaDonostiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia donostiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaDonostiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpGw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. GW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChelatococcusSpGw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExserohilumTurcica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exserohilum turcica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExserohilumTurcica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusFujiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusFujiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathymodiolusAzoricusThioautotrophicGillSymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus thioautotrophic gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BathymodiolusAzoricusThioautotrophicGillSymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSp73sEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. 73s Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSp73sEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAsperellumCbs43397(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma asperellum CBS 433.97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAsperellumCbs43397", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumHveragerdense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hveragerdense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHveragerdense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaLacuscaerulensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria lacuscaerulensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaLacuscaerulensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumJaponicumUt26sCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium japonicum UT26S Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumJaponicumUt26sCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumVaccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vaccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVaccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag1024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LamprocystisPurpurea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LamprocystisPurpurea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp10819081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1081908.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp10819081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterGummiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter gummiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobacterGummiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoenixDactylifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phoenix dactylifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhoenixDactylifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpMsmb0266Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. MSMB0266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpMsmb0266Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesSpMarseillep3160Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. MarseilleP3160 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpMarseillep3160Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGaetbulicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrabacterSpRoot85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Root85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpRoot85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesSpJdfr54Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr54Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatiglansAnilini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatiglansAnilini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasEutropha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas eutropha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEutropha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaPolarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaPolarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPiscicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piscicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiscicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicusStrDeltaHCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus str. Delta H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicusStrDeltaHCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaWallisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea wallisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaWallisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminicellaSporogenesDsm14501Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caminicella sporogenes DSM 14501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaminicellaSporogenesDsm14501Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPasteurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPasteurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusRotaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rotai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRotaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full468Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full468Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaAnisaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella anisa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaAnisaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaHanseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia hansenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaHanseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMaculosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella maculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMaculosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSulfaticallidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sulfaticallidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSulfaticallidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBorealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus borealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBorealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesInjenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myroides injenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyroidesInjenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusHarei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus harei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusHarei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp351mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 351MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp351mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteScgcAb629i23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AB629I23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAb629i23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FodinicurvataSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaSubspMultocidaStrPm70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida str. Pm70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaStrPm70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifoxyc1full4826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFOXYC1FULL4826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifoxyc1full4826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaXyliCtcb07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli CTCB07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCtcb07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCaspthauma4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TeredinibacterTurneraeT7902Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7902 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7902Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfHeteropsyllaCubanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla cubana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCubanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTuccetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTuccetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdwardsbacteriaBacteriumGwe25412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edwardsbacteria bacterium GWE25412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdwardsbacteriaBacteriumGwe25412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacterSaccharofermentansDsm14828Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans DSM 14828 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentansDsm14828Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMethanolicusMga3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus MGA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusMga3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaBurgdorferiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSpAntb6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sp. ANTB6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSpAntb6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAlcalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alcalophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAlcalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterCrystallopoietesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter crystallopoietes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCrystallopoietesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiyogibacteriaBacteriumRifcsplowo202full4513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO202FULL4513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo202full4513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GalerinaMarginata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Galerina marginata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GalerinaMarginata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeggiatoaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusTrichosporiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus trichosporium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosinusTrichosporiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCallitrichos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium callitrichos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCallitrichos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaCentrale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma centrale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaCentrale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFloridensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFloridensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSpRu39bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sp. RU39B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSpRu39bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianus3p3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus 3P3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianus3p3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAt4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AT4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAt4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidothermusCellulolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidothermus cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidothermusCellulolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaTropicalisMya3404Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis MYA-3404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaTropicalisMya3404Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAngulatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium angulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAngulatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSphaeroides241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides 241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroides241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScopuliridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scopuliridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScopuliridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacteraceaeBacteriumGwc25844(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_58_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25844", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandaracinusAmylolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sandaracinus amylolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SandaracinusAmylolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full4432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4432 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrionaceaeBacteriumBs12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium Bs12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacteriumBs12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumBrisbanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brisbanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrisbanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaParamesenteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella paramesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaParamesenteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaElaeagni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia elaeagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaElaeagni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full5423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL5423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full5423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa15613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA15613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa15613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70273Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70273 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70273Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacillusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSp10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSp10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DialisterMicroaerophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dialister microaerophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DialisterMicroaerophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumKbs89Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs89Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26618Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_66_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26618Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAt4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AT4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAt4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNovofumigatusIbt16806(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus IBT 16806 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusNovofumigatusIbt16806", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_49_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentitaleaNanhaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sedimentitalea nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SedimentitaleaNanhaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusGobiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus gobiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGobiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumMesophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum mesophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMesophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamsiaSterculiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sterculiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSterculiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloscardoviaCricetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia criceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaCricetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetalesBacteriumSpiro05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioCosticolaSubspAlcaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio costicola subsp. alcaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioCosticolaSubspAlcaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifoxyc12full6523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYC12FULL6523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyc12full6523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MortierellaVerticillataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mortierella verticillata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MortierellaVerticillataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinopsTelfairi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echinops telfairi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EchinopsTelfairi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAkl11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterUraniireducensRf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Rf4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacterUraniireducensRf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumViciae248Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae248Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. enterica serovar Typhimurium str. LT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfDactylopiusCoccusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius coccus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCoccusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeratitisCapitataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceratitis capitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CeratitisCapitataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesImmitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusIslandicusDsm13165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus DSM 13165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IgnicoccusIslandicusDsm13165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCallunaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium callunae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCallunaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccoglossusKowalevskiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccoglossus kowalevskii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccoglossusKowalevskiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaDentocariosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rothia dentocariosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RothiaDentocariosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BisonBisonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bison bison Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BisonBisonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophobacteralesBacteriumDelta02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacterales bacterium Delta_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacteralesBacteriumDelta02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsellaRubellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capsella rubella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapsellaRubellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumMar2010188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium MAR_2010_188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumMar2010188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatusPharyngisC1050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis C1050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisC1050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSp52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaSp52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_50_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViolaceusniger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceusniger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesViolaceusniger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraParasiticaInra310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica INRA-310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraParasiticaInra310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGw2011gwb1499(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB1499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb1499", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPstaah124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PsTaAH124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpPstaah124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMeleagridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma meleagridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMeleagridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaLituseburensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaPneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC1051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C1051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC1051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumGw2011gwa13910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA13910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa13910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesCardiffensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces cardiffensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesCardiffensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FukomysDamarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fukomys damarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FukomysDamarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterSpLeaf296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCurvatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurvatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusGriffiniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus griffiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusGriffiniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemominutumBirmingham1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemominutum Birmingham 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemominutumBirmingham1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RugosibacterAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rugosibacter aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RugosibacterAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofusicoccumParvumUcrnp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum UCRNP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeofusicoccumParvumUcrnp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParasporobacteriumPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasGadeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas gadei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasGadeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaediCcug18818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi CCUG18818 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediCcug18818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichelobacterNodosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dichelobacter nodosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DichelobacterNodosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterPinnipediorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusRugosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus rugosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusRugosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesCulicifaciesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles culicifacies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesCulicifaciesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKazanBacteriumGw2011gwa15015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium GW2011GWA15015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumGw2011gwa15015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonBieneusi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusObesi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusObesi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosopelagicusBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopelagicus brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopelagicusBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiaceaeBacteriumGa0074131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium Ga0074131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumGa0074131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumGrantiiDsm8605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium grantii DSM 8605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumGrantiiDsm8605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot96Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot96Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasSenticiiDsm18821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas senticii DSM 18821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FerrimonasSenticiiDsm18821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesThermoautotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermoautotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermoautotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPseudotuberculosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pseudotuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaPseudotuberculosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusVulcaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus vulcani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusVulcaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag678(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:678 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag678", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb14314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb14314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpRc2d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc2d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc2d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscoideaRubescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ascoidea rubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AscoideaRubescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicolaSociusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicola socius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSociusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HericiumAlpestre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hericium alpestre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HericiumAlpestre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTolypomycina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis tolypomycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTolypomycina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumElkaniiUsda76Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii USDA76 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiUsda76Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaMajorPcc6313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirulina major PCC 6313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirulinaMajorPcc6313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaeciumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaeciumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnh099Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh099Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioLegallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio legallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLegallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasCoralicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas coralicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AurantimonasCoralicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VignaAngularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vigna angularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VignaAngularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifoxyd1Full5236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYD1_FULL_52_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyd1Full5236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumIntracellulare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intracellulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIntracellulare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaMultacida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella multacida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaMultacida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabidopsisLyrataSubspLyrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata subsp. lyrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArabidopsisLyrataSubspLyrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFloridensisFslS101187Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria floridensis FSL S10-1187 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaFloridensisFslS101187Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumFuchskuhlense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium fuchskuhlense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumFuchskuhlense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumWalsbyiJ07hqw2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp157mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 157MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp157mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpErvv1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. ErVv1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpErvv1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColeofasciculusChthonoplastesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coleofasciculus chthonoplastes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColeofasciculusChthonoplastesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpKordi49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeijerinckiaSp28yea48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia sp. 28YEA48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaSp28yea48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterInsolitus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter insolitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterInsolitus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpBal378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BAL378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBal378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisListeriNbrc13360(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri NBRC 13360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisListeriNbrc13360", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongylocentrotusPurpuratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strongylocentrotus purpuratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrongylocentrotusPurpuratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaFusca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFusca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaConfusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella confusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaConfusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusUrinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspInaquosorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. inaquosorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspInaquosorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioProteoclasticusP6b7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus P6B7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusP6b7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusSiccatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus siccatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSiccatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumBohemicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBohemicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeyerozymaGuilliermondiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusXanthusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus xanthus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcusXanthusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterWolinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterWolinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpBiwako01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. BIWAKO-01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpBiwako01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpSg55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. SG55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpSg55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. 28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraSp28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterGlucosidilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter glucosidilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterGlucosidilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasJannaschianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas jannaschiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJannaschianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacterium311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium 311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacterium311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSp35wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 35W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp35wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimonasMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSelenitireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium selenitireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSelenitireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlmg11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALMg11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlmg11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpOr444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OR444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOr444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5053Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5053 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5053Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratiruptorSpSb1552Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor sp. SB1552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorSpSb1552Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NioellaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nioella nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NioellaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacterium9401234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9401234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9401234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasPhaseoliPvDieffenbachiaeLmg695Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli pv. dieffenbachiae LMG 695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasPhaseoliPvDieffenbachiaeLmg695Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritimibacterSpHl12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. HL-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpHl12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumValvarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumValvarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsphigho201full63240Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO201FULL63240 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho201full63240Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp123mfchir2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 123MFChir2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSp123mfchir2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFOXYA2_FULL_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpH20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaSp6021052837Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cohnella sp. 6021052837 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CohnellaSp6021052837Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaVeroralisDsm19559Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis DSM19559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisDsm19559Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumColombienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium colombiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumColombienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilaginoideaVirensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ustilaginoidea virens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UstilaginoideaVirensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocolitica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaEnterocolitica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroterricolaViridariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microterricola viridarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicroterricolaViridariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp05ny08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 05NY08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp05ny08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpNfr13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. NFR13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpNfr13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterWoluwensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter woluwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterWoluwensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumNor53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium NOR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumNor53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSwingsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium swingsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSwingsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseofuscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseofuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseofuscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterAerophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterAerophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpCs1bsmeth3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1BSMeth3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1bsmeth3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsFumosoroseaArsef2679(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea ARSEF 2679 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CordycepsFumosoroseaArsef2679", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSiccaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sicca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSiccaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicroplitisDemolitor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microplitis demolitor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicroplitisDemolitor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenitrobacteriumDetoxificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Denitrobacterium detoxificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DenitrobacteriumDetoxificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifoxyb1Full4033Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFOXYB1_FULL_40_33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifoxyb1Full4033Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaChutoStrDubaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Orientia chuto str. Dubai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OrientiaChutoStrDubaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumBeijerinckiiDsm7166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii DSM 7166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckiiDsm7166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasMuralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas muralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasMuralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusEllipticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusEllipticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumDiazoefficiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium diazoefficiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumDiazoefficiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_12_FULL_44_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusNaphthalenovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus naphthalenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNaphthalenovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgb11wgaepuloa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGB11WGAEpuloA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgb11wgaepuloa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsphigho201full4330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO201FULL4330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho201full4330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTakedensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia takedensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaTakedensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelampsoraLaricipopulinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melampsora laricipopulina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelampsoraLaricipopulinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldiarchaeumSubterraneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldiarchaeum subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldiarchaeumSubterraneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaSpJcm33374(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia sp. JCM 33374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaSpJcm33374", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumDesertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium deserti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumDesertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpHjCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. HJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpHjCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CottopercaGobio(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cottoperca gobio graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CottopercaGobio", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterLusitanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter lusitanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterLusitanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhodospiraHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetitomaculumRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetitomaculumRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocladiumSpEchbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocladium sp. ECHB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocladiumSpEchbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumU91iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium U9-1i Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumU91iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oleibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OleibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusSpD1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusSpD1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisRmscc3703Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 3703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc3703Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpStm4661Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. STM4661 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpStm4661Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpFlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Fl Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpFlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsphigho212full6614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO212FULL6614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho212full6614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNcu2d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCu2D-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNcu2d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1496 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaFacilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidocella facilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidocellaFacilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpCb0101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaG002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola G002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaG002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3818 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu036Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU036 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu036Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpHot20860m813i02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813I02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813i02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterIndonesiensis5h1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis 5H-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensis5h1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaSorghi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puccinia sorghi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PucciniaSorghi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCitronellolisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas citronellolis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCitronellolisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensFd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens FD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensFd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusSpCag542Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:542 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag542Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesMediterraneensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMediterraneensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumCaucaseum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum caucaseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumCaucaseum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaElegansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holospora elegans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HolosporaElegansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusEndophyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus endophyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusEndophyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonAplasmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Aplasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonAplasmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp11649663Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164966.3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649663Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAmyloliquefaciensDc12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DC-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDc12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusManganicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus manganicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusManganicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCurvus52592(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter curvus 525.92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterCurvus52592", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmoebophilusSp3638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus sp. 3638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusSp3638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesInvadansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces invadans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AphanomycesInvadansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanomethylicusMesodigestum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus mesodigestum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusMesodigestum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLaminariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella laminariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLaminariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBovieniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus bovienii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBovieniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaSpBal378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BAL378 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBal378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumGw2011gwc14916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWC14916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwc14916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaVersiformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrinema versiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrinemaVersiformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaPhaffiiCbs4417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii CBS 4417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffiiCbs4417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpSynace01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. SynAce01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpSynace01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterTerrenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter terrenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterTerrenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHassiacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium hassiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHassiacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HandroanthusImpetiginosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Handroanthus impetiginosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HandroanthusImpetiginosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSubantarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusSpA40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sp. A40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSpA40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlautiaStali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plautia stali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlautiaStali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonisporaThiosulfatigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisVesicatoria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris vesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisVesicatoria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisusAtcc51562Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus ATCC51562 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisusAtcc51562Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumGw2011gwc23941Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC23941 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc23941Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumFallaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fallax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFallaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermanellaStibiiresistensSb22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens SB22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistensSb22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp31yEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 31Y Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp31yEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransGilvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans gilvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgarivoransGilvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusMoraviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus moraviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMoraviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesLutiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides luti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesLutiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacebacteriaBacteriumCg2303639(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG2_30_36_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg2303639", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeri3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri 3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeri3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumDesmolansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium desmolans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDesmolansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSp4425(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. 44-25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSp4425", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaSpLeaf210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoMaydis521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis 521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UstilagoMaydis521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpEp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. EP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpEp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloligellaHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloligella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloligellaHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Haloarchaeon3a1dgrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return haloarchaeon 3A1DGR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Haloarchaeon3a1dgrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaPascullei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila pascullei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPascullei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumGilvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumGilvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaFloridensisFslS101187(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria floridensis FSL S10-1187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaFloridensisFslS101187", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilaceaeBacteriumUrhb0048Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0048 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0048Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesProvencensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces provencensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesProvencensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacteriumYongneupense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusIslandicusDsm13165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus DSM 13165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IgnicoccusIslandicusDsm13165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full3826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpCy54118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. CY54118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpCy54118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpZ31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. Z-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpZ31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumRifoxyc12full6016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium RIFOXYC12FULL6016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumRifoxyc12full6016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumMiliaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Panicum miliaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PanicumMiliaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeCc1417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4716b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4716b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4716b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaMajorPcc6313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirulina major PCC 6313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirulinaMajorPcc6313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricibacterSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaHofstadiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia hofstadii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaHofstadiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DentipellisFragilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dentipellis fragilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DentipellisFragilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShuttleworthiaSpMsx8bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia sp. MSX8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShuttleworthiaSpMsx8bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidianusHospitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidianus hospitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidianusHospitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasSpCba1134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas sp. CBA1134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronomonasSpCba1134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifoxyc2full4316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYC2FULL4316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyc2full4316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorObsidiansis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor obsidiansis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorObsidiansis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaTimonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia timonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaTimonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolinellaSuccinogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolinella succinogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolinellaSuccinogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpH20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNantensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNantensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SneathiellaGlossodoripedisJcm23214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis JCM 23214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedisJcm23214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusTimidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus timidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusTimidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat27264(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27264", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacterium4787Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 47-87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4787Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnserBrachyrhynchus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anser brachyrhynchus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnserBrachyrhynchus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPutealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPutealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NotechisScutatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Notechis scutatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NotechisScutatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSpLw13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. LW13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpLw13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium novyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNovyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedArchaeonA07hn63(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HN63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hn63", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpImhCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. IMH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpImhCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobaculumAquaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobaculum aquaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobaculumAquaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusSubspVenerealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. venerealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspVenerealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensisNbrc103114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jejuensis NBRC 103114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaJejuensisNbrc103114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDri13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DRI13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDri13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CobetiaCrustatorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cobetia crustatorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CobetiaCrustatorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterAmalonaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter amalonaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterAmalonaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWD2_38_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterArsenitoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter arsenitoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterArsenitoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpFc2018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. FC2018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpFc2018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumCg1023251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_32_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1023251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaYamanashiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaYamanashiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnasPlatyrhynchosPlatyrhynchos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anas platyrhynchos platyrhynchos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnasPlatyrhynchosPlatyrhynchos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaAquamarinaCbs119918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exophiala aquamarina CBS 119918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExophialaAquamarinaCbs119918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaSpKm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hippea sp. KM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HippeaSpKm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaBruceiBruceiTreu927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei brucei TREU927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaBruceiBruceiTreu927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasFungiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas fungiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasFungiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesulfofervidusAuxiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfofervidus auxilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfofervidusAuxiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusManasiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus manasiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusManasiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSp316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisusAtcc51562Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus ATCC51562 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisusAtcc51562Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpHzn7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. HZN7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpHzn7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAbscessusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium abscessus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAbscessusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPorcinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema porcinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPorcinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpLeaf176Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf176 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf176Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusHaloduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus halodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacillusHaloduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraSantarosaiSerovarShermaniStrLt821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira santarosai serovar Shermani str. LT 821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraSantarosaiSerovarShermaniStrLt821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCalidoustusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus calidoustus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusCalidoustusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumBerghei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium berghei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumBerghei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifoxyd2Full5815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYD2_FULL_58_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyd2Full5815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeTomatoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tomato Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTomatoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumBbfl7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BBFL7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBbfl7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterYangtzensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter yangtzensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterYangtzensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhydrobacterAerosaccus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enhydrobacter aerosaccus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnhydrobacterAerosaccus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIncarnatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces incarnatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIncarnatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaSpRitpidEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella sp. RITPId Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaSpRitpidEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomicrobiaArchaeonDtu008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon DTU008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonDtu008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaLitorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaLitorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMum116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MUM 116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMum116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioGilvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CellvibrioGilvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwf23720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWF2_37_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwf23720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChromiireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chromiireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChromiireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidiaBacteriumSm23282Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoidia bacterium SM23_28_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidiaBacteriumSm23282Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpGas474Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. GAS474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpGas474Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdwardsiellaIctaluriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella ictaluri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaIctaluriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioRenipiscariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio renipiscarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioRenipiscariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusHesperidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus hesperidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHesperidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrothrixParvicellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microthrix parvicella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrothrixParvicellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpYr651Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. YR651 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpYr651Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JorgensenbacteriaBacteriumRifcsplowo201full4525bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO201FULL4525b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo201full4525bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DokdoniaSpMed134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. MED134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpMed134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusWasatchensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus wasatchensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusWasatchensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PvcGroupBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return PVC group bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PvcGroupBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumImcc14465(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium IMCC14465 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumImcc14465", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospiraOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospira oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospiraOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaBicuspidataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiBNctc9691Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi B NCTC9691 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiBNctc9691Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioCosticolaSubspAlcaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio costicola subsp. alcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioCosticolaSubspAlcaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCoyleaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium coyleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCoyleaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeraceosorusGuamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus guamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusGuamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermophagusXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermophagus xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermophagusXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpWsm3224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspSteigerwaltiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. steigerwaltii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspSteigerwaltiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSabinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sabinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSabinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SingulisphaeraSpGp187(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera sp. GP187 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraSpGp187", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BettaSplendensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betta splendens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BettaSplendensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg16488Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_48_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg16488Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavicepsPurpurea201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea 20.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClavicepsPurpurea201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiellaGlossodoripedis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium4484113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4484_113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium4484113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpG5847(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. G5847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpG5847", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwa13910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA13910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa13910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClunioMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clunio marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClunioMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgarivoransAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgarivoransAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasHuabeiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas huabeiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasHuabeiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusElgii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus elgii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusElgii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraElsdeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera elsdenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraElsdeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaPersicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lewinella persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LewinellaPersicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaSiddalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia siddallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaSiddalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFalsenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFalsenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniclasticumRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniclasticum ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniclasticumRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorangiineaeBacteriumNic37a2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sorangiineae bacterium NIC37A_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SorangiineaeBacteriumNic37a2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JidaibacterAcanthamoebaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jidaibacter acanthamoeba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JidaibacterAcanthamoebaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasMetalliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas metalli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMetalliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_FULL_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSpCag605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurellaAcetivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella acetivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAcetivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPulmonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pulmonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPulmonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CriibacteriumBergeronii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Criibacterium bergeronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CriibacteriumBergeronii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTaiwanensisDsm21401Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis DSM 21401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensisDsm21401Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBs2016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BS-2016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBs2016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumLuteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumLuteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasRivuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas rivuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasRivuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAntarcticusDsm21422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter antarcticus DSM 21422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MaribacterAntarcticusDsm21422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumLitorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumLitorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumCg1025453Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG1025453 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg1025453Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp360mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 360MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSp360mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesChristyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles christyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesChristyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpHmsc073a11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. HMSC073A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpHmsc073a11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot655Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root655 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot655Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpCmr5cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CMR5c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCmr5cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonis603(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis 603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonis603", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeijerinckiaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeMgh78578Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae MGH78578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeMgh78578Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaMontpellierensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumYrb3002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YRB3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYrb3002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumSpCag7458120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:74_58_120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag7458120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpH7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpH7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenderiaElectrophagaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenderia electrophaga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenderiaElectrophagaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag762(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag762", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremblayaPhenacolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya phenacola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TremblayaPhenacolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo6530Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_65_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo6530Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenarcanumBioreactoricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenarcanum bioreactoricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenarcanumBioreactoricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriumGlomeransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coriobacterium glomerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriumGlomeransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KutzneriaSp744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria sp. 744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KutzneriaSp744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumRifoxyb1full4319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYB1FULL4319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyb1full4319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterCrystallopoietesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter crystallopoietes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCrystallopoietesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioRumoiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rumoiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioRumoiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAmyloliquefaciensDc12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DC-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDc12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzohydromonasAustralicaDsm1124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Azohydromonas australica DSM 1124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AzohydromonasAustralicaDsm1124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiosporiumApollinisCbs100218Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis CBS 100218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ConiosporiumApollinisCbs100218Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaistiaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaistia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaistiaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpYr412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. YR412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpYr412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LomentosporaProlificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lomentospora prolificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LomentosporaProlificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumScgcAaa027g08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027G08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027g08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasSpGwf2378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. GWF2_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpGwf2378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThermokryptusMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thermokryptus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThermokryptusMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BhargavaeaGinsengiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea ginsengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaGinsengiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopirellulaIslandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula islandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaIslandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioMixtusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio mixtus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioMixtusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusTorquis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus torquis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTorquis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaAlviniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hippea alviniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HippeaAlviniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriticumAestivumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Triticum aestivum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TriticumAestivumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReichenbachiellaAgariperforansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella agariperforans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaAgariperforansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumGw2011gwd23842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWD23842 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwd23842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_01_FULL_33_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaDonghaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaDonghaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCloacaeEcwsu1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae EcWSU1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeEcwsu1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSp12014mblmicdivEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. 12014MBLMicDiv Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSp12014mblmicdivEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpF0139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfopilaAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfopilaAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocoliticaLc20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica LC20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocoliticaLc20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EcheneisNaucratesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echeneis naucrates Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EcheneisNaucratesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaleopterusVariegatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Galeopterus variegatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GaleopterusVariegatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseochromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseochromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseochromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusPersepolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus persepolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusPersepolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwb24136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWB24136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwb24136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatabacterHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catabacter hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatabacterHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpL294Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. L294 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpL294Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaYakubaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila yakuba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DrosophilaYakubaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MastigocladusLaminosusUu774Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus UU774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MastigocladusLaminosusUu774Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaAtypicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella atypica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaAtypicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMinutissimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium minutissimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMinutissimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumParaenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenococcusSpPcc7305(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenococcus sp. PCC7305 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenococcusSpPcc7305", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMicansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella micans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMicansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumSpScadcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. SCADC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpScadcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMutabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mutabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesMutabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_40_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSociusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicola socius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSociusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterPersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter persici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchrobactrumIntermediumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum intermedium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumIntermediumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumXylanolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium xylanolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumXylanolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OreniaMarismortuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orenia marismortui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OreniaMarismortuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpYe71(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. YE71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpYe71", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSpLw13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. LW13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpLw13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelaginellaMoellendorffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selaginella moellendorffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelaginellaMoellendorffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaEchini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bizionia echini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BizioniaEchini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpYr577Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. YR577 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpYr577Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaObtusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holospora obtusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HolosporaObtusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdaphobacillusLindanitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edaphobacillus lindanitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdaphobacillusLindanitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaCinnabarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella cinnabarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LoktanellaCinnabarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoramibacterAlactolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoramibacter alactolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoramibacterAlactolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraMagnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira magna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMagnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterCrescentusCb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus CB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusCb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisMurinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis murina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PneumocystisMurinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumArcisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum arcis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumArcisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusChikugoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus chikugoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusChikugoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VavraiaCulicisSubspFloridensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vavraia culicis subsp. floridensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VavraiaCulicisSubspFloridensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaRapaSubspPekinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa subsp. pekinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrassicaRapaSubspPekinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesViscosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces viscosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesViscosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusGnavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gnavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGnavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusAsinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Equus asinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EquusAsinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho202full3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO202FULL3919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho202full3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOralisHga0225(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis HGA0225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisHga0225", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp21mfcrub11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 21MFCrub1.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp21mfcrub11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantisAtcc700779Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis ATCC700779 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisAtcc700779Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSuimastitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces suimastitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSuimastitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium7110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 71-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium7110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasAerilataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas aerilata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseomonasAerilataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisSpHl130gsbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. HL130GSB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpHl130gsbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatelliglobosisporaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catelliglobosispora koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatelliglobosisporaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiameybacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niameybacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiameybacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioVersutusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio versutus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioVersutusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaCorrodensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eikenella corrodens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EikenellaCorrodensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpIs1496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpK90mixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. K90mix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpK90mixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumRifoxyd12Full4821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYD12_FULL_48_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyd12Full4821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasTaeanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taeanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaeanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpP6b1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P6B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP6b1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DipodomysOrdii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dipodomys ordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DipodomysOrdii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermochlorobacteriaceaeBacteriumGbchlbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermochlorobacteriaceae bacterium GBChlB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermochlorobacteriaceaeBacteriumGbchlbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KnoelliaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Knoellia flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KnoelliaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaSpHk05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scytonema sp. HK-05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScytonemaSpHk05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSubsaxonicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium subsaxonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSubsaxonicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KriegellaAquimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kriegella aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KriegellaAquimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZygosaccharomycesBailiiClib213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii CLIB 213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailiiClib213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpUnccl10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. UNCCL10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpUnccl10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpFobrc9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaAdiacensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella adiacens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaAdiacensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAdhaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferAdhaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAquilaeDsm44791Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae DSM 44791 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAquilaeDsm44791Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpSy8519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SY8519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpSy8519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPerolensDsm12744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus perolens DSM 12744 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPerolensDsm12744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoaglandellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoaglandella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoaglandellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium nepotum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumNepotumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPorphyraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas porphyrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPorphyraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisStrAmesAncestorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis str. Ames Ancestor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisStrAmesAncestorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusTorquisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus torquis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTorquisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceaniovalibusGuishaninsulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceaniovalibus guishaninsula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceaniovalibusGuishaninsulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalditerrivibrioNitroreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calditerrivibrio nitroreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalditerrivibrioNitroreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHtcc2083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaAlcalifaciensDsm30120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens DSM 30120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensDsm30120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AhrensiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AhrensiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloglycomycesAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloglycomyces albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloglycomycesAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumThalassiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium thalassium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumThalassiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraHibiscaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura hibisca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraHibiscaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxocaraCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Toxocara canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ToxocaraCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParalimentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParalimentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaModicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma modicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaModicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24266Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_42_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24266Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraButanivoransNbrc103042Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thauera butanivorans NBRC 103042 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThaueraButanivoransNbrc103042Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaPneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr485Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR485 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr485Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusSpJcm16833Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. JCM 16833 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpJcm16833Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BiomphalariaGlabrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Biomphalaria glabrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BiomphalariaGlabrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeoehrlichiaLotorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neoehrlichia lotoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeoehrlichiaLotorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchrovirgaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochrovirga pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchrovirgaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioKueneniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio kuenenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioKueneniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumAaa252a02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium AAA252A02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumAaa252a02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacteriumCg1024614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_46_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumGondwanenseDsm13020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense DSM 13020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanenseDsm13020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumCeb3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium CEB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumCeb3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaLacustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaLacustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerosceptrumFracticalcisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerosceptrum fracticalcis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerosceptrumFracticalcisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaAzaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora azatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAzaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpD27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. D27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpD27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpFCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpFCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PygocentrusNattereri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pygocentrus nattereri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PygocentrusNattereri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrypanosomaBruceiBruceiTreu927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei brucei TREU927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaBruceiBruceiTreu927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocellaArvoryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocella arvoryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocellaArvoryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifcsplowo202full4814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO202FULL4814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo202full4814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumLp2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium LP2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumLp2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTsri0281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusNaphthalenovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus naphthalenovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNaphthalenovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaErythraeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora erythraea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinopolysporaErythraeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifoxyd12full3339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYD12FULL3339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyd12full3339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg166615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_66_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterKorlensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter korlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterKorlensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdobenusRosmarusDivergens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus divergens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OdobenusRosmarusDivergens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumMiliaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Panicum miliaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PanicumMiliaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpJa12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. JA12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpJa12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasIlicicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas ilicicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasIlicicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterArcticusA12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter arcticus A12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PedobacterArcticusA12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusFructosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus fructosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFructosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrobasidiumTorrendiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClostridioformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumClostridioformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZeaMaysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zea mays Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZeaMaysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRudisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter rudis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRudisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCb0205(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0205", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3789(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3789 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3789", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaBombicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella bombicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilliamellaBombicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarispirochaetaAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marispirochaeta aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarispirochaetaAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag30730263(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:307_30_263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag30730263", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumSpIppasb1200(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. IPPASB1200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpIppasb1200", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwb1471Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWB1_47_1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwb1471Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_41_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpL53140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. L53140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpL53140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusicatenibacterSaccharivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusicatenibacter saccharivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusicatenibacterSaccharivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD2_FULL_50_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidisEr3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis ER-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlastomycesDermatitidisEr3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharolyticumK10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum K10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumK10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParascardoviaDenticolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parascardovia denticolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParascardoviaDenticolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaSaharensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora saharensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaSaharensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumRimaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium rimae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumRimaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumVanbaalenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vanbaalenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVanbaalenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaDenticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema denticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaDenticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumBarkeri2011R4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium barkeri 2011-R4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeri2011R4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinkiaNeuii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winkia neuii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinkiaNeuii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixSpPcc11201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix sp. PCC 11201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixSpPcc11201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaPanacarviGsoil349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Gsoil 349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CohnellaPanacarviGsoil349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydophilaAbortusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila abortus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaAbortusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RisungbinellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Risungbinella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RisungbinellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpScn6214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SCN 62-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpScn6214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaAlbidocapillata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albidocapillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbidocapillata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorumFunduliforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum funduliforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumFunduliforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFaecichinchillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides faecichinchillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFaecichinchillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumEfficiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium efficiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEfficiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocebusMurinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microcebus murinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrocebusMurinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterVenetianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter venetianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterVenetianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag253Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:253 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag253Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_19FT_COMBO_36_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsellaGrandiflora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capsella grandiflora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CapsellaGrandiflora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterJohnsoniiXbb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii XBB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterJohnsoniiXbb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NioellaSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nioella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NioellaSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaPertussis18323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis 18323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussis18323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotum397Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium nepotum 39/7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumNepotum397Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorumJcm14966Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum JCM14966 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumJcm14966Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFxanac1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FxanaC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpFxanac1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_39_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPimensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus pimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPimensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptonychotesWeddelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptonychotes weddellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptonychotesWeddelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaApista(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea apista graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaApista", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaMortivallisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora mortivallis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaMortivallisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitansKin4M(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Kin4-M graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeumEquitansKin4M", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpYim77859Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. YIM77859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpYim77859Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerinicoccusChungangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus chungangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusChungangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibulbusIndolifexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanibulbus indolifex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanibulbusIndolifexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpOv277Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. OV277 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpOv277Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichechusManatusLatirostris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus latirostris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichechusManatusLatirostris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumA4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusGlycogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus glycogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusGlycogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaDenticariosiJcm15641(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella denticariosi JCM 15641 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaDenticariosiJcm15641", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscovopsisWeberiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escovopsis weberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscovopsisWeberiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteococcusJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteococcus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteococcusJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusLaa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius LAA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusLaa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephalotusFollicularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cephalotus follicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CephalotusFollicularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogeometricumLimi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumLimi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidoterrestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidoterrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidoterrestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusLactarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusLactarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaProteobacteriumScgcAb137C09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return zeta proteobacterium SCGC AB-137-C09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZetaProteobacteriumScgcAb137C09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichurisTrichiuraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichuris trichiura Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichurisTrichiuraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKorlensisNbrc107688Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus korlensis NBRC 107688 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusKorlensisNbrc107688Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMorhuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella morhuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMorhuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorNaganoensisNa10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis NA10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensisNa10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLuteoviolaceaBAtcc29581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea B  ATCC 29581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolaceaBAtcc29581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParastagonosporaNodorumSn15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum SN15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParastagonosporaNodorumSn15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatirhabdiumButyrativoransDsm18734Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans DSM 18734 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativoransDsm18734Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusSp10a9div0425Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 10A9DIV0425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp10a9div0425Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraMacraNbrc14102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura macra NBRC 14102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraMacraNbrc14102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumSgbin7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpF0139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScalinduaBrodaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scalindua brodae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ScalinduaBrodaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumStbin14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GanodermaSinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ganoderma sinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GanodermaSinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYD1_FULL_47_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumKbs146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium KBS146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumKbs146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusHalocasei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus halocasei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusHalocasei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetomicrobiumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterPropionicigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter propionicigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaludibacterPropionicigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpOralTaxon212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinifilumFragileJcm15579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinifilum fragile JCM 15579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinifilumFragileJcm15579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinispiraPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinispira pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinispiraPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisAtcc29212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis ATCC29212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaecalisAtcc29212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumCg2303944Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_39_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2303944Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRbg166534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_65_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot149Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root149 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot149Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBerlinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema berlinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaBerlinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusSingularisPs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus singularis PS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSingularisPs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpUnc302mfcol52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. UNC302MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhyllobacteriumSpUnc302mfcol52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KribbellaFlavidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kribbella flavida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KribbellaFlavidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpNsp21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP2.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpNsp21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumOguniense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum oguniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumOguniense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusSpRs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus sp. RS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusSpRs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofarcimenAcetoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen acetoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenAcetoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSpS4079Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. S4079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpS4079Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBombicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bombicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBombicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonadaceaeBacteriumH1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumH1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerMucosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipiger mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipigerMucosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKorlensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus korlensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusKorlensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumLuteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumLuteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirestonebacteriaBacteriumRifoxyc2full3967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYC2FULL3967 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxyc2full3967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verticillium alfalfae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerticilliumAlfalfae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaTomentosiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tomentosiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NicotianaTomentosiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacterSaccharofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisUniversalisFam5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis FAM5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisFam5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpathiphylli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter spathiphylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpathiphylli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaPunctata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza punctata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaPunctata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasLeviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas levii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasLeviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisAtcc29212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis ATCC29212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaecalisAtcc29212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasAveniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas aveniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAveniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriCari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri CARI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriCari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FabibacterPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEi5cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EI5c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEi5cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasPalmitaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hb70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HB70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hb70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RouxiellaChamberiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella chamberiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RouxiellaChamberiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HungateiclostridiumThermocellumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium thermocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumThermocellumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GastranaerophilalesBacteriumHum9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpNies3756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. NIES-3756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocSpNies3756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymophilusRaffinosivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zymophilus raffinosivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZymophilusRaffinosivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp651059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaMultivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaMultivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSydowiiCbs59365Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sydowii CBS 593.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusSydowiiCbs59365Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInadaiSerovarLymeStr10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira inadai serovar Lyme str. 10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInadaiSerovarLymeStr10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElizabethkingiaAnophelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia anophelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaAnophelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacillusFlagellatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusFlagellatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacteriumColombiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium colombiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumColombiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedBlautiaSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Blautia sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedBlautiaSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumIliopiscariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium iliopiscarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumIliopiscariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FulvivirgaImtechensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fulvivirga imtechensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FulvivirgaImtechensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatimeriaChalumnae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Latimeria chalumnae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LatimeriaChalumnae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuillusLuteusUhSluLm8N1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Suillus luteus UH-Slu-Lm8-n1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SuillusLuteusUhSluLm8N1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SanguibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCaspthauma1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumRifcsphigho212full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RIFCSPHIGHO212FULL4717 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRifcsphigho212full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluviicolaRiflensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FluviicolaRiflensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiA2165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii A2165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiA2165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnanasComosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ananas comosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnanasComosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TieghemosteliumLacteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tieghemostelium lacteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TieghemosteliumLacteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotryotiniaNarcissicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia narcissicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaNarcissicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCaseinilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus caseinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCaseinilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrovumSpJa12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. JA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpJa12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUrealyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium urealyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUrealyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JaapiaArgillacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jaapia argillacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JaapiaArgillacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesFCircinelloides1006phl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides 1006PhL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloides1006phl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumIntermedium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumIntermedium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpMa2016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. MA2016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpMa2016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetariaItalica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Setaria italica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SetariaItalica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full4934Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL4934 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full4934Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiastellaYeongjuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niastella yeongjuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiastellaYeongjuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusVestibularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus vestibularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusVestibularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamormyropsKingsleyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paramormyrops kingsleyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParamormyropsKingsleyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAmylolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAmylolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensis0850475Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoeensis 085-0475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoeensis0850475Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpSbi22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. SBI22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpSbi22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpR4368Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. R4368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpR4368Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterMilleraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter millerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterMilleraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf231Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf231Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumHochsteniumAtcc700873Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium ATCC 700873 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHochsteniumAtcc700873Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumDaeguenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium daeguense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumDaeguenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeonScgcAaa471b05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon SCGC AAA471B05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeonScgcAaa471b05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSpRubisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Rubis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpRubisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusCatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus catus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprococcusCatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApodemi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apodemi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApodemi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpKordi100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterDokdonensisDsw5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis DSW-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolaribacterDokdonensisDsw5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFOXYB1_FULL_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_41_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaNs342Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea NS342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaNs342Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumAmmoniigenesNbrc101786Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes NBRC 101786 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenesNbrc101786Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterWandonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter wandonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterWandonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeoehrlichiaLotorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neoehrlichia lotoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeoehrlichiaLotorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromassilibacillusSpMarseillep3371(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus sp. MarseilleP3371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSpMarseillep3371", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterSpLeaf3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter sp. Leaf3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSpLeaf3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumUndicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium undicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumUndicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaesserellaParasuisSh0165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaesserella parasuis SH0165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaesserellaParasuisSh0165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraYanagawae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira yanagawae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraYanagawae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensSpHeli66(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens sp. HelI66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensSpHeli66", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusLacusDsm15449(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus DSM 15449 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusLacusDsm15449", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterPhenanthrenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter phenanthrenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterPhenanthrenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusNotomytis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus notomytis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusNotomytis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodomicrobiumVannielii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium vannielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumVannielii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusChristenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus christensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusChristenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsphigho202full4912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusRubiinfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus rubiinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusRubiinfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCattleya(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cattleya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCattleya", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopilaAestuariiDsm18488Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii DSM 18488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfopilaAestuariiDsm18488Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhydraLutrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enhydra lutris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnhydraLutrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanohaloarchaeaArchaeonSg9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon SG9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonSg9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaHellenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella hellenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaHellenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetraodonNigroviridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetraodon nigroviridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetraodonNigroviridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmobacterNectariphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter nectariphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmobacterNectariphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriGwssCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri GWSS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriGwssCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaPlatycodiJcm25414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi JCM 25414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiJcm25414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacterFastidiosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coprobacter fastidiosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoprobacterFastidiosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChiloscylliumPunctatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chiloscyllium punctatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChiloscylliumPunctatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bos indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BosIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacterium4484213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichococcusPasteuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus pasteurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPasteuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaFrisiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea frisia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaFrisiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasExtremaustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas extremaustralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasExtremaustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloterricolaOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloterricola oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloterricolaOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalditerrivibrioNitroreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calditerrivibrio nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalditerrivibrioNitroreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocellaPaludicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocella paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocellaPaludicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumPendens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum pendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermofilumPendens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKle1755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KLE1755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKle1755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricellaSpT08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella sp. T08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaSpT08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpMd2005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. MD2005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpMd2005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMacra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura macra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMacra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAphoticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aphoticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAphoticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177nand(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177Nand graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177nand", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMc2017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MC2017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMc2017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloropiconPrimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloropicon primus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloropiconPrimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumOlb4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSeropedicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum seropedicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSeropedicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumRiyadhense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium riyadhense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumRiyadhense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGorillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus gorillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGorillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LunatimonasLonarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lunatimonas lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LunatimonasLonarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_16b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaBrevipalpis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina brevipalpis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaBrevipalpis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaThiooxydansDsm14619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans DSM 14619 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OttowiaThiooxydansDsm14619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisAd2017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis AD2017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisAd2017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsphigho202full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO202FULL4216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho202full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumHiltneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhoceense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phoceense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhoceense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriSg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri SG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriSg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaSpCag344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. CAG:344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpCag344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusSilvanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus silvanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusSilvanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriNf13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri NF13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriNf13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HugenholtziaRoseolaDsm9546Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola DSM 9546 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HugenholtziaRoseolaDsm9546Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumConspicuum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium conspicuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumConspicuum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensSpPamc27130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. PAMC27130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychroserpensSpPamc27130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg164813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG164813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg164813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa14021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA14021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa14021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpRoot480Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Root480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpRoot480Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpongiibacterSpImcc21906(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter sp. IMCC21906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterSpImcc21906", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitriliruptorAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusEndophyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusEndophyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterTropicalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter tropicalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterTropicalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwa24110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWA2_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwa24110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaAurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma auris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcalesBacterium7064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 70-64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasRuthenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas ruthenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRuthenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwf236839Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF236839 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf236839Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaAltunenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrinema altunense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrinemaAltunenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaInsidiosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia insidiosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaInsidiosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmanitaThiersiiSkay4041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amanita thiersii Skay4041 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmanitaThiersiiSkay4041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesAstaciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces astaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AphanomycesAstaciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumPlataniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium platani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPlataniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuaniaAlbidiflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruania albidiflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuaniaAlbidiflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSordelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sordellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSordelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusAbyssiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusAbyssiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTimonianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium timonianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTimonianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AndreprevotiaLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiumMinutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaApistaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea apista Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaApistaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumKashiwanohensePv202Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense PV20-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohensePv202Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHygroscopicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovenabulumGondwanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermovenabulum gondwanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermovenabulumGondwanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeauveriaBassianaD15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana D1-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaD15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumAb4001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AB4001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAb4001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho212full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO212FULL4422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho212full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp7016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 70-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTaa040Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA040 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa040Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSibiricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sibiricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSibiricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaAerilata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microvirga aerilata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrovirgaAerilata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoclavibacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSp348mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. 348MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSp348mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHankookensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hankookensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHankookensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSocompensisS10bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis S10B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioSocompensisS10bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEntericusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus entericus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEntericusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphiprionOcellarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion ocellaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphiprionOcellarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisPorriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botrytis porri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotrytisPorriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NectriaHaematococcaMpvi77134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Nectria] haematococca mpVI 77-13-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NectriaHaematococcaMpvi77134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OkibacteriumFritillariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Okibacterium fritillariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OkibacteriumFritillariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Danaus plexippus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DanausPlexippusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MargulisbacteriaBacteriumGwf2359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWF2359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwf2359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicoccusSagamiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicoccus sagamiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicoccusSagamiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgc07wgaepuloa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGC07WGAEpuloA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgc07wgaepuloa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LishizheniaTianjinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lishizhenia tianjinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LishizheniaTianjinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOtEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOtEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovirgulaThermocuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovirgula thermocuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovirgulaThermocuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronobacteriumTexcoconense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium texcoconense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumTexcoconense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGloeosporioidesCg14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cg-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioidesCg14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDianthicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dianthicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaDianthicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpCmr5cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CMR5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCmr5cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioZosteraeDsm11974(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae DSM 11974 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioZosteraeDsm11974", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep2415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201452450sch5900713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201452450SCH5900713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201452450sch5900713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophilaceaeBacteriumCg10262390(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophilaceae bacterium CG1_02_62_390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophilaceaeBacteriumCg10262390", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenedentesBacteriumCg1024214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium CG1024214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumCg1024214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioYellowstonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio yellowstonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioYellowstonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCanorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas canoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCanorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCalifornicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces californicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCalifornicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesClavuligerusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces clavuligerus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesClavuligerusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAquatileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquatile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquatileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumSpScn6914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 69-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn6914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomycesDermatitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHerbarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus herbarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHerbarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilimaliaeMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilimaliae massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilimaliaeMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumArcisJcm13916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum arcis JCM 13916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumArcisJcm13916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraMethylohalidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpAap60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpGxt6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. GXT6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpGxt6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoperedensNitroreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoperedens nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoperedensNitroreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolysporaHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EsoxLucius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Esox lucius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EsoxLucius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraCaeruleaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera caerulea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraCaeruleaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusTundraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus tundrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusTundraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrateuriaSpSoil773Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frateuria sp. Soil773 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrateuriaSpSoil773Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterItalicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterItalicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumIndicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumIndicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OenococcusKitaharaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus kitaharae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OenococcusKitaharaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa26223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_62_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuisYs72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis YS72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisYs72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumVaccae95051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae 95051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccae95051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpA03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. A03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpA03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg2304851Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_48_51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304851Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSaguiniDsm23967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini DSM 23967 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumSaguiniDsm23967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPasteurianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpKle1728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. KLE1728 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpKle1728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoleophilumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoleophilum album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoleophilumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndocarponPusillumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Endocarpon pusillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndocarponPusillumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSp83e34Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. 83E34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSp83e34Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CenarchaeumSymbiosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full4222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL4222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full4222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopelagicusBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpAu1208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. AU1208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpAu1208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfohalobiumRetbaenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalobium retbaense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfohalobiumRetbaenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpBr816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. BR816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpBr816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf404Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf404 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf404Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpLeaf225Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf225Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpBm10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. BM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpBm10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasOryzaeOryzicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae oryzicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaeOryzicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeosporaCaninumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neospora caninum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeosporaCaninumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulciaMuelleriSmdsemEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri SMDSEM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriSmdsemEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumGp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterJiangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter jiangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaludibacterJiangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpHjm029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HJM029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHjm029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsphigho202full4613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO202FULL4613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho202full4613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg23070394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_70_394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg23070394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisElliptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botrytis elliptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotrytisElliptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApostichopusJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apostichopus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApostichopusJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyphellophoraEuropaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyphellophora europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyphellophoraEuropaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAidingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aidingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAidingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylophilusSpLeaf220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylophilus sp. Leaf220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylophilusSpLeaf220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetofabaAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetofaba australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetofabaAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosinusSpLw3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisSorokinianaNd90prCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana ND90Pr Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BipolarisSorokinianaNd90prCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaOleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea olei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaOleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrococcusRivularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrococcusRivularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumMar2010188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium MAR_2010_188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumMar2010188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterKumamotonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter kumamotonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterKumamotonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpKo116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KO116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKo116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpAedCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. AED Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAedCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumGossypiiAtcc10895(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii ATCC 10895 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EremotheciumGossypiiAtcc10895", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonSm150Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SM1-50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSm150Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo212full4413bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO212FULL4413b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo212full4413bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMikamiiNbrc108933Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mikamii NBRC 108933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaMikamiiNbrc108933Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaTurbansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia turbans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTurbansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPlurextorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus plurextorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPlurextorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFermentansM64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans M64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFermentansM64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusObscuribacterPhosphatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Obscuribacter phosphatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusObscuribacterPhosphatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 28_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConchiformibiusKuhniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius kuhniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusKuhniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaSpF0356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. F0356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpF0356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumGw2011gwe13912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWE13912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwe13912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full4622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL4622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full4622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptoalloteichusHindustanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptoalloteichus hindustanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptoalloteichusHindustanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumRiftiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum riftiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumRiftiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphilophusCitrinellusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphilophus citrinellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphilophusCitrinellusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrospiraPlatensisC1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis C1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisC1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpFs083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. FS08-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpFs083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusSpicilegus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mus spicilegus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusSpicilegus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaitozymaPodzolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saitozyma podzolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaitozymaPodzolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumCapitatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium capitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumCapitatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAltiarchaealesArchaeonImc4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Altiarchaeales archaeon IMC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAltiarchaealesArchaeonImc4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KutzneriaAlbidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria albida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KutzneriaAlbidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpBbd19919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. BBD 1991-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpBbd19919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilvensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silvensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilvensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumPo82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Po82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPo82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioSpirochaetisodalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio spirochaetisodalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioSpirochaetisodalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopostipesSuicloacalisDsm15692Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis DSM 15692 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalisDsm15692Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpYr768Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YR768 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYr768Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarsonellaRuddiiHtThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HT Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHtThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumCag3125820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CAG:312_58_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCag3125820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisTessellariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis tessellarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisTessellariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpK4410mgs306(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. K4410MGS306 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpK4410mgs306", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoecheraStrictaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Boechera stricta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BoecheraStrictaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraAquimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobacillusCyriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus cyri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusCyriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSpPh9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. PH9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSpPh9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaAldovae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia aldovae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaAldovae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonRbg16369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon RBG_16_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonRbg16369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasNitrosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas nitrosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasNitrosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpP32eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P32E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP32eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusDestructans2063121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans 20631-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructans2063121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusArctosHorribilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ursus arctos horribilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UrsusArctosHorribilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumRifoxya1full3614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYA1FULL3614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxya1full3614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SparusAurata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sparus aurata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SparusAurata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenzhouxiangellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wenzhouxiangella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WenzhouxiangellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaOxidasica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina oxidasica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaOxidasica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KyrpidiaTusciae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kyrpidia tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KyrpidiaTusciae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTamiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tamiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaTamiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesMethylutens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpRac06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. RAC06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpRac06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumCg2304417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG2_30_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg2304417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpOsyseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OSYSE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOsyseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyorhinisGdl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis GDL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisGdl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpDsm18164(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. DSM 18164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpDsm18164", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CricetulusGriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cricetulus griseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CricetulusGriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc5015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC5015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc5015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaJejuensisDsm15929Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis DSM 15929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensisDsm15929Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg16399b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16399b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16399b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumChilenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chilense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChilenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_36_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusPenaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus penaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VagococcusPenaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaAmniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella amnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAmniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk564Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK564 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk564Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteroidesFrankliniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides franklinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesFrankliniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifoxyc12full6523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYC12FULL6523 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyc12full6523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpRoot123d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. Root123D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpRoot123d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmaAcidophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma acidophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaAcidophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAnguilliseptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas anguilliseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAnguilliseptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar324ClusterBacteriumSar324ctd7bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium SAR324CTD7B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumSar324ctd7bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpRoot1310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium3818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 38-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium3818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpT6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaHulunbeirensisJcm10989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis JCM 10989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensisJcm10989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpicoccumNigrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epicoccum nigrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpicoccumNigrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesKanasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kanasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKanasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraSpBsl9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. BSL-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpBsl9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPapuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella papuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPapuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacaDankookensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca dankookensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaDankookensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUnc280mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC280MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc280mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpKrmcy2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KRMCY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKrmcy2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaChaffeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia chaffeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaChaffeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumApsheronum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium apsheronum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumApsheronum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasArtemidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas artemidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasArtemidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfTrichogrammaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNk4a179Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a179Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAzambacteriaBacteriumRifoxyb1Full4033Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFOXYB1_FULL_40_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifoxyb1Full4033Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenibacterNanhaiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter nanhaiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenibacterNanhaiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_16b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKsb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division KSB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSomeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas somerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSomeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EisenibacterElegans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eisenibacter elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EisenibacterElegans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusFasciansLmg3625(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians LMG 3625 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansLmg3625", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusArciformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus arciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusArciformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesantisbacteriaBacteriumCg2304021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG2304021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg2304021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL479 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapillibacterCinnamivoransDsm12816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans DSM 12816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PapillibacterCinnamivoransDsm12816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_40_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesScabieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabiei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHemicellulosilyticusJcm9152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus JCM 9152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticusJcm9152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg136114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_61_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterSpDg31dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG31D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg31dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMooreiDsm22971Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei DSM22971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiDsm22971Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterCibinongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterCibinongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaInsecticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia insecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaInsecticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirundoRusticaRusticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hirundo rustica rustica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HirundoRusticaRusticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSegnicrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter segnicrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSegnicrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc5054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusRubeinfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus rubeinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusRubeinfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumSgbin8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteroidesAbscessusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides abscessus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesAbscessusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBaumanniiAtcc17978Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii ATCC 17978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiAtcc17978Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpRoot608Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root608 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot608Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusRugosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus rugosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusRugosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumMediterraneense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium mediterraneense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMediterraneense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsphigho201full4330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO201FULL4330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho201full4330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytalidiumLignicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scytalidium lignicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScytalidiumLignicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaMultipartitaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella multipartita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NakamurellaMultipartitaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaS16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida S16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaS16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaRadingaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia radingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaRadingaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliagarivoransTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExserohilumTurcicaEt28aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exserohilum turcica Et28A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExserohilumTurcicaEt28aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSocranskiiParedisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii paredis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiParedisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_44_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasSpScn6556Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas sp. SCN 65-56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasSpScn6556Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaKoehleraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella koehlerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaKoehleraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira yanagawae serovar Saopaulo str. Sao Paulo ATCC 700523 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOv608(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OV608 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv608", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButtiauxellaFerragutiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyricimonasVirosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas virosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasVirosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifcsplowo201full4626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml130628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML130628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml130628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPimensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus pimensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPimensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusVineae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus vineae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusVineae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusThermoglucosidasiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermoglucosidasius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermoglucosidasiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHamsteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hamsteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHamsteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPamc26617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26617 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesemziaIncerta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desemzia incerta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesemziaIncerta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTuberum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tuberum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTuberum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumRifcsphigho202full62130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium RIFCSPHIGHO202FULL62130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumRifcsphigho202full62130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpRifrc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. RIFRC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpRifrc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChoiromycesVenosus1206131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Choiromyces venosus 120613-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChoiromycesVenosus1206131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_53_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrilusPlanipennisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrilus planipennis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrilusPlanipennisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumBarkeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium barkeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBarkeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacterium1109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium 1109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacterium1109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpulaLacrymansVarLacrymansS73(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans var. lacrymans S7.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerpulaLacrymansVarLacrymansS73", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraJadiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraJadiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodesmiumErythraeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichodesmium erythraeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodesmiumErythraeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaGlobosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malassezia globosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalasseziaGlobosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerruconisGallopavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verruconis gallopava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerruconisGallopavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrochothrixCampestrisFslF61037Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix campestris FSL F6-1037 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrochothrixCampestrisFslF61037Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMt2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpMt2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPhyllosphaerae52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae 52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaerae52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryziasMelastigmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryzias melastigma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryziasMelastigmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesItalicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces italicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesItalicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumGondwanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusCarnicancriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus carnicancri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusCarnicancriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumBacl7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FuerstiaMarisgermanicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fuerstia marisgermanicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FuerstiaMarisgermanicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumSpTc51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium sp. TC51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumSpTc51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeutenbergiaCavernae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beutenbergia cavernae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeutenbergiaCavernae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculusVarScolymusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cynara cardunculus var. scolymus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CynaraCardunculusVarScolymusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasSpB5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas sp. B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseomonasSpB5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMeningoseptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia meningoseptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaMeningoseptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumKh1t2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KH1T2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKh1t2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantholopsHodgsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantholops hodgsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantholopsHodgsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusFijiensisDsm17918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis DSM 17918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensisDsm17918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraAlvinipulliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliaeetusLeucocephalusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliaeetus leucocephalus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaliaeetusLeucocephalusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HolosporaElegansE1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Holospora elegans E1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HolosporaElegansE1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumMizutaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium mizutaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumMizutaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaryochlorisMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acaryochloris marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcaryochlorisMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaePhaseolicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae phaseolicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePhaseolicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeanutWitchesbroomCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peanut witchesbroom Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeanutWitchesbroomCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumH88(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH88", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_44_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioXylanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio xylanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioXylanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApostasiaShenzhenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apostasia shenzhenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApostasiaShenzhenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf25093Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_50_93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25093Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumChlororespirans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespirans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPr090111t3t6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PR090111T3T6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPr090111t3t6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterJejuniNctc11168Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni NCTC11168 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuniNctc11168Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalinemaSpCaciam70dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM 70d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciam70dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSpDl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. DL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpDl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpScn6119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. SCN 61-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpScn6119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfiporiaCocosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfiporia cocos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfiporiaCocosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacterialesBacterium5955Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriales bacterium 59-55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacterialesBacterium5955Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophusFodinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophus fodinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophusFodinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSalivarius57iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius 57I Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSalivarius57iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMoraviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus moraviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMoraviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE1747Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1747 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1747Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusKakegawensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpGhaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Gha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGhaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DictyoglomusTurgidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus turgidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusTurgidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaMultilocaleAtcc49900Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale ATCC 49900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocaleAtcc49900Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThecamonasTrahensAtcc50062(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens ATCC 50062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThecamonasTrahensAtcc50062", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaSpUtamx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumUltimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pythium ultimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PythiumUltimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseriAtccBaa895Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter koseri ATCC BAA-895 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterKoseriAtccBaa895Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpB29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. B29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpB29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpNio1057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. NIO-1057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpNio1057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AstatotilapiaCallipteraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Astatotilapia calliptera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AstatotilapiaCallipteraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaConjunctivaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma conjunctivae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaConjunctivaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpentinomonasRaicheiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas raichei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasRaicheiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFastidiosusNbrc101226Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus NBRC 101226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusFastidiosusNbrc101226Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_45_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSocranskiiParedis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii paredis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiParedis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacillusTrivialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus trivialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusTrivialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusSpZs01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. ZS01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpZs01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionTm6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalothiobacillusNeapolitanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus neapolitanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusNeapolitanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MizugakiibacterSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mizugakiibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MizugakiibacterSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrinickiaCaryophylli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trinickia caryophylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrinickiaCaryophylli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSchoenbuchensisR1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis R1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensisR1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full3717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3717 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOhsuiii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OHSUIII graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOhsuiii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnimonasNigrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnimonas nigrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnimonasNigrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpAcc21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. ACC21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpAcc21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaHippikonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma hippikon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaHippikonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeotheceCitriformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece citriformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeotheceCitriformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp10819081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1081908.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp10819081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusBoritoleransDsm17298Jcm18970(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans DSM 17298 JCM 18970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusBoritoleransDsm17298Jcm18970", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAsaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAsaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpPamc25486Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAMC 25486 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpPamc25486Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpheniscorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium spheniscorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpheniscorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpNb77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColi536Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli 536 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColi536Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaToluolicaTol2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Tol2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobaculaToluolicaTol2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusTerrigenaDsm22685Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena DSM 22685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigenaDsm22685Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusWarneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus warneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusWarneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosakoniaRadicincitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia radicincitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KosakoniaRadicincitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasGudaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas gudaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasGudaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeminorellaGrimontiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leminorella grimontii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeminorellaGrimontiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumStraminisolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157H7StrSakai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157:H7 str. Sakai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157H7StrSakai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaBissettii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia bissettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaBissettii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGilichinskyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gilichinskyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGilichinskyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumSpCag7458120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:74_58_120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag7458120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScopuliridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scopuliridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScopuliridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaBeijingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaBeijingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaOstoyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armillaria ostoyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmillariaOstoyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedEubacteriumSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Eubacterium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedEubacteriumSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerMucosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipiger mucosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipigerMucosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis6119v5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 6119V5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis6119v5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumCambrienseDora20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DORA20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDora20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacillusMalaysiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus malaysiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusMalaysiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaCatarrhalisBbh18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis BBH18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalisBbh18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaDokdonensisDs3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis DS-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensisDs3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMicans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella micans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMicans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemanellaBiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holdemanella biformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoldemanellaBiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaSpCba1127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula sp. CBA1127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaSpCba1127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGladioliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia gladioli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGladioliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasCampaniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas campaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasCampaniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiofilumFlexileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiofilum flexile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiofilumFlexileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumBakii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium bakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumBakii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbidovulumXiamenenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Albidovulum xiamenense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlbidovulumXiamenenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumKashiwanohenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulgatibacterIncomptusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulgatibacter incomptus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulgatibacterIncomptusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterMallensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter mallensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterMallensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCricetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus criceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCricetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaLoescheiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella loescheii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaLoescheiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AciduliprofundumBooneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum boonei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumBooneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpFobrc6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_49_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasSpFbcdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FBCd Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFbcdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC4105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_45_10c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUnc267mfsha11m11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC267MFSha1.1M11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc267mfsha11m11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwt2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwt2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSimplexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus simplex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSimplexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaDagmatisAtcc43325Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis ATCC 43325 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaDagmatisAtcc43325Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_41_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSpPh9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. PH9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSpPh9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumCg2303812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium CG2_30_38_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumCg2303812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifcsplowo202full4814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO202FULL4814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo202full4814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumGbs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium GBS-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumGbs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscobolusImmersusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ascobolus immersus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AscobolusImmersusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag1004157Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:10041_57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag1004157Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpUnc378mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. UNC378MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpUnc378mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachanceaMirantinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachancea mirantina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachanceaMirantinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRivorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rivorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRivorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicellaMetallireducensAeb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens AeB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FervidicellaMetallireducensAeb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaApis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella apis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaApis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpRoot485Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root485 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot485Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium688Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 68-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium688Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo212full599Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO212FULL599 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo212full599Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterOrnithocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ornithocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterOrnithocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaFrigidimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella frigidimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFrigidimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfohalovibrioReitneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalovibrio reitneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfohalovibrioReitneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusCaldus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1023846(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_38_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1023846", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDiolivoransDsm14421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans DSM 14421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDiolivoransDsm14421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixBouteilleiVb521301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei VB521301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TolypothrixBouteilleiVb521301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GastranaerophilusPhascolarctosicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilus phascolarctosicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilusPhascolarctosicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraChibensisNbrc106107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura chibensis NBRC 106107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraChibensisNbrc106107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpDmeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDmeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BarnesiellaViscericolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella viscericola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaViscericolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGelidilacusDsm15343Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus DSM 15343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacusDsm15343Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PurpureocilliumLilacinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Purpureocillium lilacinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PurpureocilliumLilacinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGraminisDsm20719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus graminis DSM 20719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGraminisDsm20719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpCb00851(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. CB00851 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpCb00851", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterNamhicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter namhicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterNamhicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxKoreenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax koreense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxKoreenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RasamsoniaEmersoniiCbs39364Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii CBS 393.64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RasamsoniaEmersoniiCbs39364Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraHyodysenteriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hyodysenteriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHyodysenteriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusMulundensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus mulundensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusMulundensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumKbs146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium KBS146 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumKbs146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumSpS3pf19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium sp. S3PF19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumSpS3pf19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo201full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4717 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpYr620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR620 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria fleischmannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaFleischmannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg164410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_44_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg164410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSpWwm596Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. WWM596 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpWwm596Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoclosmatiumGlobosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizoclosmatium globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizoclosmatiumGlobosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRadioresistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter radioresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRadioresistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtochlamydiaNaegleriophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia naegleriophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaNaegleriophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspOharaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. oharae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspOharaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFlavusNrrl3357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus NRRL3357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusFlavusNrrl3357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNasicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces nasicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNasicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatiglansAniliniDsm4660(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini DSM 4660 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfatiglansAniliniDsm4660", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckiiAtcc11842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii ATCC11842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiAtcc11842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuribacillusAlkaliarsenatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus alkaliarsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusAlkaliarsenatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusHalocaseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus halocasei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusHalocaseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeRhinoscleromatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae rhinoscleromatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeRhinoscleromatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasAquamarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas aquamarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasAquamarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryotiniaCalthae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia calthae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaCalthae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumCg1023722Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium CG1_02_37_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumCg1023722Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacterFormigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OxalobacterFormigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTaa040(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa040", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuriculariopsisAmplaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Auriculariopsis ampla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AuriculariopsisAmplaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSpZwu0011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. ZWU0011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpZwu0011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumHungateiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumHungateiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CylindrospermopsisRaciborskiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermopsis raciborskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CylindrospermopsisRaciborskiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbsidiaGlaucaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Absidia glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbsidiaGlaucaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyclobacteriumQasimiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium qasimii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumQasimiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaKururiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19055Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM 19055 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19055Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMassiliogorillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliogorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliogorillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterSpSw2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. SW2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpSw2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwf24352Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWF2_43_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwf24352Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL3713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacteraceaeBacteriumCg1023614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacteraceae bacterium CG1_02_36_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacteraceaeBacteriumCg1023614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuillusLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Suillus luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuillusLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpOrs3428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 70-64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaLincolniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lincolnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLincolniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa2407b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA2407b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa2407b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTurcosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus turcosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusTurcosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCelerecrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] celerecrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelerecrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAtexabd23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ATexABD23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAtexabd23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaAffPulcherrima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia aff. pulcherrima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaAffPulcherrima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCoelicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces coelicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCoelicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeomarinobacterEctocarpiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeomarinobacter ectocarpi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeomarinobacterEctocarpiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_34_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumCch11d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH11D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch11d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsConfragosaRcef1005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps confragosa RCEF 1005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CordycepsConfragosaRcef1005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Glassbacteria bacterium RIFCSPLOWO2_12_FULL_58_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVirginiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces virginiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesVirginiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPasteurianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAzotifigensNbrc15497Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens NBRC 15497 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAzotifigensNbrc15497Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomicrostromaGlucosiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomicrostroma glucosiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomicrostromaGlucosiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumUasb340(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb340", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccipiterNisus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accipiter nisus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccipiterNisus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSharmensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sharmensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSharmensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumShigenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium shigense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumShigenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanomethylicusOleusabulum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus oleusabulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusOleusabulum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaFidelisAtccBaa318Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shewanella fidelis ATCC BAA-318 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShewanellaFidelisAtccBaa318Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgathobaculumDesmolansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agathobaculum desmolans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgathobaculumDesmolansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenolepisDiminuta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenolepis diminuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenolepisDiminuta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwd24019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWD24019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwd24019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterNyackensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter nyackensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterNyackensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaSpJg1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. JG-1b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpJg1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceicoccusPelagiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus pelagius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusPelagiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrocitellusParryiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Urocitellus parryii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrocitellusParryiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpErgs101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ERGS1:01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpErgs101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSpEhc01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. EhC01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpEhc01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiwaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niwae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiwaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FukatsuiaSymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fukatsuia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FukatsuiaSymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusRufusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus rufus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRufusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GouaniaWilldenowiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gouania willdenowi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GouaniaWilldenowiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 1_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaMeridionalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza meridionalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaMeridionalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMelliventrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus melliventris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMelliventrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobisporaSpGmku363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. GMKU363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpGmku363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidothermusCellulolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidothermus cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidothermusCellulolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisPotensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis potens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPotensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumNovocastrenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium novocastrense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNovocastrenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumScgcAaa252a02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium SCGC AAA252A02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumScgcAaa252a02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHepaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hepaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHepaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrospiraNitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesKpa171202Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes KPA171202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesKpa171202Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpNk3a76(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. NK3A76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpNk3a76", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaHelvetica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia helvetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaHelvetica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumBv3ac1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium BV3Ac1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumBv3ac1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaSpAna3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ANA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpAna3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc6312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC6312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc6312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararheinheimeraTexasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocFallax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocFallax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArgenteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus argenteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArgenteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotaleaMetallivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotalea metallivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotaleaMetallivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAbietaniphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas abietaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAbietaniphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudospirillumJaponicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudospirillum japonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudospirillumJaponicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumAbikonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium abikonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumAbikonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdaphobacillusLindanitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edaphobacillus lindanitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdaphobacillusLindanitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosisCdc317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis CDC317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaParapsilosisCdc317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaSublithincolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita sublithincola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSublithincolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSp64120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. 64-120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSp64120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogeometricumLimiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumLimiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaSpCcs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. CCS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpCcs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumHolothuriorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum holothuriorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumHolothuriorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpCag439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1024740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1024740 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1024740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumGlycines(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium glycines graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGlycines", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChauvoeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chauvoei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChauvoeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumMelA1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium MEL.A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumMelA1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumUreilyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium ureilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumUreilyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalicoccusPleomorphus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalicoccus pleomorphus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalicoccusPleomorphus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumTrichothecenolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium trichothecenolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTrichothecenolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full5223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL5223 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full5223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TyzzerellaNexilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tyzzerella nexilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TyzzerellaNexilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusIbericusCbs121593(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ibericus CBS 121593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusIbericusCbs121593", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaThiotauriniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola thiotaurini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaThiotauriniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasLignilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas lignilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolumonasLignilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusThermoamylovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus thermoamylovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusThermoamylovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaSpOralTaxon894Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ottowia sp. oral taxon 894 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OttowiaSpOralTaxon894Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JiulongibacterSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jiulongibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JiulongibacterSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GigasporaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gigaspora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GigasporaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBizertensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusMalodoratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus malodoratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMalodoratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeraceosorusBombacisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus bombacis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusBombacisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromycesRobustus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyces robustus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromycesRobustus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusVeneficusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus veneficus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusVeneficusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinocyclocheilusGrahamiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus grahami Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusGrahamiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMobaraensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mobaraensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMobaraensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumSpKb01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium sp. KB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumSpKb01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VicugnaPacos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vicugna pacos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VicugnaPacos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BariatricusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bariatricus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BariatricusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumRifcsphigho201full5025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFCSPHIGHO201FULL5025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifcsphigho201full5025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterIguaniorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter iguaniorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterIguaniorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosocosmicusExaquare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus exaquare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusExaquare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaEutrophaJmp134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha JMP134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaJmp134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg135819Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_58_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135819Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpKh1p2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. kh1p2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh1p2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudaminobacterManganicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter manganicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterManganicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumScgcAaa300k03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA300K03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa300k03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag180(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag180", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixJangbogonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix jangbogonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixJangbogonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacteriumCg10243210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_43_210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg10243210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3654(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3654 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3654", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusInfluenzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus influenzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusInfluenzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwh6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc8801Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC8801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc8801Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrrhodermaNoxiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrrhoderma noxium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrrhodermaNoxiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ToxocaraCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Toxocara canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ToxocaraCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4311bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4311b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4311bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MongoliimonasTerrestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mongoliimonas terrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MongoliimonasTerrestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMf105b01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Mf 105b01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMf105b01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydraVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydra vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydraVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpCag105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpOv335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. OV335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpOv335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LipotesVexilliferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lipotes vexillifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LipotesVexilliferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterPontiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pontiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPontiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonadaceaeBacteriumUkl131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium UKL13-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumUkl131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifcsplowo201full3912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO201FULL3912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo201full3912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaStriiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puccinia striiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PucciniaStriiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DanionellaTranslucida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Danionella translucida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DanionellaTranslucida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm47(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpIcm47", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpOk048Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OK048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOk048Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseorubiginosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseorubiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseorubiginosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioSpPealriverCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. pealriver Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPealriverCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp10a9div0425(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 10A9DIV0425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp10a9div0425", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMindensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMindensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraLinaloolentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera linaloolentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraLinaloolentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpWchac010034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. WCHAc010034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpWchac010034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCloacimonetesBacterium457255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Cloacimonetes bacterium 4572_55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCloacimonetesBacterium457255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylococcusCapsulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylococcus capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylococcusCapsulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChiloSuppressalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chilo suppressalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChiloSuppressalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMoravicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella moravica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaMoravicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzotobacterBeijerinckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzotobacterBeijerinckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DelongbacteriaBacteriumGwf24014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Delongbacteria bacterium GWF24014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DelongbacteriaBacteriumGwf24014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNanhaiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nanhaiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNanhaiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27225Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27225Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NadsoniaFulvescensVarElongataDsm6958Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens var. elongata DSM 6958 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NadsoniaFulvescensVarElongataDsm6958Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraInfestansT304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans T30-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraInfestansT304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRamulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ramulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRamulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterArenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterArenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesAlbimanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles albimanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesAlbimanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariimicrobiumKwangyangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aestuariimicrobium kwangyangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AestuariimicrobiumKwangyangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacterium311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium 311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacterium311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpEc33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ec33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpEc33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMoukalabenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium moukalabense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMoukalabenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_49_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaLupiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora lupini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaLupiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaVacciniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vaccinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaVacciniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkanindigesSpH1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges sp. H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesSpH1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFructicolaNaraGc5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Nara gc5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFructicolaNaraGc5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratiruptorSpSb1552(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor sp. SB1552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorSpSb1552", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2439bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2439b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2439bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankineaeBacteriumMt45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankineae bacterium MT45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankineaeBacteriumMt45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpTb64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. TB64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpTb64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistalesBacterium5881Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 58_81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5881Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MotiliproteusSpMsk221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Motiliproteus sp. MSK22-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MotiliproteusSpMsk221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3654Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3654 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3654Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterJunii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter junii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJunii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansAtcc27774(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ATCC27774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansAtcc27774", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioJasicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio jasicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioJasicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSpAgr2158Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. AGR2158 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpAgr2158Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NaumovozymaCastellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma castellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaCastellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaXenovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia xenovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaXenovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSpCcs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. CCS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpCcs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterButzleriEd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri ED1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriEd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 62-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonAb25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon AB_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonAb25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina palpalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaPalpalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumGwa2478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_47_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa2478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumUndae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium undae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumUndae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenarthrobacterAurescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter aurescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterAurescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpBm10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. BM10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpBm10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return candidate division ZIXI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionZixi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifoxyd1full3729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYD1FULL3729 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyd1full3729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomassariellaVexataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomassariella vexata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomassariellaVexataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumSpLeaf291Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Leaf291 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpLeaf291Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumHumicireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum humicireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHumicireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeleagrisGallopavoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meleagris gallopavo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeleagrisGallopavoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpBtai1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. BTAi1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpBtai1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisSpCib2401Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. CIB 2401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpCib2401Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobisporangiumUltimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Globisporangium ultimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlobisporangiumUltimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_41_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasMalthaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas malthae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMalthaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSaniviri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaniviri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaSeiffertii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonBa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosumWal14673(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14673 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14673", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSterculiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sterculiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSterculiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenesCect7868Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio aerogenes CECT 7868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioAerogenesCect7868Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CutibacteriumAvidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium avidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAvidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuccinatimonasSpCag777Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas sp. CAG:777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasSpCag777Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStriatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium striatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStriatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAmycolatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium amycolatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAmycolatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosyntrophaLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUrinalis228597(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis 228597 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalis228597", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumBrasilianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium brasilianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumBrasilianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnothrixRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumScrofulaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium scrofulaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumScrofulaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlutamicibacterArilaitensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter arilaitensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterArilaitensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiBerkhoffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii berkhoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiBerkhoffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumDg743Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg743Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterLudwigii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter ludwigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLudwigii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusKodakarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus kodakarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusKodakarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumRifcsplowo212full3515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaumanniaCicadellinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinibacterTainanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinibacterTainanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumSpCba1132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. CBA1132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpCba1132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPunonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas punonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPunonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ManacusVitellinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Manacus vitellinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ManacusVitellinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanithermusProfundus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanithermus profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanithermusProfundus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpVer3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. Ver3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpVer3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheileriaParva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theileria parva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheileriaParva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpScn5710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SCN 57-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpScn5710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomonachusSchauinslandiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neomonachus schauinslandi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeomonachusSchauinslandiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpLeaf50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusLacrimalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumRedseas02b3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS02B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas02b3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGa0074129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ga0074129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGa0074129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SubdoligranulumSp4354a2faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. 4354A2FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SubdoligranulumSp4354a2faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpNs7484(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. NS-7484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpNs7484", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusSpRedseas12b1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus sp. REDSEAS12B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSpRedseas12b1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MerdimonasFaecis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Merdimonas faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MerdimonasFaecis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrigamiaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strigamia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrigamiaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpadixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas spadix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpadixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc034a01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC034A01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc034a01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumUrha0028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium URHA0028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumUrha0028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaThiersiiSkay4041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amanita thiersii Skay4041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmanitaThiersiiSkay4041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorogloeopsisFritschiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorogloeopsis fritschii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorogloeopsisFritschiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacterSpHeli10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacter sp. HelI10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacterSpHeli10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSpM107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. M107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSpM107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSp8254bfaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 8_2_54BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSp8254bfaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterovibrioCalviensisDsm14347(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis DSM 14347 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioCalviensisDsm14347", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacillusKushneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinibacillus kushneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinibacillusKushneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumSpAk27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium sp. AK27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumSpAk27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarchaeumSpHarchtbsk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinarchaeum sp. HarchtBsk1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinarchaeumSpHarchtbsk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu33cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU33C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu33cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp6610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 66-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeongeupiaSpUsm3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeongeupia sp. USM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeongeupiaSpUsm3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpUrha0041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. URHA0041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpUrha0041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPhaffiiGs115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Komagataella phaffii GS115 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPhaffiiGs115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactisNbrc100932Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis NBRC 100932 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactisNbrc100932Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPerolensDsm12744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus perolens DSM 12744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPerolensDsm12744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesAcidifaciensJcm10556(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens JCM 10556 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciensJcm10556", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesLutziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesLutziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriaceaeArchaeon41258Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon 41_258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeon41258Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgreiaSpLeaf244(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf244", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymophilusRaffinosivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zymophilus raffinosivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZymophilusRaffinosivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVietnamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVietnamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaLaidlawiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma laidlawii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaLaidlawiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaTriticiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaTimonensisCris5cb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis CRIS5CB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensisCris5cb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpYr522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. YR522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpYr522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGhanaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ghanaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGhanaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumIcenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium icense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumIcenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopropionibacteriumPropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudopropionibacterium propionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudopropionibacteriumPropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChoanephoraCucurbitarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Choanephora cucurbitarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChoanephoraCucurbitarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumVerruco04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Verruco_04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumVerruco04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSpMe1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. ME-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpMe1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE183Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE183Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PowellomycesHirtus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Powellomyces hirtus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PowellomycesHirtus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCoprophilusNbrc100603(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus NBRC 100603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusCoprophilusNbrc100603", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_40_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBrasiliensisCbs101740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis CBS 101740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusBrasiliensisCbs101740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMalefermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus malefermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMalefermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacteriumUrhd0017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag956Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:956 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag956Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophusAciditrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus aciditrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophusAciditrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraPsammophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraPsammophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelftiaAcidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Delftia acidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DelftiaAcidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormivibrioCitricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formivibrio citricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormivibrioCitricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus anginosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAnginosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp103dpr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 103DPR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp103dpr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActibacteriumMucosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium mucosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumMucosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCandidatusPoseidonialesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return uncultured Candidatus Poseidoniales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UnculturedCandidatusPoseidonialesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisVesicatoriaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris vesicatoria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisVesicatoriaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpinosisporaDsm44797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora DSM 44797 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosisporaDsm44797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCanadenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canadense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanadenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumObuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium obuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumObuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaForsetii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella forsetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaForsetii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaPurinilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia purinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaPurinilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodonellumIkkaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodonellum ikkaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodonellumIkkaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaSolidipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armillaria solidipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmillariaSolidipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpCf444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. CF444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpCf444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFarciminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farciminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarciminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaUniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia uniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaUniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpiritivorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium spiritivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpiritivorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasSpHmsc077f02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC077F02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc077f02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraAerophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira aerophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraAerophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasAuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas auensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolumonasAuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraMegakaryaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora megakarya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraMegakaryaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterLignolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter lignolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLignolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizoctoniaSolaniAg1iaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1iaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4518Fw2643Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4518 (FW-2643) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4518Fw2643Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_24b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumP6a3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6a3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil805Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil805 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil805Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassilimaliaeMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilimaliae massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilimaliaeMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfarculaceaeBacteriumJdfr97Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculaceae bacterium JdFR-97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfarculaceaeBacteriumJdfr97Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwe23830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWE2_38_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwe23830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraParasitica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora parasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraParasitica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VombatusUrsinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vombatus ursinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VombatusUrsinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraSpPhs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. PHS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpPhs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusLindneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus lindneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusLindneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides insulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesInsulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterCaenitepidiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter caenitepidi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterCaenitepidiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamsiaSterculiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sterculiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSterculiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaFlavaJlt2011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella flava JLT2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GramellaFlavaJlt2011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisUo5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Uo5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisUo5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConsotaellaSalsifontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Consotaella salsifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConsotaellaSalsifontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LongisporaAlbida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Longispora albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LongisporaAlbida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_01_FULL_41_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterCupressi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter cupressi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCupressi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaSpGmoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gmo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGmoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusCollinsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus collinsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichococcusCollinsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusContaminans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusContaminans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBms12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BMS12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBms12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LambdaproteobacteriaBacteriumRifoxyd1full5627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD1FULL5627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd1full5627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3713bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3713b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3713bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHalstediiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces halstedii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHalstediiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiPv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSpJcm19050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. JCM 19050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJcm19050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichomonasVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichomonas vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichomonasVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumCg10239135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium CG10239135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumCg10239135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycetocolaSaprophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola saprophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycetocolaSaprophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimwelliaBlattaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimwellia blattae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimwelliaBlattaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumFallaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFallaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpRoot480Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Root480 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpRoot480Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaCaldifontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaCaldifontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesnuesiellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desnuesiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesnuesiellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusRobiginosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus robiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusRobiginosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumThioautotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thioautotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThioautotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthochromisPolyacanthusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acanthochromis polyacanthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcanthochromisPolyacanthusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_47_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumDtu037(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium DTU037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumDtu037", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MurdochiellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetobacteriumCasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetobacterium casensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetobacteriumCasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoffeaCanephoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coffea canephora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoffeaCanephoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterInsulaenigraeNctc12927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae NCTC 12927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigraeNctc12927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidomycesRichmondensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidomycesRichmondensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpAf1440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArcobacterSpAf1440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgibacterLectus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algibacter lectus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgibacterLectus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotoleransDsm19514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans DSM 19514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FerrithrixThermotoleransDsm19514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsplowo202full388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO202FULL388 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo202full388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GayadomonasJoobiniege(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gayadomonas joobiniege graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GayadomonasJoobiniege", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaCeler(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Grimontia celer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GrimontiaCeler", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusMulundensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus mulundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusMulundensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadaceaeBacteriumBs31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadaceae bacterium Bs31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonadaceaeBacteriumBs31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomicrobiaArchaeonDtu008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon DTU008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonDtu008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmborellaTrichopoda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amborella trichopoda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmborellaTrichopoda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImtechellaHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Imtechella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ImtechellaHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MastacembelusArmatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mastacembelus armatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MastacembelusArmatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacrococcusCaseolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus caseolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCaseolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpRoot336d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root336D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot336d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisCloacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis cloacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisCloacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida parapsilosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaParapsilosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB262(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB262", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedArchaeonA07hr67Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr67Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrateuriaAurantiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frateuria aurantia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrateuriaAurantiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpB13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. b13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpB13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RozellaAllomycisCsf55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rozella allomycis CSF55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RozellaAllomycisCsf55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiohalospira halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiohalospiraHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusEquuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus equuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusEquuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpinosisporaDsm44797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora DSM 44797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosisporaDsm44797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SideroxydansSpGwf25914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans sp. GWF2_59_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SideroxydansSpGwf25914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrooxidansAtcc23270Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC23270 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc23270Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenuibacillusMultivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenuibacillus multivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenuibacillusMultivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelatoporiaSubvermisporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GelatoporiaSubvermisporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRivorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRivorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_56_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacterium457255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium 457255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacterium457255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalisDsm15434Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis DSM15434 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisDsm15434Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13220cm27011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_70_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm27011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaPalleroniiNbrc102513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii NBRC 102513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaPalleroniiNbrc102513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus anginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAnginosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EncephalitozoonCuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesStercorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides stercoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesStercorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifoxyc2full3525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFOXYC2FULL3525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifoxyc2full3525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaInohanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia inohanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaInohanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot1433d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root1433D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot1433d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaSpDsm29012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. DSM 29012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpDsm29012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpBs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumDenitrificansDsm15936(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans DSM 15936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificansDsm15936", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaPiniCbs10737(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella pini CBS 10737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KwoniellaPiniCbs10737", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolytica101Dsm11237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidocella aminolytica 101 DSM 11237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidocellaAminolytica101Dsm11237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisAtcc700779Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis ATCC700779 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisAtcc700779Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioVulnificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio vulnificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioVulnificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaSpNd16aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. ND16A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpNd16aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumKishitaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium kishitanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumKishitaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesCryophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilvimarinusPolysaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus polysaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusPolysaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFrumentiDsm13145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti DSM 13145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFrumentiDsm13145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacterium13120cm5428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_1_20CM_54_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13120cm5428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFxanac1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. FxanaC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpFxanac1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpPamc26554(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26554", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisCinereaT4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea T4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaT4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosilyticumRuminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermaerobacterMarianensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter marianensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterMarianensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9302Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9302 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9302Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSp117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSp117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AotusNancymaae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aotus nancymaae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AotusNancymaae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTritoniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tritonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioTritoniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAraiiNbrc100433(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia araii NBRC 100433 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GordoniaAraiiNbrc100433", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasKoreensisDsm17726Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis DSM 17726 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasKoreensisDsm17726Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLatescibacterAnaerobiusScgcAaa252E07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Latescibacter anaerobius SCGC AAA252-E07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLatescibacterAnaerobiusScgcAaa252E07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisVasculorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis vasculorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisVasculorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpUnccl28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNCCL28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUnccl28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiUsda3471Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti USDA3471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiUsda3471Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumHalopraeferensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum halopraeferens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHalopraeferensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloprevotellaTanneraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella tannerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaTanneraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterCryptusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter cryptus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterCryptusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobaculumLitoreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumHqm9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium HQM9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumHqm9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPersicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPersicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromicrobiumLacuslunae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromicrobium lacuslunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromicrobiumLacuslunae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasMicraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas micra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvimonasMicraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_02_FULL_47_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSp135mfcol51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 135MFCol51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp135mfcol51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24218Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24218 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24218Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaVirensGv298(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Gv29-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaVirensGv298", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithrixFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidithrix ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidithrixFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolituusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolituusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctobacteriumSuccinatutensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium succinatutens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSuccinatutensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CinnamomumMicranthumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CinnamomumMicranthumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaLansingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella lansingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaLansingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSlackiiAtcc49928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces slackii ATCC 49928 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSlackiiAtcc49928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 27_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNantensisDsm16982Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis DSM 16982 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNantensisDsm16982Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho2024118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO2024118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho2024118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251971sch5477799aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251971SCH5477799a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251971sch5477799aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusPeptidifermentansDsm18978(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans DSM 18978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentansDsm18978", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaBelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia bellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaBelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusFerrariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ferrarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFerrariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumDicentrarchiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum dicentrarchi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumDicentrarchiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumAeronauticumDsm10349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum DSM 10349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticumDsm10349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHimb30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiraMiltonrushiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meira miltonrushii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiraMiltonrushiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaThiersiiSkay4041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amanita thiersii Skay4041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmanitaThiersiiSkay4041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronolimnobiusInnermongolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronolimnobius innermongolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronolimnobiusInnermongolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisColoradensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis coloradensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisColoradensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColeofasciculusChthonoplastesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coleofasciculus chthonoplastes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColeofasciculusChthonoplastesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp4414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 44_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumGw2011gwa24315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWA24315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwa24315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnq509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNQ-509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnq509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterMucosalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter mucosalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterMucosalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacellibacteroidesSpHhzsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macellibacteroides sp. HHZS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacellibacteroidesSpHhzsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiSubspArupensisOk94513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii subsp. arupensis OK-94-513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaVinsoniiSubspArupensisOk94513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaCaribensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caribensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaribensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntamoebaHistolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Entamoeba histolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EntamoebaHistolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisCip7865Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis CIP78.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisCip7865Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSyntrophoarchaeumButanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum butanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumButanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCcnwgs0286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens CCNWGS0286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCcnwgs0286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctobacteriumSpCag266Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag266Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfatatorAutotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAutotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneolaVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Balneola vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BalneolaVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpBvorr106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKryptoniumThompsoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptonium thompsoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptoniumThompsoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacteriumUtbcd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium UTBCD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacteriumUtbcd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallionellalesBacteriumRifcsplowo202full5747Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO202FULL5747 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo202full5747Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalostagnicolaSpA56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola sp. A56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaSpA56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpHeli7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HelI7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MaribacterSpHeli7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaViscosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moritella viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoritellaViscosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumRubrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumRubrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusVerrucosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus verrucosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusVerrucosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisAtcc6249Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis ATCC6249 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisAtcc6249Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSp25b141Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 25B141 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp25b141Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfTrichogrammaPretiosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma pretiosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaPretiosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpDb56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. DB56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpDb56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiplasmaSpMba1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidiplasma sp. MBA-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidiplasmaSpMba1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumDivergensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium divergens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumDivergensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusMaritimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus maritimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMaritimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGelidilacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaSpBbd199113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula sp. BBD 1991-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvularculaSpBbd199113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfallasAlcoholivoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas alcoholivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfallasAlcoholivoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumApsheronumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium apsheronum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumApsheronumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSyngnathidarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium syngnathidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSyngnathidarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifoxyc2full479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYC2FULL479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyc2full479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocoleusSpPcc7113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus sp. PCC7113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusSpPcc7113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAmmoniagenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ammoniagenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAmmoniagenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasOryzaeOryzicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae oryzicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaeOryzicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpL2c084a000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. L2C084A000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpL2c084a000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpRit357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RIT357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpRit357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasPituitosaNbrc102491Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa NBRC 102491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPituitosaNbrc102491Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesantisbacteriaBacteriumCg2304021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG2304021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg2304021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAnginosusF0211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus F0211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusF0211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMexicanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mexicanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMexicanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MixiaOsmundae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mixia osmundae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MixiaOsmundae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrocitellusParryii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Urocitellus parryii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrocitellusParryii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroogloeocystisSiderophila52SC1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila 5.2 s.c.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophila52SC1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSomaliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces somaliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSomaliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldibacillusDebilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldibacillus debilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldibacillusDebilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusHydrogenalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus hydrogenalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusHydrogenalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumSpLk11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls149(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls149", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumChimaeraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium chimaera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumChimaeraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterGracilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter gracilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterGracilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacterSaccharofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaLeachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma leachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaLeachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1397Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_39_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1397Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButtiauxellaFerragutiaeAtcc51602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae ATCC 51602 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiaeAtcc51602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot635(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root635 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot635", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPluripotens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pluripotens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPluripotens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisTaihuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis taihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisTaihuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC 7003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloprofundusMarisrubriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloprofundus marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloprofundusMarisrubriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCalifornicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma californicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCalifornicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisH37rv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Rv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37rv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerulinaMusivaSo2202(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva SO2202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphaerulinaMusivaSo2202", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_47_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChiloscylliumPunctatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chiloscyllium punctatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChiloscylliumPunctatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat26652(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-26652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat26652", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaCelerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Grimontia celer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GrimontiaCelerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD12_FULL_33_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarincolaHl49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola HL49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaHl49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLipophiloflavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lipophiloflavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLipophiloflavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpCag815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesDarlingiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles darlingi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesDarlingiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanofastidiosumMethylthiophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanofastidiosum methylthiophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanofastidiosumMethylthiophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaSpBsc39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga sp. BSC39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaSpBsc39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_52_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSp263sspcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. 263SSPC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSp263sspcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAmylovorus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylovorus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumDiazoefficiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium diazoefficiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumDiazoefficiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusAs9601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus AS9601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusAs9601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitaleaBiformataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea biformata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaBiformataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpRoot264Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root264 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot264Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasporobacteriumPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminicolaSpYik13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminicola sp. YIK13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminicolaSpYik13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusObesiPh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi ph1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusObesiPh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumManteniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium mantenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumManteniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroococcidiopsisThermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chroococcidiopsis thermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChroococcidiopsisThermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaMayoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia mayonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaMayoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaG002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola G002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaG002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindariusDsm2278(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus tindarius DSM 2278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanolobusTindariusDsm2278", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NafulsellaTurpanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nafulsella turpanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NafulsellaTurpanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusCandidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus candidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusCandidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaApisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaApisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterMuridarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter muridarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMuridarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpNfr13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. NFR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpNfr13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MollicutesBacteriumHr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicrobiumMukohataei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium mukohataei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumMukohataei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis865192Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 865192 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis865192Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumColicanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaZhangzhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordia zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiaZhangzhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmigerFormicilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmiger formicilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmigerFormicilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceispirillumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puniceispirillum marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PuniceispirillumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaceyellaSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laceyella sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaceyellaSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraNicotianaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora nicotianae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraNicotianaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_50_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusAmargosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus amargosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAmargosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorticoccusHydrocarbonoclasticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porticoccus hydrocarbonoclasticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorticoccusHydrocarbonoclasticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThorarchaeotaArchaeonSmtz145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon SMTZ145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonSmtz145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg134613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_13_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg134613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwb11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumToluclasticumAtcc700605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum ATCC 700605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AromatoleumToluclasticumAtcc700605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumBacl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSphaerophysaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sphaerophysae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSphaerophysaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterAurescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter aurescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterAurescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumLuticoctiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium luticocti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLuticoctiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumLactilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium lactilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumLactilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothricoidesSpSr001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktothricoides sp. SR001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktothricoidesSpSr001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThraustothecaClavataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thraustotheca clavata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThraustothecaClavataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCapitisSubspCapitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis subsp. capitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCapitisSubspCapitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumViridifuturiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium viridifuturi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumViridifuturiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NucleicultrixAmoebiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nucleicultrix amoebiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NucleicultrixAmoebiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaHermanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia hermannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaHermanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopigerDjelfimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopiger djelfimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopigerDjelfimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TsukamurellaSp1534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella sp. 1534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaSp1534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterTroitsensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter troitsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenibacterTroitsensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChroococcidiopsisThermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chroococcidiopsis thermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChroococcidiopsisThermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSalivaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella salivae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSalivaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCaccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus caccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCaccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlautiaStaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plautia stali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlautiaStaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho201full4622bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO201FULL4622b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho201full4622bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc3832Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3832 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3832Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpSoil538Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Soil538 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpSoil538Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nosema ceranae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NosemaCeranae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_38_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpTunpsc045i4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. TunPSC045I4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpTunpsc045i4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesQuadriannulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles quadriannulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesQuadriannulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusLacrimalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleomorphomonasKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PleomorphomonasKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpLup30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LUP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLup30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFo5176Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Fo5176 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFo5176Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpAzwk3bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. AzwK3b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpAzwk3bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetrotogaMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Petrotoga mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PetrotogaMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpLeaf264Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf264Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumGwc24544(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_45_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc24544", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_45_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumWg36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium WG36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumWg36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusCurdlanolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus curdlanolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCurdlanolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterIndonesiensis5h1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis 5H-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensis5h1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumUzonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum uzonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermofilumUzonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterPiechaudiiHle(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii HLE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiHle", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaToletana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia toletana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaToletana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpGa0074138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. Ga0074138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpGa0074138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusBovimastitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus bovimastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusBovimastitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasChironomi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas chironomi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachymonasChironomi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpX12014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. X1(2014) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpX12014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasMephitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas mephitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasMephitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycetosporaChiangmaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetospora chiangmaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycetosporaChiangmaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannizziaGypseaCbs118893Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nannizzia gypsea CBS 118893 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NannizziaGypseaCbs118893Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorMitchellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloramator mitchellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloramatorMitchellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RomboutsiaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMojavensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mojavensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusMojavensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMangrovisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mangrovisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMangrovisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp11000297Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1100029.7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11000297Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaJejuensisDsm15929Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis DSM 15929 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensisDsm15929Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr7277Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR7277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr7277Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpJsc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. JSC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpJsc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JiangellaGansuensisDsm44835Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Jiangella gansuensis DSM 44835 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JiangellaGansuensisDsm44835Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3810 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpNm10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. NM10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpNm10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip102129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP102129 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCip102129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSulfurreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sulfurreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterSulfurreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterSpHeli6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. HelI6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpHeli6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full3615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumFujikuroiImi58289(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi IMI 58289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumFujikuroiImi58289", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumAviumParatuberculosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium paratuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAviumParatuberculosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAlginolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alginolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlginolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpCc6yy74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CC6YY74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCc6yy74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassiosiraOceanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira oceanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThalassiosiraOceanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAmyloliquefaciensDc12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DC-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDc12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAltiarchaealesArchaeonImc4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Altiarchaeales archaeon IMC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAltiarchaealesArchaeonImc4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSp01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb14412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_44_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb14412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalescamantesBacteriumScgcAaa471m6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calescamantes bacterium SCGC AAA471M6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalescamantesBacteriumScgcAaa471m6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCelatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium celatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KalmanozymaBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterGummiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter gummiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobacterGummiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrellaAestuarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrella aestuarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrellaAestuarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinibacillusScapharcaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus scapharcae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusScapharcaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlj24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaZoogloeoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaZoogloeoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp21311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2131.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusEutactusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus eutactus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprococcusEutactusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeMaculicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae maculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeMaculicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhabdusUtahensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusUtahensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorientalisSpIm1011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis sp. IM1011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorientalisSpIm1011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa25518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_55_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa25518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaPusillaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaPusillaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosinusSpLw3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisSepedonicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis sepedonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSepedonicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolaminaSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaSpNd6we1aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rothia sp. ND6WE1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RothiaSpNd6we1aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonadaceaeBacteriumCg1026018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium CG1_02_60_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumCg1026018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumCg1025621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_56_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1025621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpMsmb0266Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. MSMB0266 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpMsmb0266Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaricaulisMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumGwf25820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium GWF2_58_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGwf25820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAlginolyticus40bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus 40B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticus40bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumAponinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium aponinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumAponinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinimonasTaiwanensisDsm18899Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis DSM 18899 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensisDsm18899Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumKocurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum kocurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumKocurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FungalSpNo14919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.14919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo14919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSandarakinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sandarakinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSandarakinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwb24136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWB2_41_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwb24136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesSalmoniphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides salmoniphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSalmoniphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanionellaTranslucidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Danionella translucida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DanionellaTranslucidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSp67h29bpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. 67H29BP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSp67h29bpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkiellaAquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkiella aquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkiellaAquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpA2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpA2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesInvadans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces invadans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AphanomycesInvadans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JacksonbacteriaBacteriumRifoxya2full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jacksonbacteria bacterium RIFOXYA2FULL4312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JacksonbacteriaBacteriumRifoxya2full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS337 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterCarbinolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter carbinolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelobacterCarbinolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacterium6911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 69-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium6911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumMtc7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium MTC7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumMtc7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesJcm10003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes JCM10003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesJcm10003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OkibacteriumFritillariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Okibacterium fritillariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OkibacteriumFritillariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterPulverisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter pulveris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FranconibacterPulverisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpR1200b2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. R1200B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpR1200b2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaDiarizonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica diarizonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaDiarizonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndozoicomonasMontiporaeCl33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae CL-33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporaeCl33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctocarpusSiliculosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectocarpus siliculosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctocarpusSiliculosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumSpWp30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. WP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumSpWp30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumThermoresistibile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium thermoresistibile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumThermoresistibile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaGrimesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia grimesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaGrimesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesUniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides uniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesUniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSpWwm596(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. WWM596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpWwm596", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumClariflavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium clariflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumClariflavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVinicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVinicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPuniceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium puniceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPuniceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasii732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii 732 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasii732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterJejuni81176(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 81176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterJejuni81176", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterCrystallopoietes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter crystallopoietes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCrystallopoietes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPseudospumaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pseudospumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPseudospumaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph899(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph899", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCalifornicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces californicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCalifornicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaAerolataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Knoellia aerolata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KnoelliaAerolataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiBulgaricusAtcc11842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus ATCC 11842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricusAtcc11842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterConcisusAtcc51562(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus ATCC51562 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisusAtcc51562", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpS17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpS17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNubinhibensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nubinhibens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNubinhibensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumPseudolongum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CosenzaeaMyxofaciensAtcc19692Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens ATCC 19692 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciensAtcc19692Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaAtypicaAcs049vsch6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica ACS049VSch6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaAcs049vsch6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRhodolunaPlanktonicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodoluna planktonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodolunaPlanktonicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc3862Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3862 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3862Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerpetosiphonAurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonAurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisUo5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Uo5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisUo5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DufoureaNovaeangliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dufourea novaeangliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DufoureaNovaeangliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaSpBsc39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga sp. BSC39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaSpBsc39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthamoebaCastellaniiStrNeffCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii str. Neff Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcanthamoebaCastellaniiStrNeffCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasChlororaphisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas chlororaphis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasChlororaphisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLentusNbrc16444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lentus NBRC 16444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusLentusNbrc16444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LambdaproteobacteriaBacteriumRifoxyd2full5016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD2FULL5016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd2full5016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterTundripaludumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter tundripaludum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacterTundripaludumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CicerArietinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cicer arietinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CicerArietinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPiscicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piscicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiscicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TesticulariaCyperiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Testicularia cyperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TesticulariaCyperiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanimonasSmirnovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas smirnovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSmirnovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNeonatiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides neonati Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNeonatiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0262Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0262Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusTibetensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusTibetensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaLongicatenaDsm13814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena DSM13814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaDsm13814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMacleodiiDeepCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Deep Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiDeepCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusIntermedius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusIntermedius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritepidaFlocculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubritepida flocculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubritepidaFlocculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisInaquosorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis inaquosorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisInaquosorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaVaviloviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea vaviloviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaVaviloviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_62_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumMarisDsm6286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum maris DSM 6286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumMarisDsm6286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifcsplowo201full4825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4825 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeotrichumCandidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geotrichum candidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeotrichumCandidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerticilliumDahliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verticillium dahliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerticilliumDahliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHominisSk119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis SK119 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisSk119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraPerniciosaFa553(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa FA553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosaFa553", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumNor53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium NOR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumNor53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpCmfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpCmfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaVacciniiNbrc15922Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vaccinii NBRC 15922 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaVacciniiNbrc15922Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumGonidiaformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium gonidiaformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumGonidiaformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallaecimonasPentaromativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas pentaromativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasPentaromativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOdoratitofuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpNio1057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. NIO-1057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpNio1057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaAcidipaludisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia acidipaludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAcidipaludisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliivibrioWodanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio wodanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliivibrioWodanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu073(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu073", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp2kl27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNiameyense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium niameyense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNiameyense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumBrasilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium brasiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBrasilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumVirgatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Panicum virgatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PanicumVirgatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumHydrogeniphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hydrogeniphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHydrogeniphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OstreococcusLucimarinusCce9901(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus CCE9901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OstreococcusLucimarinusCce9901", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumMola814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium MOLA814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumMola814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovibacillusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novibacillus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovibacillusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusCaliditerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus caliditerrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusCaliditerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpBiwako01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. BIWAKO-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpBiwako01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioBastiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bastinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBastiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesInjenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myroides injenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyroidesInjenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomeilibacteriaBacteriumRifoxyd1full3729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYD1FULL3729 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyd1full3729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaLimi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaLimi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaTardaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella tarda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaTardaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterSpYe315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. YE315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpYe315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporobacterTermitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporobacter termitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporobacterTermitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesJenseniiJcm1364Nbrc14755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides jensenii JCM 1364 NBRC 14755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardioidesJenseniiJcm1364Nbrc14755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpC100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. C100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpC100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWeihenstephanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihenstephanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusWeihenstephanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalviaSplendens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salvia splendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalviaSplendens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocellaPaludicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocella paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocellaPaludicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKrulwichiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus krulwichiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusKrulwichiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSepticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium septicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSepticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpRoot96(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot96", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaFidelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella fidelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFidelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterMicraerophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister micraerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterMicraerophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumSar86e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamlibacterTataouinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter tataouinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RamlibacterTataouinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ViridibacillusArviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Viridibacillus arvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ViridibacillusArviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacterFormigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OxalobacterFormigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaQueenslandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaQueenslandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaTaeniospiralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpPhil15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Phil15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpPhil15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LamprocystisPurpureaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LamprocystisPurpureaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFermentumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFermentumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAbawacabacteriaBacteriumRbg164210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Abawacabacteria bacterium RBG_16_42_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAbawacabacteriaBacteriumRbg164210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraLatinaNbrc106108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura latina NBRC 106108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraLatinaNbrc106108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumSp46296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum sp. 46_296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumSp46296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSp9096Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. 9096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSp9096Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe2015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE2015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe2015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesSilveraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces silverae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomycesSilveraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrobacterRadiotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter radiotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrobacterRadiotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiodiazotrophaEndolucinidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endolucinida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndolucinidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho201full388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL388 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentisphaeraSalicampi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera salicampi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraSalicampi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaAnanassae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila ananassae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaAnanassae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JatrophaCurcasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jatropha curcas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JatrophaCurcasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph809Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH809 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph809Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaSpKle1797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. KLE1797 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpKle1797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLactaridiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lactaridi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLactaridiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp360mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 360MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSp360mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpLpb0142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. LPB0142 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpLpb0142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicolaPhilippines(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Philippines graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynesporaCassiicolaPhilippines", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiscatoriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piscatorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiscatoriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusUvarumDsm19971Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum DSM 19971 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusUvarumDsm19971Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EncephalitozoonCuniculiGbM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi GB-M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculiGbM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusFf33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus FF33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusFf33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium vaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumVaginae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRbg133615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG133615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg133615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermaniaPiniformisNbrc15059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Skermania piniformis NBRC 15059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SkermaniaPiniformisNbrc15059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalyomorphaHalysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halyomorpha halys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalyomorphaHalysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag452Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:452 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag452Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriSmdsemCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri SMDSEM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriSmdsemCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaportheAmpelinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe ampelina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiaportheAmpelinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSpFf7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. FF7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSpFf7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusFlavithermusTno09006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus TNO09006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusTno09006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:924 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolisilvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solisilvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSolisilvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaFlorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma florum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaFlorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaParadisiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya paradisiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaParadisiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaLalandiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Seriola lalandi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SeriolaLalandiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PusillimonasSpT77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas sp. T77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PusillimonasSpT77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpNbc371Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. NBC371 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpNbc371Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriCariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri CARI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriCariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiWsm2783Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM2783 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm2783Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaBusckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila busckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaBusckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaUaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaUaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensMarinusS108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens marinus S1-08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NonlabensMarinusS108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedSup05ClusterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedSup05ClusterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenophonusEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsenophonus endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArsenophonusEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf238335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_38_335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf238335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicum22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum 22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicum22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusSpHmsc067e09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus sp. HMSC067E09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcusSpHmsc067e09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacterium311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium 311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacterium311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WalczuchellaMonophlebidarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Walczuchella monophlebidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WalczuchellaMonophlebidarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobifidaCellulosilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PromicromonosporaKroppenstedtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Promicromonospora kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PromicromonosporaKroppenstedtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusGp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus GP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusGp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonBa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberibacillusCalidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus calidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TuberibacillusCalidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OidiodendronMaius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oidiodendron maius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OidiodendronMaius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumHaemolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium haemolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumHaemolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseobacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumCaspactino5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaHallyeonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivita hallyeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivitaHallyeonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CadophoraSpDse1049Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cadophora sp. DSE1049 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CadophoraSpDse1049Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSpNcppb569(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. NCPPB569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpNcppb569", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho201full5431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasConfluentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas confluentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasConfluentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimiaSpSk013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimia sp. SK013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimiaSpSk013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf046Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf046 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf046Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpArh5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ARh5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpArh5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumNurukiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium nuruki Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumNurukiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaUdeisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia udeis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaUdeisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobiArchaeonJdfr42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon JdFR-42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeonJdfr42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivalisAtcc33277(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis ATCC33277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisAtcc33277", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTcuhl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TCUHL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTcuhl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpBh333Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. BH-3-3-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpBh333Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAsbs410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASBs410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsbs410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpOv335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. OV335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpOv335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYD12_FULL_48_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpDoa9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DOA9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDoa9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumAcidaminophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium acidaminophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumAcidaminophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumRifcsphigho212full369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPHIGHO212FULL369 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsphigho212full369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagirhabdusAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagirhabdus alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagirhabdusAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumSpGbchlb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. GBChlB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumSpGbchlb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NisaeaDenitrificansDsm18348(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nisaea denitrificans DSM 18348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NisaeaDenitrificansDsm18348", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusAquimarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus aquimarinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAquimarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwd23842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWD2_38_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwd23842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGhanaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ghanaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGhanaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumGwa25015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium GWA2_50_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGwa25015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeroformaArcticaJp610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica JP610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphaeroformaArcticaJp610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSpCba1132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. CBA1132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpCba1132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumConfluentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium confluentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumConfluentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrophominaPhaseolinaMs6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina MS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MacrophominaPhaseolinaMs6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAlkalisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer alkalisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferAlkalisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaSp209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpKm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiansivirgaZeaxanthinifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus concavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusConcavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo202full5117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL5117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full5117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasKoreensisDsm17726(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis DSM 17726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasKoreensisDsm17726", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusHarenaeDsm16969Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus harenae DSM 16969 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusHarenaeDsm16969Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StigmatellaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stigmatella aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StigmatellaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc078h07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC078H07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc078h07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxTemperans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax temperans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxTemperans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnidentifiedEubacteriumScb49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return unidentified eubacterium SCB49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnidentifiedEubacteriumScb49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPyloriJ99Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori J99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriJ99Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisColoradensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis coloradensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisColoradensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg166022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_60_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpUcdfrssp1630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. UCDFRSSP1630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSpUcdfrssp1630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesShahiiWal8301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes shahii WAL 8301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesShahiiWal8301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MameliellaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mameliella alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MameliellaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusGilvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGilvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwf13135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWF13135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwf13135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_45_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusPlantarumNbrc100936Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus plantarum NBRC 100936 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusPlantarumNbrc100936Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlterileibacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alterileibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlterileibacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusLimicolaDsm2279(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus limicola DSM 2279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusLimicolaDsm2279", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyphaciaMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syphacia muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyphaciaMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RufibacterRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_42_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusVelezensisYaub9601y2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis YAUB9601Y2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisYaub9601y2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycetaceaeBacteriumBa112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetaceae bacterium BA112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycetaceaeBacteriumBa112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GynuellaSunshinyiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GynuellaSunshinyiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeTw183Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae TW183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeTw183Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpRoot413d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root413D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot413d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumRileyiRcef4871(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium rileyi RCEF 4871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRileyiRcef4871", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisIgneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris igneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisIgneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo212full4426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO212FULL4426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo212full4426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioFairfieldensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fairfieldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFairfieldensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUmwgjEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWGJ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwgjEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumUrinimassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium urinimassiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumUrinimassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParauberisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parauberis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParauberisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full6819(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6819 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6819", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCandidatusPoseidonialesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Candidatus Poseidoniales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UnculturedCandidatusPoseidonialesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifcsplowo201full4733bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4733b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4733bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumStbin14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumVaginaePb189t14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae PB189T14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaePb189t14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumCg10239135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium CG1_02_39_135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumCg10239135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiGoettingenEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Goettingen Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiGoettingenEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCavendishiiDsm21758Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cavendishii DSM 21758 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCavendishiiDsm21758Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusMiurensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus miurensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusMiurensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMannanilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMannanilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplodiaSeriataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diplodia seriata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiplodiaSeriataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumChlorophenolicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum chlorophenolicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumChlorophenolicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMinutissimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium minutissimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMinutissimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyriculariaOryzae7015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyricularia oryzae 70-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyriculariaOryzae7015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumSpPsu2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium sp. PSU-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSpPsu2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpCrb83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-8-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6677Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6677 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6677Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EquusAsinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Equus asinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EquusAsinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomicrobiumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSp9135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRubidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLcm4573(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LCM 4573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLcm4573", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxXenomutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax xenomutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxXenomutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSpFf7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. FF7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSpFf7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaNapusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brassica napus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrassicaNapusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsphigho201full4441Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL4441 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full4441Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumPetroleiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylibium petroleiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylibiumPetroleiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuricoccusIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Auricoccus indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AuricoccusIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaBoydiiCdc308394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shigella boydii CDC 3083-94 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShigellaBoydiiCdc308394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaPelagiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Henriciella pelagia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HenriciellaPelagiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaPunctataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza punctata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaPunctataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumScgcAaa027n21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027N21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027n21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumBuryatenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwf26230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWF2_62_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwf26230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 63-57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifoxyd1full3927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFOXYD1FULL3927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifoxyd1full3927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumSpJ15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. J15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJ15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanotheceSpAtcc51142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. ATCC51142 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpAtcc51142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusKocuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus kocurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusKocuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusOxalaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusOxalaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspDublinensisLmg23823Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. dublinensis LMG 23823 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspDublinensisLmg23823Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumRifoxya2Full4620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFOXYA2_FULL_46_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifoxya2Full4620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilunaSpImcc13023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. IMCC13023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpImcc13023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumLentumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium lentum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumLentumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaportheHelianthiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe helianthi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiaportheHelianthiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeCwl029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae CWL029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeCwl029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaMallensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicella mallensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicellaMallensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusHesperidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus hesperidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHesperidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumDenitrificansAtcc51888Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans ATCC51888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificansAtcc51888Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusSalariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus salarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSalariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApisMelliferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apis mellifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApisMelliferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSicca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sicca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSicca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpRedseas34b3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. REDSEAS34B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpRedseas34b3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoclavibacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaErecta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea erecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaErecta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LongisporaAlbidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Longispora albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LongisporaAlbidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifcsphigho202full3936Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPHIGHO202FULL3936 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsphigho202full3936Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_01_FULL_41_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaPneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPragensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pragensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPragensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot1471(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root1471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot1471", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusNatl1aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl1aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterSpHtcc2649Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. HTCC2649 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpHtcc2649Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraMagna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMagna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarumDsm19842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum DSM 19842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PontibacterActiniarumDsm19842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusEapokensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus eapokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusEapokensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CetobacteriumSpZor0034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium sp. ZOR0034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSpZor0034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaFloridanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia floridanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaFloridanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopertinaxCoweniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfopertinax cowenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfopertinaxCoweniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioSpirochaetisodalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio spirochaetisodalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioSpirochaetisodalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspSteigerwaltiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. steigerwaltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspSteigerwaltiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinithermusHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinithermus hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinithermusHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallemiaSebiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wallemia sebi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WallemiaSebiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo202full6764(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL6764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full6764", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetromyzonMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Petromyzon marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PetromyzonMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabisAlpinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabis alpina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArabisAlpinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAurimucosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aurimucosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAurimucosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasNasturtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas nasturtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasNasturtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTerpenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia terpenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaTerpenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetranychusUrticaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetranychus urticae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetranychusUrticaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumUlceransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium ulcerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumUlceransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KetogulonicigeniumVulgareY25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Y25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgareY25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterSp4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter sp. 47-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaludibacterSp4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumP7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium P7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumP7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg2304142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_41_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2304142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu37dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU37D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu37dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA2_44_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagnetotacticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PunctulariaStrigosozonataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Punctularia strigosozonata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PunctulariaStrigosozonataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaSpMar201075Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. MAR201075 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpMar201075Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiumNeolycopersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oidium neolycopersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OidiumNeolycopersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpIbunCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. IBUN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpIbunCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatibacillumAlkenivoransDsm16219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans DSM 16219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransDsm16219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaDrilacisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niabella drilacis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiabellaDrilacisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo201full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL4510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraPsammophilaCbs110553(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila CBS 110553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraPsammophilaCbs110553", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptobacteriumCurtum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium curtum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumCurtum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSpUncmf331sha31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF331Sha3.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf331sha31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumInhibensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium inhibens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumInhibensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisFribergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis fribergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisFribergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeropyrumCaminiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum camini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeropyrumCaminiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspSalmonicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspSalmonicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiosulfovibrioPeptidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio peptidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioPeptidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaSpLeaf210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumSpCag727(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium sp. CAG:727 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumSpCag727", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsphigho201full4822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPHIGHO201FULL4822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsphigho201full4822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaLimiDsm17137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Devosia limi DSM 17137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DevosiaLimiDsm17137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpAc3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. AC-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpAc3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpEhn03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. EhN03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpEhn03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichoplaxAdhaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax adhaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxAdhaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccoglossusKowalevskii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccoglossus kowalevskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccoglossusKowalevskii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_43_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadaceaeBacterium4484173(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadaceae bacterium 4484_173 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadaceaeBacterium4484173", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumFlaccumfaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium flaccumfaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumFlaccumfaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium vaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumVaginaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaPruniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma pruni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaPruniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaLupiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLupiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaAsperellum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma asperellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAsperellum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQuintanaRm11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana RM-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaQuintanaRm11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaSpHf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia sp. HF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaSpHf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusKakegawensisNbrc103104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis NBRC 103104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensisNbrc103104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpSod10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. SOD10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpSod10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusTenax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus tenax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusTenax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh7689Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH7689 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh7689Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE183Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E183 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE183Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViridochromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridochromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridochromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSpMgh106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sp. MGH106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSpMgh106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctosCinereusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctos cinereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhascolarctosCinereusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumFalseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFalseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumThiophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum thiophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumThiophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaCeti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaCeti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusSpHmsc06h08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sp. HMSC06H08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusSpHmsc06h08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematobacterMissouriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter missouriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMissouriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumMfb021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MFB021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMfb021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRcc307Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RCC307 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRcc307Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_41_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterCibinongensis4h1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis 4H-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterCibinongensis4h1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSzechwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides szechwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSzechwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolyporusBrumalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polyporus brumalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolyporusBrumalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphilaNbrc108938Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila NBRC 108938 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphilaNbrc108938Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpRs9916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumThoeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium thoenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumThoeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpFs083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. FS08-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpFs083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpAcc21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. ACC21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpAcc21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsiiBen74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Ben 74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsiiBen74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho202full5012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL5012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full5012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumAap81b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP81b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap81b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusCyanogriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus cyanogriseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusCyanogriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxKonjaci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax konjaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxKonjaci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyperthermusButylicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyperthermus butylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyperthermusButylicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSpSo1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. SO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumSpSo1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApteryxRowi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apteryx rowi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApteryxRowi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHimalayensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus himalayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHimalayensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHengshuiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hengshuiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHengshuiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioThiocyanodenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanodenitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanodenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacterArenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter arenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThalassobacterArenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumYannicii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium yannicii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumYannicii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConsotaellaSalsifontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Consotaella salsifontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConsotaellaSalsifontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpW7784Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. W7784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpW7784Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSenegalimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaSpinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora spinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaSpinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho212full439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO212FULL439 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho212full439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CheloniaMydasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelonia mydas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CheloniaMydasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsplowo201full4531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPLOWO201FULL4531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsplowo201full4531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag1944415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG_194_44_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1944415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenxiniaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WenxiniaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpA23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. A23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpA23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaSpApa3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bizionia sp. APA-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BizioniaSpApa3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorickettsiaSp179522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sp. 179522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSp179522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PongoAbeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pongo abelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PongoAbeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnoll(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus septemdierum str. Myojin knoll graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnoll", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PachysolenTannophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PachysolenTannophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChaniaMultitudinisentensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chania multitudinisentens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChaniaMultitudinisentensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCampbellbacteriaBacteriumGw2011Od13428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium GW2011_OD1_34_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumGw2011Od13428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillionellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Millionella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MillionellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClupeaHarengus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clupea harengus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClupeaHarengus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KamptonemaFormosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kamptonema formosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KamptonemaFormosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PragiaFontiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pragia fontium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PragiaFontiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSp6378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 63-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumGeorgienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumJkg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium JKG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumJkg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanisDsm13634(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis DSM 13634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanisDsm13634", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxMucosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mucosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMucosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHomomorphusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusHomomorphusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVesiculosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vesiculosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVesiculosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs4054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanithermusProfundusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanithermus profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanithermusProfundusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeospirillumFulvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum fulvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumFulvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidibacillusFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidibacillus ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidibacillusFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpBmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Bma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpBmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvensLd2006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens LD2006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvensLd2006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeEcwsu1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae EcWSU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeEcwsu1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraPsammophilaCbs110553Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila CBS 110553 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraPsammophilaCbs110553Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpFobrc6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpD27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. D27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaSpD27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesemziaIncertaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desemzia incerta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesemziaIncertaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChamaesiphonMinutus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chamaesiphon minutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChamaesiphonMinutus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimplicispiraPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Simplicispira psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SimplicispiraPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAlcalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alcalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAlcalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacterAutotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthobacterAutotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MahellaAustraliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mahella australiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MahellaAustraliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaCaldaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Treponema caldaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TreponemaCaldaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutaceaeBacteriumTsb47Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TSB47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTsb47Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFischeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusFischeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaPolarisLmg21857Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris LMG 21857 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParaglaciecolaPolarisLmg21857Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE1214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumKomaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium komanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumKomaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LyngbyaSpPcc8106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lyngbya sp. PCC8106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LyngbyaSpPcc8106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa24015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa24015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumFalciparum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium falciparum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumFalciparum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaHaematobiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma haematobium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaHaematobiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpBa93(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa93", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirschiaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hirschia baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HirschiaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetalesBacteriumActino02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlwc3773Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3773 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3773Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusNautiliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus nautili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusNautiliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylothermusHellenicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus hellenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusHellenicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpM41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpM41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAsaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpMb2005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MB2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMb2005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacillusKekensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus kekensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusKekensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterTibetensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter tibetensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RufibacterTibetensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumMurisUcdAy4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium muris UCD-AY4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumMurisUcdAy4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaBatsensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola batsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaBatsensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoduganellaViolaceinigraDsm15887(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra DSM 15887 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigraDsm15887", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumCg1024134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_41_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1024134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GayadomonasJoobiniegeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gayadomonas joobiniege Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GayadomonasJoobiniegeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpBrhc22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BRHc22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpBrhc22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaPersicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia persica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaPersicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseinatronobacterThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseinatronobacter thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseinatronobacterThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldivirgaMaquilingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga maquilingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaMaquilingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModuliflexusFlocculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moduliflexus flocculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ModuliflexusFlocculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumHlucca01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium HLUCCA01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumHlucca01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsphigho201full4110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO201FULL4110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho201full4110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaSp5064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 50_64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp5064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPasteurianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPasteurianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTokpelaiaHoelldobleriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tokpelaia hoelldoblerii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTokpelaiaHoelldobleriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot268(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot268", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioProteolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioProteolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenicicoccusSpOralTaxon190Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus sp. oral taxon 190 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArsenicicoccusSpOralTaxon190Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisBaichengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis baichengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisBaichengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesCiferrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesCiferrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeTigr4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae TIGR4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeTigr4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZhanjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zhanjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasZhanjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaLimosaDsm17973(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Runella limosa DSM 17973 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RunellaLimosaDsm17973", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKalixensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKalixensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaChinhatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia chinhatensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaChinhatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumDcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium DC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumDcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidihalobacterFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag167Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:167 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag167Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaAgarilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lewinella agarilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LewinellaAgarilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaChinhatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia chinhatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaChinhatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineothrixAlysoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kineothrix alysoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KineothrixAlysoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumEstertheticumSubspEstertheticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium estertheticum subsp. estertheticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumEstertheticumSubspEstertheticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumSp1910bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum sp. 1910b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermofilumSp1910bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpCci3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CcI3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCci3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpMp13118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MP131-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMp13118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSchindleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter schindleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSchindleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumTerrigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerrigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFOXYA2_FULL_43_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifoxya2Full4310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGladioli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia gladioli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGladioli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaVaccimaxillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia vaccimaxillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaVaccimaxillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxEbreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax ebreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxEbreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo2024220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_02_42_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo2024220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpHm582(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. HM58-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpHm582", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter persici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpAg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinusAz3a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus AZ3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinusAz3a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotusOchrogaster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microtus ochrogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrotusOchrogaster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSciuri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sciuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSciuri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydraVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydra vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydraVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFuscovaginae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fuscovaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFuscovaginae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusEiseniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusEiseniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhodospirillumPhotometricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pararhodospirillum photometricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PararhodospirillumPhotometricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCaspthauma1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusLimicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoplanus limicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoplanusLimicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterNoctilucicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeckwithbacteriaBacteriumRifcsphigho212full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RIFCSPHIGHO212FULL4717 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRifcsphigho212full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusFerrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterFlexilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flexibacter flexilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlexibacterFlexilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarboxydothermusHydrogenoformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus hydrogenoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusHydrogenoformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalostagnicolaSpA56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola sp. A56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaSpA56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterSp302Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. 302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSp302Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodesmiumErythraeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichodesmium erythraeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodesmiumErythraeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium4632Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 46-32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4632Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterRectus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter rectus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterRectus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorNaganoensisNa10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis NA10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensisNa10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumSepticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium septicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSepticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenuibacillusMultivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenuibacillus multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenuibacillusMultivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorumJcm14966(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum JCM14966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumJcm14966", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleispiraAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oleispira antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OleispiraAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasSpWbc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas sp. WBC-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasSpWbc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaUniformisNbrc13702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia uniformis NBRC 13702 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaUniformisNbrc13702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSp11bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. 11b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSp11bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosovibrioTenuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioTenuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeTomatoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tomato Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTomatoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaSpNd16a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. ND16A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpNd16a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt372(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT372 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt372", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalarchaeumAcidiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halarchaeum acidiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalarchaeumAcidiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFragiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fragi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFragiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumGw2011gwb1471(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWB1471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwb1471", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpHgf2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HGF2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpHgf2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellamassiliaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotellamassilia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellamassiliaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5620 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpUrhd0057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. URHD0057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUrhd0057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 62-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrinicoccusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Urinicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrinicoccusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaPorcellusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cavia porcellus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaviaPorcellusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaGratiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella gratiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaGratiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaMelanogasterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila melanogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaMelanogasterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolimonasFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solimonas flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolimonasFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaXishanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia xishanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaXishanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterSpHeli6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. HelI6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpHeli6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiromycesSpE2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piromyces sp. E2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiromycesSpE2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaLascolaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella lascolaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaLascolaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliterellaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliterella atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliterellaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFordiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fordii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFordiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpR11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. R11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuegeriaSpR11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnasPlatyrhynchosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anas platyrhynchos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnasPlatyrhynchosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GynuellaSunshinyii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GynuellaSunshinyii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVanbaaleniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vanbaalenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVanbaaleniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumOlb17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium OLB17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumOlb17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavigranumRuoffiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavigranum ruoffiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavigranumRuoffiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_38_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTerpenotabidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium terpenotabidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTerpenotabidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJlsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JLS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJlsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifcsphigho212full4817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO212FULL4817 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho212full4817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpMbes04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. MBES04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpMbes04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp63Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 63 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp63Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusFamiliaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus familiaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CanisLupusFamiliaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Morchella conica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MorchellaConica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusColihominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus colihominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusColihominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUmwgjCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWGJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwgjCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpFw510t8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. FW510T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpFw510t8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwc2579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc2579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumIliopiscarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium iliopiscarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumIliopiscarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumFormosense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium formosense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFormosense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusGenomosp3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusGenomosp3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosalibacterSpMarseillep3206Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. MarseilleP3206 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerosalibacterSpMarseillep3206Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusMarincolaDsm16067(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola DSM16067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaDsm16067", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumBeibuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium beibuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBeibuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpWp9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WP9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWp9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSpPamc27137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. PAMC27137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LacinutrixSpPamc27137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusSpHmsc067e09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus sp. HMSC067E09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcusSpHmsc067e09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaAlbaNbrc15616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] alba NBRC 15616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaAlbaNbrc15616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSeoulensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces seoulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSeoulensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetalesBacteriumSpiro02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrantheGuttataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythranthe guttata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrantheGuttataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNoviomagenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium noviomagense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNoviomagenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_56_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPanisDsm6035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus panis DSM 6035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPanisDsm6035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaligenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesJohnsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaSpDw0440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. DW 0440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpDw0440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaNiastensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia niastensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaNiastensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSatsumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSatsumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSulfonivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sulfonivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSulfonivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpAl04100510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. AL041005-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpAl04100510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMoorei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solobacterium moorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolobacteriumMoorei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaViswanathiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida viswanathii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaViswanathiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaSqualenifaciensDsm18772Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens DSM 18772 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciensDsm18772Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StylophoraPistillataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stylophora pistillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StylophoraPistillataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumCulicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium culicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCulicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandarakinorhabdusLimnophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus limnophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusLimnophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaoerskoviaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraoerskovia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaoerskoviaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaFarcinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia farcinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaFarcinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensAe3010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens AE3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensAe3010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonodelphisDomestica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monodelphis domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonodelphisDomestica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumMesophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum mesophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMesophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperellaPyogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trueperella pyogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrueperellaPyogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiHcIsolateThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HC isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHcIsolateThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumibacterMarinusDsm18995Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumibacter marinus DSM 18995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CucumibacterMarinusDsm18995Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full4115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4115 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSulphureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sulphureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSulphureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumLowii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLowii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisB84634(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis B84634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisB84634", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMontpellierensisDsm17217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis DSM 17217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensisDsm17217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GuillardiaThetaCcmp2712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta CCMP2712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GuillardiaThetaCcmp2712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmigerFormicilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmiger formicilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmigerFormicilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumThioautotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thioautotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThioautotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGirerdii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma girerdii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGirerdii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:230 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaTyphiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusThermophilusLmg18311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMG18311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmg18311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumPyruvativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium pyruvativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPyruvativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaMajor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirulina major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirulinaMajor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_52_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSat1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SAT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSat1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusMacroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus macroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusMacroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPHIGHO2_12_FULL_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HebelomaCylindrosporumH7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum h7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HebelomaCylindrosporumH7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaSpinifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala spinifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaSpinifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaMojavensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila mojavensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DrosophilaMojavensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwf1327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWF1_32_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwf1327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlixibacterBellariivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prolixibacter bellariivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProlixibacterBellariivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3610b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3610b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3610b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasElongataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas elongata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasElongataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu033Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU033 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu033Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaPedrosoiCbs27137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi CBS 271.37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoiCbs27137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BigelowiellaNatans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bigelowiella natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BigelowiellaNatans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSputigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sputigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSputigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalosaccharovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halosaccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHalosaccharovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_01_FULL_48_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot682Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot682Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpLtsp885Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP885 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp885Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumVariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium varium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumVariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumScgcAaa288g21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288G21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288g21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibaculumRodentiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibaculum rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibaculumRodentiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpheniscorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium spheniscorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpheniscorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpTg39aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TG39a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpTg39aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalitaleaCylindroidesT287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides T2-87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroidesT287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterDaecheongensisDsm21074Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis DSM 21074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensisDsm21074Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RunellaSlithyformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Runella slithyformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RunellaSlithyformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsphigho201full5728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPHIGHO201FULL5728 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsphigho201full5728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaTolypothrichoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterYangtzensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter yangtzensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterYangtzensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterYeojuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter yeojuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterYeojuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb02488(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02488", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifoxyb1full4423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaMaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma mali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaMaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFallaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium fallax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFallaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumScadc123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium SCADC1_2_3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumScadc123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaSpJa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora sp. JA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpathasporaSpJa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumChlorophyti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum chlorophyti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumChlorophyti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaVietnamiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia vietnamiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaVietnamiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaSp22iis11gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. 22IIS11g Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanicolaSp22iis11gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MidichloriaMitochondriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Midichloria mitochondrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MidichloriaMitochondriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesUrogenitalisDsm15434Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis DSM15434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisDsm15434Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacteriumSm23733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full5118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL5118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full5118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpAb3007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. AB3007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpAb3007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratifractorSalsuginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratifractor salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratifractorSalsuginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusGammatoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus gammatolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGammatoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacterium4787Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 47-87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4787Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaSpAtccPta5024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. ATCC PTA-5024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpAtccPta5024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaSingaporensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha singaporensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaSingaporensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGladioliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia gladioli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGladioliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYB1_FULL_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermococcusThermolithotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus thermolithotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusThermolithotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPumilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pumilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPumilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisC6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StoquefichusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StoquefichusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterDaecheongensisDsm21074Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis DSM 21074 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensisDsm21074Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAg109o510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Ag109O510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAg109o510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusLindneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus lindneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusLindneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCallitrichosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium callitrichos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCallitrichosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesMarneffei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces marneffei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TalaromycesMarneffei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerracoccusSp273mftsu31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Terracoccus sp. 273MFTsu31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TerracoccusSp273mftsu31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrosmanniaClavigeraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Grosmannia clavigera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GrosmanniaClavigeraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpMctg268Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. MCTG268 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpMctg268Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasPalmitaticaJcm14374(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica JCM 14374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitaticaJcm14374", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHominisSk119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis SK119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisSk119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaVervactiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea vervacti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaVervactiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterCrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter crescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiberibacterCrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMerionisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus merionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMerionisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiliocolobusTephrosceles(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piliocolobus tephrosceles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiliocolobusTephrosceles", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidisEmoy2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Emoy2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidisEmoy2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraAustralica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira australica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAustralica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisPinicolaFp58527Ss1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola FP-58527 SS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FomitopsisPinicolaFp58527Ss1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGeothermarchaeotaArchaeonJdfr13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Geothermarchaeota archaeon JdFR-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGeothermarchaeotaArchaeonJdfr13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDielmoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dielmoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusDielmoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_35_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 43-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducensHbp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens HBP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensHbp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusBoritoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusBoritoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperaRadiovictrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Truepera radiovictrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrueperaRadiovictrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallithrixJacchusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Callithrix jacchus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CallithrixJacchusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag309Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:309 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag309Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpOoc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Ooc graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpOoc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKururiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaPeanutWitchesbroomEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma peanut witchesbroom Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaPeanutWitchesbroomEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalapricumSalinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halapricum salinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalapricumSalinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusSpYb142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sp. YB14-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSpYb142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumEhc02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium EhC02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumEhc02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20221 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFurnissii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio furnissii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioFurnissii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSubrutilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces subrutilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSubrutilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwa14424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWA14424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwa14424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumAAtcc3502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum A ATCC 3502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAAtcc3502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpArCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. AR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpArCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KosmotogaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAdp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ADP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAdp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodocyclaceaeBacteriumPaddy1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodocyclaceae bacterium Paddy-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodocyclaceaeBacteriumPaddy1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusZeaxanthinifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus zeaxanthinifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusZeaxanthinifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpKo116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KO116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKo116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaVarians(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria varians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaVarians", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb03911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03911 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumLevicorallinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium levicorallinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLevicorallinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterSp6612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. 66-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSp6612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacteriumSpPamc21357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinibacterium sp. PAMC 21357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinibacteriumSpPamc21357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonasPusillaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonas pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonasPusillaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusHenryi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus henryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHenryi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaLacustrisZ7289Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Z-7289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaLacustrisZ7289Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHigoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia higoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaHigoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoecheraStrictaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Boechera stricta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BoecheraStrictaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaOvata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa ovata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporomusaOvata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPseudoobscura(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscura", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb12Full5810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB12_FULL_58_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb12Full5810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpU41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. U41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpU41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAlsaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella alsatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaAlsaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0426 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp142mfcol31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 142MFCol31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp142mfcol31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaFlexneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shigella flexneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShigellaFlexneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozobelliaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudozobellia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudozobelliaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctocarpusSiliculosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectocarpus siliculosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctocarpusSiliculosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosovibrioTenuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioTenuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeJd6301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae JD6301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeJd6301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2304012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2304012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineActinobacteriumMedacidiG2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumYsd2013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSD2013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsd2013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full4412b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL4412b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full4412b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu087(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU087 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu087", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorNaganoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpBal3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. BAL3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpBal3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesAcidifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusSpPe3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus sp. PE3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DermacoccusSpPe3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalofilumOchraceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halofilum ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalofilumOchraceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNku1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. NkU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNku1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TardibacterChloracetimidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tardibacter chloracetimidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TardibacterChloracetimidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg163611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG163611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg163611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetrimonasMucosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Petrimonas mucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PetrimonasMucosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp37zxxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 37zxx Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp37zxxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDiphtheriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterActinomycetemcomitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIakyrus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces iakyrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesIakyrus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPluranimaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella pluranimalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPluranimaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpCny236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. CNY236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpCny236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallibacteriumScheffleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metallibacterium scheffleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetallibacteriumScheffleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusApachensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus apachensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusApachensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe23640Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE23640 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe23640Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full4630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL4630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full4630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEntomophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas entomophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEntomophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaPertussisTohamaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis Tohama Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussisTohamaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeeuwenhoekiellaSpMar2009132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. MAR2009132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpMar2009132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeolectaIrregularisDah3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neolecta irregularis DAH-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeolectaIrregularisDah3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocSpPcc7120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_12_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full3939Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL3939 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full3939Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampbellbacteriaBacteriumRifcsplowo2023512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO2023512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo2023512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasChitiniclasticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas chitiniclastica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasChitiniclasticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSp5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg135024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_50_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg135024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlboflavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alboflavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlboflavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforudisAudaxviatorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulforudis audaxviator Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulforudisAudaxviatorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_12_FULL_48_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg10247685(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG10247685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg10247685", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiumSpR2a62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobium sp. R2A62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobiumSpR2a62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusJilinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus jilinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusJilinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot239oh1446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT239OH1446 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot239oh1446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpOk494Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpOk494Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusNigrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusNigrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocPseudomesenteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc pseudomesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocPseudomesenteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMelliventrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus melliventris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMelliventrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsConfragosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps confragosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CordycepsConfragosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolibacterUsitatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solibacter usitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolibacterUsitatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaValaisianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella valaisiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaValaisianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanobisporaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planobispora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanobisporaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegniliparusRotundusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rotundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRotundusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYr295Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR295 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr295Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimwelliaBlattae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimwellia blattae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimwelliaBlattae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioThiophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio thiophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioThiophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaConchae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria conchae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaConchae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SucciniclasticumRuminisDsm9236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis DSM 9236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SucciniclasticumRuminisDsm9236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe2015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE2015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe2015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyd12full368Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYD12FULL368 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyd12full368Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscirickettsiaSalmonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia salmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaSalmonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4415cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4415c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4415cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacteriumCg2305140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium CG2_30_51_40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumCg2305140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpR37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpR37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisValliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis valliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisValliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAlcaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alcaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlcaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusCibariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus cibarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusCibariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpNk2b42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. NK2B42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpNk2b42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumSpJ07hqx50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum sp. J07HQX50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumSpJ07hqx50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterFiliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterFiliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusPolysaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusPolysaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf25735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_57_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpUrhd0069(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHD0069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrhd0069", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScabieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwb1397(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1397 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1397", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp174mfsha11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 174MFSha1.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp174mfsha11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterLwoffiiNctc5866(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii NCTC 5866 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiNctc5866", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiPcIsolateNhv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PC isolate NHV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPcIsolateNhv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSolincola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium solincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSolincola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMycetoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mycetoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMycetoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPrunellaeJcm25354Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaia prunellae JCM 25354 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaiaPrunellaeJcm25354Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJ33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. J33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJ33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusRambelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus rambellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusRambelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisSpAtcc49242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. ATCC49242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpAtcc49242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpBh211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. BH-2-1-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpBh211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSpDh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. DH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpDh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocosphaeraSubtropicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crocosphaera subtropica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrocosphaeraSubtropicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumCapsulatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium capsulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumCapsulatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerionesUnguiculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meriones unguiculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MerionesUnguiculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumPiscinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium piscinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumPiscinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaValaisiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella valaisiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaValaisiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaffinicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraffinicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaffinicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp292mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 292MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp292mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraCuprinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera cuprina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraCuprinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumMagnumDsm2767(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium magnum DSM 2767 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMagnumDsm2767", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaHydrolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola hydrolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaHydrolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumFunditum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium funditum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumFunditum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumAidingenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aidingense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAidingenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSp25b141(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 25B141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp25b141", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnr698Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNR698 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnr698Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistliaConsotensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tistlia consotensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TistliaConsotensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGallisepticumF(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumF", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallbacteriaBacteriumGwc24935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wallbacteria bacterium GWC24935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WallbacteriaBacteriumGwc24935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloterricolaOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloterricola oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloterricolaOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumCg2303944(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_39_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2303944", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodospiraSibirica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodospira sibirica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiorhodospiraSibirica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotaleaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotalea psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotaleaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanohaloarchaeaArchaeonB1br10u2g19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCommune(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCommune", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogladiusCalderaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermogladius calderae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermogladiusCalderaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterNecessariusAsymbioticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius asymbioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusAsymbioticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3808Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3808Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterAnodireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter anodireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterAnodireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg166630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG166630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg166630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpIdoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. IDO Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpIdoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpGai101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. GAI101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpGai101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumGilvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGilvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa25646Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_56_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25646Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumSpI15g10i2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum sp. I15G10I2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumSpI15g10i2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSputorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSputorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMultisaccharivoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multisaccharivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultisaccharivoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpIng2d1gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ING2D1G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpIng2d1gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCaseiDsm20011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei DSM20011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiDsm20011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpHmsc075b08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. HMSC075B08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpHmsc075b08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriaceaeArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SoonwooaBuanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Soonwooa buanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SoonwooaBuanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiellaPusillaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella pusilla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaPusillaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHaemophilumDsm44634Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum DSM 44634 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilumDsm44634Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScabrisporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabrisporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabrisporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdhazardiaAedisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edhazardia aedis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdhazardiaAedisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraAquimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSp6413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. 64-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaSp6413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaSpUrhb0036Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. URHB0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpUrhb0036Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRiflebacteriaBacteriumGwc2508(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riflebacteria bacterium GWC2_50_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiflebacteriaBacteriumGwc2508", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr3BacteriumGw2011gwf23518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium GW2011GWF23518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3BacteriumGw2011gwf23518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRedseas03b5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS03B5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas03b5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiHardjoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Hardjo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiHardjoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CognatiyooniaSediminumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia sediminum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaSediminumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBataviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bataviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusBataviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSyntrophoarchaeumCaldariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum caldarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumCaldariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterDongtanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter dongtanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterDongtanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSp6021061333Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 6021061333 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp6021061333Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumUzonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum uzonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermofilumUzonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaCaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiosporiumApollinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coniosporium apollinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConiosporiumApollinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaProteobacteriumScgcAb137C09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return zeta proteobacterium SCGC AB-137-C09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZetaProteobacteriumScgcAb137C09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL4812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSpRitpif(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. RITPIf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSpRitpif", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasFungivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas fungivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasFungivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EikenellaCorrodens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eikenella corrodens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EikenellaCorrodens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSp7392(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp7392", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumOpportunistumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium opportunistum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOpportunistumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImmundisolibacterCernigliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Immundisolibacter cernigliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ImmundisolibacterCernigliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_38_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpJf8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. JF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpJf8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaphorobacterSpJ551Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diaphorobacter sp. J5-51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiaphorobacterSpJ551Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterAkesuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter akesuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterAkesuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalarchaeumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalarchaeum thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalarchaeumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3523 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpM47t1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M47T1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpM47t1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusShizuokensisNbrc103103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis NBRC 103103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensisNbrc103103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraKmetyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira kmetyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraKmetyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSpUrhd0036(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. URHD0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpUrhd0036", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaProfusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella profusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProfusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRaac2wwe31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RAAC2WWE31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRaac2wwe31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnasPlatyrhynchosPlatyrhynchosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anas platyrhynchos platyrhynchos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnasPlatyrhynchosPlatyrhynchosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_12_FULL_60_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaGriseola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora griseola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaGriseola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosocosmicusExaquareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus exaquare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusExaquareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumCg2303924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium CG2303924 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumCg2303924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraKueneniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira kuenenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraKueneniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermokryptusMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermokryptus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermokryptusMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpCnj954Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. CNJ-954 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpCnj954Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersephonellaSpIf05l8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. IF05L8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpIf05l8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusHnlc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpCubenseRace1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLitoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium litorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLitoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasDaqiaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas daqiaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasDaqiaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSobrinusDsm20742Atcc33478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus DSM 20742 ATCC 33478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSobrinusDsm20742Atcc33478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacearchaeotaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacearchaeota archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacearchaeotaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwf24212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWF2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwf24212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSuccinifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema succinifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSuccinifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniaeJCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniaeJCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaAbortusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia abortus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAbortusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasutterellaExcrementihominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasutterella excrementihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParasutterellaExcrementihominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriAtcc14405Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri ATCC14405 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriAtcc14405Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpCect7735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 7735 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect7735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusTerranovensisDsm18919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis DSM 18919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensisDsm18919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwe23640Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE23640 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe23640Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpVkmb2647Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. VKMB2647 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpVkmb2647Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixTepidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix tepida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixTepidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActibacteriumMucosumKctc23349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium mucosum KCTC 23349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActibacteriumMucosumKctc23349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpS4c9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S4C9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS4c9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinocladiellaMackenzieiCbs65093Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei CBS 650.93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhinocladiellaMackenzieiCbs65093Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full4611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColumbaLiviaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Columba livia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColumbaLiviaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasSpFh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas sp. FH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasSpFh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumSpCag815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMacauensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus macauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusMacauensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterAlimentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAlimentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensF113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens F113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensF113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpHmsc073a11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. HMSC073A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpHmsc073a11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfallasArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfallasArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuxenochlorellaProtothecoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Auxenochlorella protothecoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AuxenochlorellaProtothecoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasPantelleriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas pantelleriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasPantelleriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel3a148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel3A148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel3a148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArachisHypogaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arachis hypogaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArachisHypogaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumAap99(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap99", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAb3002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AB3002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAb3002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterSpYs13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. YS13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpYs13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallionellaCapsiferriformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionella capsiferriformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellaCapsiferriformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpCzuamEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CZUAM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCzuamEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaMexicanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poecilia mexicana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoeciliaMexicanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeyerozymaSpJa9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma sp. JA9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaSpJa9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBorstelensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusChoshinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus choshinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusChoshinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPalustreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPalustreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusSendaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusGondwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus gondwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusGondwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraImmunda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora immunda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraImmunda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterNosocomialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nosocomialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNosocomialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpSk02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaAsaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaAsaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNomiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nomius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusNomiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaTemeraria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia temeraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTemeraria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpUrhe0023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHE0023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhe0023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag386(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag386", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumIwayamaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium iwayamai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PythiumIwayamaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa25412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_54_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PisolithusTinctoriusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PisolithusTinctoriusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticirepentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora triticirepentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTriticirepentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumMassiliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumMassiliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaParagorgiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bizionia paragorgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BizioniaParagorgiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasCellaseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasCellaseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesF0058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes F0058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesF0058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuccinivibrioDextrinosolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrio dextrinosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrioDextrinosolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpUasws1009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. UASWS1009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUasws1009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocellaSilvestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocella silvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocellaSilvestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegamonasHypermegaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megamonas hypermegale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegamonasHypermegaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterTundripaludumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter tundripaludum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacterTundripaludumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaIsraelensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella israelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaIsraelensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSelangorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus selangorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSelangorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesPercursus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces percursus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomycesPercursus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpAl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. AL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpAl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusMediterraneensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusMediterraneensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillerozymaFarinosaCbs7064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa CBS 7064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MillerozymaFarinosaCbs7064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4922bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4922b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4922bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheionarchaeaArchaeonDg701Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon DG-70-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeonDg701Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumHalorespiransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespiransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRu3701(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ru370.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu3701", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200240037sch5390672Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200240037SCH5390672 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200240037sch5390672Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRoseochromogenusSubspOscitansDs12976Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus subsp. oscitans DS 12.976 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenusSubspOscitansDs12976Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMt11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium mt11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMt11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpGas474Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. GAS474 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpGas474Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaGeestianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella geestiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaGeestianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumKuroshium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium kuroshium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumKuroshium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusPyridinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus pyridinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusPyridinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OligellaUrethralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oligella urethralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OligellaUrethralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSp73s(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. 73s graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSp73s", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRifcsplowo201full4813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPLOWO201FULL4813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsplowo201full4813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumNygamaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium nygamai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumNygamaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat18019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriSg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri SG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriSg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobinsoniellaPeoriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Robinsoniella peoriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RobinsoniellaPeoriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaSpMt17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia sp. MT17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaSpMt17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumSg847Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg847Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesVulgatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides vulgatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesVulgatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCetorumMit007128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT007128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit007128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasNasdae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas nasdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNasdae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaCastelliiCbs4309Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii CBS 4309 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaCastelliiCbs4309Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonadalesBacteriumRifcsplowo212599Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonadales bacterium RIFCSPLOWO2_12_59_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonadalesBacteriumRifcsplowo212599Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag545Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag545Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaPalustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaPalustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteralesBacteriumRifcsphigho201full7019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFCSPHIGHO201FULL7019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifcsphigho201full7019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpCf059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGastriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gastri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGastriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhanerochaeteCarnosaHhb10118SpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa HHB-10118-sp Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosaHhb10118SpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHispalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hispalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHispalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusMarinonascensNbrc14363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens NBRC 14363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusMarinonascensNbrc14363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPersicaAtccVr331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Francisella persica ATCC VR-331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrancisellaPersicaAtccVr331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSantoriniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter santoriniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSantoriniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusPeptonophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus peptonophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPeptonophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PersephonellaSpKm09lau8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. KM09Lau8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpKm09lau8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumWce2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumAlterfunditumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium alterfunditum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumAlterfunditumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AncylobacterRudongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ancylobacter rudongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AncylobacterRudongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusCellicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus cellicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusCellicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCitriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma citri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCitriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full5028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL5028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full5028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraChibensisNbrc106107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura chibensis NBRC 106107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraChibensisNbrc106107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiesbergeriaAnulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giesbergeria anulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiesbergeriaAnulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFlocculareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFlocculareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRbg19ftcombo3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG19FTCOMBO3910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg19ftcombo3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorOwensensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor owensensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorOwensensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VanderwaltozymaPolysporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VanderwaltozymaPolysporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTaibaishanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium taibaishanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTaibaishanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusRaoultiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus raoultii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRaoultiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiostomaPiceaeUamh11346Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae UAMH 11346 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OphiostomaPiceaeUamh11346Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpJah(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JAH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJah", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpiralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella spiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpiralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAdetyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AdeTY Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAdetyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConfluentimicrobiumSpEmb200ns6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Confluentimicrobium sp. EMB200NS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConfluentimicrobiumSpEmb200ns6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBorgpeterseniiHardjo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Hardjo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiHardjo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiibiusSpNy1634622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Branchiibius sp. NY16-3462-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BranchiibiusSpNy1634622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryziasLatipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryzias latipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryziasLatipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariniradiusSaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mariniradius saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MariniradiusSaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae168Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 168 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae168Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumRbg19ftcombo4210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RBG19FTCOMBO4210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRbg19ftcombo4210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumMela1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium MELA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumMela1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOlivaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesOlivaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusKuznetsovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus kuznetsovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusKuznetsovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaLacusLw14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina lacus LW14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaLacusLw14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaHydrogenotrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia hydrogenotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaHydrogenotrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAkiainvivens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium akiainvivens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAkiainvivens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCarboxidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium carboxidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCarboxidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGloeosporioidesCg14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cg-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioidesCg14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpStf2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. STF2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpStf2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacteraceaeBacteriumGwc25311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_53_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumArcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium arcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumArcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag345Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:345 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag345Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaCylindricaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabaena cylindrica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabaenaCylindricaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil805Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil805 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil805Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaGratianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella gratiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaGratianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDenticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella denticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDenticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanisphaeraPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanisphaera psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanisphaeraPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho201full6320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL6320 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full6320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMargulisbacteriaBacteriumGwf2359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWF2_35_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwf2359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaphidocelisSubcapitataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Raphidocelis subcapitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RaphidocelisSubcapitataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasChangbaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusAsaccharolyticusDsm20463Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus DSM 20463 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticusDsm20463Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HenriciellaLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Henriciella litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HenriciellaLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeosporobacterFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSpC3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. C3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSpC3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTerreusNih2624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus NIH2624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusTerreusNih2624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasArtemidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas artemidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasArtemidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumFormicicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium formicicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumFormicicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumAnnuumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capsicum annuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapsicumAnnuumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaPuniceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola punicea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPuniceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpWd162Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD16.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd162Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaElongataSubspGlycolyticaAtcc29315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria elongata subsp. glycolytica ATCC 29315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaElongataSubspGlycolyticaAtcc29315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusNurukiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus nuruki Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNurukiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk597(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK597 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk597", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaedaleaQuercinaL15889(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Daedalea quercina L-15889 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DaedaleaQuercinaL15889", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpF0139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovenabulumGondwanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermovenabulum gondwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermovenabulumGondwanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaMarinaDsm2698(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Afifella marina DSM 2698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AfifellaMarinaDsm2698", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLonga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina longa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLonga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpStbin5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaniviriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaniviriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBorstelensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLeaf391Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf391 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf391Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomicrobialesSpKi4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Thermomicrobiales sp. KI4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "ThermomicrobialesSpKi4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVelezensisYaub9601y2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis YAUB9601Y2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisYaub9601y2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyorhinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsidiaGlaucaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Absidia glauca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbsidiaGlaucaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumCg2306842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium CG2_30_68_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumCg2306842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAlkaliphilum121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum 12/1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilum121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf384Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf384Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KingellaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kingella denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KingellaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrechmeriaConiosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drechmeria coniospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrechmeriaConiosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaCopriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella copri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCopriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyalangiumMinutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyalangium minutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyalangiumMinutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumCg1024737Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium CG1024737 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumCg1024737Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusTorques(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Ruminococcus] torques graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusTorques", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenyingzhuangiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchekmanbacteriaBacteriumRifcsplowo212full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schekmanbacteria bacterium RIFCSPLOWO212FULL3815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchekmanbacteriaBacteriumRifcsplowo212full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriellaXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriella xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriellaXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraAustraliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphothecaResinaeAtcc22711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amorphotheca resinae ATCC 22711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmorphothecaResinaeAtcc22711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSpMar2010102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpScn5710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SCN 57-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpScn5710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumStbin15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasBoliviensisLc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas boliviensis LC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasBoliviensisLc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpLc85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. LC85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLc85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusSbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus SB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusSbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaucusCarotaSubspSativus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Daucus carota subsp. sativus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DaucusCarotaSubspSativus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhanerochaeteCarnosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaBicolorataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agreia bicolorata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgreiaBicolorataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalditerrivibrioNitroreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calditerrivibrio nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalditerrivibrioNitroreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpVkmb2647(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. VKMB2647 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpVkmb2647", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumChlororespiransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespiransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumVincentii4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusZeaxanthinifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus zeaxanthinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusZeaxanthinifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavihumibacterPetaseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag202(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag202", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAtcc13867Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ATCC 13867 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAtcc13867Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusQuebecensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus quebecensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusQuebecensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwa24212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPedis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema pedis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPedis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCalviensisDsm14347Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis DSM 14347 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioCalviensisDsm14347Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCaspiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium caspium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCaspiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMusc14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSiamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus siamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSiamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlrh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALRh graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlrh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvissimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvissimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFulvissimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterSpLeaf189Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. Leaf189 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpLeaf189Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumThoenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium thoenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumThoenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHalperniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium halperniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHalperniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiliocolobusTephroscelesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piliocolobus tephrosceles Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiliocolobusTephroscelesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticiRepentisPt1cBfp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora tritici-repentis Pt-1C-BFP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTriticiRepentisPt1cBfp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaSpCag344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. CAG:344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpCag344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeriophthalmusMagnuspinnatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Periophthalmus magnuspinnatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeriophthalmusMagnuspinnatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitibacterSpBrhc19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter sp. BRHc19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterSpBrhc19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumGas113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium GAS113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGas113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium9143bfaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 9143BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium9143bfaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FructobacillusDurionis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus durionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FructobacillusDurionis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusGauvreauii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gauvreauii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGauvreauii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk1057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK1057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk1057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixSpCaciam(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpCaciam", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSlbn53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SLBN-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSlbn53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpCag514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RicheliaIntracellularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Richelia intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RicheliaIntracellularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombusImpatiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bombus impatiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BombusImpatiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpRl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpRl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpBab2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. BAB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalobacillusSpBab2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHassiacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium hassiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHassiacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpUnc345mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. UNC345MFTsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUnc345mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosphaeraAminiphilaDsm21120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila DSM 21120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphilaDsm21120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterSphagniphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sphagniphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSphagniphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusCibarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusCibarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpAk20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. AK20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FormosaSpAk20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterDokdonensisDsw74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis DSW-74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensisDsw74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilis168(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis 168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilis168", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassilimicrobiotaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilimicrobiota timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilimicrobiotaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaBestiolaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KwoniellaBestiolaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesXylanisolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides xylanisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesXylanisolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlutamicibacterSp0426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter sp. 0426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterSp0426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesCerinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces cerinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesCerinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRifcsplowo201full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPLOWO201FULL4311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsplowo201full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumNodatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium nodatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumNodatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenitireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenitireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumManteniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium mantenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumManteniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasEncheleiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas encheleia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasEncheleiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaBruceiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma brucei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaBruceiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoruberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoruberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFrigidicarnisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium frigidicarnis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFrigidicarnisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_45_10c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida parapsilosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaParapsilosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpSn2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. SN2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlteromonasSpSn2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpCb00851Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. CB00851 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpCb00851Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisAustraliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisAustraliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriaceaeBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacteriaceae bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriaceaeBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PteropusAlecto(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pteropus alecto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PteropusAlecto", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb1388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB1388 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb1388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumAquaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAquaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzambacteriaBacteriumRifcsphigho202full4518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPHIGHO202FULL4518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsphigho202full4518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc23714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC23714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc23714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumM102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium M102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumM102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterSpA7aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. A7A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpA7aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24227 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonisDsm23387Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterIshigakiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter ishigakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterIshigakiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumGibsoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum gibsoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumGibsoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium etli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumEtliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenirhodobacterEnshiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenirhodobacter enshiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenirhodobacterEnshiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full588(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL588 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full588", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg165211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_52_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg165211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4515bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4515b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4515bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGigeriorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGigeriorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CastellaniellaCaeniNbrc101664Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella caeni NBRC 101664 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CastellaniellaCaeniNbrc101664Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisCapsici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis capsici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisCapsici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyd2full3916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYD2FULL3916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyd2full3916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusNovalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus novalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusNovalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumScardovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium scardovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumScardovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasShengliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas shengliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasShengliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc4aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchmidhempeliaBombiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schmidhempelia bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchmidhempeliaBombiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinicellaSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinicella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinicellaSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSpGwe1629Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. GWE1_62_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpGwe1629Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusBasilensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus basilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusBasilensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp11649854(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164985.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649854", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGastricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGastricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordonibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordonibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarimonadaceaeBacteriumHl109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonadaceae bacterium HL-109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinarimonadaceaeBacteriumHl109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinitogaSp1155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga sp. 1155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinitogaSp1155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesStercoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides stercoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesStercoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit016242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 01-6242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit016242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChinchillaLanigeraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chinchilla lanigera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChinchillaLanigeraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_38_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPunicea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola punicea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPunicea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaCoronariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marssonina coronariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarssoninaCoronariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpAr710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. AR7-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpAr710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumAtrosepticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium atrosepticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumAtrosepticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenophonusLipoptenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus lipoptenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusLipoptenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOv118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ov118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph2100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH2100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph2100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusFulvusHw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus HW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvusHw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumLlatzerense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium llatzerense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLlatzerense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoclostridiumStercorariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoclostridium stercorarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoclostridiumStercorariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasTranslucens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas translucens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasTranslucens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrobacterVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhlebiopsisGigantea110611Cr56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea 11061_1 CR5-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhlebiopsisGigantea110611Cr56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGillisiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gillisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGillisiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaWestfalicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia westfalica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaWestfalicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpH83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. H83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpH83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoniaMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesonia mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoniaMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaapiaArgillaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jaapia argillacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JaapiaArgillaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCoralliilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio coralliilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioCoralliilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSinesaloumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sinesaloumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSinesaloumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHtcc2148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviScgcAb598o02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi SCGC AB598O02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviScgcAb598o02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumPrunaredenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium prunaredense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPrunaredenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumQingshengiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium qingshengii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumQingshengiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumSchaalii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum schaalii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumSchaalii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterChromiiresistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chromiiresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChromiiresistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaLeachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma leachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaLeachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalusNrrlY3668(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus NRRL Y-366-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalusNrrlY3668", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSpLeaf189(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. Leaf189 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpLeaf189", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HahellaChejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hahella chejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HahellaChejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpYe44(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. YE44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpYe44", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalitaleaCylindroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpOk494(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpOk494", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpFjat14222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. FJAT-14222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpFjat14222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelliellaPelovolcaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Belliella pelovolcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BelliellaPelovolcaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuricaudaAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuodenibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duodenibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuodenibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumRimae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium rimae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumRimae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRenipiscariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio renipiscarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioRenipiscariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpYr577Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. YR577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpYr577Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2499Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2499 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2499Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedibacterSymbiosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter symbiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterSymbiosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrybacteriaBacteriumRifcsplowo201full4424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO201FULL4424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo201full4424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusFasciansD188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians D188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansD188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2304411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ByssochlamysSpectabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Byssochlamys spectabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ByssochlamysSpectabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumLimicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium limicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumLimicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full4916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumK1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium K1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumK1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesOrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces oris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesOrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpHzmEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. HZM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpHzmEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusPicturaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus picturae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusPicturaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full5117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_51_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full5117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethermicoccusShengliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethermicoccusShengliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraSedulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera sedula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraSedulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumCg1024814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium CG1024814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumCg1024814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcusLuteusStrModasaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus str. modasa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrococcusLuteusStrModasaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaCoronata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puccinia coronata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PucciniaCoronata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpLeaf53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Leaf53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpLeaf53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwc23423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC23423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc23423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSp13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc28b08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC28B08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc28b08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWirthbacteriaBacteriumCg2305411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wirthbacteria bacterium CG2_30_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWirthbacteriaBacteriumCg2305411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaPolarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPolarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymoseptoriaBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaVestfoldensisSka53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella vestfoldensis SKA53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LoktanellaVestfoldensisSka53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporobacterTermitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporobacter termitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporobacterTermitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStoquefichusSpKle1796(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. KLE1796 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpKle1796", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermopetrobacterSpTc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermopetrobacter sp. TC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermopetrobacterSpTc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorBesciiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor bescii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorBesciiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFCSPHIGHO2_01_FULL_50_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalis13sdw01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis 13SDW01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalis13sdw01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenitaleaLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenitalea lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenitaleaLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaLitoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaLitoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviitogaTunisiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Defluviitoga tunisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DefluviitogaTunisiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpAp50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraMicronuciformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera micronuciformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMicronuciformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis3145b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 3145B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis3145b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHepatariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio hepatarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioHepatariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpCl6colEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. cl6col Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCl6colEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillochlorisTrichoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillochloris trichoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillochlorisTrichoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumAnatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium anatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumAnatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisphaeraLagunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldisphaera lagunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldisphaeraLagunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_42_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaceaeBacteriumDnf00626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium DNF00626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumDnf00626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsobaculumMelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Isobaculum melis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IsobaculumMelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentinusTigrinusAlcf2ss16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentinus tigrinus ALCF2SS1-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LentinusTigrinusAlcf2ss16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TessaracoccusSpT2530Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. T2.5-30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpT2530Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchlyaHypogynaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achlya hypogyna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchlyaHypogynaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusGeothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus geothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGeothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicrobiumMukohataeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium mukohataei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumMukohataeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfococcusSp4484241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus sp. 4484_241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusSp4484241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterIrgensiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter irgensii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterIrgensiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinocyclocheilusAnshuiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus anshuiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusAnshuiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusKakegawensisNbrc103104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis NBRC 103104 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensisNbrc103104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatalinimonasAlkaloidigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catalinimonas alkaloidigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatalinimonasAlkaloidigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelongbacteriaBacteriumGwf24014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Delongbacteria bacterium GWF24014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DelongbacteriaBacteriumGwf24014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobacillusAlkalidiazotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus alkalidiazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusAlkalidiazotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBroomiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira broomii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBroomiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_50_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FukomysDamarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fukomys damarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FukomysDamarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacterFloricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacter floricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacterFloricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterMalorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter malorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterMalorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThielaviaTerrestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thielavia terrestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThielaviaTerrestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LipomycesStarkeyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LipomycesStarkeyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAgglomeratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces agglomeratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAgglomeratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaBogorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asaia bogorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsaiaBogorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumGw2011gwa14161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium GW2011GWA14161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumGw2011gwa14161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterHeyliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heylii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeyliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDendritiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpNEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. N Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpNEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGalactosidilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus galactosidilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGalactosidilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcamd2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxoplasmaGondiiVegEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii VEG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ToxoplasmaGondiiVegEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full4619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpAbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. aB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpAbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaRuminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ruminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRuminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OchrobactrumRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpS5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. S5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusSpS5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa23816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_38_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa23816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPullorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPullorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesRuminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces ruminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRuminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigidimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonJdfr21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon JdFR-21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonJdfr21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaRisticiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia risticii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaRisticiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxParadoxusS110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus S110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusS110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpHgb0020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HGB0020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHgb0020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasGilvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas gilvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasGilvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr485(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR485 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr485", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansPlanktonicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyorhinisGdl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis GDL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisGdl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusKaustophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus kaustophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusKaustophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_38_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumisMeloCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cucumis melo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CucumisMeloCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfRidgeiaPiscesaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia piscesae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeiaPiscesaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolyporusArculariusHhb13444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polyporus arcularius HHB13444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolyporusArculariusHhb13444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumWce2004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusElongatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus elongatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusElongatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoproteusUzoniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus uzoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusUzoniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesSpDsm45892(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45892 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45892", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpBica19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BICA1-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBica19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaerimneri30aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri 30a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaerimneri30aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusWelwitschiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus welwitschiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusWelwitschiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNc2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTenderiaElectrophaga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tenderia electrophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTenderiaElectrophaga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumPapyrosolvensDsm2782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens DSM 2782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensDsm2782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPaurosaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplosphaeraColitermitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplosphaera colitermitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DiplosphaeraColitermitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaWenyoniiStrMassachusettsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii str. Massachusetts Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaWenyoniiStrMassachusettsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaSpongiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KiloniellaSpongiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdoribacterSplanchnicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter splanchnicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OdoribacterSplanchnicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisPb013t23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris PB013T23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisPb013t23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium6313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 63-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwe13228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWE13228 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwe13228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaSpGmku363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. GMKU363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpGmku363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot487d2yCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root487D2Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot487d2yCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRubrolavendulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubrolavendulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubrolavendulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorumF0390(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum F0390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumF0390", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Ottowia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ottowia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Ottowia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDentasiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentasini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentasiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpSoapCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpSoapCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas noxia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasNoxiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonadaceaeCot184oh4590Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae COT184OH4590 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonadaceaeCot184oh4590Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpEp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. EP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpEp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloplanusNatansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus natans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloplanusNatansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiLondoniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii londoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiLondoniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumCg2304152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium CG2_30_41_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumCg2304152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraSpMccc1a01428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensHk44Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens HK44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensHk44Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacteriumGwa27335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegilopsTauschiiSubspStrangulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii subsp. strangulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AegilopsTauschiiSubspStrangulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterSolanacearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter solanacearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiberibacterSolanacearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag724Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:724 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag724Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermostaphylosporaChromogena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermostaphylospora chromogena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermostaphylosporaChromogena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosynnemaMirumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema mirum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaMirumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoflavimicrobiumDichotomicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoflavimicrobium dichotomicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoflavimicrobiumDichotomicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerostipesCaccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes caccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesCaccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumChoanae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium choanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumChoanae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RutstroemiaSpNjr2017aBbwCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a BBW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aBbwCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolobusVulcani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolobusVulcani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucca12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRifcsphigho201full6931(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. RIFCSPHIGHO201FULL6931 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRifcsphigho201full6931", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaGlaucaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora glauca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaGlaucaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BasileaPsittacipulmonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Basilea psittacipulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BasileaPsittacipulmonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSinuspersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sinuspersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSinuspersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpDt234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. DT234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSpDt234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CholoepusHoffmanniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Choloepus hoffmanni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CholoepusHoffmanniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumIndolisDsm755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] indolis DSM 755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumIndolisDsm755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSpJ15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. J15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJ15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TanticharoeniaSakaeratensisNbrc103193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis NBRC 103193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensisNbrc103193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumV9d3004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium V9D3004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumV9d3004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRoseochromogenusSubspOscitansDs12976Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus subsp. oscitans DS 12.976 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenusSubspOscitansDs12976Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LepisosteusOculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lepisosteus oculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LepisosteusOculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusAsymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus asymbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAsymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvencibacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Provencibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvencibacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHaloduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHaloduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanopusillusAcidilobi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanopusillus acidilobi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanopusillusAcidilobi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumXerosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium xerosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumXerosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptosphaeriaMaculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HungateiclostridiumThermocellum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium thermocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumThermocellum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DraconibacteriumOrientaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium orientale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumOrientaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UncinocarpusReesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UncinocarpusReesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusAcidocaldariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FomitopsisRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FomitopsisRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaSpRifcsphigho212full4215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coxiella sp. RIFCSPHIGHO212FULL4215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoxiellaSpRifcsphigho212full4215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacteriumRifcsplowo202full7356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium RIFCSPLOWO202FULL7356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumRifcsplowo202full7356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVinicolorAmOr11026Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor AM-OR11-026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizopogonVinicolorAmOr11026Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaBelliiRml369cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii RML369C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiRml369cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpJ39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAkibaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus akibai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAkibaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastacembelusArmatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mastacembelus armatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MastacembelusArmatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasChangbaiensisNbrc104936(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis NBRC 104936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensisNbrc104936", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumHwasookii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium hwasookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumHwasookii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPrasinopilosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces prasinopilosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPrasinopilosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodosinusMongolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodosinus mongolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodosinusMongolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixThermoacetophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIlei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ilei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIlei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWF2_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminibacterMediatlanticusTb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus TB-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticusTb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichurisMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichuris muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichurisMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterAmalonaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter amalonaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterAmalonaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterIndolifexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter indolifex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterIndolifexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurellaAcetivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAcetivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusFumigatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusFumigatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusAeolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus aeolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusAeolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfCtenarytainaEucalypti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina eucalypti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEucalypti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS237 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumMagnetotacticumMs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum MS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticumMs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumLongumNcc2705Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum NCC2705 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumLongumNcc2705Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoalloteichusSpGba12924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus sp. GBA129-24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusSpGba12924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumRbg135114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_13_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg135114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpAcn1agEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. ACN1ag Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpAcn1agEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_55_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVaccinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vaccinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaVaccinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot483d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root483D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot483d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillibacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSpUcddsuzukiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tatumella sp. UCDDsuzukii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TatumellaSpUcddsuzukiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVarsoviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces varsoviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVarsoviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumBacl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntamoebaDisparCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EntamoebaDisparCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSp5139bfaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. 5139BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusSp5139bfaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHygroscopicusJinggangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus jinggangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusJinggangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusKocurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus kocurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusKocurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumMesophilicumSr166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum SR1.6/6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicumSr166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaMorhuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella morhuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMorhuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat14578(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-14578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat14578", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CnuellaTakakiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cnuella takakiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CnuellaTakakiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillaceaeBacteriumG5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumG5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpMc138bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MC13-8B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMc138bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporichthyaPolymorpha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporichthya polymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporichthyaPolymorpha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeD39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae D39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeD39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortieraAleyrodidarumTvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum TV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumTvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EumetaJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eumeta japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EumetaJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumRhodesiaeNbb3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae NBB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeNbb3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaSpheciospongiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora spheciospongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaSpheciospongiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraVanthielii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira vanthielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraVanthielii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GambusiaAffinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gambusia affinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GambusiaAffinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasRhizophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas rhizophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasRhizophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaFormicigenerans4653afaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans 4653AFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigenerans4653afaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpLsnobCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. LSNOB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpLsnobCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCb03911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gillisia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GillisiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterGummosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter gummosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterGummosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] cellulosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBeckwithbacteriaBacteriumRbg13429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RBG_13_42_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRbg13429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 28_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticolaF0411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola F0411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaHisticolaF0411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaMytiliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia mytili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaMytiliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusBaldriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus baldri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrococcusBaldriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHeteromorphusCbs11755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus CBS 117.55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusHeteromorphusCbs11755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesMelasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles melas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesMelasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpF0370Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0370 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0370Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisRmscc3703Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 3703 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc3703Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSolaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux solani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSolaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiveispirillumIrakenseDsm11586(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Niveispirillum irakense DSM 11586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NiveispirillumIrakenseDsm11586", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPealeanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella pealeana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPealeanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasSpIs79a3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Is79A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpIs79a3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumVentriosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ventriosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumVentriosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasUtahensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas utahensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasUtahensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfidibacterTakaiiAbi70s6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii ABI70S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaiiAbi70s6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogranumGelatinilyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halogranum gelatinilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalogranumGelatinilyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaricomesPhytoseiuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acaricomes phytoseiuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcaricomesPhytoseiuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaVermiculataNbrc100427Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vermiculata NBRC 100427 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaVermiculataNbrc100427Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho202full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO202FULL4712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho202full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinilabiliaSalmonicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinilabilia salmonicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinilabiliaSalmonicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GardnerellaVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMurrayiDsm11303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus murrayi DSM 11303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DeinococcusMurrayiDsm11303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumSpMlsbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. MLSB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpMlsbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelatoclostridiumRamosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelatoclostridium ramosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErysipelatoclostridiumRamosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpE14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. e14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpE14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaArenicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinispora arenicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisporaArenicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaAquaticaFslS101188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria aquatica FSL S10-1188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaAquaticaFslS101188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprosuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprosuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprosuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVanbaalenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vanbaalenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVanbaalenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFimetariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] fimetarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFimetariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanizomenonFlosAquaeUkl13PbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aphanizomenon flos-aquae UKL13-PB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AphanizomenonFlosAquaeUkl13PbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCuatrocienegasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cuatrocienegasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCuatrocienegasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_01_FULL_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacterium13120cm46611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_1_20CM_4_66_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13120cm46611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringensStr13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens str. 13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPerfringensStr13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumDamselaeSubspDamselae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae subsp. damselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumDamselaeSubspDamselae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaOstoyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armillaria ostoyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmillariaOstoyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumBeibuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium beibuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBeibuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterDaecheongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaBritovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella britovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaBritovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusAidingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusAidingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusAzygosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus azygosporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopusAzygosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaParvirubraYit11816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sutterella parvirubra YIT 11816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SutterellaParvirubraYit11816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumHalorespiransDsm13726(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans DSM 13726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespiransDsm13726", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaParagorgiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bizionia paragorgiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BizioniaParagorgiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BursaphelenchusXylophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bursaphelenchus xylophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BursaphelenchusXylophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoaviumNbrc100491Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium NBRC 100491 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterococcusPseudoaviumNbrc100491Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSimilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus similis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSimilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaRocourtiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria rocourtiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaRocourtiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaGoodfellowiiDsm19756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii DSM 19756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowiiDsm19756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpTunpsc045i4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. TunPSC045I4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpTunpsc045i4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_12_FULL_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumImcc3088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumImcc3088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZinderiaInsecticolaCari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zinderia insecticola CARI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZinderiaInsecticolaCari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpermophilusDauricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spermophilus dauricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpermophilusDauricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaObtusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holospora obtusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HolosporaObtusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmmonsiaCrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia crescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaCrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YokenellaRegensburgeiAtcc43003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yokenella regensburgei ATCC 43003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YokenellaRegensburgeiAtcc43003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp162mfsha11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 162MFSha11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp162mfsha11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthinifaciensS86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens S86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensS86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeobacterKilaueensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter kilaueensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeobacterKilaueensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospirillumFerriphilumMl04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum ML-04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilumMl04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpEp60837Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. EP60837 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpEp60837Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKuykendallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas kuykendallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKuykendallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoagulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coagulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCoagulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium novyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNovyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerMucosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipiger mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipigerMucosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCandidatusPoseidonialesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured Candidatus Poseidoniales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UnculturedCandidatusPoseidonialesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriiaBacterium4080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriia bacterium 40-80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriiaBacterium4080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_01_FULL_44_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpBsc265Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. BSC265 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpBsc265Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpJs211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. JS21-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpJs211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeodactylumTricornutumCcap10551Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum CCAP 1055/1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutumCcap10551Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleurocapsaSpPcc7319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7319 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelioribacterRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melioribacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelioribacterRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHlucca12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumCarotovorumPc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum PC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumPc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLutraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lutrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLutraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterLuteolusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterLuteolusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusDingoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus dingo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CanisLupusDingoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9400853Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9400853 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9400853Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia symbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAzotifigensDsm17556Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens DSM 17556 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAzotifigensDsm17556Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermothielavioidesTerrestrisNrrl8126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris NRRL 8126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestrisNrrl8126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumGwd23219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAgalactiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHankookensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hankookensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHankookensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpH1ai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. H1ai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpH1ai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVermiculataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vermiculata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaVermiculataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpMp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpMp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpUnc438cl73tsus30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC438CL73TsuS30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc438cl73tsus30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumCarotovorumPc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum PC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumPc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPorphyraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas porphyrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPorphyraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCamporealensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium camporealensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCamporealensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpCag324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sp. CAG:324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSpCag324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMacacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMacacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaNewyorkensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina newyorkensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaNewyorkensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpS32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. S3-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpS32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DialisterPneumosintesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister pneumosintes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterPneumosintesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimihaloglobusSulfuriphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limihaloglobus sulfuriphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimihaloglobusSulfuriphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuritaleaHydrogenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpP1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. P1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpP1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LarimichthysCrocea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Larimichthys crocea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LarimichthysCrocea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidihalobacterProsperusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter prosperus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterProsperusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFCircinelloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliivibrioWodanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio wodanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliivibrioWodanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaSubspMasoucidaNbrc13784Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. masoucida NBRC 13784 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspMasoucidaNbrc13784Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf325Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf325 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf325Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusCcmp1375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus CCMP1375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusCcmp1375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNd2006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium ND2006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNd2006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis2Sk95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 SK95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2Sk95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifoxya12Full3519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA12_FULL_35_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya12Full3519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumGwa2478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_47_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa2478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolaciniaPetroleariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia petrolearia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPetroleariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpErv7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ERV7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpErv7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSulfidigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sulfidigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSulfidigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSphaericusOt4b31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus OT4b31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSphaericusOt4b31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpOk048Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OK048 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOk048Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumGwa15114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium GWA15114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumGwa15114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMagnumDsm2767Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium magnum DSM 2767 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMagnumDsm2767Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumChiriqhucha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium chiriqhucha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumChiriqhucha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaMallensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicella mallensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicellaMallensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicrobiumZhouiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium zhouii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumZhouiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspAchromogenesAs03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. achromogenes AS03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspAchromogenesAs03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSimulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSimulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocapsaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpCy54118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. CY54118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpCy54118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusSpMilost2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. MilosT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpMilost2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaematobacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhanerochaeteCarnosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusProomiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus proomii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusProomiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpRoot60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusPcc6301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC6301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc6301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTetanomorphumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetanomorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetanomorphumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAnimalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterThereius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter thereius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterThereius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasIlicicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas ilicicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasIlicicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviramulusIchthyoenteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus ichthyoenteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusIchthyoenteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpRoot157(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root157 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot157", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwf25713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf25713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusTerranovensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNctc7422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCTC 7422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNctc7422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyriculariaOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyricularia oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyriculariaOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPapayae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter papayae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPapayae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis2F0392(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 F0392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2F0392", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaAquamarinaCbs119918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exophiala aquamarina CBS 119918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExophialaAquamarinaCbs119918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaNigraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora nigra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaNigraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_38_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaGrahamiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella grahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaGrahamiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpKbs0721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KBS0721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKbs0721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaHofmanniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmanni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmanniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaOtae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma otae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaOtae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc511d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobaculumSpY04aas1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. Y04AAS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpY04aas1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSpSoil729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sp. Soil729 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSpSoil729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicroterricolaViridarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microterricola viridarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicroterricolaViridarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaCremeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora cremea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCremeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuribaculumIntestinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muribaculum intestinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuribaculumIntestinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellamassiliaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotellamassilia timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellamassiliaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpNo7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. 7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpNo7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellalesBacteriumRifcsphigho212full3511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3511 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPallensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pallens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPallensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpVlb120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. VLB120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpVlb120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSticklandii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sticklandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSticklandii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluviicolaRiflensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola riflensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FluviicolaRiflensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisLiminatansDsm4140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis liminatans DSM 4140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanofollisLiminatansDsm4140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedAcidilobusSpCis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. CIS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpCis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaStuartii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia stuartii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaStuartii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSp13d2w2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. 13D2W2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSp13d2w2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70273Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70273 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70273Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpSk643(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpSk643", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf337 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpRl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. RL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSpRl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumStraminisolvensJcm21531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens JCM 21531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvensJcm21531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwellbacteriaBacteriumRifcsplowo202full4511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO202FULL4511 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo202full4511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumPga8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium pGA-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumPga8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPasteurianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusEquiDsm15833Jcm10991Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus equi DSM 15833 JCM 10991 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusEquiDsm15833Jcm10991Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpBp1148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BP1-148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBp1148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpH3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. H3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpH3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUreicelerivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ureicelerivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUreicelerivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumGw2011gwf24332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWF24332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwf24332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratiruptorTergarcusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorTergarcusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FermentibacterDaniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fermentibacter daniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FermentibacterDaniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpHg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacterium13140cm46819(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium 13_1_40CM_4_68_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacterium13140cm46819", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctocarpusSiliculosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectocarpus siliculosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctocarpusSiliculosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterBizzozeroniiCcug35545Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CCUG 35545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCcug35545Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar324ClusterBacteriumRedseas27b3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium REDSEAS27B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumRedseas27b3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacterium4572351Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_35.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572351Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusDelemarRa99880Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar RA 99-880 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizopusDelemarRa99880Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusRaffinolactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariimicrobiumKwangyangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aestuariimicrobium kwangyangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AestuariimicrobiumKwangyangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf265Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf265Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpH2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. H2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpH2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiscibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuscaDomestica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Musca domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuscaDomestica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaLongaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina longa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLongaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcaricomesPhytoseiuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acaricomes phytoseiuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcaricomesPhytoseiuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJeojienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jeojiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusJeojienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full4012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondrusCrispus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chondrus crispus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChondrusCrispus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSp20gpm1509m(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. 20GPM1509m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSp20gpm1509m", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelatoclostridiumRamosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erysipelatoclostridium ramosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErysipelatoclostridiumRamosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraMicroaerophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira microaerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraMicroaerophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonadalesBacteriumRifcsplowo212599Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonadales bacterium RIFCSPLOWO2_12_59_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonadalesBacteriumRifcsplowo212599Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumMesoamericanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium mesoamericanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMesoamericanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTcuhl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TCUHL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTcuhl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesAureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesAureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpNEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. N Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpNEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusMacauensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus macauensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FictibacillusMacauensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetromyzonMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Petromyzon marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PetromyzonMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaCoronataCbs61796Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata CBS 617.96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaproniaCoronataCbs61796Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FabibacterMisakiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter misakiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FabibacterMisakiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaOtitidiscaviarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA1_44_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaFalseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFalseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolobacteriumMooreiF0204Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei F0204 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiF0204Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasMacrotermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas macrotermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMacrotermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasChangbaiensisNbrc104936Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis NBRC 104936 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensisNbrc104936Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesGlobisporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes globisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesGlobisporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaccinostercus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_43_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDmhc10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DMHC 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDmhc10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaLutimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria lutimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaLutimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumHuakuii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1438b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1438b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1438b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCytotoxicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cytotoxicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCytotoxicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraInopinataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira inopinata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraInopinataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiaControversaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tilletia controversa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TilletiaControversaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpLm6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. LM 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpLm6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumGa0077555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiolineaDisciformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiolinea disciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiolineaDisciformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteitaleaPratensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteitalea pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteitaleaPratensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidicaulisMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidicaulis marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidicaulisMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho212full4422bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4422b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4422bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SordariaMacrosporaKHellEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora k-hell Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SordariaMacrosporaKHellEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag624043Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:62_40_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag624043Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelobacterSeleniigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelobacterSeleniigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumDisporicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium disporicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDisporicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorSpAld01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloramator sp. ALD01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloramatorSpAld01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShuttleworthiaSatellesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shuttleworthia satelles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShuttleworthiaSatellesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho202full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO202FULL4712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho202full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEui1c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EuI1c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpEui1c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph973Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH973 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph973Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSd21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SD21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSd21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProsthecomicrobiumHirschiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prosthecomicrobium hirschii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProsthecomicrobiumHirschiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full5118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL5118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full5118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusHermanniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hermanniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHermanniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpZagget8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. Zagget8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZagget8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4648Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4648 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4648Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSp6378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 63-78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasMethanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas methanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasMethanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a518o7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518O7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518o7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpH5989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. H5989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpH5989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfarculusBaarsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculus baarsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfarculusBaarsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGuineaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guineae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuineaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwe13228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWE1_32_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwe13228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PimelobacterSimplexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pimelobacter simplex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PimelobacterSimplexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumVulgareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoMaydis521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis 521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UstilagoMaydis521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligotrophaCarboxidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oligotropha carboxidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OligotrophaCarboxidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVinicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVinicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumRifcsphigho212full5236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO212FULL5236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho212full5236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_43_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaEiseniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga eiseniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaEiseniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumInfernorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum infernorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumInfernorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep3244(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP3244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep3244", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BudviciaAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Budvicia aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BudviciaAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasTaiwanensisDsm18899Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis DSM 18899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensisDsm18899Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaSalaciaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrinema salaciae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSalaciaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpathiphylliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter spathiphylli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpathiphylliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofusicoccumParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeofusicoccumParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KribbellaSpAli6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kribbella sp. ALI6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KribbellaSpAli6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb14412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_44_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb14412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifcsplowo212full459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPLOWO212FULL459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsplowo212full459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumGraminearumPh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum PH-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumGraminearumPh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOvisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella ovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOvisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpWsm3626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansAtcc10379Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans ATCC10379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansAtcc10379Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumPuteiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumPuteiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaCryptomonadisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivita cryptomonadis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivitaCryptomonadisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a518o7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518O7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518o7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_42_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisDsm18711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris DSM18711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisDsm18711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSpRu39b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sp. RU39B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSpRu39b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSericeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sericea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSericeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_38_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinactinosporaThermotoleransDsm45154(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans DSM 45154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinactinosporaThermotoleransDsm45154", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacterium6920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 69-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium6920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyopneumoniae168Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae168Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCancerogenusAtcc35316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus ATCC 35316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCancerogenusAtcc35316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisUzonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis uzonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisUzonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho201full3637(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL3637 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full3637", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusPinatubonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pinatubonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPinatubonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCommuneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium commune Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCommuneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag254Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:254 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag254Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusReuteriDsm20016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri DSM20016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteriDsm20016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterOboediens174bp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens 174Bp2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterOboediens174bp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpizellomycesPunctatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpizellomycesPunctatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GrimontiaHollisae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Grimontia hollisae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GrimontiaHollisae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusSpT824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus sp. T82-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolobusSpT824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaceaeBacteriumRedseas32b1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxellaceae bacterium REDSEAS32B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaceaeBacteriumRedseas32b1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaPaurometabolicaYim90007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica YIM 90007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolicaYim90007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamulariaCollocygni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ramularia collocygni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RamulariaCollocygni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumParaoxydans77mftsu32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans 77MFTsu32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydans77mftsu32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesSaopaulense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides saopaulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSaopaulense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumBangladeshenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium bangladeshense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumBangladeshenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JaapiaArgillaceaMucl33604(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Jaapia argillacea MUCL 33604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JaapiaArgillaceaMucl33604", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacaedibacterAcanthamoebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterAcanthamoebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterAerogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter aerogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAerogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGlacialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glacialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlacialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasPhaseoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasPhaseoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaCostaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga costaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaCostaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMayottensis200901116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira mayottensis 200901116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMayottensis200901116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesGilchristiiSlh14081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii SLH14081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlastomycesGilchristiiSlh14081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumDifficileCd160Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile CD160 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficileCd160Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaGuizhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea guizhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaGuizhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacteriumPelagium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium pelagium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPelagium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag471Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:471 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag471Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterMinnesotensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter minnesotensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterMinnesotensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasHalocynthiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halocynthiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalocynthiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusParauberisKctc11537(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis KCTC11537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisKctc11537", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumPv82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum PV8-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumPv82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpDfci1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DFCI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDfci1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpZagget11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Zagget11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpZagget11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosyntrophaLipolyticaDsm11003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica DSM 11003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolyticaDsm11003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialophoraAttaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialophora attae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAttaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterAnophelisNbrc107843Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Janibacter anophelis NBRC 107843 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JanibacterAnophelisNbrc107843Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusPahariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mus pahari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusPahariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacterium4920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium 49_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacterium4920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacterSaccharofermentansDsm14828(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans DSM 14828 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentansDsm14828", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasConfluentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas confluentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasConfluentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalibacteriumHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandicaDsm15978(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica DSM 15978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandicaDsm15978", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrigopsHabroptilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strigops habroptila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrigopsHabroptilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisVer097Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Ver097 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisVer097Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiaWalkeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tilletia walkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TilletiaWalkeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutypaLata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eutypa lata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EutypaLata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PygocentrusNattereriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pygocentrus nattereri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PygocentrusNattereriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil766Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil766 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil766Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumRs24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium RS24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumRs24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumDg23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium DG_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumDg23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaMurrelliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella murrelli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaMurrelliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumEstertheticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium estertheticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumEstertheticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LupinusAngustifoliusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lupinus angustifolius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LupinusAngustifoliusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumBetavasculorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium betavasculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBetavasculorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasArboricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas arboricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasArboricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpLeaf225Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf225 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf225Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaGrimshawi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila grimshawi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGrimshawi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCynosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma cynos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCynosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaMiyamotoiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia miyamotoi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaMiyamotoiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSp9140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. 9140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSp9140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumRifcsphigho202full5217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPHIGHO202FULL5217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsphigho202full5217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesExalbidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides exalbidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesExalbidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBs2016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BS-2016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBs2016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmotaMarmotaMarmotaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marmota marmota marmota Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarmotaMarmotaMarmotaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterSpG161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. G161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpG161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaOneidensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella oneidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaOneidensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminispirochaetaSmaragdinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta smaragdinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaSmaragdinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpAna3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ANA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpAna3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CycloclasticusZanclesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus zancles Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusZanclesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorBescii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor bescii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorBescii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumLacustre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumLacustre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp453mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 453mf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp453mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillionellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Millionella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MillionellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis22083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 22083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuis22083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriboliumCastaneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tribolium castaneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TriboliumCastaneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcaceaeBacteriumCm5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium CM5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumCm5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOblongaNbrc102422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella oblonga NBRC 102422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoraxellaOblongaNbrc102422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesMediterraneensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMediterraneensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFurukawaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas furukawaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFurukawaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumDisporicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium disporicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDisporicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOlivaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesOlivaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsplowo201full4724(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4724 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4724", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPollutisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pollutisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPollutisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaSpAf7305cm02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenella sp. AF73-05CM02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaSpAf7305cm02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaBifidaNbrc103089(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] bifida NBRC 103089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaBifidaNbrc103089", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaMazeiS6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei S-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaMazeiS6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiveispirillumIrakenseDsm11586Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Niveispirillum irakense DSM 11586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NiveispirillumIrakenseDsm11586Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusKoppenhoeferiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus koppenhoeferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKoppenhoeferiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCoagulans26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OblitimonasAlkaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oblitimonas alkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OblitimonasAlkaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmoebophilusSp3638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amoebophilus sp. 36-38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmoebophilusSp3638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterSpCat2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter sp. CaT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterSpCat2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BaumanniaCicadellinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisRs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterMusarumSubspJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter musarum subsp. japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeucobacterMusarumSubspJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaMarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella marensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaMarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSubbeticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces subbeticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSubbeticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpBal39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BAL39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBal39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1024431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_44_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattellaGermanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattella germanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattellaGermanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAquaticusDsm21051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus DSM 21051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAquaticusDsm21051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsormidiumNitens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsormidium nitens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsormidiumNitens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasEucrenophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas eucrenophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasEucrenophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLowiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLowiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesImmitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelotrichaceaeBacteriumMtc7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium MTC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumMtc7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumChlorophenolicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChlorophenolicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaHenselae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella henselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaHenselae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpRuh2624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. RUH2624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpRuh2624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobacterSpDg60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter sp. DG_60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterSpDg60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSpCcs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. CCS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpCcs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumFaeciumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium faecium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumFaeciumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IlumatobacterCoccineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ilumatobacter coccineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IlumatobacterCoccineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnq509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNQ-509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnq509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaTimonensis4401737Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis 4401737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensis4401737Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeutenbergiaCavernaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beutenbergia cavernae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeutenbergiaCavernaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaOdoriferaDsm4582Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia odorifera DSM 4582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaOdoriferaDsm4582Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusKimchiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus kimchii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusKimchiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RugamonasRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rugamonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RugamonasRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSp7sr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 7SR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSp7sr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microsporum canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrosporumCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaH8234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida H8234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaH8234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeliconiusMelpomene(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Heliconius melpomene graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HeliconiusMelpomene", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSalivariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus salivarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSalivariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfCtenarytainaEucalyptiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina eucalypti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEucalyptiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpRaccoon60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. Raccoon60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpRaccoon60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisMacrogoltabidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis macrogoltabida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisMacrogoltabidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpLeaf78Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf78Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaHoronobensisHb1Jcm15518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis HB-1 JCM 15518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensisHb1Jcm15518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesCerinusSubspCerinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agromyces cerinus subsp. cerinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgromycesCerinusSubspCerinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnasPlatyrhynchos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anas platyrhynchos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnasPlatyrhynchos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifoxyd12full4821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYD12FULL4821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyd12full4821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpDnf00663Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. DNF00663 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpDnf00663Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpLeaf395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf395 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpKks102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. KKS102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpKks102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full6025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL6025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full6025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpWd121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD12.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumSimuliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smittium simulii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmittiumSimuliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpCf125Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF125 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf125Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBouchesdurhonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bouchesdurhonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBouchesdurhonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinotignumUrinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum urinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinotignumUrinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaphniaMagnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daphnia magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaphniaMagnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaAnserinaEsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Es Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaAnserinaEsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_02_FULL_45_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BipolarisOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dietzia maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DietziaMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAculeatusAtcc16872Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus ATCC 16872 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusAculeatusAtcc16872Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaSpPdc51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. PDC51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSpPdc51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrateuriaTerreaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frateuria terrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrateuriaTerreaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumElkanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumElkanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrmitellaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Urmitella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrmitellaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraAlvinipulliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimangrovimonasIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidimangrovimonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidimangrovimonasIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumGlobosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumGlobosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPumilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pumilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPumilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTremblayaPrincepsPcval(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya princeps PCVAL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPrincepsPcval", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSuccinicansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium succinicans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuccinicansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRifcsphigho212full5236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO212FULL5236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho212full5236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 64-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenopusTropicalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenopus tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenopusTropicalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSulfaticallidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sulfaticallidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSulfaticallidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodomicrobiumUdaipurense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaPfennigiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afifella pfennigii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfifellaPfennigiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTa06BacteriumDg24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium DG_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06BacteriumDg24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacterium51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 5-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4422b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4422b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4422b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumRavenspurgense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium ravenspurgense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumRavenspurgense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaFrederikseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia frederiksenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaFrederikseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaReeseiQm6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei QM6a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaReeseiQm6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IsosphaeraPallidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Isosphaera pallida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IsosphaeraPallidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpEb01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. EB01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpEb01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpM334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusTimidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus timidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusTimidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifoxyd1Full3927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFOXYD1_FULL_39_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifoxyd1Full3927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaLingualeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma linguale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLingualeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitis2Sk95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 SK95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2Sk95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSuwonensisJ43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaSpUsdaarsusmarc1261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia sp. USDAARSUSMARC1261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSpUsdaarsusmarc1261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzisolibacterPropanilivoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryzisolibacter propanilivorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzisolibacterPropanilivoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4510c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4510c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4510c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterItalicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter italicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterItalicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa1377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_37_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa1377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoorellaThermoacetica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moorella thermoacetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoorellaThermoacetica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumCg1024737Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium CG1_02_47_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumCg1024737Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaAtrinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria atrinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaAtrinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VolvoxCarteriFNagariensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri f. nagariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VolvoxCarteriFNagariensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpragueaLophii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spraguea lophii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpragueaLophii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OerskoviaEnterophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia enterophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OerskoviaEnterophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocystisAeruginosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microcystis aeruginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrocystisAeruginosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfipiaSp6413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. 64-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaSp6413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusIctaluri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ictaluri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIctaluri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NothoproctaPerdicaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nothoprocta perdicaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NothoproctaPerdicaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAceti1023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti 1023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAceti1023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacimonetesBacteriumWwei01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium WWEI_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumWwei01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutibacterProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerribacillusAidingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerribacillusAidingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmataSpIil30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. IIL30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemmataSpIil30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPylori26695Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori 26695 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPylori26695Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp35w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 35W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp35w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterGeojensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter geojensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGeojensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitisViniferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vitis vinifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VitisViniferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpBcu110501(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BCU110501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBcu110501", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumSpRoot189(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum sp. Root189 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumSpRoot189", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallinaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpathasporaPassalidarumNrrlY27907Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum NRRL Y-27907 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpathasporaPassalidarumNrrlY27907Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpMits9509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf23829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonBa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr50345Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR50345 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr50345Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiensJcm6334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens JCM6334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensJcm6334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaPediculischaeffiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pediculischaeffi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPediculischaeffiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotruncusSpG3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpG3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumViridifuturi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium viridifuturi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumViridifuturi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp37maCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 37MA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSp37maCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumPennivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium pennivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumPennivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaFuscaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida fusca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaFuscaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_01_FULL_44_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumTsurumienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium tsurumiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumTsurumienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24817 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PatagioenasFasciataMonilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Patagioenas fasciata monilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PatagioenasFasciataMonilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasReinhardtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas reinhardtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasReinhardtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpP37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. P37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpP37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf151(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf151 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf151", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumCavolei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum cavolei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumCavolei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpB2m1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. B2M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpB2m1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumBranderiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium branderi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBranderiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansBc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans BC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansBc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterMusarumSubspJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter musarum subsp. japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeucobacterMusarumSubspJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorumFunduliformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum funduliforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumFunduliformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpS7Ms2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S7 MS 2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS7Ms2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterNoctilucaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaPurinilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia purinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaPurinilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaImmobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella immobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DokdonellaImmobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHaemolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus haemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHaemolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimicrobiumThiodismutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldimicrobium thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldimicrobiumThiodismutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_41_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAquimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAquimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraInfestansT304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans T30-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraInfestansT304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TeredinibacterTurneraeT7901(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7901", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSaliperosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saliperosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaliperosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumHimb59(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb59", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb02488Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02488 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02488Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaTriticiIpo323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici IPO323 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiIpo323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FinegoldiaMagnaAtcc53516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC53516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc53516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpBal3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. BAL3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpBal3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarincolaHl49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola HL49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaHl49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfopilaAestuariiDsm18488(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii DSM 18488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfopilaAestuariiDsm18488", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterYoungae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter youngae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterYoungae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioFibrisolvensDsm3071(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens DSM 3071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensDsm3071", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCostaricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus costaricensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCostaricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaLongibrachiatumAtcc18648Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum ATCC 18648 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatumAtcc18648Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyoglomusThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumHimb114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGwa1418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GWA1_41_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGwa1418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmoparaHalstediiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmopara halstedii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmoparaHalstediiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpNo7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpNo7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClunioMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clunio marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClunioMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusMaritimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ursus maritimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrsusMaritimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosiphoMelanesiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho melanesiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoMelanesiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanospirillumHungatei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanospirillum hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanospirillumHungatei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrusClementina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrus clementina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrusClementina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacteraceaeBacteriumAb14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacteraceae bacterium AB_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OxalobacteraceaeBacteriumAb14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HathewayaProteolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HathewayaProteolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngustibacterSpRoot456(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Angustibacter sp. Root456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AngustibacterSpRoot456", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumHaemolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium haemolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumHaemolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuricibacterSpH121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sp. H121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSpH121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterSp6223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. 62-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSp6223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp131216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 13-12-16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp131216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StylophoraPistillata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stylophora pistillata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StylophoraPistillata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaVaviloviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea vaviloviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaVaviloviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpMjr8396cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. MJR8396C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpMjr8396cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChungbukense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chungbukense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChungbukense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMycoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mycoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMycoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14615 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSubvibrioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas subvibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSubvibrioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaBraziliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leishmania braziliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaBraziliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoclostridiumPhocaeense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phocaeense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhocaeense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnicellularCyanobacteriumSu2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium SU2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UnicellularCyanobacteriumSu2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifoxyd1full4821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFOXYD1FULL4821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifoxyd1full4821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaetbulibacterSaemankumensisDsm17032(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis DSM 17032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensisDsm17032", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusTinctoriusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PisolithusTinctoriusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumCg2304315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_43_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2304315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineosphaeraLimosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kineosphaera limosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KineosphaeraLimosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAt4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AT4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAt4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumRbg166821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_68_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DracunculusMedinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dracunculus medinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DracunculusMedinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTsri0281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_35_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpLycopersici4287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici 4287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersici4287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusVulcanius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus vulcanius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVulcanius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNeptuniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio neptunius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioNeptuniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAbscessusNbrc100374(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia abscessus NBRC 100374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAbscessusNbrc100374", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DothistromaSeptosporumNze10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dothistroma septosporum NZE10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DothistromaSeptosporumNze10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpLeaf7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxPacificusW115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus W11-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxPacificusW115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSophoraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sophorae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSophoraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRapamycinicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rapamycinicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRapamycinicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaPini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella pini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KwoniellaPini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrateuriaTerrea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frateuria terrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrateuriaTerrea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisCip7865Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis CIP78.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisCip7865Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlaviramulusBasaltis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus basaltis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusBasaltis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplocarponRosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diplocarpon rosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiplocarponRosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumImmobileAtcc35973Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile (ATCC 35973) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobileAtcc35973Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaniviriJcm17471Dsm24301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri JCM 17471 DSM 24301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaniviriJcm17471Dsm24301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinispiraPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinispira pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinispiraPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalinemaSpCaciam70dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM 70d Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciam70dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAtroolivaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atroolivaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAtroolivaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctopirusHydrillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus hydrillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusHydrillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnormaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enorma timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnormaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroscillaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microscilla marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicroscillaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophothermusLipocalidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus lipocalidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusLipocalidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumCg1023722Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium CG1023722 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumCg1023722Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAcidiproducensDsm23148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens DSM 23148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAcidiproducensDsm23148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelosinusFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbiconiuxGinsengiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux ginsengi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxGinsengiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRbg13469Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RBG_13_46_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRbg13469Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpLeaf264(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf264", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumButyricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium butyricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumButyricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSaccharolyticusJop10301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus JOP 1030-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticusJop10301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaPallensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pallens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPallensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp8g7msg3316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 8G7MSG3316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp8g7msg3316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4416 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPestisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pestis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaPestisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwb1471Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWB1_47_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwb1471Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumJdfr86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpOsyse(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OSYSE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOsyse", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6803Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6803Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaMarisrubriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marisrubri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarisrubriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensKs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens KS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensKs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxJadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax jadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxJadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaConsociataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Massilia consociata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MassiliaConsociataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu033Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU033 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu033Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RikenellaMicrofususEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rikenella microfusus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RikenellaMicrofususEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumCelatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium celatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumCelatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FungalSpNo14919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.14919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo14919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPinnipediorumSubspPinnipediorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum subsp. pinnipediorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorumSubspPinnipediorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusRubeinfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus rubeinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusRubeinfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRuminisAtcc27782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis ATCC27782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRuminisAtcc27782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaCurassoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma curassoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaCurassoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7SakaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Sakai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7SakaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSpPamc26640(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PAMC 26640 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPamc26640", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpAlt199Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. ALT199 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpAlt199Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMediterraneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mediterranei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMediterraneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterRodentium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterRodentium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSocius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicola socius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSocius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediculusHumanusCorporis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus corporis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PediculusHumanusCorporis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaEquifetaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma equifetale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaEquifetaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSoleaferreaMassiliensisAp7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Soleaferrea massiliensis AP7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSoleaferreaMassiliensisAp7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusTorquesAtcc27756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus torques ATCC27756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusTorquesAtcc27756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaBeijingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaBeijingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimazuellaKribbensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimazuella kribbensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimazuellaKribbensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylohalobiusCrimeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylohalobius crimeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylohalobiusCrimeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0091Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0091Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpNor37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. NOR37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpNor37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalitaleaSaponilacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalitalea saponilacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalitaleaSaponilacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlemurSimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prolemur simus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProlemurSimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrmitellaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Urmitella timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrmitellaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium284(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium284", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArhCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArhCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinivibrioAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinivibrio alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinivibrioAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marine Group III Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCdtb01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CdTB01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCdtb01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpCaciam22h1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. CACIAM 22H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpCaciam22h1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodosporaAnserinaSMatEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina S mat+ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PodosporaAnserinaSMatEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterSenuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter senuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSenuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpIso899Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. Iso899 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpIso899Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho201full4098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO201FULL4098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho201full4098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaNeofelifaecisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia neofelifaecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaNeofelifaecisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeonamhaeicolaSpS23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Seonamhaeicola sp. S2-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SeonamhaeicolaSpS23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaNapusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brassica napus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrassicaNapusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc11e11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC11E11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc11e11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusKimchii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus kimchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusKimchii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumPhytohabitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium phytohabitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumPhytohabitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaCarbonacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora carbonacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCarbonacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpinaciaOleraceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spinacia oleracea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpinaciaOleraceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumExtorquensPa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens PA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensPa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetobacteriumCasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetobacterium casensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetobacteriumCasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonasHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermomonasHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpF0418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAquistagniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus aquistagni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAquistagniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumRifcsphigho202full62130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium RIFCSPHIGHO202FULL62130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumRifcsphigho202full62130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumArcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium arcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumArcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaPolarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPolarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSp1138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumMedpeswcelCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium MedPESWcel Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumMedpeswcelCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FinegoldiaMagnaAtcc29328(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC29328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc29328", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaWheatBlue(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma wheat blue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaWheatBlue", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMaddingley(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Maddingley graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMaddingley", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaDonostiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia donostiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaDonostiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterSpAg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. Ag1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpAg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMassiliensis4401292Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis 4401292 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesMassiliensis4401292Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg136212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaPolyisoprenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia polyisoprenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaPolyisoprenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSalinitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaSinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraMethylohalidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosphaerulaPalustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaerula palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosphaerulaPalustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprosuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprosuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprosuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdwardsiellaHoshinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella hoshinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaHoshinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterAsburiaeLf7aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter asburiae LF7a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAsburiaeLf7aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel131208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_31_208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel131208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPanaciterraeDsm19096Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae DSM 19096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusPanaciterraeDsm19096Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpRoot635Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root635 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot635Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumSg839(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg839", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistesJonesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synergistes jonesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynergistesJonesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusSp29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. 2.9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusSp29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophobacterFumaroxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter fumaroxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterFumaroxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacterSpHeli10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacter sp. HelI10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacterSpHeli10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocPseudomesenteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc pseudomesenteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocPseudomesenteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhodobacterSpCcbmm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pararhodobacter sp. CCBMM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PararhodobacterSpCcbmm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PochoniaChlamydosporia170Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia170Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYC2_FULL_47_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpOlb3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. OLB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpOlb3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumisMeloVarMakuwaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo var. makuwa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CucumisMeloVarMakuwaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanPaniscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pan paniscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PanPaniscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpRim11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MartelellaMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Martelella mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MartelellaMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZhanjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zhanjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasZhanjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAquilaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAquilaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcidipropioniciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidipropionici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcidipropioniciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofarcimenAcetoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen acetoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenAcetoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaHaemolyticaBovine(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica BOVINE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaBovine", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitisJcm10512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis JCM 10512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitisJcm10512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasAerilata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas aerilata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseomonasAerilata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110056Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110056Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterActinomycetemcomitansRhaa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans RhAA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansRhaa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFujikuroiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumFujikuroiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGa0074137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpCag2416221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241_62_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag2416221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpAr153Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. AR 15-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpAr153Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcticibacterSvalbardensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter svalbardensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterSvalbardensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumBavaricumDsm4179Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum DSM 4179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricumDsm4179Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_36_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacterium9403326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9403326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9403326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSlackii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces slackii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSlackii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSpHl35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. HL35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpHl35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterRarus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter rarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRarus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo201full4826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO201FULL4826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo201full4826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusHominisC80(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis C80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisC80", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPerflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria perflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPerflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosotenuisChungbukensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis chungbukensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisChungbukensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpSw2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. SW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpSw2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusTerrigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaDiclinaVs20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina VS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaDiclinaVs20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMellifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMellifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumMobileF1926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium mobile F1926 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EpibacteriumMobileF1926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccipiterNisusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accipiter nisus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccipiterNisusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumBrachy(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium brachy graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBrachy", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeBvOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpPrwf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PRwf1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPrwf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinomonasHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansM341Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans M341 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansM341Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpBtai1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. BTAi1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpBtai1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumVulpinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium vulpinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumVulpinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterKorlensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter korlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterKorlensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4354Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4354 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4354Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZinderiaInsecticolaCariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zinderia insecticola CARI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZinderiaInsecticolaCariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumAmorphae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium amorphae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAmorphae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillochlorisTrichoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillochloris trichoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillochlorisTrichoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGorillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gorillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGorillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRoquefortiFm164Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium roqueforti FM164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRoquefortiFm164Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OreochromisNiloticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis niloticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OreochromisNiloticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumFalciparum3d7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum 3D7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumFalciparum3d7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMustelaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mustelae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMustelaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterPelagiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter pelagius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPelagiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnaportheOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthe oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnaportheOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolffiiSerovarKhoratStrKhoratH2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolffii serovar Khorat str. Khorat-H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolffiiSerovarKhoratStrKhoratH2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho212full4219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusHerbariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus herbarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHerbariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxya12full5229Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA12FULL5229 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya12full5229Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontStrainCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont strain Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontStrainCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOleovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oleovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOleovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumMarseillenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marseillense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarseillenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutusSpGas368Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opitutus sp. GAS368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpitutusSpGas368Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWF2_43_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaeroformaArcticaJp610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica JP610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphaeroformaArcticaJp610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLarvaeSubspLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae subsp. larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusLarvaeSubspLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlesiocystisPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plesiocystis pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlesiocystisPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumParvulumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium parvulum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumParvulumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGerencseriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGerencseriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaBogorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asaia bogorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsaiaBogorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NothoproctaPerdicariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nothoprocta perdicaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NothoproctaPerdicariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrantae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brantae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrantae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaCricetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia criceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaCricetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterCitreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter citreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterCitreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt372Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT372 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt372Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRifcsphigho212full6519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. RIFCSPHIGHO212FULL6519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRifcsphigho212full6519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaXenobioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala xenobiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaXenobioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HumibacterAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Humibacter albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HumibacterAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisHaa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris HaA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisHaa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PluralibacterGergoviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pluralibacter gergoviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PluralibacterGergoviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ItalianCloverPhyllodyPhytoplasmaStrMa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Italian clover phyllody phytoplasma str. MA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ItalianCloverPhyllodyPhytoplasmaStrMa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParoeduraPictaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paroedura picta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParoeduraPictaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnionYellows(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Onion yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OnionYellows", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatranaerobiusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natranaerobius thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatranaerobiusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumSm2361Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SM23_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSm2361Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumUasb124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCassavaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cassavae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCassavaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaprolegniaDiclinaVs20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina VS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaDiclinaVs20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theileria orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheileriaOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumUmmarienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium ummariense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumUmmarienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaBryophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bryophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBryophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4558Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4558 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4558Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaUmbonataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella umbonata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUmbonataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaAminisulfidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga aminisulfidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaAminisulfidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasLeviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas levii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasLeviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterorhabdusCaecimurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus caecimuris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusCaecimurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolibacillusSilvestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solibacillus silvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolibacillusSilvestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtrovirideImi206040Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride IMI 206040 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAtrovirideImi206040Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaSp1534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella sp. 1534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaSp1534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesHl037pa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes HL037PA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesHl037pa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PogonaVitticepsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pogona vitticeps Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PogonaVitticepsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiXiangfangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei xiangfangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiXiangfangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNamurensisDsm19117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis DSM 19117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNamurensisDsm19117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSpRm16704(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM16704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm16704", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterFreundiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter freundii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterFreundiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsphigho201full4623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL4623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full4623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpLeaf2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Leaf2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpLeaf2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSpg23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SPG23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSpg23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa25518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_55_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa25518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWeihenstephanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusWeihenstephanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesPubescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trametes pubescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrametesPubescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxobacterPfennigii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oxobacter pfennigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OxobacterPfennigii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpDsm25559Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. DSM 25559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpDsm25559Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharobutylicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharobutylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharobutylicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHlucca08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumMurisUcdAy4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium muris UCD-AY4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumMurisUcdAy4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumGw2011gwc14916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWC14916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwc14916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubellimicrobiumMesophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpM313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. m313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpM313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterDelicatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter delicatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurvibacterDelicatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumFabrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium fabrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumFabrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEndobugulaSertula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Endobugula sertula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusEndobugulaSertula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumGw2011Od13428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium GW2011_OD1_34_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumGw2011Od13428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaLettingaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga lettingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermotogaLettingaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_01_FULL_48_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeokomagataeaThailandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeokomagataeaThailandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusSpTm1035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. TM1035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseovariusSpTm1035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaBelliiRml369cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii RML369C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiRml369cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrobacteralesBacteriumUrhd0059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium URHD0059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacteriumUrhd0059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_50_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full5011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusContaminansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusContaminansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemoglobinophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus haemoglobinophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusHaemoglobinophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpOk665(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK665 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpOk665", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumAgresteDsm44070(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum agreste DSM 44070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumAgresteDsm44070", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionivibrioDicarboxylicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionivibrio dicarboxylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionivibrioDicarboxylicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysemysPicta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chrysemys picta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChrysemysPicta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg2304514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG2304514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg2304514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGordonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gordonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGordonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaceaeBacteriumKa00182Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium KA00182 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumKa00182Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicractiniumConductrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micractinium conductrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicractiniumConductrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SlackiaPiriformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Slackia piriformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SlackiaPiriformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonadalesBacteriumRifoxya1full6910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium RIFOXYA1FULL6910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacteriumRifoxya1full6910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusOryzaeRib40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae RIB40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusOryzaeRib40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusPittmaniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaApereaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cavia aperea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaviaApereaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionispiraArborisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionispira arboris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionispiraArborisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp11000297(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1100029.7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11000297", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRapiDsm19907Jcm15042Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rapi DSM 19907 JCM 15042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRapiDsm19907Jcm15042Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRubidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumRifoxyb1full3315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium RIFOXYB1FULL3315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumRifoxyb1full3315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusCatusGd7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus catus GD/7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoprococcusCatusGd7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusHeterorhabditisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus heterorhabditis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusHeterorhabditisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFermentibacterDaniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fermentibacter daniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFermentibacterDaniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfallasAlcoholivorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas alcoholivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfallasAlcoholivorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaSimulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSimulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumJdfr77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocorpusculumLabreanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum labreanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumLabreanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiodendronMaiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oidiodendron maius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OidiodendronMaiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlobisporangiumUltimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Globisporangium ultimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlobisporangiumUltimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaeniclostridiumSordelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paeniclostridium sordellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaeniclostridiumSordelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrobacterPenzbergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrobacter penzbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrobacterPenzbergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodomicrobiumUdaipurenseJa643(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense JA643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurenseJa643", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4516Fw969(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4516 (FW-969) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4516Fw969", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidomycesRichmondensisBfw(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis BFW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidomycesRichmondensisBfw", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitiniphilusShinanonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpN54mgs139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. N54MGS139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpN54mgs139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiAnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi Ana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiAnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicusStrDeltaHEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus str. Delta H Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicusStrDeltaHEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfPedicinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaSp111n121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dietzia sp. 111N12-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DietziaSp111n121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusDelemarEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus delemar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopusDelemarEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMuridarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter muridarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMuridarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VenturiaNashicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Venturia nashicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VenturiaNashicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillisiaBrevisNbrc105863Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Millisia brevis NBRC 105863 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MillisiaBrevisNbrc105863Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenericutesBacteriumGwd23827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWD2_38_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwd23827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioliNbrc102428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fumarioli NBRC 102428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusFumarioliNbrc102428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumLacusprofundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lacusprofundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLacusprofundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumOraleDsm12838(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale DSM 12838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumOraleDsm12838", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterSpNb311aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. Nb-311A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSpNb311aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassilioclostridiumColi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilioclostridium coli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilioclostridiumColi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCurvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter curvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCurvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoemansiaReversaNrrl1564Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coemansia reversa NRRL 1564 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoemansiaReversaNrrl1564Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3715 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpSyk6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. SYK6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpSyk6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusSediminisNbrc103570Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis NBRC 103570 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmphibacillusSediminisNbrc103570Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AptenodytesForsteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aptenodytes forsteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AptenodytesForsteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwc14518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWC14518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwc14518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPantheris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPantheris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGas113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium GAS113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGas113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermogladiusCellulolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermogladius cellulolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermogladiusCellulolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusFiculneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus ficulneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFiculneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSobrinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSobrinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMontpellierensisDsm17217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis DSM 17217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensisDsm17217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSp5h374(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. 5H374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSp5h374", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPiriflorinigransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminimonasQiaohouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminimonas qiaohouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminimonasQiaohouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchangiumSpCbG35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archangium sp. Cb G35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchangiumSpCbG35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_42_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumOlb9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaSeiffertiiAtcc49495Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii ATCC 49495 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertiiAtcc49495Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag3212622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:321_26_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag3212622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesTimonensisJc136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes timonensis JC136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesTimonensisJc136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadetesBacterium13120cm46611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_1_20CM_4_66_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13120cm46611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliogorillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliogorillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliogorillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpNkbg15041cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. NKBG15041c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpNkbg15041cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumChungbukenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chungbukense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChungbukenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag449(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:449 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag449", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinifilumFragile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinifilum fragile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinifilumFragile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf371Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf371Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph3623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 3623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph3623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacillusKushneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinibacillus kushneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinibacillusKushneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusReuszeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus reuszeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusReuszeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumGibsoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum gibsoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumGibsoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcaligenesFaecalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenes faecalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcaligenesFaecalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeokomagataeaThailandicaNbrc106555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica NBRC 106555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeokomagataeaThailandicaNbrc106555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23066Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23066 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23066Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaCruziStrainClBrenerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi strain CL Brener Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaCruziStrainClBrenerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusMusculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mus musculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusMusculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporomusaSphaeroidesDsm2875Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides DSM 2875 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporomusaSphaeroidesDsm2875Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaPersicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaPersicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag956Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:956 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag956Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenopusLaevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenopus laevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenopusLaevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseatelesDepolymerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseateles depolymerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseatelesDepolymerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerinusCanaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serinus canaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerinusCanaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillaceaeBacteriumGas479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium GAS479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumGas479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbusAd2013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus AD2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusAlbusAd2013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKribbensisDsm17871Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus kribbensis DSM 17871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusKribbensisDsm17871Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FenollariaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fenollaria timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FenollariaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGa0074134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0074134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0074134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsphigho202full4613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO202FULL4613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho202full4613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumAmbiguumIamM71Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidium ambiguum IAM M-71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhormidiumAmbiguumIamM71Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaProteobacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return zeta proteobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaProteobacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothielavioidesTerrestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaFaecisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaFaecisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NegativibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Negativibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NegativibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumTenueNies30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phormidium tenue NIES-30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhormidiumTenueNies30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSpE463Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. E463 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpE463Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpP838Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. P838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpP838Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSpNl5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nl5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNl5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IchthyophthiriusMultifiliisStrainG5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis strain G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliisStrainG5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPopuletiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] populeti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPopuletiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpPsnih1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpH103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaTobetsuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella tobetsuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaTobetsuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24716 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumCg10247685Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_47_685 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg10247685Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsplowo201full4610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO201FULL4610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo201full4610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeTigr4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae TIGR4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeTigr4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidocella aminolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidocellaAminolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg136020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_60_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg136020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumScindens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scindens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScindens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumHum1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSalegensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas salegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSalegensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDevrieseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus devriesei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDevrieseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNd2006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium ND2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNd2006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwd23259Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_59 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23259Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGje10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GJE10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGje10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaQuinlivaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella quinlivanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuinlivaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusSpKu26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaTolypothrichoidesVb61278Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides VB-61278 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoidesVb61278Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpBvorr034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrrhodermaNoxiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrrhoderma noxium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrrhodermaNoxiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag533(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag533", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumWds1c4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium WDS1C4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumWds1c4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusAutotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus autotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioglobusAutotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMayottensis200901116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira mayottensis 200901116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMayottensis200901116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTokpelaiaHoelldoblerii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tokpelaia hoelldoblerii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTokpelaiaHoelldoblerii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaYamanashiensisNbrc100130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis NBRC 100130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaYamanashiensisNbrc100130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaSiddallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia siddallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaSiddallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobutyricumHallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobutyricum hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobutyricumHallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSpA11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. A11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpA11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces canus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllokutzneriaAlbataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allokutzneria albata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllokutzneriaAlbataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTanneraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella tannerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTanneraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeiaOryzaeDsm17879(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leeia oryzae DSM 17879 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeeiaOryzaeDsm17879", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEdwardsbacteriaBacteriumGwe25412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Edwardsbacteria bacterium GWE2_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusEdwardsbacteriaBacteriumGwe25412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesJenseniiJcm1364Nbrc14755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides jensenii JCM 1364 NBRC 14755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardioidesJenseniiJcm1364Nbrc14755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEquinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEquinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleiagrimonasSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oleiagrimonas soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OleiagrimonasSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusVersmoldensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus versmoldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVersmoldensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixLacustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiothrixLacustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAciduriciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidurici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAciduriciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelotomaculumSpDtu098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum sp. DTU098 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumSpDtu098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSp1nls2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Afipia sp. 1NLS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AfipiaSp1nls2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterMustelae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter mustelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMustelae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCherryEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cherry Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCherryEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg1024390(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1024390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1024390", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumScgcAaa252n14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252N14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252n14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumKroppenstedtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kroppenstedtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKroppenstedtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaNasimuriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rothia nasimurium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RothiaNasimuriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpM412017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41(2017) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpM412017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasResinovoransNbrc106553(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans NBRC106553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransNbrc106553", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisV583Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis V583 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalisV583Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSpRoot187Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora sp. Root187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSpRoot187Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar86ClusterBacteriumSar86aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasBeringensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas beringensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasBeringensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinusCanariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serinus canaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerinusCanariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HabropodaLaboriosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Habropoda laboriosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HabropodaLaboriosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpDg25bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinibacterTainanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinibacterTainanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AvibacteriumParagallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioCholeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpCrb83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-8-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeronii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterBizzozeronii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterSpRedseas28b5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. REDSEAS28B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpRedseas28b5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFlavusNrrl3357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus NRRL3357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusFlavusNrrl3357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalneolaSpEhc07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Balneola sp. EhC07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BalneolaSpEhc07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBombi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBombi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRenniniDsm20253Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rennini DSM 20253 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRenniniDsm20253Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAvidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium avidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAvidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpHmsc072f04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC072F04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc072f04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc24211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc24211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSpEbm38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter sp. EBM-38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSpEbm38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumPentaromativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium pentaromativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumPentaromativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCoronafaciensPvPorriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens pv. porri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciensPvPorriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaOtitidiscaviarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumSp5120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. 51_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSp5120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpJa23ba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA23Ba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa23ba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumGw2011gwf24219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWF24219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwf24219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobalesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobalesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4246Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4246 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4246Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumGondwanenseDsm13020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense DSM 13020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanenseDsm13020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSynechococcusSpongiarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Synechococcus spongiarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSynechococcusSpongiarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMeningitidisMc58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria meningitidis MC58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMeningitidisMc58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSartorii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sartorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSartorii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSpCamponotileonardi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotileonardi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotileonardi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusPersicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus persicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacillusPersicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndolissoclinumFaulkneriL5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinocatenisporaSeraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinocatenispora sera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinocatenisporaSeraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumEtliCiat652Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CIAT652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCiat652Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHordeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hordei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHordeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumCg2303520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium CG2303520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumCg2303520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermabacterSpHfh0086(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter sp. HFH0086 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DermabacterSpHfh0086", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RosaChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rosa chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RosaChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaYuzhufengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia yuzhufengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaYuzhufengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPiscicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piscicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiscicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpisthorchisViverriniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis viverrini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisViverriniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusMaliNbrc102425Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali NBRC 102425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusMaliNbrc102425Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioGracilisDsm16080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis DSM 16080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioGracilisDsm16080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpUrhe0023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHE0023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhe0023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioStylochiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio stylochi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioStylochiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf13410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF1_34_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf13410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermonemaRossianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermonema rossianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermonemaRossianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHtcc2083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumInsubricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium insubricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumInsubricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwb1378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBarengoltziiG22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii G22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltziiG22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa13330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaAmethystinaLaam081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Laccaria amethystina LaAM-08-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LaccariaAmethystinaLaam081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacteraceaeBacteriumAb14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacteraceae bacterium AB_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OxalobacteraceaeBacteriumAb14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremococcusColeocolaAcs139vcol8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola ACS139VCol8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaAcs139vcol8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSonorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sonorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSonorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusKuroshimensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus kuroshimensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusKuroshimensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCollinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces collinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCollinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE3198(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3198", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf288Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf288 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf288Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFirmus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus firmus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFirmus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwa25611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA25611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa25611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasNaejangsanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas naejangsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNaejangsanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureispiraSpCcbqb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureispira sp. CCBQB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureispiraSpCcbqb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJ33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. J33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJ33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaJogaejeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella jogaejeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaJogaejeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaCurassoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma curassoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaCurassoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaHoronobensisHb1Jcm15518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis HB-1 JCM 15518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensisHb1Jcm15518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpHu2014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. HU2014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpHu2014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCurieaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curieae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurieaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LinumUsitatissimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Linum usitatissimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LinumUsitatissimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumScgcAaa027k21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium SCGC AAA027K21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumScgcAaa027k21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KribbellaCatacumbae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kribbella catacumbae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KribbellaCatacumbae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixVenerupisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix venerupis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixVenerupisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevisNbrc100599(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis NBRC100599 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisNbrc100599", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpS62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S-6-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpBv3ac4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BV3Ac4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBv3ac4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusXanthusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus xanthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcusXanthusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BiomphalariaGlabrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Biomphalaria glabrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BiomphalariaGlabrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnc496mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC496MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc496mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpAntH11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant H11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpAntH11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRubiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rubi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRubiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterUrsingiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter ursingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterUrsingiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_35_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoturnixJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coturnix japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoturnixJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFischeriNrrl181(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fischeri NRRL 181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusFischeriNrrl181", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpCag368Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:368 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag368Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraAtramentaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura atramentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraAtramentaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaccinostercusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinocatenisporaSeraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinocatenispora sera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinocatenisporaSeraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHiranonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hiranonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHiranonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpBv1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. BV1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpBv1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNasuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNasuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorellaSorokiniana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorella sorokiniana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorellaSorokiniana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theileria orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheileriaOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LynxCanadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lynx canadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LynxCanadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaMarinaDsm2698Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Afifella marina DSM 2698 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AfifellaMarinaDsm2698Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PomaceaCanaliculataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pomacea canaliculata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PomaceaCanaliculataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VenturiaNashicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Venturia nashicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VenturiaNashicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumGwf24151Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_41_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf24151Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumEquinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium equinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumEquinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpCf384Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. CF384 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCf384Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpMwyl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MWYL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMwyl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpathiphylliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter spathiphylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpathiphylliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaCoxensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea coxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NonomuraeaCoxensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLeptum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium leptum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLeptum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta Mad698R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD2_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumF0540Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium F0540 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumF0540Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCch5f6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCH5F6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCch5f6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloprofundusSedimenti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloprofundus sedimenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloprofundusSedimenti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdiutrixIntracellularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adiutrix intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdiutrixIntracellularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScalinduaBrodae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scalindua brodae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ScalinduaBrodae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilaceaeBacterium11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilaceae bacterium 11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilaceaeBacterium11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAbortus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia abortus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAbortus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg136212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_62_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaAerofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella aerofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaAerofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpHel185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudozobelliaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudozobellia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudozobelliaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerbacteriaBacteriumRbg13378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fischerbacteria bacterium RBG13378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FischerbacteriaBacteriumRbg13378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhygromyxaSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enhygromyxa salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnhygromyxaSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSalinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSalinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumUrha0028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium URHA0028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumUrha0028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptobacteriumSpCag338Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium sp. CAG:338 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumSpCag338Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinimicrobiumAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosphaeraStadtmanae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera stadtmanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraStadtmanae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrabulsiellaOdontotermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trabulsiella odontotermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrabulsiellaOdontotermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterBizzozeroniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobiumNarugenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobium narugense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobiumNarugenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaBorealisF4128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia borealis F-4128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaBorealisF4128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CajanusCajanEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cajanus cajan Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CajanusCajanEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifoxyc2full4512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYC2FULL4512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyc2full4512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpMed121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MED121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMed121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusHomomorphusCbs101889(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus CBS 101889 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusHomomorphusCbs101889", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_44_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumXbb2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm35210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmatimonadetesBacterium13140cm6414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 13_1_40CM_64_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium13140cm6414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpAap58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. AAP58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpAap58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilibacteriumTimonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mobilibacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MobilibacteriumTimonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloplanusVescusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus vescus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloplanusVescusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumVaccae95051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae 95051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccae95051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSclerotialusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sclerotialus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSclerotialusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag380(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag380", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaestuariivitaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudaestuariivita atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudaestuariivitaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGloeosporioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterAntibioticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter antibioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterAntibioticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolimonasSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solimonas soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolimonasSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrombidiumDeliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrombidium deliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrombidiumDeliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraFaineiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira fainei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraFaineiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioSpMa26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MA2-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMa26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaFaecimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaFaecimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesIndistinctusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes indistinctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesIndistinctusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpLa11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LA11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLa11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_37_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis865192Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 865192 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis865192Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusIheyensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus iheyensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusIheyensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalisGambiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glossina palpalis gambiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlossinaPalpalisGambiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterEpoxidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter epoxidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterEpoxidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassilioclostridiumColiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilioclostridium coli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilioclostridiumColiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCarbinoliphilusSubspOakridgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus subsp. oakridgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilusSubspOakridgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniborusEthanoligenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus ethanoligenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusEthanoligenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12458059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245805.9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12458059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaCastelliiCbs4309(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma castellii CBS 4309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaCastelliiCbs4309", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyd12full368Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYD12FULL368 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyd12full368Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilaChrysaetosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquila chrysaetos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquilaChrysaetosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnh099Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH099 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh099Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaphidiopsisBrookiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Raphidiopsis brookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RaphidiopsisBrookiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium filum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdoribacterLaneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter laneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OdoribacterLaneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKalixensisDsm16043Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis DSM 16043 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKalixensisDsm16043Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumAap38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpAgr2160(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. AGR2160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpAgr2160", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumStanieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumStanieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocapsaRoseopersicinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa roseopersicina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaRoseopersicinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SericytochromatiaBacteriumS15bmn24raac196Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24RAAC_196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24raac196Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacaSpPts2502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca sp. PTS2502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaSpPts2502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaMonacensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia monacensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaMonacensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusSpGba12924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus sp. GBA129-24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusSpGba12924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolanumLycopersicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solanum lycopersicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolanumLycopersicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCag988Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CAG:988 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCag988Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterFrateurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter frateurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GluconobacterFrateurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumMunicipale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum municipale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumMunicipale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaOxytocaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella oxytoca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaOxytocaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaSpScgcAaa288l16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. SCGC AAA288L16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpScgcAaa288l16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumOrbiculareMaff240422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare MAFF 240422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculareMaff240422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOrisrattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisrattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilicibacterLacuscaerulensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter lacuscaerulensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SilicibacterLacuscaerulensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GolovinomycesMagnicellulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces magnicellulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesMagnicellulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13140cm2607Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_40CM_2_60_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13140cm2607Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthiaCatenaformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthia catenaformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthiaCatenaformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumCg1023721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WirthbacteriaBacteriumCg2305411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wirthbacteria bacterium CG2305411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WirthbacteriaBacteriumCg2305411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumGrahamiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium grahamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGrahamiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrivivaxSpScn71131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax sp. SCN 71-131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxSpScn71131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaBettyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella bettyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaBettyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisLucifugusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myotis lucifugus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyotisLucifugusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraLatinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura latina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraLatinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDiolivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDiolivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SimkaniaNegevensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Simkania negevensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SimkaniaNegevensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariniphagaAnaerophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mariniphaga anaerophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MariniphagaAnaerophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalarsenatibacterSilvermaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halarsenatibacter silvermanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalarsenatibacterSilvermaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterobasidionIrregulareTc321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare TC 32-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HeterobasidionIrregulareTc321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarininemaMesophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marininema mesophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarininemaMesophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaAquimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia aquimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaAquimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaPsittaci10139811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 10139811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci10139811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumGwa24518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_45_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa24518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpW7784Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. W7784 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpW7784Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf236131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF236131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf236131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CardiobacteriumValvarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumValvarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumErythrophleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium erythrophlei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumErythrophleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesAstaci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces astaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AphanomycesAstaci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusSpCag917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumGlutamicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glutamicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlutamicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpOralTaxon414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. oral taxon 414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpOralTaxon414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParaplantarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paraplantarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParaplantarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaLacustrisZ7289Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Z-7289 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaLacustrisZ7289Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumNuruki(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium nuruki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumNuruki", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0262Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0262 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0262Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPiratica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piratica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiratica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumOlb16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium OLB16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumOlb16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerfeziaBoudieriAtccMya4762Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Terfezia boudieri ATCC MYA-4762 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TerfeziaBoudieriAtccMya4762Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulciaMuelleriCari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri CARI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriCari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterAlimentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter alimentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAlimentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfiporiaCocosMd104Ss10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolfiporia cocos MD-104 SS10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolfiporiaCocosMd104Ss10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc4496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC44/96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc4496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilumDsm16684Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum DSM 16684 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilumDsm16684Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShinellaSpGws1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. GWS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpGws1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumUkl132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium UKL13-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumUkl132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraHyodysenteriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hyodysenteriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHyodysenteriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreniaMetallireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orenia metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OreniaMetallireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParadoxumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium paradoxum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumParadoxumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaSgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Sg Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpLeaf191Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf191Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk564Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK564 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk564Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpCit045Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. CIT045 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpCit045Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaWadsworthii9715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii 9715 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaWadsworthii9715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGilvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGilvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAdhaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer adhaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferAdhaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RasamsoniaEmersoniiCbs39364(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii CBS 393.64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RasamsoniaEmersoniiCbs39364", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh7689(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH7689 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh7689", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LodderomycesElongisporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LodderomycesElongisporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaReeseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma reesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaReeseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFuchuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fuchuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFuchuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusCarnicancri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus carnicancri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusCarnicancri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterRhizovicinusDsm16549Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus DSM 16549 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinusDsm16549Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumA2Kyoto(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A2 Kyoto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumA2Kyoto", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytosporaLeucostomaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cytospora leucostoma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CytosporaLeucostomaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanPaniscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pan paniscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PanPaniscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEndophyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas endophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEndophyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSp513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. 5.13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSp513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophothermusSpDtu052Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus sp. DTU052 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusSpDtu052Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrucellaAbortus2308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brucella abortus 2308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrucellaAbortus2308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_37_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriAtcc11577Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri ATCC11577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriAtcc11577Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoproteusUzoniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus uzoniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusUzoniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHtcc2150Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2150 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2150Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterJaachiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter jaachi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaachiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumChlorophenolicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChlorophenolicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimonasCellulosilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylanimonas cellulosilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylanimonasCellulosilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminibacterMediatlanticusTb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus TB-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticusTb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BosIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bos indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BosIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutisporaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutispora thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutisporaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifcsphigho212full4817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO212FULL4817 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho212full4817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCacaonumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCacaonumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidicellaMetallireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidicellaMetallireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceibacterAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceibacter atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceibacterAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusOpacusB4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus B4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusOpacusB4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCaccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAcidivoransNbrc108247Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia acidivorans NBRC 108247 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAcidivoransNbrc108247Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaPolaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPolaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOtitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas otitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOtitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusBaldri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus baldri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrococcusBaldri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspLausannensisLmg23824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lausannensis LMG 23824 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLausannensisLmg23824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSalanitronisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salanitronis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalanitronisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCalviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCalviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudacidovoraxIntermedius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax intermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxIntermedius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OblitimonasAlkaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oblitimonas alkaliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OblitimonasAlkaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumSalinarumNrc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium salinarum NRC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalobacteriumSalinarumNrc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_56_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyi195Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi 195 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyi195Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivirgaCyanobacteriivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivirga cyanobacteriivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivirgaCyanobacteriivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpNdb4y10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. NDB4Y10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpNdb4y10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PopulusAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Populus alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PopulusAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusNakayamae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus nakayamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusNakayamae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpIp16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. IP16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpIp16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaLongibrachiatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpGw103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. GW103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpGw103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomarinaGelatinilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomarina gelatinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomarinaGelatinilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimihaloglobusSulfuriphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limihaloglobus sulfuriphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimihaloglobusSulfuriphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpFth1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. FTH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DehalobacterSpFth1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TigriopusCalifornicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tigriopus californicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TigriopusCalifornicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntamoebaDisparEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba dispar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EntamoebaDisparEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPiezotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella piezotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPiezotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAgglomeratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces agglomeratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAgglomeratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomycesCerevisiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces cerevisiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesCerevisiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCl95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. cl95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCl95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPHIGHO2_01_FULL_65_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenotaleaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenotalea thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenotaleaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUzinuraDiaspidicolaStrAsnerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uzinura diaspidicola str. ASNER Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUzinuraDiaspidicolaStrAsnerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoorellaGlycerini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moorella glycerini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoorellaGlycerini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm23732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaClarridgeiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella clarridgeiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaClarridgeiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopigerSalifodinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopiger salifodinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopigerSalifodinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaStewartiiSubspStewartiiDc283(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii subsp. stewartii DC283 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantoeaStewartiiSubspStewartiiDc283", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterWiegeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter wiegelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterWiegeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPlantarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus plantarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusPlantarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgb11wgaepuloa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGB11WGAEpuloA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgb11wgaepuloa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMoscoviense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum moscoviense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMoscoviense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrothrixParvicella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microthrix parvicella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrothrixParvicella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulciaMuelleriCariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri CARI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriCariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaRhizophilaDc2201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila DC2201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaDc2201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChokoriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chokoriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaChokoriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCaenarcanumBioreactoricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caenarcanum bioreactoricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaenarcanumBioreactoricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioRenipiscarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio renipiscarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioRenipiscarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalimicrobiumCyclicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium cyclicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumCyclicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs836(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs836", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cloacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCloacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaChilensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella chilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaChilensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumZavarziniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium zavarzinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumZavarziniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasArabiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas arabiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasArabiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumOrbiculareMaff240422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare MAFF 240422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculareMaff240422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnolisCarolinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anolis carolinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnolisCarolinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaKunkeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaKunkeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheileriaEquiStrainWaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria equi strain WA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TheileriaEquiStrainWaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasLenta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasLenta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpZor0019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ZOR0019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpZor0019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_49_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterKomagatae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter komagatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterKomagatae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophorhabdusAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophorhabdus aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophorhabdusAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag590Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag590Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesFinegoldiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes finegoldii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesFinegoldiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRbg166422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RBG_16_64_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRbg166422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusGilardiiCr3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii CR3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CupriavidusGilardiiCr3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumCamembertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium camemberti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCamembertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TogniniaMinima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Togninia minima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TogniniaMinima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpYr583Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. YR583 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpYr583Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBingmayongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus bingmayongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusBingmayongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPeregrinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium peregrinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPeregrinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaNorrlandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella norrlandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaNorrlandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathymodiolusAzoricusThioautotrophicGillSymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus thioautotrophic gill symbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BathymodiolusAzoricusThioautotrophicGillSymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaWaksmaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella waksmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWaksmaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaSp2812b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 2812B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp2812b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FabibacterPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsphigho212full4816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO212FULL4816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho212full4816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraAquaemixtaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquaemixtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquaemixtaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelaginellaMoellendorffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selaginella moellendorffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelaginellaMoellendorffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaAlgaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa algae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaAlgaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OstreococcusLucimarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OstreococcusLucimarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioPiezophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio piezophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioPiezophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumThiophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum thiophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumThiophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpTne862Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. TNe-862 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpTne862Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusAutotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioglobusAutotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides insulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesInsulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsplowo201full4327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChauvoeiJf4335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chauvoei JF4335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumChauvoeiJf4335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterJejuniNctc11168(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni NCTC11168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuniNctc11168", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpL2c084a000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. L2C084A000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpL2c084a000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaLitoreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola litoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicolaLitoreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AotusNancymaaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aotus nancymaae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AotusNancymaaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LelliottiaAmnigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lelliottia amnigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LelliottiaAmnigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm44268(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44268", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterJejuniNctc11168Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni NCTC11168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuniNctc11168Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidiaBacterium4341Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium 43-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacterium4341Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantisX(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis X graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisX", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusMirabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteus mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteusMirabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterorhabdusMucosicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus mucosicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusMucosicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolactobacillusTerraeHkm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae HKM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusTerraeHkm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPutrefaciensKs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens KS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensKs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag1004157(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:10041_57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag1004157", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasSpAap120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas sp. AAP120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasSpAap120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UlvibacterSpLpb0005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter sp. LPB0005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UlvibacterSpLpb0005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRedseas12b4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS12B4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas12b4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StachybotrysChlorohalonata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarincolaHl49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola HL49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaHl49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelusAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Struthio camelus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StruthioCamelusAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiosporiumApollinisCbs100218Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis CBS 100218 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ConiosporiumApollinisCbs100218Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVancouverensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vancouverensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVancouverensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivalisW83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis W83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisW83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterCelticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter celticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCelticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCb0101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSibiricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sibiricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSibiricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpDsm11652Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. DSM 11652 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpDsm11652Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg136020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG136020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg136020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRs9917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpC03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsphigho201full4827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4827 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh5701Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 5701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SynechococcusSpWh5701Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaMegapolitanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia megapolitana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMegapolitanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaMorbillorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella morbillorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemellaMorbillorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg10243210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_43_210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg10243210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeophocaenaAsiaeorientalisAsiaeorientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis asiaeorientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalisAsiaeorientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRu33aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU33A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu33aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LarimichthysCroceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Larimichthys crocea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LarimichthysCroceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusFulvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MyxococcusFulvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1999Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1999 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1999Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacterium13220cm2628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium 13_2_20CM_2_62_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacterium13220cm2628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumCaspalpha2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumGa0077560Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium Ga0077560 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumGa0077560Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpNc3005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc3005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumRosaNbrc15208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium rosa NBRC 15208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumRosaNbrc15208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCryaerophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cryaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCryaerophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasBoliviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas boliviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasBoliviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBnl1100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BNL1100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBnl1100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudodonghicolaXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudodonghicola xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudodonghicolaXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaSp6041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moorella sp. 60_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoorellaSp6041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaHelgolandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia helgolandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaHelgolandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParainfluenzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parainfluenzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusParainfluenzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSpHmsc063g07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. HMSC063G07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpHmsc063g07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesArizonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycomycesArizonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumGwe25113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium GWE2_51_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumGwe25113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpSgdv85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. SGDV85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpSgdv85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSpL2l1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. L2L1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpL2l1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSenmaizukei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpAe3005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. AE3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpAe3005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedMegasphaeraSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Megasphaera sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedMegasphaeraSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomicrobialesBacteriumKi4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobiales bacterium KI4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermomicrobialesBacteriumKi4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaMicrofusus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rikenella microfusus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RikenellaMicrofusus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumNordicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nordicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNordicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetalesBacteriumSpiro07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureocirculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureocirculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureocirculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1416 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHel13349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel13349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolaribacterSpHel13349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichechusManatusLatirostrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus latirostris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichechusManatusLatirostrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumRm5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium RM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumRm5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferSpWsm1721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. WSM1721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpWsm1721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifcsplowo212full3511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPLOWO212FULL3511 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsplowo212full3511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp303mfcol52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 303MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp303mfcol52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansAtcc27774Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ATCC27774 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansAtcc27774Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScleropagesFormosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scleropages formosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScleropagesFormosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWb2n11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Wb2n-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWb2n11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSp22ii122f38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 22II122F38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp22ii122f38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaTyphiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaAgriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella agri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaAgriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaStercoreaCag629(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea CAG:629 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaStercoreaCag629", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp2a57ct2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 2A57CT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSp2a57ct2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaBuccalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia buccalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaBuccalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HodgkiniaCicadicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hodgkinia cicadicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HodgkiniaCicadicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsplowo201full5118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO201FULL5118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo201full5118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpAg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumElkaniiUsda76Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii USDA76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiUsda76Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosarcinaSpBus5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosarcina sp. BuS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosarcinaSpBus5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumDesmolansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium desmolans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDesmolansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenariaAnguillulaePl171Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Catenaria anguillulae PL171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CatenariaAnguillulaePl171Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RothiaNasimuriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rothia nasimurium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RothiaNasimuriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpRedseas34b3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. REDSEAS34B3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpRedseas34b3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacterSpBrhc7aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacter sp. BRHc7a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacterSpBrhc7aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CallipeplaSquamata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Callipepla squamata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CallipeplaSquamata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaSpMxaz02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidocella sp. MXAZ02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidocellaSpMxaz02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaSaliphilaYim90502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila YIM 90502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphilaYim90502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpR372017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37(2017) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpR372017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumEstertheticumSubspEstertheticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium estertheticum subsp. estertheticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumEstertheticumSubspEstertheticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterobasidionIrregulareTc321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare TC 32-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HeterobasidionIrregulareTc321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSp831bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 831b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp831bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusEnclensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus enclensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEnclensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterOryzifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter oryzifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOryzifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterVinelandiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter vinelandii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzotobacterVinelandiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSpSb3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. SB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpSb3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPHIGHO2_12_FULL_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichantheliumOligosanthesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dichanthelium oligosanthes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DichantheliumOligosanthesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyberlindneraJadinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraJadinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpA23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. A23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpA23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumOxalicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium oxalicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumOxalicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterButzleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter butzleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterButzleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaStercorariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla stercoraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaStercorariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpLeaf394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusCapsularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corchorus capsularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorchorusCapsularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumSpJ07hqx50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum sp. J07HQX50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumSpJ07hqx50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCircumdentariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas circumdentaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCircumdentariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpNfacc26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. NFACC26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpNfacc26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeinonellaPeptonophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Seinonella peptonophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SeinonellaPeptonophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium13140cm6517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_65_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutibacterProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutibacterProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlectensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flectens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFlectensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23066(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23066 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23066", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilomicrobiumInsigneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Filomicrobium insigne Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FilomicrobiumInsigneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChinchillaLanigeraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chinchilla lanigera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChinchillaLanigeraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaceaeBacteriumHl53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarinaceae bacterium HL-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaceaeBacteriumHl53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGa0077554Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077554Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumCg1026336(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_63_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1026336", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterNyackensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter nyackensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterNyackensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumHalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumHalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaBatsensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola batsensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanicolaBatsensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocoliticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaEnterocoliticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCollagenovoransDsm3089Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans DSM 3089 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCollagenovoransDsm3089Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFaecisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFaecisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesCardiffensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces cardiffensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesCardiffensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpA12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. A12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpA12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UncinocarpusReesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UncinocarpusReesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSaprophyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus saprophyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSaprophyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolitaleaCanadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solitalea canadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolitaleaCanadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaEpimycesCbs60696Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces CBS 606.96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaproniaEpimycesCbs60696Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpQhl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. QHL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpQhl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpMl96Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ML96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMl96Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaAlni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia alni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaAlni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminiphilusCircumscriptusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminiphilus circumscriptus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminiphilusCircumscriptusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAurantifolia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma aurantifolia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAurantifolia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenansDsm11527Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans DSM 11527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenansDsm11527Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloactinosynnemaSpL07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema sp. L-07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaSpL07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HebelomaCylindrosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HebelomaCylindrosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRit328Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. RIT328 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRit328Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDentalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaElongata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaElongata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaMoutnovskiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta moutnovskia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaMoutnovskiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpNies3756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. NIES-3756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocSpNies3756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3742Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3742 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3742Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaSingaporensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha singaporensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaSingaporensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyunsoonleellaJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyunsoonleella jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyunsoonleellaJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSputorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sputorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSputorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaMatsumotoense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora matsumotoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMatsumotoense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParabrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabrevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusIniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus iniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasSpCnpt3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas sp. CNPT3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromonasSpCnpt3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpFsw0699(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. FSW06-99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFsw0699", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumIncanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum incanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumIncanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarumDsm19842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum DSM 19842 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PontibacterActiniarumDsm19842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwf24212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWF2_42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwf24212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterAcetatoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter acetatoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterAcetatoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfospiraJoergenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfospira joergensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfospiraJoergenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyriculariaOryzae7015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyricularia oryzae 70-15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyriculariaOryzae7015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGa0077543Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077543 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077543Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo212full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO212FULL4712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo212full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUnc358mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC358MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc358mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAtrophaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus atrophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAtrophaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistalesBacterium5424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 54_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_12_FULL_44_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaProfusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella profusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProfusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MiscellaneousCrenarchaeotaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeotaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveraIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KluyveraIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSp638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. 638 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSp638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumJeikeium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeikeium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeikeium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasPratensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas pratensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasPratensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUrmo17wk12i8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URMO17WK12I8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpUrmo17wk12i8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCoubleaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia coubleae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaCoubleaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesChelonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides chelonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesChelonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpD16r12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16R12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16r12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasEuvesicatoriaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas euvesicatoria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasEuvesicatoriaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCylindrosporumDsm605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum DSM 605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporumDsm605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeeksellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weeksella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeeksellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumKishitanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium kishitanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumKishitanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSalifodinaeDsm8989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus salifodinae DSM 8989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalococcusSalifodinaeDsm8989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4513Fw928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4513 (FW-928) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4513Fw928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumAmmoniigenesNbrc101786Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes NBRC 101786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenesNbrc101786Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UreibacillusThermosphaericus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ureibacillus thermosphaericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UreibacillusThermosphaericus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpPamc28756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. PAMC 28756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpPamc28756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpAc23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. AC-23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpAc23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusGlucosetrophusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus glucosetrophus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylovorusGlucosetrophusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorangiumCellulosumSo01572(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So01572 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSo01572", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ByssochlamysSpectabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Byssochlamys spectabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ByssochlamysSpectabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HabropodaLaboriosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Habropoda laboriosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HabropodaLaboriosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusAsaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaOralTaxonTm7xEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria oral taxon TM7x Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaOralTaxonTm7xEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicatellaElegansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaElegansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaProfunda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga profunda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaProfunda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTriplexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium triplex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTriplexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumHum9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAlgidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus algidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlgidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IctidomysTridecemlineatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ictidomys tridecemlineatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IctidomysTridecemlineatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Valsa mali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ValsaMaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSp348mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. 348MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSp348mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeliobacteriumModesticaldum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heliobacterium modesticaldum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeliobacteriumModesticaldum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa15613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA15613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa15613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DonghicolaEburneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Donghicola eburneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DonghicolaEburneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCorienseDsm10284(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum coriense DSM 10284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCorienseDsm10284", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDurusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus durus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDurusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCelluloflavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces celluloflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCelluloflavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPunctiformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc punctiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocPunctiformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSenmaizukeiDsm21775Nbrc103853Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei DSM 21775 NBRC 103853 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukeiDsm21775Nbrc103853Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPyruviciproducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pyruviciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPyruviciproducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAlniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGillisiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gillisiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGillisiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCt34Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CT34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCt34Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpLshc420b00(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSHC420B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLshc420b00", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpLc238Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. LC238 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLc238Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParauberisKctc11537Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis KCTC11537 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisKctc11537Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaportheAmpelinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe ampelina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiaportheAmpelinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumRimaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium rimae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumRimaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDownei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus downei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDownei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus garvieae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusGarvieae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumTestaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium testaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTestaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumL41aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium L41A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumL41aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteocatellaSphenisci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteocatella sphenisci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteocatellaSphenisci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPedisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema pedis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPedisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJidaibacterAcanthamoeba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jidaibacter acanthamoeba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJidaibacterAcanthamoeba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaParisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Paris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaParisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterMetallireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterMetallireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioPaciniiDsm19139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio pacinii DSM 19139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioPaciniiDsm19139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4461(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4461", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp142mfcol31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 142MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp142mfcol31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusSpOk028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumRifcsplowo201full4825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4825 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpicheriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus spicheri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpicheriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaEiseniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaEiseniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasSpHmsc077f02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC077F02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc077f02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterLappiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter lappiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterLappiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedButyricicoccusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Butyricicoccus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedButyricicoccusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc9022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC9022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc9022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YaniellaHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yaniella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YaniellaHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaGracilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospinaGracilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidiumTenue(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidium tenue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidiumTenue", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpAm1d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. AM1D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpAm1d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpHk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. HK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpHk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumWieringae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium wieringae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWieringae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusLaterosporusDsm25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus DSM25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusDsm25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaRiguiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma rigui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRiguiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycisphaeraMikurensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaera mikurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraMikurensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumSpF0372Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium sp. F0372 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumSpF0372Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalibacteriumHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_01_FULL_33_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCoprophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSp3363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. 3363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalothrixSp3363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaphniaPulexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daphnia pulex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaphniaPulexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParacollinoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracollinoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacollinoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwb26322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPyridomyceticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pyridomyceticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPyridomyceticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheobromaCacaoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theobroma cacao Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheobromaCacaoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDakarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dakarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusDakarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumCg1024737(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium CG1_02_47_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumCg1024737", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCoprococcusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Coprococcus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedCoprococcusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonMixed(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixed", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusSpCag782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus sp. CAG:782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprococcusSpCag782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoculleusBourgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusBourgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumHydrothermaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSpG11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpG11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSp12014mblmicdiv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. 12014MBLMicDiv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSp12014mblmicdiv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGa0074134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0074134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0074134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaSpDt234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. DT234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSpDt234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KoribacterVersatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Koribacter versatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KoribacterVersatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannospalaxGaliliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nannospalax galili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NannospalaxGaliliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiO157h7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusColihominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus colihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusColihominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalobiumEvestigatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PicrophilusTorridusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Picrophilus torridus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PicrophilusTorridusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaSpOk004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella sp. OK004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaSpOk004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhocaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phocae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhocaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicatellaAdiacens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella adiacens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaAdiacens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StomatobaculumLongumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stomatobaculum longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StomatobaculumLongumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisMaydis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris maydis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BipolarisMaydis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpTolm(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. TolM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpTolm", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLnjc398b00Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNJC398B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnjc398b00Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerotiniaSclerotiorum1980Uf70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum 1980 UF-70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorum1980Uf70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcetothermiaBacteriumJdfr48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMacacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMacacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfDrosophilaMelanogasterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila melanogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaMelanogasterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LechevalieriaXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusLactarisCc59002dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris CC59_002D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusLactarisCc59002dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeoalkalibacterFerrihydriticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter ferrihydriticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterFerrihydriticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxNanhaiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxNanhaiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpMc2021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasSenticiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas senticii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimonasSenticiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAkariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia akari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAkariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzohydromonasAustralicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azohydromonas australica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzohydromonasAustralicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaQueenslandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaQueenslandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpTd01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. TD01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpTd01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaPalustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaPalustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TermitomycesSpJ132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Termitomyces sp. J132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TermitomycesSpJ132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusDingoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus dingo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CanisLupusDingoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumZeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumZeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalioglobusPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalioglobusPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTropicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTropicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusAmericanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ursus americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrsusAmericanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChthoniobacterFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chthoniobacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChthoniobacterFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumIslandicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum islandicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumIslandicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeTagetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tagetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTagetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaDiobovataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula diobovata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaDiobovataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusEndophyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusEndophyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpSoil805(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil805 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil805", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf391Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf391 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf391Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kurthia senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KurthiaSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumJeddahense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeddahense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeddahense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCg2303166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_31_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaLascolaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella lascolaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaLascolaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhasianusColchicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phasianus colchicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhasianusColchicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaPhocaeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella phocaeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaPhocaeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscibacillusSalipiscariusJcm13188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius JCM 13188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscariusJcm13188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiPcNhvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PC NHV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPcNhvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurobacteriumIndicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumIndicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolaminaSpCba1230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sp. CBA1230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSpCba1230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BipolarisOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumHassiacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium hassiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHassiacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FonsecaeaErectaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea erecta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaErectaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpGd7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. GD7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpGd7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpP6w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. P6W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpP6w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpHun102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HUN102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHun102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioStylochi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio stylochi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioStylochi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaInopinataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scardovia inopinata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScardoviaInopinataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusWCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusWCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAlkalitellurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alkalitelluris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAlkalitellurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaYeatsiiGm274bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii GM274B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaYeatsiiGm274bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EikenellaCorrodensAtcc23834(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens ATCC23834 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EikenellaCorrodensAtcc23834", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisMusacearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris musacearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisMusacearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFallonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella fallonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaFallonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FermentimonasCaenicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fermentimonas caenicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FermentimonasCaenicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb14412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB14412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb14412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumFuchskuhlenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium fuchskuhlense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumFuchskuhlenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0429 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusWarneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus warneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusWarneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMmg1533(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1533", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpPamc22219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. PAMC22219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpPamc22219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariprofundusMicoguttaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus micogutta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MariprofundusMicoguttaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFOXYA2_FULL_38_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoolittleaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doolittlea endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoolittleaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCaballiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus caballi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCaballiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumBrhc20aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium BRHc20a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumBrhc20aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidomycesRichmondensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidomycesRichmondensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlantibacterFlavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter flavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlantibacterFlavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPhaeoluteigriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces phaeoluteigriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPhaeoluteigriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropithecusCoquereliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propithecus coquereli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropithecusCoquereliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumCg1024134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1024134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1024134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoraliomargaritaSpCag312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita sp. CAG:312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaSpCag312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full4719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL4719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full4719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasEnteropelogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas enteropelogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasEnteropelogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOryziterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oryziterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusOryziterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_12_FULL_46_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaHeveanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KwoniellaHeveanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSalifodinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus salifodinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusSalifodinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAap43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AAP43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAap43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizophyllumCommuneH48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune H4-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchizophyllumCommuneH48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaIowaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma iowae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaIowaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusFasciansD188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians D188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansD188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonasAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp15544247Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1554424.7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp15544247Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixBouteilleiVb521301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei VB521301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TolypothrixBouteilleiVb521301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiaciniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niacini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusNiaciniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oulorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOulorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RunellaLimosaDsm17973Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Runella limosa DSM 17973 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RunellaLimosaDsm17973Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLeaf155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacterium5254faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 5254FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium5254faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd2004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD2004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd2004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JejuiaPallidilutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jejuia pallidilutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JejuiaPallidilutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAcidisoliDsm12555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidisoli DSM 12555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcidisoliDsm12555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioPutealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPutealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophusFodinaeScgcAaa011A17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophus fodinae SCGC AAA011-A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophusFodinaeScgcAaa011A17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaXenovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia xenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaXenovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusGrossensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus grossensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusGrossensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaNamhaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olleya namhaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlleyaNamhaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumGalatiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium galatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumGalatiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPneumoniaeLpcolnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae LPCoLN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniaeLpcolnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag253(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:253 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag253", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InediibacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Inediibacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "InediibacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumBergheiAnkaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei ANKA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumBergheiAnkaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasaccharibacterApiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parasaccharibacter apium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParasaccharibacterApiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAurantiacumDsm6208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum DSM 6208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacumDsm6208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHerbarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus herbarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHerbarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpIng2d1g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ING2D1G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpIng2d1g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NelumboNuciferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nelumbo nucifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NelumboNuciferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCoatesbacteriaBacteriumRbg136614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Coatesbacteria bacterium RBG_13_66_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCoatesbacteriaBacteriumRbg136614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiigatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niigatensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiigatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthiaAtcc49260Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia ATCC49260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthiaAtcc49260Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MillerozymaFarinosaCbs7064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Millerozyma farinosa CBS 7064 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MillerozymaFarinosaCbs7064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetariaItalicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Setaria italica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SetariaItalicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumAquaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumAquaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPollutisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pollutisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPollutisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProfftellaArmaturaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Profftella armatura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProfftellaArmaturaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktomarinaTemperataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktomarina temperata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktomarinaTemperataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumSpScn7031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 70-31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn7031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCoprostanoligenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium coprostanoligenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCoprostanoligenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusHunanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus hunanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHunanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitoleransNbrc108937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans NBRC 108937 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAmikacinitoleransNbrc108937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnormaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enorma massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnormaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag274Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:274 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag274Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeRhinoscleromatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae rhinoscleromatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeRhinoscleromatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocodylusPorosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crocodylus porosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrocodylusPorosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusSolfataricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus solfataricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfolobusSolfataricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAmel2xe9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Amel2xE9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAmel2xe9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaToletanaDappPg735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia toletana DAPP-PG 735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErwiniaToletanaDappPg735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGa0077527(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077527", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHammesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHammesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLongwoodensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces longwoodensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLongwoodensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2479 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetomicrobiumHydrogeniformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium hydrogeniformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumHydrogeniformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaThermoaceticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moorella thermoacetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoorellaThermoaceticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSparsogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sparsogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSparsogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpNml130628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML130628 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml130628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaToletanaDappPg735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia toletana DAPP-PG 735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErwiniaToletanaDappPg735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaLijiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaLijiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyd1full4619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYD1FULL4619 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyd1full4619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaSpVcsm12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSM12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OlleyaSpVcsm12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorAustralicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloramator australicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloramatorAustralicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeefgeaRivuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deefgea rivuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeefgeaRivuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpEjy3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. EJY3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEjy3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumOceanosedimentum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium oceanosedimentum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumOceanosedimentum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalotoleransDsm16375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans DSM 16375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinococcusHalotoleransDsm16375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYC12_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalneolaVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Balneola vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BalneolaVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavidovirens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavidovirens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavidovirens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCoronafaciensPvPorriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens pv. porri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciensPvPorriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumM11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterPersicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter persicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPersicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumAurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium aurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpR1ns10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. R1NS10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpR1ns10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidibacillusDecaturensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacillus decaturensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidibacillusDecaturensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMediterraneensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMediterraneensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BubalusBubalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bubalus bubalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BubalusBubalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusDora7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus DORA7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusDora7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpEhn04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. EhN04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpEhn04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaMultimorphosaCbs102226(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa CBS 102226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosaCbs102226", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClostridioforme2149faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme 2149FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioforme2149faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriovoraxMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCasei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCasei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpRlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpRlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusArcularius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polyporus arcularius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolyporusArcularius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAmycolatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium amycolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAmycolatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpPf153Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Pf153 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPf153Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumArgentinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium argentinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArgentinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisNigrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisNigrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusShizuokensisNbrc103103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis NBRC 103103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensisNbrc103103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusThermoamylovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus thermoamylovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusThermoamylovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterBaekdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter baekdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterBaekdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAnticariensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas anticariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasAnticariensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariibacterSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aestuariibacter salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AestuariibacterSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_12_FULL_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterOboediensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterOboediensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpOk605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OK605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOk605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaGuanche(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila guanche graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGuanche", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumHum1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumAlcaliphilum20zEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum 20Z Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilum20zEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasArsenitoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas arsenitoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomonasArsenitoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosimicrobiumFunkeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium funkei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumFunkeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpJcbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. JCB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpJcbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaLanzarotensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachancea lanzarotensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachanceaLanzarotensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaUreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina ureae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaUreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf267Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf267 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf267Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumSpEnrichmentCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichmentCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeersiaPerrieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leersia perrieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeersiaPerrieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LinderinaPennisporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Linderina pennispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LinderinaPennisporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumS85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium S85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumS85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_42_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumPavilionensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium pavilionensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumPavilionensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOryzisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvularculaOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpAt1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. AT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAt1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FangiaHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fangia hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FangiaHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFumigatusAf293Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Af293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusFumigatusAf293Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisColoradensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis coloradensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisColoradensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusPropionicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus propionicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelosinusPropionicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusEhimensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusEhimensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPluripotensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pluripotens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPluripotensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaHypogeiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia hypogeia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHypogeiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtelocyanobacteriumThalassaIsolateAlohaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atelocyanobacterium thalassa isolate ALOHA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtelocyanobacteriumThalassaIsolateAlohaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFrederiksbergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas frederiksbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFrederiksbergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumLychnidisdioicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum lychnidisdioicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisdioicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocaldumSzegedienseO12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense O-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylocaldumSzegedienseO12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcmicro4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PunicaGranatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Punica granatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PunicaGranatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DracunculusMedinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dracunculus medinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DracunculusMedinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumXpb1003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XPB1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXpb1003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYC2_FULL_39_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSpAl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. AL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpAl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisFribergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis fribergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisFribergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterFormicigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidibacterFormicigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaMuridarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia muridarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaMuridarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumFoliorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium foliorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumFoliorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OttowiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ottowia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OttowiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacteriumCsp16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium CSP1-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumCsp16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMultivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia multivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaMultivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLc145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LC145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLc145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpKjjCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KJJ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKjjCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpKh2c16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. KH2C16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh2c16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag302Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:302 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag302Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusYoungiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus youngiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusYoungiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full5314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL5314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full5314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_36_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpUcdgkaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UCDGKA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUcdgkaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalioglobusJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalioglobusJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpUnc345mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. UNC345MFTsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUnc345mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesEggerthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides eggerthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesEggerthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumArborisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium arboris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumArborisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Bacterium2013arg42i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Arg42i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013arg42i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_33_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSpT436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. T436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpT436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIhuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIhuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisAtcc35310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis ATCC35310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisAtcc35310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSpAntb6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sp. ANTB6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSpAntb6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTaa486(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa486", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospirillumFerriphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalviaSplendensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salvia splendens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalviaSplendensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRoot1497(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root1497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot1497", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasPratensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasPratensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUrinalisFb127cna2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis FB127CNA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalisFb127cna2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumMultihospitiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium multihospitium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMultihospitiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSaccharovorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum saccharovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSaccharovorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassiosiraOceanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thalassiosira oceanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThalassiosiraOceanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirschiaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hirschia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HirschiaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpNdb2meth1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. NDB2Meth1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpNdb2meth1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisIgneusKol5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris igneus Kol 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisIgneusKol5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerminiimonasArsenicoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenicoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenicoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumRosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium rosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumRosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumKnowlesiStrainH(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi strain H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesiStrainH", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumKhcpx20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KHCPX20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKhcpx20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSp19m6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 19m6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp19m6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariibacterSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aestuariibacter salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AestuariibacterSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpDd12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. DD12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShinellaSpDd12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGr602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GR 6-02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGr602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaFungorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia fungorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFungorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDelongbacteriaBacteriumGwf24014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Delongbacteria bacterium GWF2_40_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDelongbacteriaBacteriumGwf24014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesChristyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles christyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesChristyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpNrrlb16348(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16348", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusScapharcaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus scapharcae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusScapharcaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHeli29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. HelI29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GillisiaSpHeli29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumGw2011gwf23915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium GW2011GWF23915 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumGw2011gwf23915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumCanariasenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium canariasense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCanariasenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemolamaeStrPurdueCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemolamae str. Purdue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemolamaeStrPurdueCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaCitreaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora citrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCitreaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloscardoviaMacacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaMacacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusPhoceensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus phoceensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprococcusPhoceensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpCc6yy74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CC6YY74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCc6yy74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararheinheimeraTexasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110053(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110053", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHaemophilumDsm44634Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum DSM 44634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilumDsm44634Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KurthiaSpDielmoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. Dielmo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KurthiaSpDielmoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpNbs1129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NBS 11-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNbs1129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMucilaginosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp17376(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 17376 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSp17376", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesAbscessus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesAbscessus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaGingivalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga gingivalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGingivalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterOskolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter oskolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RathayibacterOskolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasRhizophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas rhizophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasRhizophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AciduliprofundumBooneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum boonei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumBooneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporisoriumScitamineumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporisorium scitamineum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporisoriumScitamineumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumElephantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium elephantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumElephantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumSubspPolymorphum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. polymorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspPolymorphum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Belnapia rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BelnapiaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf238335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_38_335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf238335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiumSpBvorr034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusChungwhensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus chungwhensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacillusChungwhensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCacaonumDsm21116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum DSM 21116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCacaonumDsm21116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpRtaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. RTa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterSpRtaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTyphaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus typhae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTyphaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusHydrogenoformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus hydrogenoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusHydrogenoformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd2004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd2004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusIhumiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihumii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhumiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedosphaeraParvula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedosphaera parvula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedosphaeraParvula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusSpYb142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sp. YB14-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSpYb142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSiligurienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium siliguriense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSiligurienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterIcosiumassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter icosiumassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterIcosiumassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersephonellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Persephonella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PersephonellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonasAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StoquefichusSpSb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. SB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpSb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParainfluenzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parainfluenzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusParainfluenzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTimonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTimonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesCryophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaMarinaDsm45152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella marina DSM 45152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SciscionellaMarinaDsm45152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpUrhd0057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. URHD0057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUrhd0057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeratocystisFimbriataCbs114723(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata CBS 114723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CeratocystisFimbriataCbs114723", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterDokdonensisDsw5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis DSW-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolaribacterDokdonensisDsw5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusChampanellensis18p13Jcm17042(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis 18P13 JCM 17042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusChampanellensis18p13Jcm17042", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumNamibiaeCbs14797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae CBS 147.97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumNamibiaeCbs14797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo202full6128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LihuaxuellaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lihuaxuella thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LihuaxuellaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesQuadriannulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles quadriannulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesQuadriannulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpD5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. D5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpD5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_56_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaMegalochromosomataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia megalochromosomata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaMegalochromosomataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisSpAtcc49242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. ATCC49242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpAtcc49242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full3928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL3928 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full3928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_37_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAtrophaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus atrophaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAtrophaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumCg2304320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2304320 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2304320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSubvibrioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas subvibrioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSubvibrioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumTibetenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum tibetense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTibetenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDaliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus daliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusDaliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaeBacteriumRifcsplowo2123915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospinae bacterium RIFCSPLOWO2_12_39_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospinaeBacteriumRifcsplowo2123915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusMaritimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMaritimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioHungateiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio hungatei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioHungateiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumMs0242aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS0242A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0242aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpPcc7105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 7105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaDasanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moritella dasanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoritellaDasanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpNdb2meth4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. NDB2Meth4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpNdb2meth4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaThermarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga thermarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermotogaThermarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedMegasphaeraSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Megasphaera sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedMegasphaeraSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaArthritidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arthritidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArthritidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpPcc9228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 9228 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc9228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrospiraNitrosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus lacustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusLacustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaSpMy04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. MY04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpMy04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpMarseillep3201tEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. MarseilleP3201T Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpMarseillep3201tEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocodylusPorosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crocodylus porosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrocodylusPorosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacteriumUrhd0017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumHch1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium HCH-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumHch1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpDdh964Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. DDH964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpDdh964Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRifcsplowo201full4314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPLOWO201FULL4314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsplowo201full4314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSpP610x1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. P610X1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpP610x1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacacaMulattaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macaca mulatta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacacaMulattaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilimonasTropica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilimonas tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilimonasTropica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterRoseosalivarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeOfficinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae officinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOfficinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMcba15001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensSpYik11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. YIK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpYik11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumHalophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHalophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzonexusHydrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azonexus hydrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzonexusHydrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevrieseaAgamarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devriesea agamarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevrieseaAgamarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycetalesBacteriumActino02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumMultiglobuliferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum multiglobuliferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMultiglobuliferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSulphureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sulphureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSulphureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypsizygusMarmoreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hypsizygus marmoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HypsizygusMarmoreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusFructosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus fructosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFructosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpLeaf51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofastidiosumMethylthiophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanofastidiosum methylthiophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanofastidiosumMethylthiophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplocarponRosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diplocarpon rosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiplocarponRosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaGeojedonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivita geojedonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivitaGeojedonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzobacteroidesPseudotrichonymphae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azobacteroides pseudotrichonymphae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzobacteroidesPseudotrichonymphae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasFuttsuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas futtsuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimonasFuttsuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagneticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharoperbutylacetonicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharoperbutylacetonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharoperbutylacetonicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPseudoalcaligenesAd6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes AD6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesAd6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaZhangzhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordia zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiaZhangzhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumSp1910b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum sp. 1910b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermofilumSp1910b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifcsphigho201full4610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaAdelaidensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella adelaidensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaAdelaidensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaAlniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia alni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaAlniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KalmanozymaBrasiliensisGhg001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis GHG001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensisGhg001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaSeiffertiiAtcc49495(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii ATCC 49495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertiiAtcc49495", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium RIFCSPHIGHO2_12_FULL_53_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilusLmg18311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMG18311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmg18311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliagarivoransMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumSphagniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sphagni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSphagniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudozymaBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxSp19m6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 19m6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp19m6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteriumSp457220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium sp. 4572_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumSp457220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasSpOralTaxon110StrF0139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. oral taxon 110 str. F0139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParvimonasSpOralTaxon110StrF0139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwb1397Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1397 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1397Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlenkiaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klenkia soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlenkiaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusAeolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus aeolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusAeolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6258Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6258Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloactinosynnemaAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUrhc0008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHC0008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrhc0008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusSpRedseaS12B1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus sp. REDSEA-S12_B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSpRedseaS12B1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesBurtoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesBurtoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraOligosporaAtcc43269Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura oligospora ATCC 43269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraOligosporaAtcc43269Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhocaeicolaAbscessusCcug55929(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus CCUG 55929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessusCcug55929", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisCinereaT4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea T4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaT4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNeoehrlichiaLotorisStrRac413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Neoehrlichia lotoris str. RAC413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNeoehrlichiaLotorisStrRac413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSuebicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus suebicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSuebicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynesporaCassiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaAvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaAvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho201full4120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO201FULL4120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho201full4120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionispiraArboris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionispira arboris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionispiraArboris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDsm4029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DSM 4029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDsm4029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa23217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_32_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa23217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpP22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HypoxylonSpCo275(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CO27-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCo275", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaPiezophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga piezophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinitogaPiezophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_43_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerminiimonasArsenitoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenitoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenitoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusNecator(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus necator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNecator", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumExBugulaNeritinaAb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium (ex Bugula neritina AB1) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumExBugulaNeritinaAb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusAsaccharolyticusDsm20463Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus DSM 20463 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticusDsm20463Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LynxCanadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lynx canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LynxCanadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveraCryocrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera cryocrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KluyveraCryocrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAmazonitimonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amazonitimonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmazonitimonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumVignae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium vignae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumVignae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpMarseilleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. Marseille Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpMarseilleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5323 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraOligosporaAtcc43269Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura oligospora ATCC 43269 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraOligosporaAtcc43269Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_37_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinalesArchaeonMethan01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Methan_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeonMethan01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hr67Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr67Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FischerellaSpPcc9605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaMannitolilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia mannitolilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaMannitolilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusViretiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vireti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusViretiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumWalsbyiJ07hqw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioDiazotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio diazotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioDiazotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUnc358mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC358MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc358mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaHubeiensisSy62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis SY62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudozymaHubeiensisSy62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesF0058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes F0058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesF0058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0472Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0472Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumGallicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium gallicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGallicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYokosukanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yokosukanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYokosukanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsiiBen74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Ben 74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsiiBen74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosediminibacterOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosediminibacter oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosediminibacterOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBrantaeDsm23927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brantae DSM 23927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrantaeDsm23927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaRubidaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia rubidaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaRubidaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RudaeaCellulosilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rudaea cellulosilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RudaeaCellulosilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropilaelapsMercedesaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tropilaelaps mercedesae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TropilaelapsMercedesaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpEhn04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. EhN04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpEhn04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPstaah124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PsTaAH124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpPstaah124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrozanskiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella drozanskii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrozanskiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGwa26437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWA2_64_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwa26437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaReeseiQm6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei QM6a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaReeseiQm6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfatatorAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraPhenolivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera phenolivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraPhenolivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasOryziterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas oryziterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasOryziterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusGarvieaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAutolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces autolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAutolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSpMai1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. MAI-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpMai1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKorlensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus korlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusKorlensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimimaricolaHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifoxyd1Full3927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFOXYD1_FULL_39_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifoxyd1Full3927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FenollariaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fenollaria timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FenollariaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_63_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpBv3p1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BV3P1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBv3p1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaAgarilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lewinella agarilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LewinellaAgarilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaNbrc14164(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida NBRC14164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaNbrc14164", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterNectaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nectaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNectaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpBcu110501Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BCU110501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBcu110501Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaSp90Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. 90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSp90Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpBv1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. BV1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpBv1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFulvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fulva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFulvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaAmazonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella amazonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAmazonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpPrwf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PRwf1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPrwf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaForsetiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella forsetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaForsetiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisLiminatansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis liminatans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanofollisLiminatansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaSpJt01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. JT01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpJt01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipiger thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipigerThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpBvorr034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalypteAnnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calypte anna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalypteAnnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpOv259Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV259 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv259Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumMetalliduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium metallidurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumMetalliduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwel(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWEL graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwel", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanomassiliicoccusIntestinalisIssoireMx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomassiliicoccusIntestinalisIssoireMx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerracoccusSp273mftsu31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Terracoccus sp. 273MFTsu31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TerracoccusSp273mftsu31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSimiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas simiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSimiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianusIfo328301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus IFO328301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianusIfo328301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDentalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum3841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 3841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum3841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LibanicoccusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Libanicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LibanicoccusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaOtitidisNbrc100426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gordonia otitidis NBRC 100426 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GordoniaOtitidisNbrc100426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRenale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium renale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRenale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumAbikonenseNbrc16140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium abikonense NBRC 16140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumAbikonenseNbrc16140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwe14915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE14915 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe14915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusLactarisCc59002d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris CC59_002D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusLactarisCc59002d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaRocourtiaeFslF6920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria rocourtiae FSL F6-920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaRocourtiaeFslF6920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumOncopeltiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium oncopeltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumOncopeltiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDowneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus downei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDowneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumCg1023251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_32_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1023251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CongregibacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Congregibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CongregibacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumDicentrarchi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum dicentrarchi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumDicentrarchi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumLindaniclasticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lindaniclasticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLindaniclasticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_48_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusF0211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus F0211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusF0211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4113bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4113b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4113bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsplowo201full4813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPLOWO201FULL4813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsplowo201full4813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusArciformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus arciformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusArciformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPinetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pineti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPinetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaTyphiStrB9991cwppCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi str. B9991CWPP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTyphiStrB9991cwppCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInterrogans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira interrogans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInterrogans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpKim(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. KIM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpKim", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full487Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL487 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full487Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaOligosperma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala oligosperma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaOligosperma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovigenitaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovigenitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovigenitaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpB6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. B6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpB6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPullorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPullorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumKocuriiJcm14978Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum kocurii JCM 14978 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumKocuriiJcm14978Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSp43bgom46mCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 43BGOM46m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp43bgom46mCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseorubiginosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseorubiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseorubiginosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterHeylii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heylii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeylii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpCzuam(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CZUAM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCzuam", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloropiconPrimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloropicon primus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloropiconPrimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogemmatisporaOnikobensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora onikobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaOnikobensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusSpJf8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. JF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpJf8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumCg2304152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium CG2_30_41_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumCg2304152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa25646Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_56_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25646Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumGranulosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium granulosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumGranulosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaligenesNbrc14159(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes NBRC14159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenesNbrc14159", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBizertensisDsm18034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis DSM 18034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensisDsm18034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaDenticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema denticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaDenticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriiaBacteriumRifoxyc2full3518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriia bacterium RIFOXYC2FULL3518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriiaBacteriumRifoxyc2full3518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPbh53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PBH53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPbh53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasMariniglutinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas mariniglutinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasMariniglutinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaOtitidisNbrc100426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia otitidis NBRC 100426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GordoniaOtitidisNbrc100426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSucicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSucicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaMarinaDsm45152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella marina DSM 45152 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SciscionellaMarinaDsm45152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumSpMj126nf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium sp. MJ126NF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumSpMj126nf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolineaTardaNobi1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanolinea tarda NOBI-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanolineaTardaNobi1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAmylolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amylolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmylolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumDakarense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium dakarense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDakarense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusIgniterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus igniterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusIgniterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodothermusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodothermusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomarinumVadi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomarinum vadi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomarinumVadi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloquadratumWalsbyiJ07hqw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSp73b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. 73B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSp73b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaCaviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila caviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaCaviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_01_FULL_45_25b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSimiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSimiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag563(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag563", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDecumbensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium decumbens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDecumbensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpJha26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCaspthauma4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterIrgensii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter irgensii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterIrgensii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeO395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O395 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusPlakortidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus plakortidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusPlakortidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSpRim47Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim47Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaStercoreaCag629Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella stercorea CAG:629 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaStercoreaCag629Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsplowo201full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL3811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RosaChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rosa chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RosaChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorBasaltisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor basaltis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratireductorBasaltisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuribacillusAlkaliarsenatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus alkaliarsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusAlkaliarsenatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiispiraPapahanaumokuakeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terasakiispira papahanaumokuakeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerasakiispiraPapahanaumokuakeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocSpNies3756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. NIES-3756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocSpNies3756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpH115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5411b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpJb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. JB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpJb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaEffusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCohniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cohnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCohniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixSpCaciamCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpCaciamCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavisolibacterTropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterTropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerulinaMusivaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerulina musiva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerulinaMusivaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaElizabethaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella elizabethae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaElizabethaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaLimiDsm17137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Devosia limi DSM 17137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DevosiaLimiDsm17137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFutsaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFutsaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHimastatinicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaZeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya zeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaZeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaSpLeaf244Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf244 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf244Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTegetincolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4632(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 46-32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4632", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaNaganishiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania naganishii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaNaganishiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaPanamericanaUamh10762Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia panamericana UAMH 10762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaPanamericanaUamh10762Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelotrichaceaeBacterium3153Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 3153 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium3153Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhodobacterSpCcbmm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pararhodobacter sp. CCBMM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PararhodobacterSpCcbmm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasSpBgc7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. BGC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpBgc7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpTw10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. TW10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnsiferSpTw10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumAlcoholivorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alcoholivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlcoholivorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidomycesRichmondensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidomycesRichmondensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiphonobacterAquaeclaraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Siphonobacter aquaeclarae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SiphonobacterAquaeclaraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSpCamponotileonardiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotileonardi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotileonardiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpFa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. FA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpFa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumHalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium hallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumHalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichophytonInterdigitale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichophytonInterdigitale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronospiraThiodismutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronospira thiodismutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronospiraThiodismutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeI113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae I113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeI113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinocyclocheilusGrahamiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus grahami Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusGrahamiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SymbiobacteriumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SymbiobacteriumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaclostridiumBifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraclostridium bifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaclostridiumBifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OttowiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ottowia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OttowiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaPedi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia pedi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPedi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesChartreusisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces chartreusis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesChartreusisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterBeijerinckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzotobacterBeijerinckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaboniaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gabonia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GaboniaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimazuellaKribbensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimazuella kribbensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimazuellaKribbensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterSpSk20926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. SK20926 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpSk20926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaMelanogasterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila melanogaster Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaMelanogasterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitrellaBrassicaformisCcmp3155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis CCMP3155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VitrellaBrassicaformisCcmp3155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSwuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus swuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSwuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwe13912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWE13912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwe13912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus siamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSiamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptobacteriumSpCag338(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium sp. CAG:338 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumSpCag338", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCrudilactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium crudilactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCrudilactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TursiopsTruncatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tursiops truncatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TursiopsTruncatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaParis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila Paris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaParis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylella fastidiosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylellaFastidiosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantAfricanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant africanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantAfricanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpRac03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. RAC03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpRac03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumCsp16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium CSP1-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumCsp16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumAquatile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquatile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquatile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa536n21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA536N21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa536n21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnobacteriumBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnobacteriumBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GonapodyaProliferaJel478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gonapodya prolifera JEL478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GonapodyaProliferaJel478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpWsm3224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoyosellaSubflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoyosella subflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoyosellaSubflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaJiangsuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia jiangsuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaJiangsuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesExfoliatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces exfoliatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesExfoliatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneatrixAlpicaDsm16621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Balneatrix alpica DSM 16621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BalneatrixAlpicaDsm16621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSphaerophysaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sphaerophysae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSphaerophysaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJohnsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJohnsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosotenuisChungbukensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis chungbukensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisChungbukensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumIntermediumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumIntermediumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpPcc7407Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC7407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7407Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSp174Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. 174 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSp174Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosarcinaSpBus5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosarcina sp. BuS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosarcinaSpBus5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpL294Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. L294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpL294Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaCaldifontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaCaldifontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixAgardhiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix agardhii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixAgardhiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallemiaIchthyophagaExf994(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga EXF-994 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WallemiaIchthyophagaExf994", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumGriseofulvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium griseofulvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumGriseofulvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasDenitrificansDsm6059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans DSM 6059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificansDsm6059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumDamselaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium damselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumDamselaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarivitaHallyeonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivita hallyeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivitaHallyeonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpEl159Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. EL159 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpEl159Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacterium6551(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium 65-51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacterium6551", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusSpRs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus sp. RS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusSpRs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumWoodiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium woodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWoodiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo201full3811bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL3811b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full3811bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMobaraensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mobaraensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMobaraensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphomyrmexCostatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyphomyrmex costatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyphomyrmexCostatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp131216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 13-12-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp131216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpBg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Bg2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpBg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSpObrc55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. OBRC5-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpObrc55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaSibiricaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia sibirica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaSibiricaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaXishanensisNbrc101358Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia xishanensis NBRC 101358 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaXishanensisNbrc101358Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OdobenusRosmarusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Odobenus rosmarus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OdobenusRosmarusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaToletanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia toletana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaToletanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaHoutenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica houtenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaHoutenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13724Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13724 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13724Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc074e01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC074E01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc074e01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnobacteriumBovisDsm14045(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis DSM 14045 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnobacteriumBovisDsm14045", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsplowo202full388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO202FULL388 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo202full388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumCb782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum CB782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumCb782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSynoviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma synoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSynoviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribiusSpMola401Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Maribius sp. MOLA401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MaribiusSpMola401Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrobacterAplysinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter aplysinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrobacterAplysinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsFumosoroseaArsef2679Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea ARSEF 2679 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CordycepsFumosoroseaArsef2679Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpYr247Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. yr247 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpYr247Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrobacterRadiotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrobacterRadiotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusFlagellatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus flagellatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusFlagellatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCaenarcanumBioreactoricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caenarcanum bioreactoricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaenarcanumBioreactoricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PteropusVampyrus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pteropus vampyrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PteropusVampyrus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaPurinilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia purinilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaPurinilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusCaroliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mus caroli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusCaroliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZonotrichiaAlbicollisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zonotrichia albicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZonotrichiaAlbicollisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumTcs56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCincinnatiensisDsm19608Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis DSM 19608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioCincinnatiensisDsm19608Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpNcr5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. NCR5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpNcr5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterSpM18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphellophoraEuropaeaCbs101466(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea CBS 101466 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyphellophoraEuropaeaCbs101466", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQueenslandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaQueenslandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpM143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumAgarivoransYm01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans YM01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransYm01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumArizonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium arizonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumArizonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseoruberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoruberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOrisDsm18711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris DSM18711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisDsm18711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopelagicusSpRedseas31b2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus sp. REDSEAS31B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusSpRedseas31b2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_40_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLiaoningenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium liaoningense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLiaoningenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniCnb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni CNB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniCnb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcaligenesFaecalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenes faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcaligenesFaecalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSpCastelsardo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. Castelsardo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpCastelsardo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocKimchii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc kimchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocKimchii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanodenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanodenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaPnomenusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pnomenusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPnomenusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamazzottiusVarieornatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ramazzottius varieornatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RamazzottiusVarieornatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviimonasSp20v17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas sp. 20V17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DefluviimonasSp20v17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeyerozymaGuilliermondiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegetibacterKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Segetibacter koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SegetibacterKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl2004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl2004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiCj3sym(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti CJ3sym graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiCj3sym", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpMf4836(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. MF4836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMf4836", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:448 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacterialesBacteriumAlc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium ALC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumAlc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligoflexusTunisiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oligoflexus tunisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OligoflexusTunisiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenobaculumSpHoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. HO Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpHoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSp01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMc2017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MC2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMc2017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPopuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumPopuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalonotiusSpJ07hn4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halonotius sp. J07HN4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalonotiusSpJ07hn4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasXanthomarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xanthomarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXanthomarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaFlabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella flabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaFlabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKorlensisNbrc107688Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus korlensis NBRC 107688 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusKorlensisNbrc107688Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JiangellaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_37_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaRubrilucens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella rubrilucens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaRubrilucens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforhopalusSingaporensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulforhopalus singaporensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulforhopalusSingaporensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaSpKle1797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. KLE1797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpKle1797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCremoricolorataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cremoricolorata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCremoricolorataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ViridibacillusArvi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Viridibacillus arvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ViridibacillusArvi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSp2009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. 2009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSp2009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RicheliaIntracellularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Richelia intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RicheliaIntracellularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusXylanilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus xylanilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusXylanilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumSuecicumHhb10207Ss3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum HHB10207 ss-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumSuecicumHhb10207Ss3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPaurosaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaCt18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Salmonella enterica CT18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaCt18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpZym1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. ZYM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpZym1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSinopsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sinopsychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSinopsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAnserina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia anserina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaAnserina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassilibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParahaemolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus parahaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParahaemolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPinihumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPinihumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifcsplowo201full3912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFCSPLOWO201FULL3912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifcsplowo201full3912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesertifilumSpIppasb1220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desertifilum sp. IPPASB1220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesertifilumSpIppasb1220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeocapsaSpPcc73106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC73106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc73106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilanimonasLenta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Silanimonas lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SilanimonasLenta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpBmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BMA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaSp609(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. 60_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSp609", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaHalifaxensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella halifaxensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaHalifaxensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1590Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1590Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusHomomorphusCbs101889Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus CBS 101889 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusHomomorphusCbs101889Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusVanfongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus vanfongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusVanfongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteeleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella steelei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteeleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yoonia rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YooniaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovisM02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis m02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovisM02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactis4877Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis 4877 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactis4877Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpC8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpFw1012b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. FW1012B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpFw1012b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerpetosiphonGeysericola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon geysericola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonGeysericola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenticepsClupeoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Denticeps clupeoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DenticepsClupeoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctopirusLimnophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus limnophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusLimnophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumInsubricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium insubricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumInsubricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr80Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr80Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichormusSpNmc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichormus sp. NMC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichormusSpNmc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacterRiflensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacter riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacterRiflensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLincolnensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lincolnensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLincolnensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpKh32cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. KH32C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpKh32cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisGranuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisGranuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquiflexumBalticumDsm16537(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquiflexum balticum DSM 16537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquiflexumBalticumDsm16537", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaBusckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila busckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaBusckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpUcdfrssp1630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. UCDFRSSP1630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSpUcdfrssp1630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBiviaDnf00188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia DNF00188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaDnf00188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumCsp14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium CSP1-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumCsp14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocellaArvoryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocella arvoryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocellaArvoryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusChikugoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus chikugoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusChikugoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_54_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrolobusFumariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrolobus fumarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrolobusFumariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOligofermentansDsm15707Lmg22743Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans DSM 15707 LMG 22743 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOligofermentansDsm15707Lmg22743Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot682Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root682 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot682Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAzotoformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus azotoformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAzotoformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumSaponariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum saponariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSaponariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpBa94(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa94", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumKomaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium komanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumKomaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TersicoccusSpBi70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus sp. Bi-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TersicoccusSpBi70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHimb058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumChlororespiransDsm11544Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans DSM 11544 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespiransDsm11544Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonInterdigitaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichophytonInterdigitaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumRbg166413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_64_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag474Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:474 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag474Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4515Fw2607Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4515 (FW-2607) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4515Fw2607Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterDubiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter dubius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDubiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaHispanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena hispanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaHispanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraLicerasiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira licerasiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraLicerasiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusErwiniaHaradaeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Erwinia haradaeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusErwiniaHaradaeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoanaerobacterStomatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoanaerobacter stomatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoanaerobacterStomatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSp4081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 40-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp4081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicum22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum 22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicum22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaAtypicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella atypica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaAtypicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadalesBacteriumBs08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium BS08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumBs08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpShues1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. SHUES1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpShues1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSuccinifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema succinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSuccinifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SandarakinorhabdusSpAap62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus sp. AAP62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusSpAap62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterHelveticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FranconibacterHelveticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusEllipticusCbs70779Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus CBS 707.79 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusEllipticusCbs70779Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium6313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 63-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpTca20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. TCA20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpTca20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaSpNd6we1aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rothia sp. ND6WE1A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RothiaSpNd6we1aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlectobacillusMajor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flectobacillus major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlectobacillusMajor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmataMassiliana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmata massiliana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmataMassiliana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumKctc3527Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum KCTC3527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumKctc3527Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTriplex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium triplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTriplex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu33c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU33C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu33c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricisUamh7299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polytolypa hystricis UAMH7299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolytolypaHystricisUamh7299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioFibrisolvensNd3005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens ND3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensNd3005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodothermusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodothermusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiochaetaPulveraceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta pulveracea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaPulveraceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlucuronolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glucuronolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlucuronolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaAffPulcherrimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia aff. pulcherrima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaAffPulcherrimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPallidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema pallidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPallidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeotomaLepidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neotoma lepida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeotomaLepidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3812bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3812b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3812bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13724Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_37_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13724Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUvarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUvarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhygromyxaSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enhygromyxa salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnhygromyxaSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHimastatinicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOy3wo11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OY3WO11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOy3wo11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpRv1423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. RV1423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpRv1423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PalaeococcusPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumCg2304417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG2_30_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg2304417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasThermotoleransDsm14292Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans DSM 14292 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasThermotoleransDsm14292Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPinetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pineti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPinetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterNoctilucicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCereusRock344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus Rock3-44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusRock344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorallococcusCoralloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus coralloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorallococcusCoralloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumGw2011gwb1547(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium GW2011GWB1547 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumGw2011gwb1547", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_36_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_12_FULL_44_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSp2mfcol31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 2MFCol31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSp2mfcol31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFrankenforstenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpA45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. A45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpA45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumEnclense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium enclense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumEnclense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptonemaIlliniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptonema illini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptonemaIlliniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_39_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_63_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKalixensisDsm16043Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis DSM 16043 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKalixensisDsm16043Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DendrobiumCatenatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dendrobium catenatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DendrobiumCatenatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag709Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:709 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag709Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoceaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phocea massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhoceaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full5011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL5011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full5011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCg1023572Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG1_02_35_72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg1023572Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiK12SubstrMg1655(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. MG1655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrMg1655", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimonasMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSaliperosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saliperosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaliperosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumMurisRn66Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris RN66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumMurisRn66Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFluxus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fluxus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFluxus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesTriticiR3111a1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici R3-111a-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesTriticiR3111a1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full3816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_38_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full3816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterTolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter tolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterTolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRibeironis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ribeironis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRibeironis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodictyonPhaeoclathratiforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon phaeoclathratiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelodictyonPhaeoclathratiforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TimonellaSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Timonella senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TimonellaSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumSpNbc371(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. NBC371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpNbc371", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriaceaeBacteriumDw12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriaceae bacterium DW12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriaceaeBacteriumDw12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpG1w1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. G1w1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpG1w1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPlatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces platensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPlatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCasei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium casei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCasei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPettenkoferiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pettenkoferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPettenkoferiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHtcc2207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCamelliaeDsm22697Jcm13995Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae DSM 22697 JCM 13995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCamelliaeDsm22697Jcm13995Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaChitosanitabidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph298Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 298 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph298Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph12015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1(2015) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpSph12015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk268Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk268Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterLanceolatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurvibacterLanceolatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeyerozymaGuilliermondii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisCloacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis cloacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisCloacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL4812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentinusTigrinusAlcf2ss16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lentinus tigrinus ALCF2SS1-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LentinusTigrinusAlcf2ss16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesLutzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesLutzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaMajorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirulina major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirulinaMajorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSpCag462(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag462", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoeciliaMexicanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poecilia mexicana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoeciliaMexicanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSullaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sullae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSullaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriaceaeBacteriumDw12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriaceae bacterium DW12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriaceaeBacteriumDw12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumAap81bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP81b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap81bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterLanienaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lanienae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLanienaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidophilus30sc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus 30SC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilus30sc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FurculomycesBoomerangus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Furculomyces boomerangus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FurculomycesBoomerangus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSepticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea septica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSepticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolobusVulcaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolobusVulcaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmobacterAquatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter aquatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmobacterAquatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrifolaFrondosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Grifola frondosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GrifolaFrondosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumPrausnitziiL26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii L26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiL26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TomitellaBiformataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tomitella biformata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TomitellaBiformataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalibacteriumHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCatenulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces catenulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCatenulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_46_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUdagawaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus udagawae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusUdagawaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpNctc13003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. NCTC 13003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpNctc13003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtomycesLactucaedebilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Protomyces lactucaedebilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProtomycesLactucaedebilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopostipesSuicloacalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioCosticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio costicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioCosticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpCf514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. CF514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpCf514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaGansuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jiangella gansuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JiangellaGansuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumDtu079Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu079Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonauticusSubmarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus submarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSubmarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaPomeroyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria pomeroyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaPomeroyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusSpOk042(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus sp. OK042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusSpOk042", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavimarinaSpHeli48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavimarina sp. HelI48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavimarinaSpHeli48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusVelezensisTrigocor1448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus velezensis TrigoCor1448 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusVelezensisTrigocor1448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydatigeraTaeniaeformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydatigera taeniaeformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydatigeraTaeniaeformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesJohnsoniiDsm18315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii DSM 18315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsoniiDsm18315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa1478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA1478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa1478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPectinophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pectinophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPectinophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanidioschyzonMerolaeStrain10dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae strain 10D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolaeStrain10dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasHofstadiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasHofstadiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidibacillusFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidibacillus ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidibacillusFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGraevenitziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces graevenitzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGraevenitziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumAmbiguumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidium ambiguum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidiumAmbiguumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxCitrulli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax citrulli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCitrulli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4332b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4332b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4332b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4311b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4311b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4311b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAsterYellowsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma aster yellows Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaAsterYellowsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusThioreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus thioreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusThioreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaQuasipneumoniaeSubspSimilipneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae subsp. similipneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniaeSubspSimilipneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGlycerinitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces glycerinitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGlycerinitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg165211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG165211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg165211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiameybacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niameybacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiameybacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KribbellaSpAli6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kribbella sp. ALI6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KribbellaSpAli6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterCrusticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterCrusticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFloridensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaFloridensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaEuropaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGraminicolaM1001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola M1.001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGraminicolaM1001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumRifcsphigho212full5321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium RIFCSPHIGHO212FULL5321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumRifcsphigho212full5321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeB728aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae B728a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeB728aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliopsisZonata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliopsisZonata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophilia5bai2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia 5BAI2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophilia5bai2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialophoraAmericana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialophora americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAmericana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg165211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG165211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg165211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium6137faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 6_1_37FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium6137faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisCinereaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BotrytisCinereaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaTurfanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria turfanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaTurfanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumC7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllisonellaHistaminiformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allisonella histaminiformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllisonellaHistaminiformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcremoniumChrysogenumAtcc11550(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum ATCC 11550 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcremoniumChrysogenumAtcc11550", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc29g08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC29G08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc29g08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSharpeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSharpeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaVincentiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema vincentii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaVincentiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminibacterMediatlanticusTb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus TB-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticusTb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElioraeaTepidiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elioraea tepidiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElioraeaTepidiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MooreaProducensPal815081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens PAL-8-15-08-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MooreaProducensPal815081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensMesophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens mesophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensMesophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSpNrrlb16210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sp. NRRLB16210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSpNrrlb16210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsukibacteriumIkkenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium ikkense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumIkkenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaHanseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia hansenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaHanseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerochaetaCoccoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta coccoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaCoccoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanidioschyzonMerolaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NodosilineaNodulosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nodosilinea nodulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NodosilineaNodulosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeOzaenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae ozaenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeOzaenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifcsplowo201full4925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag288(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag288", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpP4b1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. P4B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpP4b1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu053Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU053 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu053Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterUlvicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter ulvicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterUlvicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpPcc7105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 7105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSuccinogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSuccinogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumHalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Panicum hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PanicumHalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxHongdengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax hongdengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxHongdengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaSublithincola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita sublithincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSublithincola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpFobeg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. FOBEG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpFobeg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldalkalibacillusThermarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldalkalibacillus thermarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldalkalibacillusThermarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterHyointestinalisSubspHyointestinalisLmg9260Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis subsp. hyointestinalis LMG 9260 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalisSubspHyointestinalisLmg9260Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorallococcusSpCag1435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus sp. CAG:1435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorallococcusSpCag1435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelomonasSpRoot662(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root662 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot662", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusRivorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRivorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwc14518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWC1_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwc14518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacterium457255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium 457255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacterium457255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBingchenggensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bingchenggensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBingchenggensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKalixensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKalixensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnormaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enorma massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnormaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpA47Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. A47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpA47Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiploscapterPachysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diploscapter pachys Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiploscapterPachysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisalinibacterKiritimatiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldisalinibacter kiritimatiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldisalinibacterKiritimatiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConexibacterWoeseiDsm14684Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei DSM14684 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiDsm14684Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzambacteriaBacteriumRifcsplowo201full4625Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4625 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4625Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_46_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasPhyllosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas phyllosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasPhyllosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPituitosaNbrc102491(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa NBRC 102491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPituitosaNbrc102491", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudocatenulatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudocatenulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudocatenulatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifoxyc1full3818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYC1FULL3818 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyc1full3818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpA4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpA4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusAuricularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus auricularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAuricularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusSpHmsc067e09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus sp. HMSC067E09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcusSpHmsc067e09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb03234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IchthyophthiriusMultifiliis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuribacillusAlkaliarsenatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus alkaliarsenatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusAlkaliarsenatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiplasmaSpMba1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidiplasma sp. MBA-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidiplasmaSpMba1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaePhaseolicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae phaseolicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePhaseolicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSp63713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. 63-713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSp63713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumZeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumZeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzambacteriaBacteriumRifoxyb1full4033Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFOXYB1FULL4033 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifoxyb1full4033Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DactylellinaHaptotylaCbs20050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla CBS 200.50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DactylellinaHaptotylaCbs20050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpBr18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Br18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpBr18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusFervensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus fervens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusFervensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNbrc110611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 110611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc110611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpVlb120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. VLB120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpVlb120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full5011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL5011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full5011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusSpA40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sp. A40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSpA40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusColumbaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus columbae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusColumbaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyramidobacterPiscolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter piscolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterPiscolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitiporiaMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fomitiporia mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FomitiporiaMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAbawacabacteriaBacteriumRbg164210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Abawacabacteria bacterium RBG_16_42_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAbawacabacteriaBacteriumRbg164210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusDpc4571Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus DPC4571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusDpc4571Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TarsiusSyrichtaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tarsius syrichta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TarsiusSyrichtaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5329Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5329 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5329Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpRd272Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Rd 27.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpRd272Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MooreaProducensPal815081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moorea producens PAL-8-15-08-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MooreaProducensPal815081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpinosisporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosisporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConexibacterWoeseiDsm14684(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei DSM14684 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiDsm14684", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumLf3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return bacterium LF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriumLf3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisHerdmanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis herdmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeminocystisHerdmanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_52b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterPeloridisLmg23910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter peloridis LMG 23910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPeloridisLmg23910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaAfricanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta africana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaAfricanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaeciumNrrlb2354Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium NRRLB2354 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumNrrlb2354Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpUnc402clcolCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. UNC402CLCol Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpUnc402clcolCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasSenticiiDsm18821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas senticii DSM 18821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FerrimonasSenticiiDsm18821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaUbonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia ubonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaUbonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpKk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. KK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpKk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumCg2303729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium CG2_30_37_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumCg2303729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioParahaemolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio parahaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioParahaemolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterHepaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hepaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHepaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioFischeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliivibrioFischeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DactylellinaHaptotylaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DactylellinaHaptotylaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PluralibacterGergoviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pluralibacter gergoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PluralibacterGergoviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumRifoxya12full3519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA12FULL3519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya12full3519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesChelonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides chelonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesChelonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaSclerotiorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PatulibacterAmericanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter americanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PatulibacterAmericanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopertinaxCoweniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfopertinax cowenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfopertinaxCoweniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofundulusKuznetsoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus kuznetsovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusKuznetsoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiccibacterTuricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SiccibacterTuricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraSantarosaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira santarosai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSantarosaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlkaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-79 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladopsisRepensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladopsis repens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MastigocladopsisRepensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpMarseillep2426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. MarseilleP2426 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpMarseillep2426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaEffusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaEffusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwa14424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWA14424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwa14424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rahnella aquatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RahnellaAquatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaranusKomodoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Varanus komodoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VaranusKomodoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusFonticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus fonticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFonticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumLentiflavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lentiflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLentiflavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiaceaeBacteriumGa0074131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium Ga0074131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumGa0074131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliopsisZonataCbs50665(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata CBS 506.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliopsisZonataCbs50665", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFructivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fructivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFructivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumThermophilumVarThermophilumDsm1495(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum var. thermophilum DSM 1495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumThermophilumVarThermophilumDsm1495", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysFlagrans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys flagrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysFlagrans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaMultimorphosaCbs102226Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa CBS 102226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosaCbs102226Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EcheneisNaucratesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echeneis naucrates Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EcheneisNaucratesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpQxt31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. QXT-31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpQxt31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraCarrioniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora carrionii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraCarrioniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelotomaculumSpDtu098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum sp. DTU098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumSpDtu098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4470(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4470 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4470", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaMuciniphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia muciniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaMuciniphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpKms(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. KMS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpKms", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosMutusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bos mutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BosMutusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloquadratumWalsbyiJ07hqw2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi J07HQW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiJ07hqw2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesocricetusAuratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesocricetus auratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesocricetusAuratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DinothrombiumTinctoriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dinothrombium tinctorium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DinothrombiumTinctoriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMinimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium minimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMinimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesExalbidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides exalbidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesExalbidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaDsm15696Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola DSM15696 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaDsm15696Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpVt162(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. VT 162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpVt162", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenitrovibrioAcetiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Denitrovibrio acetiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DenitrovibrioAcetiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusVietnamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus vietnamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusVietnamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AncylostomaCaninum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma caninum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCaninum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavicepsPurpureaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Claviceps purpurea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClavicepsPurpureaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesUncialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces uncialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesUncialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentitaleaNanhaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sedimentitalea nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SedimentitaleaNanhaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGigeriorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGigeriorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis2Sk95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 SK95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2Sk95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelativoransSpBnc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. BNC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpBnc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YokenellaRegensburgeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yokenella regensburgei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YokenellaRegensburgeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaLongaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina longa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLongaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrionalesBacteriumGwa2659Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrionales bacterium GWA2_65_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrionalesBacteriumGwa2659Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwa24518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa24518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaphorinaCitri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diaphorina citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiaphorinaCitri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraMurdochii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira murdochii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraMurdochii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg1023112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1023112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1023112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPenetrans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma penetrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPenetrans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho201full4111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO201FULL4111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho201full4111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinitogaHydrogenitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaceaeBacteriumHl53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarinaceae bacterium HL-53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaceaeBacteriumHl53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlantibacterFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlantibacterFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpFobeg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. FOBEG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpFobeg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpRoot656Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root656 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot656Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitellibacterAquimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vitellibacter aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VitellibacterAquimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuromonadaceaeBacteriumGwc25813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadaceae bacterium GWC2_58_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadaceaeBacteriumGwc25813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpS9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSpC3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. C3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSpC3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabeoRohita(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labeo rohita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabeoRohita", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SideroxydansLithotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans lithotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SideroxydansLithotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpDjl10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. djl-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpDjl10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesSk182bjcvi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes SK182BJCVI graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesSk182bjcvi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1986(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1986", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasSpAap120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas sp. AAP120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasSpAap120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeovisonVisonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neovison vison Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeovisonVisonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonRbg19ftcombo5621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO5621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo5621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmoparaHalstediiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmopara halstedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmoparaHalstediiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesSpShpl14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChristensenellaceaeBacteriumPhil7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumConfluentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium confluentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumConfluentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCag495(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CAG:495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCag495", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSpRubisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Rubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpRubisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAlniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumDeltae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium deltae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumDeltae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumBkt015925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum BKT015925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumBkt015925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBornimenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium bornimense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBornimenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterJiangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaludibacterJiangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaConcava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia concava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaConcava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaGallinaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia gallinacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaGallinaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAzotifigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAzotifigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumCanisCbs113480Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microsporum canis CBS 113480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrosporumCanisCbs113480Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseobacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolineaTardivitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolinea tardivitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolineaTardivitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensisNbrc103114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jejuensis NBRC 103114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaJejuensisNbrc103114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquidulcibacterPaucihalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquidulcibacter paucihalophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquidulcibacterPaucihalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSyntrophoarchaeumButanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum butanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumButanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronospiraThiodismutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronospira thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronospiraThiodismutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterHeidelbergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heidelbergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeidelbergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedAcidilobusSpMgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. MG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpMgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycetocolaMiduiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola miduiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycetocolaMiduiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaPhaffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopedobacterSaltansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudopedobacter saltans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudopedobacterSaltansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusHominickiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus hominickii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusHominickiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixEikelboomiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix eikelboomii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiothrixEikelboomiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomonasIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosalsumZhilinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosalsumZhilinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiBjab07104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii BJAB07104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiBjab07104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticaulisKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ponticaulis koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PonticaulisKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisPvCampestrisStrAtcc33913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris pv. campestris str. ATCC 33913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisPvCampestrisStrAtcc33913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpOl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. OL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpOl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothrixSoehngenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothrixSoehngenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpLeaf72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Leaf72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpLeaf72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusFlavithermusWk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus WK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusWk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeovibrioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeovibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeovibrioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReinekeaBlandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Reinekea blandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ReinekeaBlandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlycomycesTenuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycomycesTenuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxXenomutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax xenomutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxXenomutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlegusellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olegusella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlegusellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpHh01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. HH01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpHh01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesDavaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces davaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDavaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentisphaeraSalicampiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera salicampi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraSalicampiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaObeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia obeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaObeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAtratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces atratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAtratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho202full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm2793Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM2793 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm2793Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsdaarsusmarc1296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSpYr403Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux sp. YR403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSpYr403Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumViciae248(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae248", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSpDw0440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. DW 0440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpDw0440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSabaudienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sabaudiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSabaudienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TulasnellaCalosporaMut4182Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tulasnella calospora MUT 4182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TulasnellaCalosporaMut4182Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSclerotionigerCbs115572(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger CBS 115572 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotionigerCbs115572", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb243495d8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_495D8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243495d8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmaragdicoccusNiigatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smaragdicoccus niigatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmaragdicoccusNiigatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioInopinatusDsm10711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus DSM 10711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatusDsm10711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesSpLutziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides sp. lutzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesSpLutziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSp4557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 4557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp4557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusAdriaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus adriaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusAdriaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacillusDecaturensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacillus decaturensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidibacillusDecaturensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonScgcAaa007o23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA007O23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa007o23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAbscessusNbrc100374Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia abscessus NBRC 100374 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAbscessusNbrc100374Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRifcsphigho201full4414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPHIGHO201FULL4414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsphigho201full4414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChishuiellaChangwenlii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chishuiella changwenlii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChishuiellaChangwenlii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHeli88Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. HelI88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHeli88Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumRiftiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum riftiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumRiftiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusVulcanalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus vulcanalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusVulcanalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterFlexilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flexibacter flexilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlexibacterFlexilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalvatorMerianae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salvator merianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalvatorMerianae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxya12full3519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA12FULL3519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya12full3519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaArenicorallina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KosmotogaArenicorallina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRbg13469(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RBG_13_46_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRbg13469", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSulfidophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sulfidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSulfidophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBeveridgeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus beveridgei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusBeveridgeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PestalotiopsisFiciW1061(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici W106-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PestalotiopsisFiciW1061", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfOnchocercaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Onchocerca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfOnchocercaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaAtrinaeC38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria atrinae C3-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KocuriaAtrinaeC38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterCaenitepidi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter caenitepidi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterCaenitepidi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveromycesLactisNrrlY1140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis NRRL Y-1140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KluyveromycesLactisNrrlY1140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaAlbertiiTw07627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii TW07627 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiTw07627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumRussiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium russii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumRussiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnormaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enorma timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnormaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13220cm2648Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_64_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm2648Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplocarponRosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diplocarpon rosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiplocarponRosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSp05ny08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 05NY08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp05ny08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:617 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraLicerasiaeStrMmd4847Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira licerasiae str. MMD4847 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraLicerasiaeStrMmd4847Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMeningitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria meningitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMeningitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDegerlachei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium degerlachei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDegerlachei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasPolymorphaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas polymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasPolymorphaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RutstroemiaSpNjr2017aBbw(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a BBW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aBbw", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusAsaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSymbiosumWal14673Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14673 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14673Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTimonensis4401737Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis 4401737 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensis4401737Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasNeptunium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas neptunium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasNeptunium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisCga009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris CGA009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisCga009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaPneumophilaPasculleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila pascullei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPasculleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAculeatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusAculeatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaleopterusVariegatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Galeopterus variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GaleopterusVariegatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumPolonicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium polonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumPolonicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumZeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium zeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumZeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTuccetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTuccetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumSaccharolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium saccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSaccharolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusVenerealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus venerealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusVenerealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpCo6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus sp. CO-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusSpCo6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFlocculare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFlocculare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTuccetiDsm20183(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti DSM 20183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTuccetiDsm20183", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterJeongneungensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter jeongneungensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterJeongneungensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasUenonisDsm23387Jcm13868Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 JCM 13868 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387Jcm13868Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthocomusHoazinCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opisthocomus hoazin Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpisthocomusHoazinCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium loti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumLotiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumEhc02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium EhC02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumEhc02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNamurensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNamurensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHamsteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hamsteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHamsteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusSpM41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus sp. M41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusSpM41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpJ31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. J31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpJ31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLutaoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lutaoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLutaoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaCrocinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia crocina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaCrocinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUrhb0044(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHB0044 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhb0044", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OryzaSativa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArhEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArhEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCiat652Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CIAT652 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCiat652Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterAcinonychisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter acinonychis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAcinonychisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndomicrobiumProavitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endomicrobium proavitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndomicrobiumProavitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumVitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium vitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumVitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylococcopsisSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dactylococcopsis salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DactylococcopsisSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPrimitiaZas1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeBacterium16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium 16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacterium16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrotoleransDsm18569Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans DSM 18569 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HymenobacterPsychrotoleransDsm18569Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusMauleoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus mauleonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusMauleoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiBacteriumNicil2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium NICIL-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumNicil2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpHk10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. HK10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpHk10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AphanizomenonFlosaquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aphanizomenon flosaquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AphanizomenonFlosaquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSp6610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 66-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioSpJcm19062(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. JCM 19062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpJcm19062", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFicaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia ficaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaFicaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonMixedCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixedCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpJgi0001016m12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. JGI 0001016M12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpJgi0001016m12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNeuiiDsm8576Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii DSM8576 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiDsm8576Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonTcbr11e2g14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNfr07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenihalanaerobacterShriftiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenihalanaerobacter shriftii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenihalanaerobacterShriftiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag567Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag567Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaculaToluolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaToluolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4470Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4470 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4470Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronobacteriumTexcoconenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium texcoconense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumTexcoconenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaSpUcdkl20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. UCDKL20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpUcdkl20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesMarneffeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces marneffei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TalaromycesMarneffeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlatysternonMegacephalumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Platysternon megacephalum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlatysternonMegacephalumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaFlavaJlt2011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gramella flava JLT2011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GramellaFlavaJlt2011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumSpCag727Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium sp. CAG:727 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumSpCag727Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlr1721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALR1721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlr1721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGracilibacteriaBacteriumCg10238174Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gracilibacteria bacterium CG1_02_38_174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGracilibacteriaBacteriumCg10238174Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpScn6821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SCN 68-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpScn6821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceibacteriumSpImcc21224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puniceibacterium sp. IMCC21224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PuniceibacteriumSpImcc21224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag884Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:884 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag884Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpRoot136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. Root136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpRoot136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumCg2304652Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_46_52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2304652Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpLmtr3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LMTR 3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLmtr3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_40_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaMediocidicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora mediocidica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaMediocidicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaJiangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaJiangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwc24418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWC24418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwc24418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaHulunbeirensisJcm10989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis JCM 10989 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensisJcm10989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterPseudethanolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter pseudethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterPseudethanolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaJiangningensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella jiangningensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaJiangningensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24716 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaNivaraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza nivara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OryzaNivaraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusGondwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus gondwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusGondwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaribacterHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laribacter hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaribacterHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibiumSpTrichskd4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseibium sp. TrichSKD4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseibiumSpTrichskd4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpL2c084a000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. L2C084A000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpL2c084a000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LinderinaPennisporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Linderina pennispora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LinderinaPennisporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumExBugulaNeritinaAb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium (ex Bugula neritina AB1) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumExBugulaNeritinaAb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaChitinilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia chitinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaChitinilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StomatobaculumLongum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stomatobaculum longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StomatobaculumLongum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonBenhamiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichophytonBenhamiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusWelwitschiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus welwitschiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusWelwitschiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProsekiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas prosekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProsekiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSoliNbrc106424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Variovorax soli NBRC 106424 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VariovoraxSoliNbrc106424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumSpOralTaxon193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. oral taxon 193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumSpOralTaxon193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalsuginibacillusKocuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salsuginibacillus kocurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalsuginibacillusKocuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeraceosorusGuamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus guamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusGuamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwb13613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_36_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb13613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4515Fw2607Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4515 (FW-2607) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4515Fw2607Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacimicrobiumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacimicrobium alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacimicrobiumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBauzanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas bauzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBauzanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MollicutesBacteriumHr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarimonasRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonas rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinarimonasRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobialesBacteriumKi4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobiales bacterium KI4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermomicrobialesBacteriumKi4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalalkalicoccusJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halalkalicoccus jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalalkalicoccusJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiL26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii L26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiL26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaIvanovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria ivanovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaIvanovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMagnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMagnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwd23614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWD2_36_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwd23614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMayottensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira mayottensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMayottensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOdoratitofuiDsm19909Jcm15043Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui DSM 19909 JCM 15043 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofuiDsm19909Jcm15043Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSwingsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium swingsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSwingsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumInhibensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium inhibens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumInhibensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonadalesBacteriumRifcsplowo212599(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonadales bacterium RIFCSPLOWO2_12_59_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonadalesBacteriumRifcsplowo212599", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BryobacterAggregatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bryobacter aggregatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BryobacterAggregatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CruoricaptorIgnavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cruoricaptor ignavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CruoricaptorIgnavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusVenerealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus venerealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusVenerealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536g10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536G10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536g10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAlliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea allii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaAlliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb02923(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02923 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02923", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisLatensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis latens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisLatensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumDeleyianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum deleyianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumDeleyianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMediterraneiS699Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei S699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisMediterraneiS699Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZinderiaInsecticolaCariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zinderia insecticola CARI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZinderiaInsecticolaCariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterJohnsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJohnsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpLeaf53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Leaf53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpLeaf53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRbg166213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_62_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifoxya2full3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL3919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusStomatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus stomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusStomatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumAromaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum aromaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AromatoleumAromaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAsteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium asteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAsteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterFrateuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter frateurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GluconobacterFrateuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusYedoensisVarNudiflora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prunus yedoensis var. nudiflora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrunusYedoensisVarNudiflora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea ananatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnanatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraYellowstonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera yellowstonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraYellowstonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFp211j200Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FP211J200 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFp211j200Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiberibacterAfricanusPtsapsy(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liberibacter africanus PTSAPSY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiberibacterAfricanusPtsapsy", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasKyonanensisDsm18153Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis DSM 18153 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FerrimonasKyonanensisDsm18153Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeomargaritaLithophoraAlchichicaD10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Alchichica-D10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GloeomargaritaLithophoraAlchichicaD10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24668(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24668 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24668", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrodochiumBolleyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microdochium bolleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrodochiumBolleyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthobacterSoliDsm19599Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli DSM 19599 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoliDsm19599Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntestinimonasMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpUnc302mfcol52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. UNC302MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhyllobacteriumSpUnc302mfcol52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYD1_FULL_37_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaedaleaQuercinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daedalea quercina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaedaleaQuercinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeBacterium16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium 16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacterium16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellalesBacteriumRifcsphigho212full3714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensisDsm12906Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis DSM 12906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensisDsm12906Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DipodomysOrdiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dipodomys ordii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DipodomysOrdiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhizobiumPolonicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium polonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumPolonicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium6eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 6E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium6eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllokutzneriaAlbata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allokutzneria albata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllokutzneriaAlbata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYr295(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr295", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSparsogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sparsogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSparsogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc055a01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC055A01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc055a01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPiscicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piscicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiscicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaChahannaoensisJcm10990Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis JCM 10990 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensisJcm10990Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaFrisiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea frisia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaFrisiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumDivergens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium divergens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumDivergens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumKutscheriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kutscheri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKutscheriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfatatorAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMediterranei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMediterranei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Babesia equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BabesiaEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaOnionYellowsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma onion yellows Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaOnionYellowsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNdiopicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ndiopicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusNdiopicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxyc12Full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYC12_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyc12Full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb241528o2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241528O2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528o2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaExalbidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia exalbida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaExalbidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AegilopsTauschiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aegilops tauschii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AegilopsTauschiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterAkesuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter akesuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterAkesuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcetotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acetotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcetotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesUniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides uniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesUniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwc14518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWC1_45_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwc14518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPedocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pedocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPedocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioQuintilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio quintilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioQuintilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumFlorentinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium florentinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFlorentinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpNp3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NP3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpNp3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpR1ns10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. R1NS10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpR1ns10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaRodasii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rodasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaRodasii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_36_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusLimiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus limi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusLimiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpCag241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerminephrobacterEiseniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verminephrobacter eiseniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerminephrobacterEiseniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylonaHeveaeTc161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xylona heveae TC161 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XylonaHeveaeTc161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Candida] intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThiodiazotrophaEndolucinidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endolucinida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndolucinidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyricimonasVirosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas virosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasVirosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpOv510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. OV510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpOv510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumThalassium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium thalassium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumThalassium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpQh12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. QH-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpQh12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSaelicesensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora saelicesensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSaelicesensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylovulumMiyakonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpGw1013h11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. GW101-3H11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpGw1013h11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterCelerSubspAstrifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter celer subsp. astrifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeucobacterCelerSubspAstrifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFermentumIfo3956Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum IFO3956 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFermentumIfo3956Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVenezuelaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces venezuelae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVenezuelaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacterium6813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium 68-1-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacterium6813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClupeaHarengusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clupea harengus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClupeaHarengusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusEhimensisA2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusEhimensisA2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAraiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia araii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaAraiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLpb0140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LPB0140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLpb0140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGlycinifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus glycinifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGlycinifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmadillidiumVulgare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armadillidium vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmadillidiumVulgare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaSpRitpidCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella sp. RITPId Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaSpRitpidCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaCaldariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema caldarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaCaldariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelothrixTonsillarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix tonsillarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixTonsillarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasSpScn70307(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas sp. SCN 70-307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasSpScn70307", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanis209318Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis 209318 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanis209318Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpQa3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. QA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpQa3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSydowiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sydowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSydowiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaAquamarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala aquamarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaAquamarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesBailiiClib213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii CLIB 213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailiiClib213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpYr768Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YR768 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYr768Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpOk281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OK281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOk281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrettanomycesBruxellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces bruxellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesBruxellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusConstellatusPharyngisSk1060(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis SK1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisSk1060", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisV583Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis V583 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalisV583Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHimb083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCyriacigeorgica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia cyriacigeorgica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaCyriacigeorgica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCip562Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP56.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip562Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumSalicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum salicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSalicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodisPhaseoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisPhaseoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSpAbm4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. AbM4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpAbm4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StackebrandtiaNassauensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stackebrandtia nassauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StackebrandtiaNassauensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRhizoxinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia rhizoxinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRhizoxinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaDisplodereCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nematocida displodere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NematocidaDisplodereCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoflavonifractorCapillosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor capillosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorCapillosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaHypogeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaAdiacensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella adiacens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaAdiacensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaVulnerisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia vulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaVulnerisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonasPhototrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas phototrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasPhototrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaRhizospheraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia rhizosphera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaRhizospheraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeosporobacterSubterraneusDsm17957Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus DSM 17957 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneusDsm17957Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumLssob(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium LSSOB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumLssob", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpA49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. A49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpA49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalanaerobiumHydrogeniformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumHydrogeniformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr70337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4655Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4655Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusConstellatusPharyngisC1050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis C1050 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisC1050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSp4681Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 4681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSp4681Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxParadoxus110b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus 110B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VariovoraxParadoxus110b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFloridensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFloridensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. houtenae str. ATCC BAA-1581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm35217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaMultilocaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_38_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata var. bicuspidata NRRL YB-4993 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_34_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpD16r12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16R12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16r12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreochromisAureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OreochromisAureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusBrockianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus brockianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusBrockianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteriumAutotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumAutotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfUnidentified(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentified", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHarenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia harenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaHarenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomirabilisOxyferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomirabilis oxyfera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomirabilisOxyferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMannitolivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus mannitolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMannitolivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumOtsza272(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium OTSzA272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumOtsza272", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalarchaeumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalarchaeum thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalarchaeumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterBeijingensisDsm21582Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis DSM 21582 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DyadobacterBeijingensisDsm21582Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraRubrobrunea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRubrobrunea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasArcis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas arcis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasArcis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhabdusUtahensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus utahensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusUtahensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSmegmatisMc2155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis MC2155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisMc2155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Haemophilus] felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaWheatBlueEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma wheat blue Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaWheatBlueEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDonghicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter donghicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDonghicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChokoriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chokoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaChokoriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusMahiiDsm5219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii DSM 5219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusMahiiDsm5219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumTcs52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChishuiellaChangwenliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chishuiella changwenlii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChishuiellaChangwenliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAminophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio aminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAminophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarcicellaHirudinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudarcicella hirudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudarcicellaHirudinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full497Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL497 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full497Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg166630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG166630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg166630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraKernoviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora kernoviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraKernoviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrancourtellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drancourtella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrancourtellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LagierellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lagierella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LagierellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKryptoniumThompsoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptonium thompsoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptoniumThompsoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalibacteriumQingdaonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium qingdaonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumQingdaonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifoxyd1full4821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFOXYD1FULL4821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifoxyd1full4821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterJohnsoniiXbb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii XBB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterJohnsoniiXbb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpKw12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. KW12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpKw12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaliobacillusSpPm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus sp. PM-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusSpPm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporumMel28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Mel28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TuberMelanosporumMel28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumScgcAaa298d23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA298D23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa298d23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSimiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSimiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransMarinusDsm23064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus DSM 23064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransMarinusDsm23064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndersenbacteriaBacteriumRifcsphigho201full4636Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Andersenbacteria bacterium RIFCSPHIGHO201FULL4636 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AndersenbacteriaBacteriumRifcsphigho201full4636Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumCapsulatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium capsulatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumCapsulatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSpG11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpG11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_51_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeotogaPetraea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geotoga petraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeotogaPetraea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaProteobacteriumMl8f1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium ML8F1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMl8f1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoaurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoaurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoaurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGoldsteiniiDsm19448Wal12034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii DSM 19448 WAL 12034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteiniiDsm19448Wal12034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumOlb7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumLacustreDsm10312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre DSM 10312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronumLacustreDsm10312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSpitsbergense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma spitsbergense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSpitsbergense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobaculumSpHoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. HO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpHoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ImmundisolibacterCernigliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Immundisolibacter cernigliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ImmundisolibacterCernigliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SordariaMacrosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sordaria macrospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SordariaMacrosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParabuchneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabuchneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabuchneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return candidate division TM6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionTm6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthia316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia 316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthia316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeauveriaBassianaArsef2860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana ARSEF 2860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaArsef2860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpOrs3428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpB2m1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. B2M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpB2m1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenopusTropicalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenopus tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenopusTropicalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaVulnerisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia vulneris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaVulnerisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1092Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1092 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1092Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNodosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces nodosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNodosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattellaGermanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattella germanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattellaGermanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFonticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia fonticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaFonticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBaroniaeDsm16972Jcm13447Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella baroniae DSM 16972 JCM 13447 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBaroniaeDsm16972Jcm13447Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusBvHnlc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpTb23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. TB23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpTb23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaylandiaZebraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maylandia zebra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaylandiaZebraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurivibrioAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurivibrio alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurivibrioAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActibacteriumMucosumKctc23349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium mucosum KCTC 23349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActibacteriumMucosumKctc23349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_01_FULL_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpMc138bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MC13-8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMc138bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpRoot630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SusScrofa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sus scrofa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SusScrofa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorellaAsinigenitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorella asinigenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorellaAsinigenitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraSojae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraSojae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TardiphagaRobiniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga robiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TardiphagaRobiniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarivitaGeojedonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivita geojedonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivitaGeojedonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumChauvoeiJf4335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chauvoei JF4335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumChauvoeiJf4335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm18996Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 18996 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm18996Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterRoseusDsm17521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter roseus DSM 17521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PontibacterRoseusDsm17521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa14021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA14021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa14021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusUrinimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus urinimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusUrinimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusArctosHorribilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ursus arctos horribilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UrsusArctosHorribilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaGlauca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaGlauca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacteriumJsc12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium JSC12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumJsc12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCitroniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium citroniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCitroniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_43_17b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFructicolaNaraGc5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Nara gc5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFructicolaNaraGc5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpH2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpH2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpSynace01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. SynAce01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpSynace01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllomycesMacrogynusAtcc38327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus ATCC 38327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AllomycesMacrogynusAtcc38327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumMarseillep2935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium MarseilleP2935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumMarseillep2935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterSedlakiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sedlakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSedlakiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixSoehngeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothrixSoehngeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisCinerea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BotrytisCinerea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpJc4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. JC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpJc4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumGeorgiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiemerellaAnatipestiferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riemerella anatipestifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiemerellaAnatipestiferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberibacillusSpMarseillep3662Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tuberibacillus sp. MarseilleP3662 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuberibacillusSpMarseillep3662Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonasPusillaCcmp1545Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla CCMP1545 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicromonasPusillaCcmp1545Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcyrthosiphonPisumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acyrthosiphon pisum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcyrthosiphonPisumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterLimosusNbrc16128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Janibacter limosus NBRC 16128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JanibacterLimosusNbrc16128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1026051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_60_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1026051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumPseudosasicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium pseudosasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPseudosasicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag452(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:452 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag452", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterRhizovicinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixSpP13c2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. P13C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpP13c2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AedesAegyptiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aedes aegypti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AedesAegyptiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeBacterium457278(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium457278", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesCulicifacies(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles culicifacies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesCulicifacies", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRoot1497Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root1497 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot1497Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaatingaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caatingaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaatingaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpragueaLophiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spraguea lophii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpragueaLophiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivalisAtcc33277Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis ATCC33277 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisAtcc33277Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolichospermumCircinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dolichospermum circinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DolichospermumCircinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusToleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius tolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusToleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOzensisDsm23829Jcm17196(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis DSM 23829 JCM 17196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOzensisDsm23829Jcm17196", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusInersEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus iners Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusInersEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusChromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus chromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusChromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesOdoratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusAsiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus asini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAsiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasTaeanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taeanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaeanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacillusKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFluorescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CionaSavignyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ciona savignyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CionaSavignyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpV450Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. V450 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpV450Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentisphaeraSalicampiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera salicampi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraSalicampiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full3725Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3725 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3725Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalobiumEvestigatumZ7303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Z-7303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatumZ7303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRbg19ftcombo367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG19FTCOMBO367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg19ftcombo367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumGraminearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium graminearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumGraminearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumCg1026336Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_63_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1026336Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAmikacinitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpEpa45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. EPa45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpEpa45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacaAbyssiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibaca abyssi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacaAbyssiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccibacterColletisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter colletis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SiccibacterColletisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaCryptomonadisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivita cryptomonadis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivitaCryptomonadisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSpJc230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. JC230 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpJc230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolentinusLepideusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neolentinus lepideus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeolentinusLepideusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusInulinusCasdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus CASD Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusInulinusCasdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumRifcsplowo201full5028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPLOWO201FULL5028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsplowo201full5028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGwa15412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GWA15412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGwa15412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLfm046Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. LFM046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLfm046Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoldemanellaBiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holdemanella biformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoldemanellaBiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusAs9601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus AS9601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusAs9601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterPetaseusNbrc106054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus NBRC 106054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseusNbrc106054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScophthalmusMaximusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scophthalmus maximus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScophthalmusMaximusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodomicrobiumUdaipurenseJa643Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense JA643 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurenseJa643Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonJgiOtu1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon JGI OTU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonJgiOtu1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CedeceaNeteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cedecea neteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CedeceaNeteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat22090Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-22090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat22090Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthellaSpCag298Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:298 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag298Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasYangmingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas yangmingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasYangmingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CriblamydiaSequanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Criblamydia sequanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CriblamydiaSequanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InquilinusLimosusDsm16000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Inquilinus limosus DSM 16000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "InquilinusLimosusDsm16000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho201full388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL388 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolineaTardaNobi1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanolinea tarda NOBI-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanolineaTardaNobi1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetosphaeriaTurcicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Setosphaeria turcica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SetosphaeriaTurcicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwa13330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumPeriodonticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium periodonticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPeriodonticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AstatotilapiaCalliptera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Astatotilapia calliptera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AstatotilapiaCalliptera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9401234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9401234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9401234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriN26808(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori N26808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriN26808", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlautiaStaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plautia stali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlautiaStaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraMultiparaAtcc19207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara ATCC19207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaAtcc19207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira vanthielii serovar Holland str. Waz Holland ATCC 700522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusStrModasaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus str. modasa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrococcusLuteusStrModasaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasChukchiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas chukchiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasChukchiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusLitoralisDsm5473Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus litoralis DSM 5473 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermococcusLitoralisDsm5473Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaSpYcwa18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kushneria sp. YCWA18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KushneriaSpYcwa18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12747566Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274756.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747566Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusBoritoleransDsm17298Jcm18970Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans DSM 17298 JCM 18970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusBoritoleransDsm17298Jcm18970Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSp20bnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 20BN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSp20bnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoaLoaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loa loa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoaLoaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaCapsosiphonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita capsosiphonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AequorivitaCapsosiphonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgaricusBisporusVarBurnettiiJb137S8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus var. burnettii JB137-S8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgaricusBisporusVarBurnettiiJb137S8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutypaLataUcrel1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata UCREL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EutypaLataUcrel1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcaligenesFaecalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenes faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcaligenesFaecalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalothiobacillusSpXi15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. XI15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpXi15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodiomycesAlkalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SodiomycesAlkalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaEchinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gramella echinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GramellaEchinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFructosivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fructosivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFructosivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTasmaniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tasmaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioTasmaniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRapi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rapi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRapi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC2_FULL_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaBigeminaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Babesia bigemina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BabesiaBigeminaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PalaeococcusFerrophilusDsm13482Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus DSM 13482 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilusDsm13482Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxRowiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apteryx rowi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApteryxRowiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesMarneffeiAtcc18224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei ATCC 18224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TalaromycesMarneffeiAtcc18224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_47_33b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJaponicaNbrc103040Dsm22348Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas japonica NBRC 103040 DSM 22348 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasJaponicaNbrc103040Dsm22348Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumVacuolatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSalanitronis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salanitronis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalanitronis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ModestobacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumChlororespiransDsm11544Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans DSM 11544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespiransDsm11544Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpOrs3324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSpMs5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. MS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSpMs5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCollinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces collinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCollinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BergeyellaZoohelcumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bergeyella zoohelcum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BergeyellaZoohelcumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGa0074139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeriophthalmusMagnuspinnatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Periophthalmus magnuspinnatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeriophthalmusMagnuspinnatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidipiscis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidipiscis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidipiscis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusInfluenzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus influenzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusInfluenzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag1000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRubrobruneaNbrc15275(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea NBRC 15275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRubrobruneaNbrc15275", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolectaIrregularisDah3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neolecta irregularis DAH-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeolectaIrregularisDah3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpWriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. wRi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaSpWriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterHeparinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter heparinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterHeparinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronorubrumTexcoconense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum texcoconense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTexcoconense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFOXYD1_FULL_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1438bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1438b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1438bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaPthiripubisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pthiripubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPthiripubisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_51_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpYe71Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. YE71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpYe71Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumWasabiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium wasabiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumWasabiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaMultacidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella multacida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaMultacidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CF335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerobacterThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerobacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerobacterThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonadaceaeBacteriumUkl131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium UKL13-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumUkl131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusLentulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus lentulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusLentulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrilusPlanipennis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrilus planipennis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrilusPlanipennis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSolisilvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter solisilvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSolisilvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusOxalaticusNbrc13593(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus NBRC 13593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CupriavidusOxalaticusNbrc13593", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp21331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2133.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot1221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root1221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot1221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumRifcsphigho212full369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPHIGHO212FULL369 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsphigho212full369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodiomycesAlkalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SodiomycesAlkalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplosphaeraColitermitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Diplosphaera colitermitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DiplosphaeraColitermitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifcsphigho201full4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocinitomixCatalasitica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix catalasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixCatalasitica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSpScn65179(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. SCN 65-179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpScn65179", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPurisNbrc108233Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia puris NBRC 108233 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaPurisNbrc108233Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthobacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinicellaSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinicella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinicellaSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniaeHk85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae HK 85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusPittmaniaeHk85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterGangjinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter gangjinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterGangjinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaEquifetaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma equifetale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaEquifetaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraLicerasiaeStrMmd4847(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira licerasiae str. MMD4847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraLicerasiaeStrMmd4847", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMegateriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina megaterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMegateriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFarraginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farraginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarraginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApostasiaShenzhenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apostasia shenzhenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApostasiaShenzhenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevilineaSaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levilinea saccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevilineaSaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumCiceriCa181Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri ca181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriCa181Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalostagnicolaLarseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola larsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaLarseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumKlh11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium KLH11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumKlh11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPontisDsm8475Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pontis DSM 8475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPontisDsm8475Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TremblayaPhenacola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya phenacola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TremblayaPhenacola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc24211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc24211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasAbyssalisTar001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis TAR-001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalisTar001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusChliarophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus chliarophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusChliarophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumHomopropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium homopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHomopropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorocebusSabaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorocebus sabaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorocebusSabaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumCellulansJ1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans J1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulansJ1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_40_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumPutridalgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium putridalgicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPutridalgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SusScrofaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sus scrofa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SusScrofaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC4105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquiflexumBalticumDsm16537Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquiflexum balticum DSM 16537 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquiflexumBalticumDsm16537Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303346(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_33_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303346", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusDelemar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus delemar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopusDelemar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpPdc64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. PDC64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpPdc64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasKoyamaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas koyamae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasKoyamaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerracidiphilusGabretensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terracidiphilus gabretensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerracidiphilusGabretensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporumMel28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Mel28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TuberMelanosporumMel28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusPseudoficulneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus pseudoficulneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FructobacillusPseudoficulneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensisNbrc103114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jejuensis NBRC 103114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaJejuensisNbrc103114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumGw2011gwd23842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWD23842 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwd23842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSmaragdinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta smaragdinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSmaragdinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumLividum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium lividum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JanthinobacteriumLividum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaMorganiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Morganella morganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MorganellaMorganiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusHyovaginalisDsm12219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis DSM 12219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalisDsm12219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpCag831(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:831 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag831", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbidosporaMongoliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora mongoliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaMongoliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterAcinonychisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter acinonychis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAcinonychisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaTuronicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma turonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTuronicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpOlga172(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. OLGA172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpOlga172", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaryophanonTenueCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caryophanon tenue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaryophanonTenueCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatiglansAniliniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatiglansAniliniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpRac03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. RAC03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpRac03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumUasb124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpCc9311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDiphtheriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumVacciniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium vaccinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumVacciniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisDavidiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Myotis davidii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MyotisDavidiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaplochromisBurtoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haplochromis burtoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaplochromisBurtoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpUnc380mfsha31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. unc380mfsha3.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpUnc380mfsha31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesStipitatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TalaromycesStipitatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FinegoldiaMagnaAtcc29328Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC29328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc29328Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcyrthosiphonPisumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acyrthosiphon pisum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcyrthosiphonPisumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiohalorhabdusDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiohalorhabdus denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiohalorhabdusDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenophonusLipoptenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus lipoptenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusLipoptenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OwenweeksiaHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Owenweeksia hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OwenweeksiaHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhizobiumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumHydrogeniphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hydrogeniphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHydrogeniphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasFungivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas fungivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasFungivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWD2_38_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwd23842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo201full3334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO201FULL3334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo201full3334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMoscovienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum moscoviense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMoscovienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeMgh78578(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae MGH78578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeMgh78578", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesAcidifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysOligosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysOligosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSporothermoduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sporothermodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSporothermoduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HirundoRusticaRustica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hirundo rustica rustica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HirundoRusticaRustica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaapiaArgillaceaMucl33604Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Jaapia argillacea MUCL 33604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JaapiaArgillaceaMucl33604Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HylemonellaGracilisNiagara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis Niagara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisNiagara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumSpCcfee5018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium sp. CCFEE 5018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumSpCcfee5018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpOralTaxon299StrF0039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. oral taxon 299 str. F0039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpOralTaxon299StrF0039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc7217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusStrMit9303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. MIT 9303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrMit9303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNeoehrlichiaLotorisStrRac413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Neoehrlichia lotoris str. RAC413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNeoehrlichiaLotorisStrRac413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpBl8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BL8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBl8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromassilibacillusSpMarseillep3371Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus sp. MarseilleP3371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSpMarseillep3371Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ItalianCloverCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Italian clover Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ItalianCloverCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraParasiticaInra310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica INRA-310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraParasiticaInra310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SabulitectumSilensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sabulitectum silens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SabulitectumSilensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4825 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaldieriaSulphuraria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Galdieria sulphuraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GaldieriaSulphuraria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArthromitusSpSfbTurkey(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arthromitus sp. SFB-turkey graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusArthromitusSpSfbTurkey", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPHIGHO2_12_FULL_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_44_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPlebeius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides plebeius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPlebeius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMmg1533Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1533Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariprofundusFerrooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus ferrooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MariprofundusFerrooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IndibacterAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Indibacter alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IndibacterAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterSpAtcc31444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. ATCC31444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpAtcc31444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumChkci001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaAchromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida achromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaAchromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSp37zxxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 37zxx Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp37zxxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumLentumNbrc107847Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lentum NBRC 107847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLentumNbrc107847Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesQinglanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qinglanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQinglanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumSpPcc7001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. PCC7001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpPcc7001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaPahangiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brugia pahangi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrugiaPahangiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterAsburiaeLf7a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter asburiae LF7a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAsburiaeLf7a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofervidusAuxiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofervidus auxilii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofervidusAuxiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCoryneformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium coryneforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCoryneformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpCag439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DufoureaNovaeangliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dufourea novaeangliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DufoureaNovaeangliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StackebrandtiaNassauensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stackebrandtia nassauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StackebrandtiaNassauensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_37_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaAphisGlycinesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Aphis glycines) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAphisGlycinesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaSpWa102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. WA102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpWa102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindariusDsm2278Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus tindarius DSM 2278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanolobusTindariusDsm2278Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCinnabarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trametes cinnabarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrametesCinnabarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUzinuraDiaspidicolaStrAsnerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uzinura diaspidicola str. ASNER Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUzinuraDiaspidicolaStrAsnerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwc25213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC2_52_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc25213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilibacterTermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pilibacter termitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PilibacterTermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwb24136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWB2_41_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwb24136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NautiliaProfundicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nautilia profundicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NautiliaProfundicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumTwa4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TWA4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTwa4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterUraniireducensRf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Rf4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacterUraniireducensRf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumScgcAaa288n07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288N07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288n07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCetorumMit007128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT007128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit007128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElaeophoraElaphiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elaeophora elaphi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElaeophoraElaphiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_02_FULL_42_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBrassicacearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaNorrlandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella norrlandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaNorrlandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGr1643(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium GR16-43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGr1643", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaFaecis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaFaecis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceicoccalesBacteriumVerruco02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSp6626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. 66-26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSp6626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumBdw918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BDW918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBdw918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosynechococcusSpNk55a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus sp. NK55a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusSpNk55a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpYcrl4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. YCRL4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpYcrl4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpP11g5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNiastensisDsm21313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia niastensis DSM 21313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MassiliaNiastensisDsm21313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLincolnensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lincolnensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLincolnensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg164411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumGlobosumCbs14851(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum CBS 148.51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumGlobosumCbs14851", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumSpCag815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. CAG:815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpCag815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSyntrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter syntrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSyntrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpRc586Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. RC586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioSpRc586Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusLahaulensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus lahaulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrococcusLahaulensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCh12iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CH12i Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCh12iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterFerrugineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter ferrugineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterFerrugineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeyerozymaSpJa9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma sp. JA9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaSpJa9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtochlamydiaAmoebophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia amoebophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaAmoebophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot61(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot61", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesDarlingiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles darlingi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesDarlingiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyb1full3916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYB1FULL3916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyb1full3916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaceaeBacteriumDnf00626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium DNF00626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumDnf00626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusLactolyticusS7113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus S7113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusS7113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBeijingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBeijingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumD1873Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum D 1873 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumD1873Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrucellaMelitensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brucella melitensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrucellaMelitensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpLrs4154Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. LRS4.154 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpLrs4154Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabiaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arabia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArabiaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcaligenaceaeBacteriumDtu041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenaceae bacterium DTU041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcaligenaceaeBacteriumDtu041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTeresFTeres01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres f. teres 0-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTeresFTeres01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifoxyd2full5815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYD2FULL5815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyd2full5815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSpDh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. DH-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpDh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumLongipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium longipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumLongipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSpHeli90Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. HelI90 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSpHeli90Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfCtenarytaina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytaina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlysiellaCrassaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alysiella crassa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlysiellaCrassaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallemiaMellicolaCbs63366(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia mellicola CBS 633.66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WallemiaMellicolaCbs63366", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaDsm15696Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola DSM15696 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaDsm15696Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioThiocyanoxidansArh2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerotilusNatans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerotilus natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerotilusNatans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviScgcAb598o02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi SCGC AB598O02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviScgcAb598o02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSpL21rpuld2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. L21RPulD2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpL21rpuld2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolani123eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani 123E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolani123eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpTomcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. TomC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpTomcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusMaripaludisS2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis S2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisS2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaApereaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cavia aperea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaviaApereaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdhazardiaAedisUsnm41457Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Edhazardia aedis USNM 41457 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EdhazardiaAedisUsnm41457Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSubterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Knoellia subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSubterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp141Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 141 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp141Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyncephalastrumRacemosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syncephalastrum racemosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyncephalastrumRacemosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSpRitpifCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. RITPIf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSpRitpifCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FermentimonasCaenicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fermentimonas caenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FermentimonasCaenicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioHepatariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio hepatarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioHepatariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvibaculumLavamentivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvibaculum lavamentivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvibaculumLavamentivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetoanaerobiumSticklandiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetoanaerobium sticklandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetoanaerobiumSticklandiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasponiaAndersoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parasponia andersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParasponiaAndersoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobaculumHydrogeniformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumHydrogeniformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_01_FULL_48_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo201Full4816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpCag317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaGoodfellowii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaSpGbr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gbr graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGbr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeomargaritaLithophoraAlchichicaD10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Alchichica-D10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GloeomargaritaLithophoraAlchichicaD10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumG186arEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum G186AR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumG186arEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FomitopsisRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumCf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium CF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumCf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipaludibacillusAgaradhaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus agaradhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAgaradhaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpPdc64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. PDC64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpPdc64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaLacteaDsm19367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella lactea DSM 19367 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NakamurellaLacteaDsm19367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerophagaThermohalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerophaga thermohalophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerophagaThermohalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumKyorinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kyorinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKyorinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomycesGilchristiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomycesGilchristiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumReuteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium reuteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumReuteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaePhaseolicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae phaseolicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePhaseolicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasHaloplanktisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotruncusSpCag528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:528 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasSpB5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas sp. B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseomonasSpB5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenesDsm13106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes DSM 13106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenesDsm13106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85201350091sch5140682Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201350091SCH5140682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201350091sch5140682Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhlebiopsisGigantea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhlebiopsisGigantea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaThermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fischerella thermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FischerellaThermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpMd2005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. MD2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpMd2005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovirgulaThermocuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovirgula thermocuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovirgulaThermocuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobaculumTerrenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobaculum terrenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobaculumTerrenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothelomycesThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumBrhc25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium BRHc25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumBrhc25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuculusCanorusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cuculus canorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CuculusCanorusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaCoriaceaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia coriaceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaCoriaceaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubritepidaFlocculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubritepida flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubritepidaFlocculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb241528n17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_528N17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528n17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlectobacillusMajorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flectobacillus major Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlectobacillusMajorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KingellaOralisAtcc51147Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kingella oralis ATCC 51147 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KingellaOralisAtcc51147Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumAviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MycobacteriumAviumAviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanogenicArchaeonMixedCultureIso4G1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed culture ISO4-G1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixedCultureIso4G1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaWenchangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea wenchangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaWenchangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusCatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus catus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprococcusCatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AvibacteriumParagallinarum221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumKbs83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaNiwaeNbrc108934Dsm45340Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niwae NBRC 108934 DSM 45340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaNiwaeNbrc108934Dsm45340Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasAquamarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas aquamarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasAquamarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterGummosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter gummosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterGummosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoniliophthoraPerniciosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumKbs96Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs96Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanibacillusModesticaldusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulcanibacillus modesticaldus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulcanibacillusModesticaldusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraKuenenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira kuenenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraKuenenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterCibinongensis4h1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis 4H-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterCibinongensis4h1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifoxyd1full4224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD1FULL4224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd1full4224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaVaferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia vafer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaVaferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumLuticocti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium luticocti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLuticocti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasAgitataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas agitata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAgitataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpLtsp849(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP849 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp849", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmanitaThiersii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amanita thiersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmanitaThiersii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag169Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag169Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ItalianCloverPhyllodyPhytoplasmaStrMa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Italian clover phyllody phytoplasma str. MA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ItalianCloverPhyllodyPhytoplasmaStrMa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpN5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. N5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpN5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho202full4012bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO202FULL4012b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho202full4012bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumStbin11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaRodasiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rodasii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaRodasiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg165711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_57_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurotusOstreatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PleurotusOstreatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizoctoniaSolaniAg1ibEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1ibEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberBorchiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tuber borchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuberBorchiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TachikawaeaGelatinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tachikawaea gelatinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TachikawaeaGelatinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpiritivorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium spiritivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpiritivorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaKashmirensisW13003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis W13003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisW13003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpNdb2meth1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. NDB2Meth1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpNdb2meth1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf236839Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF2_36_839 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf236839Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusParabrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus parabrevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusParabrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacterium351910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium 351910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacterium351910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCag1963641Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CAG:196_36_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCag1963641Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexusAurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusCaldoxylosilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus caldoxylosilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusCaldoxylosilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZhongshaniaAliphaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zhongshania aliphaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZhongshaniaAliphaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LautropiaMirabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lautropia mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LautropiaMirabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerGoleimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopiger goleimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopigerGoleimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampbellbacteriaBacteriumRifcsplowo201full3415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO201FULL3415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo201full3415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiptonbacteriaBacteriumGwb1496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium GWB1496 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumGwb1496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AhrensiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusLuteusDsm17002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus luteus DSM 17002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusLuteusDsm17002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiaeAtcc27957Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae ATCC27957 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeAtcc27957Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsplowo202full4710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO202FULL4710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo202full4710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmergomycesPasteurianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmergomycesPasteurianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPseudintermedius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermedius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumParaconglomeratumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium paraconglomeratum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumParaconglomeratumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusClarus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus clarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizophagusClarus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RosenbergiellaNectareaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rosenbergiella nectarea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RosenbergiellaNectareaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumUj101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium UJ101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumUj101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_48_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaLanzarotensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachancea lanzarotensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachanceaLanzarotensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaSpAb629b18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. AB629B18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpAb629b18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpKh1p2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. kh1p2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh1p2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterKobeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter kobei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterKobeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpDg25b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full3816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL3816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full3816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumGwf24514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumSpWcc10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. WCC10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpWcc10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TistrellaMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tistrella mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TistrellaMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumRoseum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumRoseum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumZor0006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ZOR0006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumZor0006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA2_44_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraOligosporaAtcc43269(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura oligospora ATCC 43269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraOligosporaAtcc43269", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusSpMv1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. MV1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusSpMv1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumPullulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaEburneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora eburnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaEburneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolactobacillusTerraeHkm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae HKM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusTerraeHkm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpSfdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaAlkalescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alkalescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlkalescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifoxya2Full4310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFOXYA2_FULL_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifoxya2Full4310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho201full4523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO201FULL4523 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho201full4523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludisphaeraBorealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paludisphaera borealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaludisphaeraBorealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpOk626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. ok626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpOk626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelothrixTonsillarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix tonsillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixTonsillarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasCellaseaDsm20118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea DSM 20118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CellulomonasCellaseaDsm20118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterJejuni81176Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 81176 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterJejuni81176Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavochromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavochromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrondihabitansSpLeaf304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. Leaf304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpLeaf304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTakakiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium takakiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTakakiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterSpTr13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter sp. TR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterSpTr13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusGeothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus geothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGeothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylothermaceaeBacteriaB42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria B42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteriaB42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRifamycini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRifamycini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorObsidiansisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor obsidiansis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorObsidiansisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusSpMm3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus sp. MM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusSpMm3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloactinobacteriumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloactinobacterium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloactinobacteriumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphiprionPercula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion percula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphiprionPercula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr3BacteriumGw2011gwf23518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium GW2011GWF23518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3BacteriumGw2011gwf23518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesUrinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwe24236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_42_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe24236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaSpUtamx2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMediterraneensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides mediterraneensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMediterraneensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPlebeiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides plebeius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPlebeiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpNsp21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP2.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpNsp21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiCft073(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli CFT073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiCft073", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg2305367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_53_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2305367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNeoehrlichiaLotorisStrRac413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Neoehrlichia lotoris str. RAC413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNeoehrlichiaLotorisStrRac413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpF0440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag568Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag568Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VagococcusTeuberiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus teuberi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VagococcusTeuberiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAchromatiumPalustreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Achromatium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAchromatiumPalustreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeroglobusGeminatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeroglobus geminatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeroglobusGeminatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidimonasBauzanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candidimonas bauzanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidimonasBauzanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAeronauticumDsm10349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum DSM 10349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticumDsm10349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_12_FULL_45_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpEhn03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. EhN03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpEhn03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae232(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 232 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae232", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpScn6214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SCN 62-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpScn6214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterSpRedseas28b5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. REDSEAS28B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpRedseas28b5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPhoenicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus phoenicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPhoenicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1590Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1590 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1590Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterGuttiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter guttiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGuttiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterNitrogenifigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter nitrogenifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterNitrogenifigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceibacteriumMercuriale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceibacterium mercuriale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceibacteriumMercuriale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrobacterRadiotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrobacterRadiotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalicatenaContorta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena contorta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaContorta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiSl33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii SL33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiSl33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpSk37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. SK37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSpSk37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRhodochrousEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodochrous Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodochrousEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiSerovarHardjoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Hardjo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarHardjoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesEuropaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesEuropaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaGinsengisegetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga ginsengisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaGinsengisegetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumBergheiAnkaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei ANKA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumBergheiAnkaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumM2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf405Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf405Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermorudisPeleaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermorudis peleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermorudisPeleaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAlimentariusDsm20249Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius DSM 20249 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlimentariusDsm20249Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsdaarsusmarc1296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifcsphigho201full63240Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO201FULL63240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho201full63240Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntamoebaDispar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Entamoeba dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EntamoebaDispar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4113b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4113b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4113b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumAerolatumDsm21857Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum DSM 21857 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatumDsm21857Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full4016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasNeptuniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas neptunium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasNeptuniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaPinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga pinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaPinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumChubuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chubuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumChubuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1025541Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025541 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025541Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSoleaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum soleae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSoleaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacterium5419Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 54-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium5419Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpTarazona(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Tarazona graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpTarazona", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterShowaeRm3277Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae RM3277 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeRm3277Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaSubspPascullei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. pascullei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspPascullei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpNfr01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. NFR01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpNfr01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiaportheHelianthiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe helianthi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiaportheHelianthiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumA4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicycliphilusDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MizugakiibacterSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mizugakiibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MizugakiibacterSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAsiaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacteriumGlomerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coriobacterium glomerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriumGlomerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAsaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCcnwgs0286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens CCNWGS0286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCcnwgs0286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp7243faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 7243FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp7243faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusIsoporaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus isoporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusIsoporaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisLatensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis latens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisLatensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumOxalicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium oxalicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumOxalicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCystitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriCd034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri CD034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriCd034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelesianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solemya velesiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelesianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCrustorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crustorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrustorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusAntranikianii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus antranikianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusAntranikianii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumCapitatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium capitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumCapitatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumAerolatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucinivoransHirudinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucinivorans hirudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucinivoransHirudinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomarinumVadiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomarinum vadi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomarinumVadiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacteriumCg2304061(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_40_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304061", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaeruleatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caeruleatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaeruleatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSuebicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus suebicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSuebicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGottheiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gottheilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGottheiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumLychnidisdioicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum lychnidisdioicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisdioicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbiconiuxSolaniNbrc106740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux solani NBRC 106740 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HerbiconiuxSolaniNbrc106740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohalieaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudohaliea rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudohalieaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCg1024617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium CG1_02_46_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCg1024617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiptonbacteriaBacteriumRifcsplowo212full6015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO212FULL6015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo212full6015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusLuminescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus luminescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLuminescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaPhototrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea phototrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaPhototrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcusTerreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus terreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcusTerreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumClariflavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium clariflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumClariflavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParageobacillusThermantarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermantarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermantarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeminorellaGrimontiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leminorella grimontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeminorellaGrimontiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumHigginsianumImi349063Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum IMI 349063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianumImi349063Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBaroniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella baroniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBaroniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGwe23716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_37_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe23716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaViridescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella viridescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaViridescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJce(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJce", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc2458Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC2458 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc2458Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumSp1860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. 1860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumSp1860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpAmel2xe9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Amel2xE9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAmel2xe9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTyrobutyricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tyrobutyricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTyrobutyricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_38_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTuaregiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tuaregi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTuaregiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisNigoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis nigoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisNigoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaMontpellierensisDsm17217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis DSM 17217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensisDsm17217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesSalmoniphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides salmoniphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSalmoniphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTyphiStrB9991cwppEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi str. B9991CWPP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTyphiStrB9991cwppEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpSk37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. SK37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSpSk37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CutibacteriumAvidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium avidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAvidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaStercorea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella stercorea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaStercorea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EucalyptusGrandisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eucalyptus grandis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EucalyptusGrandisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HericiumAlpestreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hericium alpestre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HericiumAlpestreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSpF0087Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0087 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0087Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasJatrophaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas jatrophae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasJatrophaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarboxydothermusIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPaucivoransNbrc100373Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia paucivorans NBRC 100373 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaPaucivoransNbrc100373Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInadai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira inadai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInadai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpSm22m07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SM22M-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpSm22m07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinactinosporaThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinactinosporaThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSulfidiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sulfidiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSulfidiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaEuropaeaSh398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea SH398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaeaSh398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaHolmesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella holmesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaHolmesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhlebiaCentrifuga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phlebia centrifuga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhlebiaCentrifuga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YuhushiellaDeserti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yuhushiella deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YuhushiellaDeserti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpC448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. C448 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpC448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFarraginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus farraginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFarraginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSpAe122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. AE122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasSpAe122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaistiaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaistia soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaistiaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaKudriavzevii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pichia kudriavzevii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PichiaKudriavzevii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCaseinilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus caseinilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCaseinilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesScott(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Scott graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesScott", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSp2ht1a6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. 2HT1A6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSp2ht1a6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesUrogenitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacteriumCg2304061Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_40_61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304061Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbidosporaCretaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora cretacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaCretaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematomicrobiumSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haematomicrobium sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaematomicrobiumSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansPlanktonicusIiD5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus II-D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicusIiD5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4648(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4648 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4648", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus panis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpA16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. A16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpA16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSpM107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. M107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSpM107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumGenospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium genosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumGenospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaSpD27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. D27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaSpD27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp3211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp3211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSordellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sordellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSordellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusPropionicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus propionicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelosinusPropionicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusTorquesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Ruminococcus] torques Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusTorquesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPHIGHO2_02_FULL_45_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosyntrophaLipolyticaDsm11003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica DSM 11003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolyticaDsm11003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpLeaf359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Leaf359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLeaf359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpCsm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. CSM-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpCsm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCetorumMit995656(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT995656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit995656", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaAureaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa aurea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAureaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansAtcc27774Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ATCC27774 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansAtcc27774Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumImcc26207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYD1_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyd1Full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliiglaciecolaLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliiglaciecola lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliiglaciecolaLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMiricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia miricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ElizabethkingiaMiricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWeihaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus weihaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusWeihaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumRoseumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium roseum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumRoseumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisCf1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis CF1b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisCf1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalinemaSpCaciamCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciamCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmittiumMucronatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smittium mucronatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmittiumMucronatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumVacciniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium vaccinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumVacciniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaniviriJcm17471Dsm24301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri JCM 17471 DSM 24301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaniviriJcm17471Dsm24301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeronosporaEffusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peronospora effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeronosporaEffusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalinemaSpCaciam70d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM 70d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciam70d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_55_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMt11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium mt11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMt11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinivibrionaceaeBacteriumWg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrionaceae bacterium WG-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrionaceaeBacteriumWg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararhizobiumPolonicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium polonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumPolonicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaBifida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella bifida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaBifida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioMixtusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio mixtus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioMixtusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKwashiorkori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kwashiorkori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusKwashiorkori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Henriciella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HenriciellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumUsda6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumNitrogenifigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium nitrogenifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumNitrogenifigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumEuropaeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium europaeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumEuropaeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScleropagesFormosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scleropages formosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScleropagesFormosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeduiniMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beduini massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeduiniMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSpCaAtcc33047Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. CA ATCC 33047 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpCaAtcc33047Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpJa23baCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA23Ba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa23baCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpSoil777Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil777Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfatatorIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSpA13lCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. A13L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpA13lCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMurrayiDsm11303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus murrayi DSM 11303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DeinococcusMurrayiDsm11303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterosteliumAlbumPn500Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Heterostelium album PN500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HeterosteliumAlbumPn500Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicola5aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola 5A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicola5aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiae14628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae 14628 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiae14628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichosporonAsahiiVarAsahiiCbs8904(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii var. asahii CBS 8904 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichosporonAsahiiVarAsahiiCbs8904", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpCacia14h2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. CACIA14H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpCacia14h2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaRodasiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rodasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaRodasiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeropyrumCaminiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum camini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeropyrumCaminiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterSpCcs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. CCS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpCcs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaGlebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTyrobutyricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tyrobutyricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTyrobutyricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumThermocellumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium thermocellum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminiclostridiumThermocellumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSphaericusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSphaericusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumYanoikuyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium yanoikuyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumYanoikuyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRaac2wwe31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RAAC2WWE31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRaac2wwe31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseoverticillatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseoverticillatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseoverticillatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IzhakiellaAustraliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella australiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaAustraliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumThiodismutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiodismutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodovibrioSp970Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodovibrio sp. 970 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiorhodovibrioSp970Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaPediEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia pedi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPediEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumGb30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum GB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumGb30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpAu20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsbolusVerrucosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asbolus verrucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsbolusVerrucosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDaejeonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium daejeonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDaejeonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumCg2304421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_44_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpScn7327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. SCN 73-27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpScn7327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensisDsm45107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis DSM 45107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensisDsm45107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HesseltinellaVesiculosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hesseltinella vesiculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HesseltinellaVesiculosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaTropicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tropica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTropicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemominutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemominutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemominutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaAerogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella aerogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaAerogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaCornellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria cornellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaCornellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeR6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae R6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeR6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisAtcc14393(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ATCC14393 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAtcc14393", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusSpPe3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus sp. PE3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DermacoccusSpPe3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerriphaselusSpR1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus sp. R1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusSpR1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNeoaurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neoaurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeoaurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiaceaeBacteriumSg6c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium SG6C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumSg6c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpNsubCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. Nsub Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpNsubCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhoceenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phoceense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhoceenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaLeachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma leachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaLeachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpF0426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCitroniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium citroniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCitroniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiansivirgaZeaxanthinifaciensCcSamt1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens CC-SAMT-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCcSamt1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4518Fw2643(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4518 (FW-2643) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4518Fw2643", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot568Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root568 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot568Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUrhd0025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHD0025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhd0025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromohalobacterSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpJm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwf23876Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF23876 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf23876Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp22311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2231.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp22311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistalesBacterium5881Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 58_81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5881Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusYonginensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus yonginensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusYonginensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAceticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aceticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAceticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGallinarumDsm18171Jcm13658Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum DSM 18171 JCM 13658 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesGallinarumDsm18171Jcm13658Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpRoot710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticumS6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum S6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumS6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerriglobusRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpTdk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. TDK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpTdk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasTaxiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas taxi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTaxiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag253Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag253Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpAlt199Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. ALT199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpAlt199Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilanimonasLentaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Silanimonas lenta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SilanimonasLentaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaCylindricaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabaena cylindrica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabaenaCylindricaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrdosporaColligataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ordospora colligata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrdosporaColligataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium loti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumLotiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuraticoccusMonumentiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Auraticoccus monumenti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AuraticoccusMonumentiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesemziaIncertaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desemzia incerta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesemziaIncertaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpJs623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JS623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpJs623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctobacteriumSpCag207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EptesicusFuscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eptesicus fuscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EptesicusFuscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaligenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobius653lCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius 653L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobius653lCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloprofundusSedimentiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloprofundus sedimenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloprofundusSedimentiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpMc2021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo212full6015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO212FULL6015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo212full6015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSegetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium segetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSegetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesSpAsf519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. ASF519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesSpAsf519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusWasatchensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus wasatchensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusWasatchensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag798Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:798 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag798Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumOxalicum1142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum 114-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliumOxalicum1142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosphaeraSpWgk6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera sp. WGK6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraSpWgk6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusCaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus californiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusCaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaFlavaNbrc102514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava NBRC 102514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaFlavaNbrc102514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsialesBacteriumExBugulaNeritinaAb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium (ex Bugula neritina AB1) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsialesBacteriumExBugulaNeritinaAb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParaphrohaemolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paraphrohaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParaphrohaemolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiaWalkeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tilletia walkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TilletiaWalkeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaCruzi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaCruzi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusObesiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusObesiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCoraliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio coralii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCoraliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesFinegoldiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes finegoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesFinegoldiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpC06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpMd27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. MD27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpMd27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwf23566(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWF23566 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwf23566", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterHelveticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter helveticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FranconibacterHelveticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticumDsm21995(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum DSM 21995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLipolyticumDsm21995", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinopsTelfairiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echinops telfairi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EchinopsTelfairiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_59_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpJc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. JC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpJc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasDiversa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas diversa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasDiversa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg2304514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG2304514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg2304514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGobiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gobiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGobiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full5338Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL5338 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full5338Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusOncorhynchi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus oncorhynchi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusOncorhynchi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpQa3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. QA3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpQa3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpWb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. WB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpWb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaRubrilucensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella rubrilucens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaRubrilucensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCucumis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cucumis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCucumis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisH37ra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Ra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37ra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13140cm6927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_1_40CM_69_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13140cm6927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpF0412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. F0412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpF0412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasSpB5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas sp. B5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseomonasSpB5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCostaricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus costaricensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCostaricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumCg2303729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium CG2_30_37_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumCg2303729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JatrophihabitansEndophyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jatrophihabitans endophyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JatrophihabitansEndophyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerasakiellaMagneticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella magnetica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaMagneticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEdens01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Edens01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEdens01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumMela1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium MELA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumMela1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwc24418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWC24418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwc24418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_43_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LepisosteusOculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lepisosteus oculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LepisosteusOculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusZeaxanthinifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus zeaxanthinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusZeaxanthinifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAcetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter aceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAcetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumH143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSimplexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSimplexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaRapaSubspPekinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa subsp. pekinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrassicaRapaSubspPekinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconacetobacterDiazotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter diazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterDiazotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribiusSpMola401Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Maribius sp. MOLA401 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MaribiusSpMola401Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpH5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRumoiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rumoiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioRumoiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaJejudonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordia jejudonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiaJejudonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpRoot81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Root81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpRoot81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusActinosclerusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus actinosclerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusActinosclerusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSartoriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sartorii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSartoriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMultihospitiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium multihospitium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMultihospitiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAtcc31555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ATCC31555 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAtcc31555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full3811bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL3811b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full3811bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerodermaCitrinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scleroderma citrinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SclerodermaCitrinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeO1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "VibrioCholeraeO1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSp2136faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 2136FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp2136faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpFjat14222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. FJAT-14222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpFjat14222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasMoolapensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas moolapensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronomonasMoolapensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaFuscipesFuscipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glossina fuscipes fuscipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlossinaFuscipesFuscipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPersicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPersicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaCarnea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia carnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaCarnea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParaplantarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paraplantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParaplantarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorQuimbayensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloramator quimbayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloramatorQuimbayensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4516Fw969Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4516 (FW-969) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4516Fw969Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxLentus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxLentus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraCyclicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira cyclica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraCyclicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemetriaTerragenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demetria terragena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemetriaTerragenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntestinibacterBartlettii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intestinibacter bartlettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntestinibacterBartlettii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterNitrogenifigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter nitrogenifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterNitrogenifigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag632Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:632 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag632Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaSalaciae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrinema salaciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSalaciae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraMoscoviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira moscoviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraMoscoviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumH1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumH1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpQhl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. QHL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpQhl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full4432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4432 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReichenbachiellaFaecimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella faecimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaFaecimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24535Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24535 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24535Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisTropicalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisTropicalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusSpSoil803Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil803Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosulfurimonasDismutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfurimonas dismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosulfurimonasDismutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolobusPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolobusPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusVestibularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus vestibularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusVestibularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobacteriovoraxAntillogorgiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteriovorax antillogorgiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobacteriovoraxAntillogorgiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella histicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaHisticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaSpF0422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpF0422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusMahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusMahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsplowo202full4710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO202FULL4710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo202full4710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kingella denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KingellaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachypodiumDistachyonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachypodium distachyon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachypodiumDistachyonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFulva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fulva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFulva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusMauleoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus mauleonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusMauleoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraKmetyiSerovarMalaysiaStrBejoIso9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira kmetyi serovar Malaysia str. Bejo-Iso9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraKmetyiSerovarMalaysiaStrBejoIso9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumEuropaeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium europaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumEuropaeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpBr816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. BR816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpBr816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisPhaseoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisPhaseoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpBm10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. BM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpBm10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSpEbm43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta sp. EBM-43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaSpEbm43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusStelliferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus stellifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusStelliferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaSediminilitorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kangiella sediminilitoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KangiellaSediminilitorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraMobilis13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis 13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilis13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumIndicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumIndicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinibacterTainanensisDsm15459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis DSM 15459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinibacterTainanensisDsm15459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NosocomiicoccusSpNp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus sp. NP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NosocomiicoccusSpNp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBaratii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium baratii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBaratii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumResistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium resistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumResistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCantonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus cantonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCantonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaTm7xCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria TM7x Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaTm7xCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho201Full5513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_01_FULL_55_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho201Full5513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumNordicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nordicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNordicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumSit11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium SIT11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumSit11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaThermarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga thermarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermotogaThermarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSmithiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus smithii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSmithiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSlbn35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. SLBN-35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSlbn35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumLf3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return bacterium LF3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriumLf3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSimilisDsm23365Jcm2765(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus similis DSM 23365 JCM 2765 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSimilisDsm23365Jcm2765", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaGummosaDsm723Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Derxia gummosa DSM 723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DerxiaGummosaDsm723Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumFreudenreichii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium freudenreichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumFreudenreichii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrothrixParvicellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microthrix parvicella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrothrixParvicellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpartansiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium spartansii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpartansiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesKatraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces katrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKatraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusJostiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus jostii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusJostiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpEcsmb14101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ECSMB14101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpEcsmb14101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpAb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. aB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpAb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpNrrlb16348Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16348 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16348Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiibiusSpNy1634622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Branchiibius sp. NY16-3462-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BranchiibiusSpNy1634622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesPapillosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides papillosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesPapillosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisSpAtcc49242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. ATCC49242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpAtcc49242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRattaustralianiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattaustraliani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattaustralianiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHodgkiniaCicadicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hodgkinia cicadicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHodgkiniaCicadicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterSenuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter senuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSenuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4717 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonquetellaAnthropiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jonquetella anthropi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JonquetellaAnthropiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllochromatiumVinosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium vinosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumVinosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpLeaf141Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf141Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumXueshanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xueshanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXueshanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacteriumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapioAnubis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Papio anubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PapioAnubis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilamentousCyanobacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return filamentous cyanobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FilamentousCyanobacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpYr558(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. YR558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpYr558", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThamnocephalisSphaerosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thamnocephalis sphaerospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThamnocephalisSphaerosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusThracensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus thracensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusThracensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAzotoformansLmg9581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus azotoformans LMG 9581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAzotoformansLmg9581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpYr375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. yr375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpYr375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionicicellaSuperfundiaDsm22317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionicicella superfundia DSM 22317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundiaDsm22317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynchytriumEndobioticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium endobioticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynchytriumEndobioticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumFrankenforstenseDsm45800Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense DSM 45800 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstenseDsm45800Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalodesulfurarchaeumFormicicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfurarchaeum formicicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalodesulfurarchaeumFormicicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPetrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella petrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaPetrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinum202fCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum 202F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinum202fCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnochordaPilosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnochorda pilosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnochordaPilosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypholomaSublateritiumFd334Ss4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium FD-334 SS-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HypholomaSublateritiumFd334Ss4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinorNm305Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor NM305 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinorNm305Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiphinematobacterSpIdahoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xiphinematobacter sp. Idaho Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XiphinematobacterSpIdahoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodosporidiumToruloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodosporidium toruloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodosporidiumToruloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full4012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpBis7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. BIS7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpBis7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg1023112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_31_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1023112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNomiusNrrl13137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nomius NRRL 13137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusNomiusNrrl13137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Loktanella hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LoktanellaHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodolunaPlanktonicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna planktonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodolunaPlanktonicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumTrifoliiCb782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii CB782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiCb782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeggiatoaLeptomitoformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa leptomitoformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaLeptomitoformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpIbvhs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviWkb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi wkB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviWkb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellaCapsiferriformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionella capsiferriformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellaCapsiferriformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyscomitrellaPatens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Physcomitrella patens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhyscomitrellaPatens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSimplex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSimplex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumCavoleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum cavolei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumCavoleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraNanhaiensisE4078(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis E407-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensisE4078", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRbg19ftcombo3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG19FTCOMBO3910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg19ftcombo3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesQinglanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qinglanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQinglanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecatorAmericanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Necator americanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NecatorAmericanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophaceaeBacteriumCg2304912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_49_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2304912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_12_FULL_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumSpF0552Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum sp. F0552 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSpF0552Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_02_FULL_39_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapaverSomniferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Papaver somniferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PapaverSomniferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAeronauticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusPleuropneumoniae5bL20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 5b L20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae5bL20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml140438Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML140438 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml140438Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LitorimicrobiumTaeanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litorimicrobium taeanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitorimicrobiumTaeanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteipulveratusHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasCrevioricanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas crevioricanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCrevioricanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaldiniaSpEc12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daldinia sp. EC12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaldiniaSpEc12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpWp9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WP9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWp9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwa13921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlantibacterSpLeaf314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter sp. Leaf314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlantibacterSpLeaf314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumFlaccumfaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium flaccumfaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumFlaccumfaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full5314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL5314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full5314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAzotifigensDsm17556(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens DSM 17556 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAzotifigensDsm17556", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusSpEllin185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. Ellin185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DermacoccusSpEllin185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGingeriNcppb3146Lmg5327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri NCPPB 3146 LMG 5327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasGingeriNcppb3146Lmg5327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwa25416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_54_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpCf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalobacter sp. CF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalobacterSpCf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermosubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesGlobisporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes globisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesGlobisporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavisolibacterGinsengisoliDsm18119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli DSM 18119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoliDsm18119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythiumIrregulareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium irregulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PythiumIrregulareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaSp6palisep08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. 6PALISEP08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSp6palisep08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrombidiumDelienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrombidium deliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrombidiumDelienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolaminaPelagica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolamina pelagica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolaminaPelagica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FicedulaAlbicollisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ficedula albicollis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FicedulaAlbicollisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonBa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStoquefichusSpKle1796Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. KLE1796 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpKle1796Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpMst1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MSt1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMst1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetobutylicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetobutylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetobutylicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumGallicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium gallicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGallicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis865192(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 865192 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis865192", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaTamlensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yoonia tamlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YooniaTamlensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4226(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4226", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSprentiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterPickeringiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter pickeringii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterPickeringiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmotaMarmota(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marmota marmota graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarmotaMarmota", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MollicutesBacteriumHr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHarbinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces harbinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHarbinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantholopsHodgsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantholops hodgsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantholopsHodgsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusThermoglucosidasius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermoglucosidasius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermoglucosidasius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusHippei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusHippei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaTm7x(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria TM7x graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaTm7x", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PannonibacterPhragmitetus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pannonibacter phragmitetus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PannonibacterPhragmitetus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpYl23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YL23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYl23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterSpTr13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter sp. TR13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterSpTr13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpP838(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. P838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpP838", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaSp7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSp7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FischerellaThermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella thermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FischerellaThermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAridiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer aridi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferAridiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterSolanacearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter solanacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiberibacterSolanacearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosaetaHarundinacea6acCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea 6Ac Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosaetaHarundinacea6acCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasCompostiDsm21721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonas composti DSM 21721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonasCompostiDsm21721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaSpRifoxya12full4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. RIFOXYA12FULL4616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpRifoxya12full4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpJ31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. J31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpJ31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacterSpBrhc7a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacter sp. BRHc7a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacterSpBrhc7a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumWsm2304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum WSM2304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumWsm2304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaConceptionensis9403948Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis 9403948 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaConceptionensis9403948Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteri10023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri 10023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteri10023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_41_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf194Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf194 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf194Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSaudiphocaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudiphocaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudiphocaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo212full6015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO212FULL6015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo212full6015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPutrefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella putrefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPutrefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpLeaf261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaseolusVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaseolus vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaseolusVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeoalkalibacterFerrihydriticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter ferrihydriticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterFerrihydriticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpS718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S718 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaInohanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia inohanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaInohanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHimalayensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus himalayensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHimalayensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024082(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024082", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPersicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus persicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPersicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_44_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSp3363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. 3363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalothrixSp3363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidihalobacterProsperusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter prosperus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterProsperusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaricaulisMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAidingenseJcm13560Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aidingense JCM 13560 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumAidingenseJcm13560Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_12_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho212Full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpFc2018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. FC2018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpFc2018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaBacilliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria bacilliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaBacilliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaDermatitidisNihUt8656(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis NIH/UT8656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExophialaDermatitidisNihUt8656", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisKctc3167Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis KCTC3167 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisKctc3167Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterNeustonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter neustonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterNeustonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterLanienae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lanienae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLanienae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatirhabdiumButyrativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumArgentinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium argentinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArgentinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocCitreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc citreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCitreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BulleidiaExtructaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bulleidia extructa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BulleidiaExtructaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPeucetia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora peucetia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPeucetia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaQuasipneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMarshiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella marshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMarshiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudohongiellaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSaniviriJcm17471Dsm24301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri JCM 17471 DSM 24301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaniviriJcm17471Dsm24301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaJiangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaJiangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpKpr6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. kpr-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpKpr6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchangiumGephyraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archangium gephyra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchangiumGephyraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifoxyb1full4033Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFOXYB1FULL4033 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifoxyb1full4033Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimicrobiumPachnodaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaRupisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga rupis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaRupisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaVignaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga vignae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaVignaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaChahannaoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinicolaVietnamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echinicola vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EchinicolaVietnamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHel133143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. Hel1_33_143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpHel133143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPectinovorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium pectinovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPectinovorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSpTm1035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseovarius sp. TM1035 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseovariusSpTm1035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpF52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. F52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpF52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumMelilotiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium meliloti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMelilotiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumVivax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium vivax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumVivax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusParasiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusParasiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMarseillep2986Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium MarseilleP2986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMarseillep2986Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SideroxydansLithotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans lithotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SideroxydansLithotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFructosivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fructosivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFructosivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermanellaAerolataKacc11604(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Skermanella aerolata KACC 11604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SkermanellaAerolataKacc11604", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpB13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. b13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpB13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNeworleansenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neworleansense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeworleansenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpCny236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. CNY236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpCny236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PochoniaChlamydosporia123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesTurgidiscabies(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces turgidiscabies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTurgidiscabies", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalimicrobiumCyclicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium cyclicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumCyclicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full4732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_47_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full4732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloterrigenaMahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena mahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaMahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solemya velum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd2full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD2FULL4114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd2full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymophilusRaffinosivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymophilus raffinosivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZymophilusRaffinosivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilanimonasLentaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Silanimonas lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SilanimonasLentaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacinutrixSp5h374Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. 5H374 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSp5h374Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasUtahensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas utahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasUtahensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaSolani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaSolani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAceti1023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti 1023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAceti1023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo202full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO202FULL4018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo202full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAnaemiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia anaemiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAnaemiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSp6r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. 6R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSp6r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBiomig1nCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BIOMIG1N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBiomig1nCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaMattheeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mattheei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMattheeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospiraTrueperi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospira trueperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospiraTrueperi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpZagget11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Zagget11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpZagget11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumIndologenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indologenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndologenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaTrachomatisDUw3CxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis D/UW-3/CX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatisDUw3CxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumCiceriBiovarCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri biovar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriBiovarCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaAuratinigraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora auratinigra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAuratinigraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxyb1full4319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYB1FULL4319 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyb1full4319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusSolitariusNbrc100494(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius NBRC 100494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetragenococcusSolitariusNbrc100494", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusClavatusNrrl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus NRRL 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusClavatusNrrl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpE14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. e14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpE14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChaetomiumGlobosumCbs14851Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum CBS 148.51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumGlobosumCbs14851Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MageeibacillusIndolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mageeibacillus indolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MageeibacillusIndolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElioraeaTepidiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elioraea tepidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElioraeaTepidiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFonticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia fonticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaFonticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumNalgiovense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nalgiovense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNalgiovense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifcsplowo2123612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFCSPLOWO2_12_36_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifcsplowo2123612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium MA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc23941Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_39_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc23941Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHylemonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hylemonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHylemonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloversatilisDiscipulorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis discipulorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisDiscipulorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilegiaCoeruleaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquilegia coerulea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquilegiaCoeruleaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FimbriimonasGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fimbriimonas ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FimbriimonasGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoolittleaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doolittlea endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoolittleaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeijerinckiaSp28yea48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia sp. 28YEA48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaSp28yea48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiochaetaLigniariaNrrl30616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria NRRL 30616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ConiochaetaLigniariaNrrl30616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DermabacterVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DermabacterVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopostipesSuicloacalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterCaesariensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter caesariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterCaesariensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZunongwangiaProfundaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia profunda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaProfundaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaDistributaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta distributa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaDistributaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpH14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaTetraspermaFgsc2509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma FGSC 2509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeurosporaTetraspermaFgsc2509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWB1_43_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpScn6214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SCN 62-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpScn6214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAmikacinitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSp369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 36-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiostomaPiceaeUamh11346Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae UAMH 11346 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OphiostomaPiceaeUamh11346Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusArctos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ursus arctos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrsusArctos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_12_FULL_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSouthafrica7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SouthAfrica7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSouthafrica7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensQ287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Q287 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensQ287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReinekeaBlandensisMed297Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Reinekea blandensis MED297 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ReinekeaBlandensisMed297Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterMetallireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterMetallireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumXinjiangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumSpRoot495(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root495 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot495", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCl2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohongiellaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTenax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium tenax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTenax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxBoronicumulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax boronicumulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxBoronicumulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaPanamericanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Baudoinia panamericana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BaudoiniaPanamericanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSp1m11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 1M-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp1m11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQuintanaRm11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella quintana RM-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaQuintanaRm11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrugiaPahangiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brugia pahangi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrugiaPahangiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusIntermediusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusIntermediusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTetaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaAmbifariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ambifaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAmbifariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpMb2005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MB2005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMb2005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilaChrysaetos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquila chrysaetos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquilaChrysaetos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEisenbacteriaBacteriumRbg167146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Eisenbacteria bacterium RBG_16_71_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusEisenbacteriaBacteriumRbg167146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoclostridiumStercorarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoclostridium stercorarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoclostridiumStercorarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBikiniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bikiniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBikiniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensF2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens F2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensF2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusChilensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusCyanogriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus cyanogriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusCyanogriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAmmonioxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia ammonioxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAmmonioxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumCg2303210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_32_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfUnidentifiedScalySnailIsolateMonjuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified scaly snail isolate Monju Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentifiedScalySnailIsolateMonjuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApostichopusJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apostichopus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApostichopusJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumKbs83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterNeptunius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter neptunius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterNeptunius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculischaeffiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculischaeffi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculischaeffiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumJdfr78(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr78", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusBaldriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus baldri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrococcusBaldriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodosporidiumToruloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodosporidium toruloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodosporidiumToruloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFischeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fischeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioFischeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasMephitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas mephitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasMephitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumLipolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumDurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium durum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusParviboronicapiensJcm18861(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens JCM 18861 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiensJcm18861", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraPsammophilaCbs110553Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila CBS 110553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraPsammophilaCbs110553Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnatilineaApprima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornatilinea apprima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnatilineaApprima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinispirillumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinispirillum alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinispirillumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSp24yea8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. 24YEA8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSp24yea8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThioglobusSpRedseaS12B1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus sp. REDSEA-S12_B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSpRedseaS12B1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NelumboNuciferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nelumbo nucifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NelumboNuciferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNasuensisJcm17158(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis JCM 17158 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNasuensisJcm17158", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSyringaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix syringae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSyringaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpOv277(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. OV277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpOv277", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_38_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSphaeroides241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides 241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroides241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioMexicanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mexicanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMexicanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26618(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_66_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26618", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliangiumOchraceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haliangium ochraceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaliangiumOchraceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaFlorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma florum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaFlorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNavarrensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio navarrensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioNavarrensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpLeaf7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumViolaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium violaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumViolaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibaculumRodentium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibaculum rodentium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibaculumRodentium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNeonataleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium neonatale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNeonataleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpCaviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpCaviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYC1_FULL_38_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaAtcc25996Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa ATCC25996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaAtcc25996Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrabulsiellaGuamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella guamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrabulsiellaGuamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusUrinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaineyellaAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Raineyella antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RaineyellaAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AiluropodaMelanoleuca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ailuropoda melanoleuca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AiluropodaMelanoleuca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSp8254bfaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 8_2_54BFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSp8254bfaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisAtcc29212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecalis ATCC29212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaecalisAtcc29212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusFujiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusFujiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesVulturisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces vulturis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesVulturisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGw2011Gwa25212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GW2011_GWA2_52_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGw2011Gwa25212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpDi166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. DI166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpDi166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwc25213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC2_52_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc25213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioCrossotusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio crossotus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioCrossotusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCalidoustusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus calidoustus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusCalidoustusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusYanchengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus yanchengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacillusYanchengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraTerpstraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira terpstrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraTerpstraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaLijiangensisNbrc108240Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis NBRC 108240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaLijiangensisNbrc108240Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichococcusFlocculiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus flocculiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichococcusFlocculiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZobelliaGalactanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zobellia galactanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZobelliaGalactanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterBemidjiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter bemidjiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterBemidjiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaTrachomatisDUw3Cx(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis D/UW-3/CX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatisDUw3Cx", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiEuryarchaeoteRedseaS11B3n4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote REDSEA-S11_B3N4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeoteRedseaS11B3n4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenarchaeotaArchaeon13140cm35217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpInlla21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. INlla21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpInlla21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCavendishiiDsm21758Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cavendishii DSM 21758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCavendishiiDsm21758Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaFidelisAtccBaa318Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella fidelis ATCC BAA-318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShewanellaFidelisAtccBaa318Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniclasticumRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniclasticum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniclasticumRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalitaleaCylindroidesT287(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides T2-87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroidesT287", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofarcimenIntricatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen intricatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenIntricatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeeksellaSpFf8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Weeksella sp. FF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WeeksellaSpFf8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_02_FULL_45_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinispiraMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinispira mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinispiraMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPiscicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piscicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiscicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisFw213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis FW213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisFw213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranaeBrl01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nosema ceranae BRL01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NosemaCeranaeBrl01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaGranuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaistia granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaistiaGranuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialocephalaScopiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala scopiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaScopiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaToruloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula toruloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaToruloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomonasIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomonasIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpOralTaxon299StrF0039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. oral taxon 299 str. F0039 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpOralTaxon299StrF0039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwa13716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWA13716 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwa13716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpNoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpNoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusGarvieaeLg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Lg2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeLg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheobromaCacaoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theobroma cacao Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheobromaCacaoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpHmsc08h08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HMSC08H08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHmsc08h08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFermentum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFermentum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpFy07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. FY-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpFy07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterCrescentusCb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus CB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusCb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaErythra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella erythra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaErythra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPorcinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium porcinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPorcinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpShues1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. SHUES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpShues1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSilagei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus silagei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSilagei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCannabis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisSpAc460Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc460Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumRobertsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium robertsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRobertsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPlurextorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus plurextorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPlurextorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SingulisphaeraAcidiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraAcidiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusLacisalsi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus lacisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusLacisalsi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaOroxyliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia oroxyli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaOroxyliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesExfoliatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces exfoliatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesExfoliatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifoxyb1full5435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYB1FULL5435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyb1full5435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilaceaeBacterium11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilaceae bacterium 11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilaceaeBacterium11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaBuccalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia buccalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaBuccalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaAldovae67083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae 670-83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaAldovae67083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag451Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:451 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag451Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumEmtcatb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium EMTCatB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumEmtcatb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot482Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root482 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot482Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferGlycinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer glycinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferGlycinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBgeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bge Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBgeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulieris281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris 281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulieris281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmpedobacterFalseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter falsenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterFalseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpStm4661Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. STM4661 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpStm4661Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusYeeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus yeei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusYeeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomirabilisOxyferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomirabilis oxyfera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomirabilisOxyferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4718 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiphiliumRubrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumRubrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusTengchongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusTengchongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaGlebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodonellumIkkaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodonellum ikkaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodonellumIkkaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpNfr16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NFR16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNfr16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpUnc362mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNC362MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpUnc362mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSaburreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonBa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaBrunneaFSpMultigermtubiMbM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea f. sp. multigermtubi MB_m1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarssoninaBrunneaFSpMultigermtubiMbM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararhizobiumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumBal199Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium BAL199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumBal199Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpAa23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. AA23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpAa23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpHh13063007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. HH130630-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpHh13063007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRbg19ftcombo5311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG19FTCOMBO5311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg19ftcombo5311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidisEmoy2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Emoy2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidisEmoy2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOryzisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesResistomycificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces resistomycificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesResistomycificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumRifcsplowo212full5922Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO212FULL5922 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo212full5922Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaDilworthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia dilworthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDilworthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cellulovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiHtThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HT Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHtThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpAedEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. AED Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAedEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAssamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAssamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterInsulaenigrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EptatretusBurgeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eptatretus burgeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EptatretusBurgeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaMuralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaMuralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndolissoclinumFaulkneriL2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaCaballeronis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caballeronis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaballeronis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasElongataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasElongataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHdn1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HdN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHdn1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyd2full3512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYD2FULL3512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyd2full3512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratiruptorTergarcusDsm16512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus DSM 16512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitratiruptorTergarcusDsm16512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaSpCag344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. CAG:344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpCag344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpZxy2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ZXY-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpZxy2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaProteobacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return zeta proteobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaProteobacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiemerellaColumbinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuillusLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Suillus luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuillusLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubglaciescola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subglaciescola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubglaciescola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinotignumUrinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum urinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinotignumUrinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiaAmniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sneathia amnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SneathiaAmniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OttowiaThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077532Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077532 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077532Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylonaHeveaeTc161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylona heveae TC161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XylonaHeveaeTc161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterOxydans621hEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans 621H Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydans621hEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077527Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077527Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumRs24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium RS24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumRs24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CricetulusGriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cricetulus griseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CricetulusGriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophusGentianae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus gentianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophusGentianae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarichromatiumPurpuratum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marichromatium purpuratum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarichromatiumPurpuratum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOeniDsm19972Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oeni DSM 19972 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOeniDsm19972Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrusSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrusSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpQxt31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. QXT-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpQxt31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCurieae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curieae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurieae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSp11andimar09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. 11ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSp11andimar09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc7002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbiconiuxGinsengiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux ginsengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxGinsengiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythonBivittatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Python bivittatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PythonBivittatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VavraiaCulicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vavraia culicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VavraiaCulicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpOk605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OK605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOk605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RicinusCommunis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ricinus communis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RicinusCommunis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpS4c9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S4C9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS4c9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasViscosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas viscosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasViscosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymomonasMobilisPomaceaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis pomaceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisPomaceaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldiarchaeumSubterraneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldiarchaeum subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldiarchaeumSubterraneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwb14311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWB14311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwb14311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkanindigesSpH1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges sp. H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesSpH1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GymnopilusDilepis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gymnopilus dilepis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GymnopilusDilepis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesmosporaSp8437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desmospora sp. 8437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesmosporaSp8437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorOwensensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor owensensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorOwensensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptobacteriumSpCag338Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium sp. CAG:338 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumSpCag338Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumFreiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium freii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFreiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterSp12014mblmicdiv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. 12014MBLMicDiv graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterSp12014mblmicdiv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusCaldusSm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus SM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldusSm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisNigrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisNigrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusIntermediusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus intermedius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusIntermediusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpBgarf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BGARF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBgarf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpCp53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cp53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCp53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelesianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solemya velesiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelesianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasAutotrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas autotrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasAutotrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusPakistanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus pakistanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusPakistanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpN3cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. N3C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpN3cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsosphaeraPallida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Isosphaera pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IsosphaeraPallida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusHesperidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus hesperidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusHesperidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHomeothermusArabinoxylanisolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Homeothermus arabinoxylanisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHomeothermusArabinoxylanisolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumCymbalariaeDbvpg7215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae DBVPG#7215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EremotheciumCymbalariaeDbvpg7215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLjungdahliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ljungdahlii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLjungdahliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusTorquesAtcc27756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus torques ATCC27756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusTorquesAtcc27756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TsukamurellaSp1534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella sp. 1534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaSp1534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPelagia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pelagia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPelagia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag192(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:192 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag192", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaHippikon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma hippikon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaHippikon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumBaccatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capsicum baccatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapsicumBaccatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaBrunnea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marssonina brunnea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarssoninaBrunnea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSediminilitorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSediminilitorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19046Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM19046 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJcm19046Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DonghicolaEburneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Donghicola eburneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DonghicolaEburneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorhizobiumGalegaeOfficinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae officinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOfficinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorientalisRegularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis regularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorientalisRegularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumGrahamiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium grahamii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGrahamiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesVenezuelensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides venezuelensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesVenezuelensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacterium13220cm2648Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_64_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm2648Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CutibacteriumAcnesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium acnes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAcnesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoplasmaTermitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoplasma termitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoplasmaTermitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpV48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. V48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpV48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusSbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus SB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusSbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumYuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium yurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumYuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaTayloriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella taylorii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaTayloriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaParvirubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sutterella parvirubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SutterellaParvirubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaFortuita(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia fortuita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaFortuita", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfohalotomaculumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalotomaculum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfohalotomaculumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaOrientalisStrainShintokuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis strain Shintoku Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TheileriaOrientalisStrainShintokuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeospirillumMolischianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum molischianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumMolischianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLongumNcc2705(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum NCC2705 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumLongumNcc2705", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpGw460121014lb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. GW460121014LB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpGw460121014lb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioExovorusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio exovorus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioExovorusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJensenii1153chn(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 1153CHN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii1153chn", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseriAtccBaa895Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter koseri ATCC BAA-895 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterKoseriAtccBaa895Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasBhubaneswarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas bhubaneswarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomonasBhubaneswarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterCurvatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter curvatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterCurvatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysOligosporaAtcc24927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora ATCC 24927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobotrysOligosporaAtcc24927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSpCit045Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. CIT045 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpCit045Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumVerruco04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Verruco_04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumVerruco04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumJsc12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium JSC12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumJsc12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpMc2013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiaePg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae PG2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiaePg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmaeJ233Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma palmae J233 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaPalmaeJ233Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpLeaf344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Leaf344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLeaf344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumAilaauiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium ailaaui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumAilaauiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaFrigiditurrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella frigiditurris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaFrigiditurrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpLycopersici4287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici 4287 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersici4287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterPelagius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPelagius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpFf12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FF12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFf12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaSpAd3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Martelella sp. AD-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MartelellaSpAd3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusTriatomaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus triatomae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTriatomaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimenticolaThiotauriniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola thiotaurini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaThiotauriniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1024126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasSpLm091Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. LM091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpLm091Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaNavojoa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila navojoa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaNavojoa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasAbyssiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasAbyssiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBiviaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bivia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBiviaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaSennetsuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sennetsu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSennetsuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFormosensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas formosensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFormosensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAc2024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AC2024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAc2024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ViridibacillusArenosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arenosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ViridibacillusArenosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSmaragdinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta smaragdinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSmaragdinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumRifcsplowo212full5922Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO212FULL5922 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo212full5922Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpLb2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLb2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThorarchaeotaArchaeonSmtz145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon SMTZ145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonSmtz145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_12_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaVallismortisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula vallismortis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaVallismortisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VittaformaCorneaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vittaforma corneae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VittaformaCorneaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusIshikawaellaCapsulataMpkobe(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ishikawaella capsulata Mpkobe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusIshikawaellaCapsulataMpkobe", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyd2full3512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYD2FULL3512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyd2full3512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocolitica8081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica 8081 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocolitica8081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSplendidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio splendidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSplendidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParameciumTetraureliaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paramecium tetraurelia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParameciumTetraureliaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesShahiiWal8301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes shahii WAL 8301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesShahiiWal8301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerotilusNatansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerotilus natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerotilusNatansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaTm7xEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria TM7x Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaTm7xEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSp4814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 48-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp4814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpFcs014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsoniaIntracellularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lawsonia intracellularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LawsoniaIntracellularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEvansiaMuelleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Evansia muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusEvansiaMuelleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaTanakaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella tanakaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaTanakaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AhrensiaSp13gom1096m(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. 13GOM1096m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSp13gom1096m", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusButanolivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus butanolivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusButanolivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCaldiarchaeumSubterraneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caldiarchaeum subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaldiarchaeumSubterraneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasCellaseaDsm20118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea DSM 20118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CellulomonasCellaseaDsm20118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TanticharoeniaSakaeratensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFp211j200(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FP211J200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFp211j200", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesSilveraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces silverae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomycesSilveraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaFlagellatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola flagellatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaFlagellatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLkl04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. LKL04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLkl04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpCch5a5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. CCH5A5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpCch5a5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaWoodyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella woodyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWoodyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusJeddahenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus jeddahense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusJeddahenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumSpGbchlbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. GBChlB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumSpGbchlbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumSpLk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LodderomycesElongisporusNrrlYb4239Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus NRRL YB-4239 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LodderomycesElongisporusNrrlYb4239Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSp3c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. 3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSp3c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpLc3010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LC3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLc3010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaetbulibacterSaemankumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMikellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mikella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMikellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full5017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL5017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full5017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusLactolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OtolemurGarnettiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Otolemur garnettii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OtolemurGarnettiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhenoliruptrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phenoliruptrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhenoliruptrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChoiromycesVenosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Choiromyces venosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChoiromycesVenosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp233421i1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 233421I1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp233421i1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporangiumAurantiacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporangium aurantiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptosporangiumAurantiacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMinimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium minimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMinimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzhakiellaCapsodisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella capsodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaCapsodisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodalisLikeEndosymbiontOfProechinophthirusFluctusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodalis-like endosymbiont of Proechinophthirus fluctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SodalisLikeEndosymbiontOfProechinophthirusFluctusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAcidominimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus acidominimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAcidominimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondromycesCrocatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces crocatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChondromycesCrocatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiversisporaEpigaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diversispora epigaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiversisporaEpigaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharolyticumWm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum WM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumWm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaCrocina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia crocina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaCrocina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulansExf150(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans EXF-150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumPullulansExf150", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansD7s1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans D7S1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansD7s1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaOvipneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovipneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvipneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPanaciterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPanaciterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSpEs052Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sp. ES.052 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSpEs052Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilusLmg18311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMG18311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmg18311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesBarnesiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides barnesiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesBarnesiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxya1full3614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYA1FULL3614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxya1full3614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVaccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcusTerreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus terreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcusTerreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusParalvinellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus paralvinellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusParalvinellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpStbin4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaConsociataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Massilia consociata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MassiliaConsociataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumRufumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rufum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRufumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MotiliproteusSpMsk221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Motiliproteus sp. MSK22-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MotiliproteusSpMsk221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumLimigenitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium limigenitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLimigenitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumVentriculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ventriculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumVentriculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4328(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4328", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilis3112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis 3112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilis3112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuricoccusIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Auricoccus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AuricoccusIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpTf25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tf2-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTf25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterJejuni414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuni414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpA9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. A9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpA9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg136510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_65_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaEffusaAp103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa AP103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusaAp103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaAzatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora azatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAzatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTrifolii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum trifolii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTrifolii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPiriflorinigransCfbp5888Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans CFBP 5888 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigransCfbp5888Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypothrixBouteilleiVb521301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei VB521301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TolypothrixBouteilleiVb521301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethermicoccusShengliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethermicoccusShengliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonIso4h5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon ISO4H5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonIso4h5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa1418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA1418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa1418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSpizizeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis spizizenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisSpizizeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpHmsc76g11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. HMSC76G11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpHmsc76g11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumXinjiangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xinjiangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXinjiangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaDonghaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina donghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaDonghaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosporomusaSubterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporomusa subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerosporomusaSubterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumPhenoliresistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium phenoliresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumPhenoliresistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpS23321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. S23321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpS23321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSp1513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 1513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp1513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifoxyc2Full479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYC2_FULL_47_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyc2Full479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusMaritimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ursus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrsusMaritimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpHot20860m813o14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813O14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813o14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAvidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium avidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAvidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_49_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeCwl029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae CWL029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeCwl029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa2377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA2377 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa2377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxRadicisN35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax radicis N35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxRadicisN35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_42_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaSpRitpid(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella sp. RITPId graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaSpRitpid", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccibacterTuricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SiccibacterTuricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombyxMoriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bombyx mori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BombyxMoriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpBc26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. BC26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpBc26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBoroniphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus boroniphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusBoroniphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKwashiorkoriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kwashiorkori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusKwashiorkoriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaCherriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella cherrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaCherriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JonquetellaAnthropiDsm22815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi DSM22815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiDsm22815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf4489(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF4489 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf4489", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSabinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sabinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSabinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPapayaeJcm25143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter papayae JCM 25143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPapayaeJcm25143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NippostrongylusBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nippostrongylus brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NippostrongylusBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAkagiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium akagii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAkagiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurellaAcetivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAcetivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil787Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil787 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil787Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumBouchesdurhonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium bouchesdurhonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumBouchesdurhonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasSpRcc299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonas sp. RCC299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicromonasSpRcc299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelomonasSpRoot1237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisBenevestitusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis benevestitus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBenevestitusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeeksellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weeksella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeeksellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full468(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full468", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaNanhaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNanhaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpScn6822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. SCN 68-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpScn6822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaMuciniphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia muciniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaMuciniphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IsosphaeraPallidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Isosphaera pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IsosphaeraPallidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSpMsx33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. MSX33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpMsx33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpPamc26642Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. PAMC 26642 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpPamc26642Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloactinobacteriumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloactinobacterium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloactinobacteriumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFermentibacterDaniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fermentibacter daniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFermentibacterDaniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusVariansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus varians Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusVariansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSpAntb6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sp. ANTB6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSpAntb6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumGwa27335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterMyodisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter myodis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMyodisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermincolaPotensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermincola potens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermincolaPotensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TidjanibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tidjanibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TidjanibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusHb27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCulexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Culex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCulexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumM6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCarsonellaRuddiiPv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwe13228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWE13228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwe13228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MillisiaBrevisNbrc105863(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Millisia brevis NBRC 105863 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MillisiaBrevisNbrc105863", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquicursorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equicursoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquicursorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat29814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophusFodinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophus fodinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophusFodinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasSpFh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas sp. FH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasSpFh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FortieaContortaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fortiea contorta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FortieaContortaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistesJonesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synergistes jonesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynergistesJonesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaAtlantica22ii1410f7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica 22II14-10F7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZunongwangiaAtlantica22ii1410f7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacterium13140cm6927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_1_40CM_69_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13140cm6927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpOk494Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK494 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpOk494Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSpCag977(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. CAG:977 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSpCag977", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteipulveratusMongoliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus mongoliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusMongoliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpAzwk3bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. AzwK3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpAzwk3bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLc145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LC145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLc145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAeronauticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAespoeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aespoeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAespoeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterNecessarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterNecessarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaSorghiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puccinia sorghi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PucciniaSorghiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpKk3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. KK3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpKk3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaAtrinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria atrinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaAtrinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusBrasiliensisCbs101740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis CBS 101740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusBrasiliensisCbs101740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpNrrlb16802Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NRRLB16802 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNrrlb16802Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OperophteraBrumata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Operophtera brumata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OperophteraBrumata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_40_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusSpMctg156Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. MCTG156 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpMctg156Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KandleriaVitulinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kandleria vitulina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KandleriaVitulinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DacryopinaxPrimogenitusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dacryopinax primogenitus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DacryopinaxPrimogenitusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg165811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_58_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumSpKb01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium sp. KB01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumSpKb01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LambdaproteobacteriaBacteriumRifoxyd1full5627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD1FULL5627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd1full5627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNdongoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ndongoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNdongoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaP74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila P74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaP74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full3410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumLongisporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verticillium longisporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerticilliumLongisporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuricaudaSpMar201075(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. MAR201075 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpMar201075", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumBal38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BAL38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBal38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitiniphilusShinanonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBovis914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis 914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovis914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwc24544Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_45_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc24544Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCaspthauma3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumEuropaeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium europaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumEuropaeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaGrimmiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia grimmiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGrimmiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumMunicipaleDsm44069Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum municipale DSM 44069 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumMunicipaleDsm44069Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMosseliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mosselii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMosseliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumAtrosepticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium atrosepticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumAtrosepticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HomeothermusArabinoxylanisolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Homeothermus arabinoxylanisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HomeothermusArabinoxylanisolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumBangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum bangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumBangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpWmmb714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumMolleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium molle Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumMolleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterNicotinovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nicotinovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterNicotinovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinilactibacillusPiezotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus piezotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPiezotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphriteaJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphritea japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphriteaJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag488Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:488 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag488Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylicusMesodigestumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus mesodigestum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusMesodigestumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AvibacteriumParagallinarum72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumAnisopliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpJs614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. JS614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJs614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusContaminans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusContaminans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantii3937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii 3937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantii3937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacterium4920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4920 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UliginosibacteriumGangwonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uliginosibacterium gangwonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UliginosibacteriumGangwonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaUaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaUaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifcsplowo2023512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO2023512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo2023512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_02_FULL_44_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRifcsphigho202full4012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO202FULL4012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho202full4012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusObscuribacterPhosphatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Obscuribacter phosphatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusObscuribacterPhosphatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaHarzianumCbs22695Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma harzianum CBS 226.95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaHarzianumCbs22695Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumEscambiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAnserinaEs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Es graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaAnserinaEs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaKingae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kingella kingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KingellaKingae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusChikugoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus chikugoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusChikugoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveromycesLactisNrrlY1140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis NRRL Y-1140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KluyveromycesLactisNrrlY1140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAmylovorusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylovorusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNovofumigatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusNovofumigatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpHiyo8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Hiyo8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHiyo8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusNigrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusNigrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterLovleyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter lovleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterLovleyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag272Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:272 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag272Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusYayanosiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus yayanosii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusYayanosiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAzotifigensNbrc15497(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens NBRC 15497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAzotifigensNbrc15497", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrleanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orleanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrleanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesNeonati(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides neonati graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNeonati", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPittii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pittii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPittii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaMesophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola mesophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaMesophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIntestinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium intestinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIntestinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusAcidocaldariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicoccusPhenolivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicoccus phenolivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicoccusPhenolivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynespora cassiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynesporaCassiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterNamhaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter namhaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterNamhaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSharpeaeJcm1186Dsm20505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae JCM 1186 DSM 20505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSharpeaeJcm1186Dsm20505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirillosporaAlbida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirillospora albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirillosporaAlbida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaricaPapaya(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Carica papaya graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaricaPapaya", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaIndicaGroupCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Group Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaIndicaGroupCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPutrefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSwuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSwuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusVillosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosopelagicusBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopelagicus brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopelagicusBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSmegmatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium smegmatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSmegmatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtribacteriaBacteriumRbg19ftCombo3514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium RBG_19FT_COMBO_35_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumRbg19ftCombo3514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumSpI15g10i2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum sp. I15G10I2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumSpI15g10i2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaJamestowniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella jamestowniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaJamestowniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraSpPhs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. PHS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpPhs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterHenricii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter henricii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterHenricii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedMethanoculleusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Methanoculleus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedMethanoculleusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumValentinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium valentinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumValentinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusFujiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusFujiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Selenomonas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Selenomonas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNt26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NT-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNt26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaSp6021052837Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cohnella sp. 6021052837 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CohnellaSp6021052837Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAgilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus agilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAgilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelotomaculumSpDtu098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum sp. DTU098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumSpDtu098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisphaeraLagunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldisphaera lagunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldisphaeraLagunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LongisporaAlbidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Longispora albida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LongisporaAlbidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CulexQuinquefasciatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Culex quinquefasciatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CulexQuinquefasciatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraInfestansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora infestans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraInfestansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesMerdaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides merdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMerdaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPapyrosolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium papyrosolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPapyrosolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMirabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mirabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMirabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasUreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas ureae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasUreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaAvicenniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAvicenniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinispiraPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinispira pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinispiraPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpCs1gbmeth3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1GBMeth3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1gbmeth3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpPh1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. PH1b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPh1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasMephitisDsm12574(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas mephitis DSM 12574 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LuteimonasMephitisDsm12574", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumCg1023722(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium CG1_02_37_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumCg1023722", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusPleuropneumoniae14074Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 1 4074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae14074Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGilvigriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvigriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvigriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrcinusOrca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Orcinus orca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OrcinusOrca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaScatoligenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella scatoligenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaScatoligenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml140438Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML140438 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml140438Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpSt904Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. ST904 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpSt904Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaProteobacteriumMlsdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium MLSD Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMlsdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantiiEch703Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch703Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesRuminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces ruminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRuminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumYuanmingense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium yuanmingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumYuanmingense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumInersEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium iners Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumInersEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpAtcc31444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. ATCC31444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpAtcc31444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpSt04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. ST04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpSt04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpOxb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OxB-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOxb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaMuridarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia muridarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaMuridarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSartisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sartisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSartisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusMicrosporusAtcc52813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus microsporus ATCC 52813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizopusMicrosporusAtcc52813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriMf28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri MF28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriMf28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumBrhc0Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BRHc0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBrhc0Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_02_FULL_45_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaFrigidimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella frigidimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFrigidimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CycloclasticusSpSymbiontOfBathymodiolusHeckerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus heckerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusHeckerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisJsc3b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris JSC-3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisJsc3b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaCanadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaCanadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaStriiformisFSpTriticiPst78Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Puccinia striiformis f. sp. tritici PST-78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PucciniaStriiformisFSpTriticiPst78Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaSpHl35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. HL35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpHl35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaMirobrigensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora mirobrigensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMirobrigensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraLicerasiaeStrMmd4847Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira licerasiae str. MMD4847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraLicerasiaeStrMmd4847Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaSpAk20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. AK20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FormosaSpAk20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr1BacteriumGw2011Gwc14913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR1 bacterium GW2011_GWC1_49_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1BacteriumGw2011Gwc14913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumJeanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium jeanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumJeanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_41_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusVersmoldensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus versmoldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVersmoldensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifoxyd1full3935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD1FULL3935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd1full3935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGobiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gobiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGobiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpRv1423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. RV1423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpRv1423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSputorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSputorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpSa39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. SA39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpSa39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hr60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOlivaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces olivaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesOlivaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumHaoraniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium haoranii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHaoraniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixSpCaciam69dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM 69d Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LimnothrixSpCaciam69dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEhc04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EhC04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpEhc04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParamicrosporidiumSaccamoebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paramicrosporidium saccamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParamicrosporidiumSaccamoebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpDd12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. DD12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShinellaSpDd12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpHl58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. HL58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpHl58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSaudimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaThermolimosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermolimosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermolimosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenoxybacterAcetivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenoxybacter acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenoxybacterAcetivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasHofstadiiJcm17038Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii JCM 17038 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasHofstadiiJcm17038Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasSpBrl61Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas sp. BRL61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TolumonasSpBrl61Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpCg2304434(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. CG2_30_44_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpCg2304434", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TanticharoeniaSakaeratensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraHakonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpPbn3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PBN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpPbn3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusDestructansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaChrysopicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma chrysopicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaChrysopicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRbg134015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG134015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg134015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC12_FULL_34_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromassilibacillusSpMarseillep3371Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus sp. MarseilleP3371 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSpMarseillep3371Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGastricusPs3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus PS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGastricusPs3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusFlavithermusAk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus AK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusAk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLicheniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus licheniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLicheniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaBroomeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia broomeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaBroomeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSenegalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSenegalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaDermatitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaDermatitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsplowo201full4534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO201FULL4534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo201full4534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTtu2014080asc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TTU2014-080ASC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTtu2014080asc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodictyonPhaeoclathratiformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon phaeoclathratiforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelodictyonPhaeoclathratiformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAlcoholivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alcoholivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlcoholivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PusillimonasNoertemanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas noertemannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PusillimonasNoertemanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquaspirillumSpLm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum sp. LM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSpLm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaAxanthumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma axanthum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaAxanthumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaAfricana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaAfricana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesSpShpl62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasAzotifigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAzotifigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusMetallicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusMetallicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSaburreumF0468Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum F0468 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumF0468Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongylocentrotusPurpuratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strongylocentrotus purpuratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrongylocentrotusPurpuratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiigatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niigatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiigatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeovisonVison(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neovison vison graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeovisonVison", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil787Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil787 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil787Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumGwa24518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_45_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa24518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMidichloriaMitochondriiIricvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Midichloria mitochondrii IricVA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMidichloriaMitochondriiIricvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwf1496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_49_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioInopinatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusAmylolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusAmylolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGastricusPs3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus PS3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGastricusPs3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaIslandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula islandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaIslandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndozoicomonasMontiporaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaMaceachernii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella maceachernii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaMaceachernii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpGw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. GW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChelatococcusSpGw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphriteaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphritea atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphriteaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLuteoviolaceaBAtcc29581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea B  ATCC 29581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolaceaBAtcc29581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumMs0243cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS024-3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0243cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacinutrixHimadriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix himadriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixHimadriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SordariaMacrospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sordaria macrospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SordariaMacrospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSartisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sartisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSartisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpNrrlb16802Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NRRLB16802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNrrlb16802Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgibacterAlginicilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algibacter alginicilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAlginicilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCloacaeAtcc13047(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae ATCC13047 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeAtcc13047", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyocaulusViviparus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dictyocaulus viviparus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DictyocaulusViviparus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpUnc363mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC363MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc363mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSp3131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 3_1_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpApg3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. APG3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitrosospiraSpApg3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHuangheensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas huangheensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasHuangheensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviWkb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi wkB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviWkb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxosarcinaSpGi1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxosarcina sp. GI1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxosarcinaSpGi1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs1612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS1612 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs1612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusTerrigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlligatorSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alligator sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlligatorSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpHl93Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL-93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl93Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnditaleaAndensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anditalea andensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnditaleaAndensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaledivibacterHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maledivibacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaledivibacterHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachanceaMirantinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachancea mirantina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachanceaMirantinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus warneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusWarneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpRoot1272(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. Root1272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpRoot1272", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumFrigidisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium frigidisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFrigidisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterFulvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter fulvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterFulvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopelagiusInordinatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopelagius inordinatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopelagiusInordinatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSiccatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus siccatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSiccatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumPhaeobacteroidesDsm266Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides DSM266 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesDsm266Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterSp4d4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter sp. 4D4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FabibacterSp4d4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisDsm19559(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis DSM19559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisDsm19559", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaoultellaOrnithinolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Raoultella ornithinolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RaoultellaOrnithinolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfUnidentifiedEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentifiedEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria ivanovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaIvanoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HumibacillusSpDsm29435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Humibacillus sp. DSM 29435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HumibacillusSpDsm29435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPerflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria perflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPerflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumBarkeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium barkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBarkeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDisiensFb03509anCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens FB03509AN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensFb03509anCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwf2339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWF2_33_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwf2339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_44_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_44_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumOxidoreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium oxidoreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumOxidoreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_44_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterActinosclerus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter actinosclerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterActinosclerus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTkp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TKP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpTkp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaGottschalkiiDsm13577Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii DSM 13577 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkiiDsm13577Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf99Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf99Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbmousenlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseNL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousenlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaBillingiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia billingiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaBillingiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSclerotionigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotionigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeminocystisSpNies3708Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3708Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaHelveticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia helvetica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaHelveticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpDb56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. DB56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpDb56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus siamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSiamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicronemaHongdechlorisC2206Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris C2206 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomicronemaHongdechlorisC2206Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484171(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484171", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiveispirillumIrakenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niveispirillum irakense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiveispirillumIrakenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosporaCaninum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neospora caninum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeosporaCaninum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpMebic08052Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. MEBiC08052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSpMebic08052Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusArachidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus arachidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusArachidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSp5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudolabrysSpRoot1462Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudolabrys sp. Root1462 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudolabrysSpRoot1462Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaToruloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula toruloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaToruloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacillusTrivialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus trivialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusTrivialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSuisStrIllinoisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma suis str. Illinois Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSuisStrIllinoisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPraediiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus praedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPraediiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslp40081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLP40081 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslp40081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronincolaPeptidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronincola peptidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronincolaPeptidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaVinsoniiArupensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii arupensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiArupensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteroidesChelonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides chelonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesChelonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiolapillusBrandeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiolapillus brandeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiolapillusBrandeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCulicicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma culicicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCulicicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusMicrotiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus microti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMicrotiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpCf108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12W3110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 W3110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12W3110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumGw2011gwb1385Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWB1385 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwb1385Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CercocebusAtysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cercocebus atys Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CercocebusAtysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumHuakuii7653rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii 7653R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuii7653rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VitrellaBrassicaformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VitrellaBrassicaformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzonexusHydrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azonexus hydrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzonexusHydrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBiflexaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira biflexa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBiflexaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolisilvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solisilvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSolisilvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatlockiaMicdadeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tatlockia micdadei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TatlockiaMicdadeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCellostaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellostaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellostaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumScgcAaa027n21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027N21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027n21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiR88b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti R88b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiR88b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterCondimenti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter condimenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CronobacterCondimenti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UzinuraDiaspidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uzinura diaspidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UzinuraDiaspidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumPsychroaquaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium psychroaquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPsychroaquaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpWg21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. WG21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpWg21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium MA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaStewartiiSubspStewartiiDc283Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantoea stewartii subsp. stewartii DC283 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantoeaStewartiiSubspStewartiiDc283Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisCremorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis cremoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisCremorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelianthusAnnuus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helianthus annuus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelianthusAnnuus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpEc33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ec33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpEc33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensisDsm11113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis DSM 11113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensisDsm11113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg165817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_58_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhynchosporiumCommuneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhynchosporium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhynchosporiumCommuneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpB29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. B29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpB29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnq509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNQ-509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnq509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTuscaniense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium tuscaniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTuscaniense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpS6262Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S6-262 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpS6262Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreicellaSpSe45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. SE45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitreicellaSpSe45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumLipolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumHydatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hydatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHydatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaDenitrificansAtcc33394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella denitrificans ATCC 33394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KingellaDenitrificansAtcc33394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfCimexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBuccalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgassizii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agassizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgassizii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GanodermaSinenseZz02141Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ganoderma sinense ZZ0214-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GanodermaSinenseZz02141Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsplowo212full5310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPhilomiragiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella philomiragia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPhilomiragiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_44_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoribacteriaBacteriumWga3gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poribacteria bacterium WGA3G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoribacteriaBacteriumWga3gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf454Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf454 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf454Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaMaltosaXu316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Xu316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaMaltosaXu316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_39_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBeijingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus beijingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBeijingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNctc7422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCTC 7422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNctc7422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo2OfFrankliniellaOccidentalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 of Frankliniella occidentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2OfFrankliniellaOccidentalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumFrediiNgr234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii NGR234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiNgr234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumJosuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium josui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumJosuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrantaeDsm23927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brantae DSM 23927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrantaeDsm23927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBeijerinckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter beijerinckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBeijerinckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccomyxaSubellipsoideaC169Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea C-169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoideaC169Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycomycesBlakesleeanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSwuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSwuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMachipongonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus machipongonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMachipongonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpClo3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. CLO-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpClo3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PopulusAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Populus alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PopulusAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full4424bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4424b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4424bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaArabinofermentansNrrlYb2248Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Candida] arabinofermentans NRRL YB-2248 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaArabinofermentansNrrlYb2248Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaceaeBacteriumIbvucb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRoot700Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot700Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaportheOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthe oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnaportheOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelatoporiaSubvermisporaBEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GelatoporiaSubvermisporaBEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioWodanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio wodanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliivibrioWodanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsPolyrhachisFurcataBcc54312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachis-furcata BCC 54312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisFurcataBcc54312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlcaliphilaJab1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila JAB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphilaJab1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumPoae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumPoae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTremblayaPhenacolaPaveCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya phenacola PAVE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPhenacolaPaveCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaDilworthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia dilworthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaDilworthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusF0211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus F0211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusF0211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFischeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusFischeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpUsba49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. USBA 49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpUsba49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetothermiaBacteriumJdfr52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaConjunctivaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma conjunctivae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaConjunctivaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwd23333(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWD2_33_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwd23333", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivirgaCyanobacteriivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivirga cyanobacteriivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivirgaCyanobacteriivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumNam1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum NAm1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumNam1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full468Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL468 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full468Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot483d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root483D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot483d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIhuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIhuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpRoot157Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root157 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot157Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaWeihenstephanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria weihenstephanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaWeihenstephanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisSorokiniana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BipolarisSorokiniana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaThalassocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella thalassocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaThalassocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxParadoxusEps(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus EPS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusEps", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterCaceresiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter caceresii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ModestobacterCaceresiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKisonensisF0435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis F0435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKisonensisF0435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusPcc6301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC6301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc6301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPapuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella papuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPapuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BettaSplendens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betta splendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BettaSplendens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk569Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk569Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpRoot413d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root413D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot413d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusPortucalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr88Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr88Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpDdh964(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. DDH964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpDdh964", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaOralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kingella oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KingellaOralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf407Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf407 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf407Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusAmylolentusCbs6039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus CBS 6039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptococcusAmylolentusCbs6039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorumF0390Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum F0390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumF0390Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaHypogeia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia hypogeia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHypogeia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMagnumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium magnum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMagnumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cucumibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CucumibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobutyricumHalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobutyricum hallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobutyricumHalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotionigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotionigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUdagawae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus udagawae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusUdagawae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaCephalotes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atta cephalotes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AttaCephalotes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077545Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077545Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSpHgb0015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. HGB0015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpHgb0015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpRoot1272Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. Root1272 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpRoot1272Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocinitomixAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHimastatinicusAtcc53653(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus ATCC 53653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicusAtcc53653", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanimonasSmirnoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas smirnovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSmirnoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusLactarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusLactarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAntCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAntCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpEr1a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. ER1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEr1a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAlkalicaDsm8900Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica DSM 8900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalicaDsm8900Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumMiluonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium miluonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMiluonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratifractorSalsuginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratifractor salsuginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratifractorSalsuginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit055293Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 05-5293 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit055293Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritimibacterSpHl12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter sp. HL-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterSpHl12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlrhEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALRh Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlrhEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRbg166411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_64_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisDnf00985(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis DNF00985 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisDnf00985", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusCaldusSm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus SM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldusSm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaErectaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea erecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaErectaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusSpXh2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus sp. XH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusSpXh2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPseudalcaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudalcaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudalcaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRu36d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU36D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu36d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumCynomolgiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium cynomolgi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumCynomolgiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusColumbae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus columbae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusColumbae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterSegnisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter segnis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSegnisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaSpPdc51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. PDC51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSpPdc51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillibacteriumTimonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium timonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumTimonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusShacheensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shacheensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusShacheensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho201full4622bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO201FULL4622b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho201full4622bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AstyanaxMexicanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Astyanax mexicanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AstyanaxMexicanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobaculumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo201full3334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO201FULL3334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo201full3334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxVolcaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferax volcanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferaxVolcaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpYbe204(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. YBE204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpYbe204", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaFaecalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaFaecalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminobacterSpRm87Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter sp. RM87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminobacterSpRm87Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctopirusLimnophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus limnophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusLimnophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TomitellaBiformataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tomitella biformata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TomitellaBiformataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterDaltoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter daltonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterDaltoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNuni2hmbin001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaNigraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora nigra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaNigraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNecrophorumD12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum D12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumD12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterAalborgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter aalborgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterAalborgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaAerocolonigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria aerocolonigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LechevalieriaAerocolonigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterOxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconobacterOxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWC2_33_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCylindrosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogladiusCalderaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermogladius calderae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermogladiusCalderaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusWakoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus wakoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusWakoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FicedulaAlbicollis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ficedula albicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FicedulaAlbicollis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzotobacterChroococcumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfovibrioPeptidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio peptidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioPeptidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumAsp1005aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium ASP10-05a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumAsp1005aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaRuestringensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda ruestringensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaRuestringensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumBacl7Mag120322Bin74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 MAG-120322-bin74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Mag120322Bin74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaSpEhc01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. EhC01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpEhc01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaUsdaarsusmarc1261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot482Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot482Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumXanthum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xanthum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXanthum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalyomorphaHalys(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halyomorpha halys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalyomorphaHalys", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesFunestusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles funestus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesFunestusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAcetothermiaBacteriumJdfr52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg166615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_66_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLactisRw25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lactis RW2-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumLactisRw25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc23210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC23210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc23210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifoxya2full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL4118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Glassbacteria bacterium RIFCSPLOWO2_12_FULL_58_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilisFCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilisFCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsplowo202full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumRaac4od11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium RAAC4OD11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumRaac4od11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperellaBernardiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trueperella bernardiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrueperellaBernardiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichosporonAsahiiVarAsahiiCbs8904Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii var. asahii CBS 8904 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichosporonAsahiiVarAsahiiCbs8904Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraRamorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora ramorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraRamorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC1_37_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpOhsuic4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. OHSUIC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpOhsuic4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolbachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolbachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolbachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilimaliaeMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilimaliae massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilimaliaeMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSaudimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus saudimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSaudimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa25510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_55_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniphilumAcetatigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum acetatigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumAcetatigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpC105kso13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C105KSO13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC105kso13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaAcidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa acidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporomusaAcidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusEndophyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus endophyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusEndophyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomicrococcusAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neomicrococcus aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeomicrococcusAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterNorwichensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter norwichensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterNorwichensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumRedseas34b6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS34B6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas34b6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaWillistoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila willistoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaWillistoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IctalurusPunctatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ictalurus punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IctalurusPunctatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoaciditogaLauensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoaciditoga lauensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoaciditogaLauensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiribacterSpUahsp71(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter sp. UAHSP71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpiribacterSpUahsp71", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasSpBiir7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. BIIR7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpBiir7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisAtcc903Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis ATCC903 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisAtcc903Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrivivaxGelatinosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax gelatinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxGelatinosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliiroseovariusSediminilitoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusSediminilitoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho201full4120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO201FULL4120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho201full4120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacillusSpOk032Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk032Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_01_FULL_43_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaWiggsiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scardovia wiggsiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScardoviaWiggsiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_46_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpLeaf363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Leaf363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLeaf363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensJangbogonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens jangbogonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensJangbogonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MobiluncusCurtisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 40-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD1_FULL_39_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd1Full3935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1No423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 No. 423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1No423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumParvumAcb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum ACB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OribacteriumParvumAcb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsathyrellaAberdarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psathyrella aberdarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsathyrellaAberdarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_12_FULL_48_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSpTsri0078Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. TSRI0078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpTsri0078Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaBelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia bellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaBelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLsjc280b00Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSJC280B00 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLsjc280b00Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaeniopygiaGuttata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taeniopygia guttata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaeniopygiaGuttata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaHoronobensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpInlla21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. INlla21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpInlla21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaNbrc14164Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida NBRC14164 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaNbrc14164Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumRbg16439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG_16_43_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg16439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMuralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMuralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaZoodegmatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria zoodegmatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaZoodegmatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasMetalli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas metalli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMetalli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Candida] intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc81Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc81Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiumAgarilyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium agarilyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumAgarilyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaThermophilaDsm6578(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila DSM 6578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaThermophilaDsm6578", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHBB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaTaeniospiralisNbrc102512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis NBRC 102512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralisNbrc102512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpC561(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. C561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpC561", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSkirrowii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter skirrowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSkirrowii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFraserbacteriaBacteriumRbg16559(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fraserbacteria bacterium RBG_16_55_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFraserbacteriaBacteriumRbg16559", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpMarseillep3519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. MarseilleP3519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpMarseillep3519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_63_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriticumAestivumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Triticum aestivum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TriticumAestivumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaMacacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaMacacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinimicrobiumCatenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium catena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumCatenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronomonasSpCba1134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas sp. CBA1134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronomonasSpCba1134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSinaloensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sinaloensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSinaloensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquabacteriumSpNj1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquabacterium sp. NJ1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquabacteriumSpNj1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHelveticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBorgpeterseniiPomonaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Pomona Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiPomonaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusYunnanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus yunnanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusYunnanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnimonasNigrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnimonas nigrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnimonasNigrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EwingellaAmericana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ewingella americana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EwingellaAmericana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisTerraeSubspTerraeNbrc15098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae subsp. terrae NBRC 15098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisTerraeSubspTerraeNbrc15098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a520k10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a520K10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a520k10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaphrinaDeformansPycc5710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans PYCC 5710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TaphrinaDeformansPycc5710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoceaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phocea massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhoceaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelaginellaMoellendorffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selaginella moellendorffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelaginellaMoellendorffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifoxyb1Full5435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYB1_FULL_54_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyb1Full5435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaPsychrerythraea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioOxyclinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio oxyclinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioOxyclinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaFuscaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaFuscaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpC100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. C100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpC100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGlaucescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces glaucescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlaucescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaGansuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jiangella gansuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JiangellaGansuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraGargensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera gargensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraGargensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFrigidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio frigidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFrigidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaJaponicaDsm16301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica DSM 16301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaDsm16301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full3928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL3928 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full3928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBromiiL263Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bromii L2-63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusBromiiL263Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimiaSpSk013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimia sp. SK013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimiaSpSk013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotruncusSpCag528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho2024118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_41_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho2024118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg134015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_13_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg134015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpMEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. M Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpMEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetonemaLongumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetonema longum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetonemaLongumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaPiniCbs10737Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella pini CBS 10737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KwoniellaPiniCbs10737Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumScardoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium scardovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumScardoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGordoniiMs1Dsm23371(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii MS-1 DSM 23371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGordoniiMs1Dsm23371", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4572128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 4572_128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4572128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaDysenteriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shigella dysenteriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShigellaDysenteriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMegateriumMsp201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium MSP201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumMsp201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaMuralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaMuralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensisDsm12906Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis DSM 12906 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensisDsm12906Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho202full5216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL5216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full5216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArh2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GW2011_GWA2_52_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusInersCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus iners Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusInersCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaHydrophobicaNbrc16057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica NBRC 16057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GordoniaHydrophobicaNbrc16057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YangiaSpCcbmm3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yangia sp. CCBMM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YangiaSpCcbmm3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinilyticumAquatile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumAquatile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumKutscheriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kutscheri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKutscheriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSpLm3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. LM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLm3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumJgi0000077k19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium JGI 0000077K19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumJgi0000077k19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpP2b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. P2b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpP2b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpAf1028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpAf1028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusSpSoil748(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil748 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil748", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusIainarchaeumAndersoniiScgcAaa011E11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Iainarchaeum andersonii SCGC AAA011-E11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusIainarchaeumAndersoniiScgcAaa011E11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicoprobacterFaecalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicoprobacter faecalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicoprobacterFaecalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwf24352Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWF2_43_52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwf24352Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpPsbb023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. PSBB023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPsbb023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenulisporaAcidiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenulispora acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenulisporaAcidiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRbg166213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSalariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpAbgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ABG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAbgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BilophilaWadsworthia316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia 316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthia316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPlantarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus plantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPlantarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaWadsworthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWadsworthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaHelgolandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia helgolandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaHelgolandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaMarinistellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria marinistellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaMarinistellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpMc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. MC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpMc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpCcge1002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpA3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpA3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaBrunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella brunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaBrunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterWinogradskyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter winogradskyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrobacterWinogradskyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaceaeBacteriumFsla50209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesPosadasiiStrSilveiraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii str. Silveira Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesPosadasiiStrSilveiraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusHaemoperoxidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus haemoperoxidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHaemoperoxidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylanimicrobiumPachnodaeJcm13526Nbrc107786Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae JCM 13526 NBRC 107786 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodaeJcm13526Nbrc107786Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasileaPsittacipulmonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Basilea psittacipulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BasileaPsittacipulmonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifcsphigho202full4214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO202FULL4214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho202full4214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutusSpGas368(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opitutus sp. GAS368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpitutusSpGas368", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeliponaQuadrifasciataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melipona quadrifasciata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeliponaQuadrifasciataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrobacterXylanophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter xylanophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrobacterXylanophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNamurensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNamurensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinimonasAmylolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinimonas amylolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinimonasAmylolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioProteolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio proteolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioProteolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumCitreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium citreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumCitreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosumWal14163(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14163 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14163", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasSpDtu018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorOwensensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor owensensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorOwensensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusSpOk032Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK032 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk032Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPersicaAtccVr331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella persica ATCC VR-331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrancisellaPersicaAtccVr331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterCryohalolentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cryohalolentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCryohalolentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumChungangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chungangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChungangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6728 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs836Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs836Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitromicrobiumSpJlt1363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JLT1363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJlt1363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterAlbidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter albidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAlbidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumNitrativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe23640(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE2_36_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe23640", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpU5l(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. U5L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpU5l", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChishuiellaChangwenliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chishuiella changwenlii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChishuiellaChangwenliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBeijerinckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBeijerinckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumDsm525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum DSM525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumDsm525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusRaoultiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus raoultii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRaoultiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaElongataSubspGlycolyticaAtcc29315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria elongata subsp. glycolytica ATCC 29315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaElongataSubspGlycolyticaAtcc29315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hordeum vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HordeumVulgareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterChinhatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter chinhatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterChinhatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuisR61Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis R61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisR61Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaGlobosaCbs7966Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia globosa CBS 7966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MalasseziaGlobosaCbs7966Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrococcusMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrococcus mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrococcusMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag567(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag567", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaTyrosinoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga tyrosinoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaTyrosinoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaMangroviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KwoniellaMangroviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSp519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. 51_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSp519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelliellaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Belliella baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BelliellaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioSpJc8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. JC8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpJc8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaSclerotiorum1980Uf70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum 1980 UF-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorum1980Uf70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaporthiopsisPoaeAtcc64411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae ATCC 64411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoaeAtcc64411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitreimonasSalinariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citreimonas salinaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitreimonasSalinariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaMassilioguelmaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia massilioguelmaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaMassilioguelmaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb1437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB1437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb1437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumZagget2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSp1135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpN(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpN", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligellaUreolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oligella ureolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OligellaUreolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaFacilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidocella facilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidocellaFacilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo202full4011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO202FULL4011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo202full4011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumRifcsplowo202full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPLOWO202FULL4216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsplowo202full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterMathraniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathraniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfAcanthamoebaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Acanthamoeba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfAcanthamoebaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterInsulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter insulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterInsulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAidingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAidingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumAmericanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium americanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumAmericanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumCg1025453Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG1_02_54_53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg1025453Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasPhycophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas phycophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasPhycophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeBvOfficinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. officinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOfficinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaHelicoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma helicoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaHelicoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusMicrocarpus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PisolithusMicrocarpus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSartisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sartisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSartisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenitaleaLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenitalea lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenitaleaLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermobacterSpCat2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter sp. CaT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterSpCat2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpHmp52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. HMP52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpHmp52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumGp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpStbin5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumSpLc103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium sp. LC103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumSpLc103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterArseniciresistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter arseniciresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterArseniciresistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeogobiusMelanostomusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neogobius melanostomus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeogobiusMelanostomusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumEstertheticumSubspEstertheticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium estertheticum subsp. estertheticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumEstertheticumSubspEstertheticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc2459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC2459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc2459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSp73sCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. 73s Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSp73sCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPLOWO2_01_FULL_60_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesNeonatiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides neonati Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNeonatiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFf9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FF9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFf9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansHk1651Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans HK1651 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansHk1651Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMethanolicusMga3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus MGA3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusMga3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGaetbulicolaGung47Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Gung47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicolaGung47Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciensMa2007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens MA2007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensMa2007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusDevoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus devorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusDevoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoykebacteriaBacteriumRbg16439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_43_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulciaMuelleriGwssCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri GWSS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriGwssCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallosphaeraCuprinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera cuprina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraCuprinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusXylanexedens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus xylanexedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusXylanexedens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CardiobacteriumValvarumF0432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum F0432 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CardiobacteriumValvarumF0432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp4fCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 4F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp4fCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaBurgdorferiB31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi B31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferiB31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumSar86eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpKg01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KG01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKg01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiAtcc17978(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii ATCC 17978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiAtcc17978", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSp4814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 48-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp4814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3773Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3773 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3773Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumHafniense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium hafniense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumHafniense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaLactamicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria lactamica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaLactamicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpLeaf201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesmosporaSp8437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desmospora sp. 8437 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesmosporaSp8437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaitoellaComplicataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saitoella complicata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaitoellaComplicataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumDiernhoferi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium diernhoferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDiernhoferi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioParadoxusArh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus ARh 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxusArh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermanellaStibiiresistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaSordidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia sordidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaSordidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa23816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_38_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa23816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatagonusWagneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catagonus wagneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatagonusWagneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenotaleaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenotalea thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenotaleaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCnt360(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt360", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSp20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. 20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSp20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrocadiaCaroliniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia caroliniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaCaroliniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpMwb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MWB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpMwb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimicrobiaceaeBacteriumRaap2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiaceae bacterium RAAP-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiaceaeBacteriumRaap2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpExBiomphalariaGlabrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. (ex Biomphalaria glabrata) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpExBiomphalariaGlabrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumThalpophilumDsm11723(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum DSM 11723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilumDsm11723", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosphaeraAminiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSpOccitanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium sp. occitanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSpOccitanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodisCitriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis citri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisCitriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaceaeBacteriumDnf00626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium DNF00626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumDnf00626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensSpPamc27130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. PAMC27130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychroserpensSpPamc27130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumCg1024814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium CG1024814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumCg1024814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHammesiiDsm16381Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii DSM 16381 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHammesiiDsm16381Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusIgniterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus igniterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusIgniterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fumarioli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFumarioli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacterium1109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium 1109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacterium1109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaccariaAmethystinaLaam081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Laccaria amethystina LaAM-08-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LaccariaAmethystinaLaam081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiumSpLsa18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium sp. LSA18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumSpLsa18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho201full4523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO201FULL4523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho201full4523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMacleodiiBlackEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Black Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiBlackEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaesserellaParasuisSh0165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaesserella parasuis SH0165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaesserellaParasuisSh0165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterOboediens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterOboediens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterGenomosp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter genomosp. 2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterGenomosp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisUo5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis Uo5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisUo5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiCj3symEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti CJ3sym Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiCj3symEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0701Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0701Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaDiminutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma diminutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaDiminutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixThermoacetophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpA3h3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. A3H3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpA3h3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaFucicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga fucicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaFucicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumThalpophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumVignaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium vignae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumVignaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaSpUtamx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMaliNbrc15500Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas mali NBRC 15500 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMaliNbrc15500Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudacidovoraxIntermediusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxIntermediusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxSp22iis10sEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax sp. 22IIs10s Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseivivaxSp22iis10sEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaSpMar2010147(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010147", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FurculomycesBoomerangusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Furculomyces boomerangus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FurculomycesBoomerangusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSaprophytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia saprophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSaprophytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusClavatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus clavatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusClavatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexusIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GambusiaAffinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gambusia affinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GambusiaAffinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpM47t1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M47T1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpM47t1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFryxellicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fryxellicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFryxellicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaModicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma modicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaModicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiardiaLambliaAtcc50803Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia ATCC 50803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaAtcc50803Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthobacterSoliDsm19599(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli DSM 19599 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoliDsm19599", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_51_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRubidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwc23612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWC2_36_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwc23612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilariopsisChorda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilariopsis chorda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilariopsisChorda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterNonchromogenicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter nonchromogenicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterNonchromogenicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpGfaj1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. GFAJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpGfaj1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrinisRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSolanacearumPsi07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum PSI07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPsi07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFirmusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus firmus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFirmusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Babesia bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BabesiaBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpRoot720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdhazardiaAedis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edhazardia aedis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdhazardiaAedis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full5114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL5114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full5114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisericumSpCg2303611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum sp. CG2_30_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldisericumSpCg2303611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaStriiformisFSpTriticiPst78(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia striiformis f. sp. tritici PST-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PucciniaStriiformisFSpTriticiPst78", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesXylophagusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xylophagus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXylophagusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricisUamh7299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polytolypa hystricis UAMH7299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolytolypaHystricisUamh7299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasStellipolaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas stellipolaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasStellipolaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomicrobiumOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinomicrobium oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinomicrobiumOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisListeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisListeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaPanamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leishmania panamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeishmaniaPanamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DendrosporobacterQuercicolusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dendrosporobacter quercicolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DendrosporobacterQuercicolusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSp64120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. 64-120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSp64120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYD2_FULL_35_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpAb134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Ab134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpAb134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteraceaeBacteriumAt5844Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacteraceae bacterium AT5844 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacteraceaeBacteriumAt5844Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacterium13220cm6814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 13_2_20CM_68_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium13220cm6814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothelomycesThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterSpMed193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. MED193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpMed193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwb1471Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWB1471 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwb1471Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumCg2304315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2304315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumXerosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium xerosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumXerosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf22910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_29_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf22910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaProteamaculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia proteamaculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaProteamaculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaMimosarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia mimosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMimosarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaVagansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea vagans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaVagansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LambdaproteobacteriaBacteriumRifoxyd2full5016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD2FULL5016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd2full5016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSp11kri321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. 11kri321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KurthiaSp11kri321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMassiliensis4401292(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis 4401292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesMassiliensis4401292", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KrasilnikoviellaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Krasilnikoviella flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KrasilnikoviellaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaniaMultitudinisentensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chania multitudinisentens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChaniaMultitudinisentensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HahellaGanghwensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hahella ganghwensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HahellaGanghwensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaprevotellaClara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella clara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaClara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminobacterHydrogenoformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneolaVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Balneola vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BalneolaVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UrsusMaritimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ursus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UrsusMaritimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpCit045(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. CIT045 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpCit045", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThraustothecaClavata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thraustotheca clavata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThraustothecaClavata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumPropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium propionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumPropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaEnhydraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia enhydra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaEnhydraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRochalimae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rochalimae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaRochalimae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaeniglutamicibacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TulasnellaCalosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tulasnella calospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TulasnellaCalosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacterium9403326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9403326 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9403326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmoebophilusAsiaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus asiaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusAsiaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusXiangfangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus xiangfangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusXiangfangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaPneumophilaPasculleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila pascullei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPasculleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferacalesArchaeonDl31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Haloferacales archaeon DL31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "HaloferacalesArchaeonDl31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndobugulaSertula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endobugula sertula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndobugulaSertula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium637(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium637", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumDiernhoferiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium diernhoferi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDiernhoferiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArgenteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus argenteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArgenteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumFalciparumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium falciparum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumFalciparumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumUc511d10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpOv118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ov118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiaceaeBacteriumKb18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridiaceae bacterium KB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiaceaeBacteriumKb18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpN324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. N324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpN324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EisenbacteriaBacteriumRbg167146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eisenbacteria bacterium RBG167146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EisenbacteriaBacteriumRbg167146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharolyticumWm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum WM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumWm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwc25213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC2_52_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc25213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFLusitanicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterLuteolusNbrc107841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus NBRC 107841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterLuteolusNbrc107841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomethylicusOleusabulumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus oleusabulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusOleusabulumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpKle1728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. KLE1728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpKle1728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumKh2t8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium KH2T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumKh2t8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusEthanoliduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus ethanolidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusEthanoliduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovibrioSalinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovibrio salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovibrioSalinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumCeleriflavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium celeriflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCeleriflavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosocosmicusExaquareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus exaquare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusExaquareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_54_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaMarismortui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula marismortui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaMarismortui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaGlobosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malassezia globosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalasseziaGlobosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRbg19ftcombo367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG19FTCOMBO367 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg19ftcombo367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfatatorIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumArgentoratense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium argentoratense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumArgentoratense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusFervens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus fervens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusFervens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasMucosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas mucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseomonasMucosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrososphaeraGargensisGa92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrososphaera gargensis Ga9.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrososphaeraGargensisGa92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisBriggsae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis briggsae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBriggsae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogeaDsm11164Nbrc106472(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea DSM 11164 NBRC 106472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudothermotogaHypogeaDsm11164Nbrc106472", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioCellulolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio cellulolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetivibrioCellulolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterAalborgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterAalborgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonadaceaeBacteriumCg1026018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium CG1_02_60_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumCg1026018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaWiggsiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scardovia wiggsiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScardoviaWiggsiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPlantarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus plantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPlantarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterSpNb68Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB68 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb68Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldisalinibacterKiritimatiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldisalinibacter kiritimatiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldisalinibacterKiritimatiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpAcam123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ACAM123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAcam123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpS6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpS6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGastriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGastriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_54_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriiaBacterium4080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriia bacterium 40-80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriiaBacterium4080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatoriaAcuminataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria acuminata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaAcuminataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh8016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrivivaxBenzoatilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax benzoatilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxBenzoatilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumJdfr86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumKashiwanohenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full4317bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL4317b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full4317bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetragenococcusMuriaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus muriaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusMuriaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusIntermediusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus intermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIntermediusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesBacteriumScgcAaa011b20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011B20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011b20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_36_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiaSanguinegens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sneathia sanguinegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SneathiaSanguinegens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndomicrobiumProavitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endomicrobium proavitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndomicrobiumProavitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_33_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntomoplasmaMelaleucaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterSalinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacteriumGwa27023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlcaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpTdk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. TDK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpTdk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaSpSwk7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula sp. SWK7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaSpSwk7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpL250Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L250 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpL250Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumCentrolobiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium centrolobii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCentrolobiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSp217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. 217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSp217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStoquefichusSpSb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. SB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpSb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromatialesBacteriumUscgtaylor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromatiales bacterium USCgTaylor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromatialesBacteriumUscgtaylor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_16b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylophilusAlvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylophilus alvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomethylophilusAlvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmticiciaOligotrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emticicia oligotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmticiciaOligotrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacterium4484213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMutansUa159Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans UA159 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansUa159Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucunaPruriensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucuna pruriens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucunaPruriensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusSpTolsrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus sp. TolSR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusSpTolsrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumFossorDsm15642Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopobium fossor DSM 15642 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopobiumFossorDsm15642Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaCinereaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria cinerea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCinereaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasBadiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas badia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasBadiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VombatusUrsinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vombatus ursinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VombatusUrsinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpHw567(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HW567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHw567", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_40_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpWcd3002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd3002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NotechisScutatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Notechis scutatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NotechisScutatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnchocercaOchengi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca ochengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OnchocercaOchengi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolymorphumGilvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polymorphum gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolymorphumGilvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpCag241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransAlbusMkt106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans albus MKT 106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgarivoransAlbusMkt106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AndreeseniaAngustaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Andreesenia angusta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AndreeseniaAngustaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureococcusAnophagefferensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aureococcus anophagefferens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AureococcusAnophagefferensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrybacteriaBacteriumRifcsplowo2024220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO2024220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo2024220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsmarc1261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInterrogansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira interrogans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInterrogansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacillusKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LebetimonasSpJs170Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lebetimonas sp. JS170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LebetimonasSpJs170Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElaeophoraElaphiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elaeophora elaphi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElaeophoraElaphiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabisAlpinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arabis alpina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArabisAlpinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArcachonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arcachonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArcachonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag964(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag964", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusHorikoshiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus horikoshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusHorikoshiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYB1_FULL_46_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPedisStrTA4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Treponema pedis str. T A4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TreponemaPedisStrTA4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkiellaCookevillensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkiella cookevillensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkiellaCookevillensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusQingdaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus qingdaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusQingdaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspDiarizonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. diarizonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspDiarizonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterAtrinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter atrinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterAtrinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaWeihenstephanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaWeihenstephanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumIntracellulareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intracellulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIntracellulareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusVillosusKin24T80Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus KIN24-T80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosusKin24T80Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Leptotrichia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Leptotrichia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRu33bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. RU33B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu33bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpH5989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. H5989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpH5989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFradiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fradiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFradiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesDokdonensisFr1436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis FR1436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardioidesDokdonensisFr1436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwc24418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWC24418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwc24418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesAmestolkiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces amestolkiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAmestolkiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSpUrhd0082Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter sp. URHD0082 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSpUrhd0082Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpGw1013h11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. GW101-3H11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpGw1013h11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumGw2011gwa24314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA24314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa24314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSuwonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter suwonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSuwonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpTnhr37b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. TNHR37B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpTnhr37b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusCarbonariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumZag111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium Zag111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumZag111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioFibrisolvensNd3005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens ND3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensNd3005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSpDsm44205Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44205Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSpJc230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. JC230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpJc230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterMishustinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter mishustinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterMishustinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHepatarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio hepatarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioHepatarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSp4425Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. 44-25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSp4425Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterCibariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCibariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumPhragmitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium phragmitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPhragmitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterEpoxidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter epoxidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterEpoxidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSphaericusOt4b31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus OT4b31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSphaericusOt4b31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MogibacteriumSpCm50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mogibacterium sp. CM50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MogibacteriumSpCm50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpMl3w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ML3W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpMl3w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocellaSilvestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocella silvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocellaSilvestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwb13322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanopyrusKandleriAv19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri AV19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanopyrusKandleriAv19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPeriocalifornicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides periocalifornicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPeriocalifornicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisSk1074Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK1074 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk1074Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensisCau28Dsm22330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis CAU 28 DSM 22330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusChungangensisCau28Dsm22330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpAm4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. AM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpAm4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasHelleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas helleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHelleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusChampanellensis18p13Jcm17042Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis 18P13 JCM 17042 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusChampanellensis18p13Jcm17042Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporobacterMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMesonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mesonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMesonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeeksellaVirosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weeksella virosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeeksellaVirosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg134610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_46_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg134610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaInohanensisNbrc100128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia inohanensis NBRC 100128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaInohanensisNbrc100128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumVaginaePb189t14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae PB189T14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaePb189t14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FonsecaeaMultimorphosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodovibrioSp970(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodovibrio sp. 970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiorhodovibrioSp970", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpHmsc76g11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. HMSC76G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpHmsc76g11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaSpiniferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala spinifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaSpiniferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterRectusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter rectus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterRectusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacillusGlycogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus glycogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusGlycogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeribacillusPallidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeribacillus pallidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeribacillusPallidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRoot154Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot154Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumD16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusLaterosporusLmg15441(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus LMG15441 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusLmg15441", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidaceaeBacteriumBroad1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioidaceae bacterium Broad1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardioidaceaeBacteriumBroad1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensSbw25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens SBW25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensSbw25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGallinaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcobacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helcobacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelcobacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermophagusXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermophagus xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermophagusXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasYunxiaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas yunxiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasYunxiaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAutolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces autolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAutolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5225Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5225 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5225Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaEpidermidihirudinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia epidermidihirudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaEpidermidihirudinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMikamiiNbrc108933Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mikamii NBRC 108933 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaMikamiiNbrc108933Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpLsnob(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. LSNOB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpLsnob", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumThiosulfatophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiosulfatophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiosulfatophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseinatronobacterThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseinatronobacter thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseinatronobacterThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraMeyeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira meyeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMeyeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_46_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwf23566Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWF2_35_66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwf23566Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PusillimonasNoertemannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas noertemannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PusillimonasNoertemannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGanghwenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium ganghwense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGanghwenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YooniaVestfoldensisSka53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis SKA53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisSka53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaSgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Sg Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMalicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Valsa malicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ValsaMalicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumScgcAaa252m02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium SCGC AAA252M02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumScgcAaa252m02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxDieseloleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax dieselolei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxDieseloleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TardibacterChloracetimidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tardibacter chloracetimidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TardibacterChloracetimidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacterium6411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 64-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium6411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpH567Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. H567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpH567Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_42_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpWsf3629Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. WSF 3629 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpWsf3629Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaParva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora parva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaParva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallipeplaSquamataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Callipepla squamata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CallipeplaSquamataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh7803Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7803 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7803Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag1944415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG_194_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1944415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizophyllumCommuneH48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune H4-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchizophyllumCommuneH48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumGwa27023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraRubrobruneaNbrc15275Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea NBRC 15275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRubrobruneaNbrc15275Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full4211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL4211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full4211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasEuvesicatoria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas euvesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasEuvesicatoria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavisolibacterTropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter tropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterTropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpYr247(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. yr247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpYr247", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr78Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr78Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriaceaeBacteriumChkci004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpN902109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. N902109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpN902109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HylemonellaGracilisAtcc19624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis ATCC19624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisAtcc19624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiscibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusSilesiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus silesiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSilesiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumGoodiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium goodii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGoodiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSpM18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaShahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella shahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaShahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumFacileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium facile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumFacileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200210029sch5224772Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200210029SCH5224772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200210029sch5224772Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NotamacropusEugeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Notamacropus eugenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NotamacropusEugeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg164921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg164921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexusSpMsg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. MSG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpMsg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothrixSoehngeniiGp6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii GP6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanothrixSoehngeniiGp6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPHIGHO2_01_FULL_57_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumXenophagumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium xenophagum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumXenophagumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritaleaMyrionectaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maritalea myrionectae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaritaleaMyrionectaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSepticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea septica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSepticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumDivergensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium divergens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumDivergensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumAnthropiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum anthropi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumAnthropiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full5114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL5114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full5114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumToluclasticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AromatoleumToluclasticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaDiminutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma diminutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaDiminutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaCaviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia caviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaCaviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaMagadiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba magadii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaMagadiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hr67(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr67", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPersimilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila persimilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPersimilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaArgentinensisDsm12282Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis DSM 12282 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaloarculaArgentinensisDsm12282Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaceaeBacteriumRedseas32b1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxellaceae bacterium REDSEAS32B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaceaeBacteriumRedseas32b1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinidiaChinensisVarChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinidia chinensis var. chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinidiaChinensisVarChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoplanesSpZ2yc6860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoplanes sp. Z2YC6860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoplanesSpZ2yc6860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpLeaf2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Leaf2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpLeaf2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMarthiiFslS4120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria marthii FSL S4-120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaMarthiiFslS4120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthS86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. S86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthS86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsJavanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps javanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CordycepsJavanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KryptoniumThompsoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kryptonium thompsoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KryptoniumThompsoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGwa2509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GWA2_50_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGwa2509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRbg136816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_13_68_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg136816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpH103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumGw2011gwa1409Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium GW2011GWA1409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumGw2011gwa1409Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumExtorquensPa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens PA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensPa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpCs1bsmeth3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1BSMeth3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1bsmeth3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNordii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides nordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNordii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpMbes04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. MBES04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpMbes04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistophilusSomniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Histophilus somni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HistophilusSomniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHeckeshornense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heckeshornense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeckeshornense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrinickiaSymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trinickia symbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrinickiaSymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSpC1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sp. C1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSpC1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSwezeyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus swezeyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSwezeyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumSpMj3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium sp. MJ3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalimicrobiumSpMj3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlaviflexusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flaviflexus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlaviflexusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FournierellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fournierella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FournierellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBryantiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bryantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBryantiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronococcusJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronococcusJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf198Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf198 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf198Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSaerimneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaerimneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusDictyosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus dictyosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusDictyosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpMit0602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusParcubacteriaBacterium4484255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Parcubacteria bacterium 4484_255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusParcubacteriaBacterium4484255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumNigerienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium nigeriense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNigerienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAegiribacteriaBacteriumMlsCEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aegiribacteria bacterium MLS_C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAegiribacteriaBacteriumMlsCEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSp6736Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 67-36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6736Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumHydrothermaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf2890Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2890 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2890Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumCarboxydivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum carboxydivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumCarboxydivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DracunculusMedinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dracunculus medinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DracunculusMedinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFluvialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fluvialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioFluvialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorhizobiumGalegaeOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa076p13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasTurrisvirgataeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas turrisvirgatae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTurrisvirgataeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg23041165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG23041165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg23041165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSp9120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. 9120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSp9120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterLanceolatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurvibacterLanceolatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaOtaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma otae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaOtaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FontibacillusPanacisegetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fontibacillus panacisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FontibacillusPanacisegetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpD104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. D104 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinomonasSpD104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CystobacterFerrugineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cystobacter ferrugineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CystobacterFerrugineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumTerrigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerrigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZymaeDsm19395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zymae DSM 19395 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZymaeDsm19395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpGai101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. GAI101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpGai101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira yanagawae serovar Saopaulo str. Sao Paulo ATCC 700523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumMultivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum multivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumMultivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaPomeroyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria pomeroyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaPomeroyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAsiaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAsiaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilimicrobiotaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilimicrobiota timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilimicrobiotaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimentitaleaNanhaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sedimentitalea nanhaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SedimentitaleaNanhaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAidingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAidingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpBal3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. BAL3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpBal3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc23941Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_39_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc23941Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacibacillusPorcorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacillus porcorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacibacillusPorcorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LottiaGiganteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lottia gigantea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LottiaGiganteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaPnomenusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pnomenusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPnomenusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedBlautiaSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Blautia sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedBlautiaSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpAli22i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. ALI22I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpAli22i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosynechococcusElongatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus elongatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusElongatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusClausseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus claussenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusClausseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHeckeshornenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heckeshornense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeckeshornenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAdiutrixIntracellularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adiutrix intracellularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdiutrixIntracellularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpAt9bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. At9b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpAt9bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumExtorquensPa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens PA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensPa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSp2mfcol31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 2MFCol31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSp2mfcol31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaHydrogenitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTolypomycinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis tolypomycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTolypomycinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaJaponicaDsm16301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica DSM 16301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaDsm16301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaVersiforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrinema versiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrinemaVersiforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSpS4079Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. S4079 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpS4079Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNakamuraiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus nakamurai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusNakamuraiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag465Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:465 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag465Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaPallensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pallens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPallensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasChitiniclastica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas chitiniclastica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasChitiniclastica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRifcsphigho202full4313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPHIGHO202FULL4313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsphigho202full4313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaPutidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia putida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaPutidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PristionchusPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pristionchus pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PristionchusPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesSpAsf519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides sp. ASF519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesSpAsf519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonadalesBacteriumGa0077531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RutstroemiaSpNjr2017aWrk4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a WRK4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aWrk4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifoxyc2full3812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFOXYC2FULL3812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifoxyc2full3812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasZehnderiOl4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi OL-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderiOl4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioIshigakensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ishigakensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioIshigakensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaSpRifoxya12full4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. RIFOXYA12FULL4616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpRifoxya12full4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCrudilactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium crudilactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCrudilactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaeumannomycesTriticiR3111a1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici R3-111a-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesTriticiR3111a1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPruniNbrc15498Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pruni NBRC 15498 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPruniNbrc15498Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAlginolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioAlginolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHimb11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HIMB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHimb11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterSpSoil728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. Soil728 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpSoil728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaOtitidisNbrc100426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia otitidis NBRC 100426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GordoniaOtitidisNbrc100426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAustralienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma australiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAustralienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminomonasPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminomonas paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminomonasPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacterium4572351Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_35.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572351Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYC2_FULL_45_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodisPhaseoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis phaseoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisPhaseoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenaeusVannameiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penaeus vannamei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenaeusVannameiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUrinalis228597Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis 228597 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalis228597Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDowneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus downei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDowneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopogonVesiculosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vesiculosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVesiculosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg163611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_36_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg163611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp2622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrospiraNitrosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLaminariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella laminariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLaminariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterPropionicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter propionicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelobacterPropionicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGw2011gwb15010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB15010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb15010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZobelliaUliginosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zobellia uliginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZobelliaUliginosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOryzihabitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzihabitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzihabitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterPostgateiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter postgatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterPostgateiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WheatBlue(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wheat blue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WheatBlue", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumUrocaniciphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium urocaniciphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUrocaniciphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4519Fw2642Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4519 (FW-2642) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4519Fw2642Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumPcc7702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium PCC7702 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumPcc7702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_01_FULL_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Camellia sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CamelliaSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaTemerariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia temeraria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTemerariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KriegellaAquimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kriegella aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KriegellaAquimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFructosivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fructosivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFructosivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaseolibacterFlectensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaseolibacter flectens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaseolibacterFlectensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaSpSe31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella sp. SE31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SciscionellaSpSe31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSpLeaf414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. Leaf414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpLeaf414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AvibacteriumParagallinarum221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 221 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilaceaeBacteriumUrhb0048(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0048", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViridosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridosporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenatarsenatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpZagget11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Zagget11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpZagget11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiribacterSalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiribacterSalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesPhaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myroides phaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyroidesPhaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_43_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiariaAnomalaUbc951(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tilletiaria anomala UBC 951 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TilletiariaAnomalaUbc951", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VittaformaCorneaeAtcc50505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vittaforma corneae ATCC 50505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VittaformaCorneaeAtcc50505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc7335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EptesicusFuscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eptesicus fuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EptesicusFuscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaSpiritensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella spiritensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSpiritensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenedentesBacteriumJgi0000039j10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium JGI 0000039J10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumJgi0000039j10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StemphyliumLycopersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stemphylium lycopersici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StemphyliumLycopersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMp13118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MP131-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMp13118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaccharosporaIrregularisDsm2635(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis DSM 2635 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularisDsm2635", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_01_FULL_41_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifcsphigho202full3412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPHIGHO202FULL3412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsphigho202full3412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp2a57ct2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 2A57CT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSp2a57ct2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovivaxRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halovivax ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalovivaxRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumAcidaminophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium acidaminophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumAcidaminophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDiphtheriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg136414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf343(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf343", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpN(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpN", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaAsaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella asaccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaAsaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelobacterSpSfb93(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter sp. SFB93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelobacterSpSfb93", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterFormicigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidibacterFormicigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisCinereaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisCinereaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RummeliibacillusStabekisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rummeliibacillus stabekisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RummeliibacillusStabekisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysemysPictaBelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta bellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChrysemysPictaBelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraSpCag484Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:484 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag484Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumGw2011gwa25212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GW2011GWA25212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGw2011gwa25212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBovoculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovoculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoraxellaBovoculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaMusaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora musae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaMusaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpOv510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. OV510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpOv510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRifoxyb1full4015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFOXYB1FULL4015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifoxyb1full4015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumStraminisolvensJcm21531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens JCM 21531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvensJcm21531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb14412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_44_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb14412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLappah108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLappah108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBauzanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas bauzanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBauzanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusButanolivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus butanolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusButanolivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMatruchotii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium matruchotii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMatruchotii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwa13716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWA1_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwa13716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TateyamariaSpAngs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria sp. ANGS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TateyamariaSpAngs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaG002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola G002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaG002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDiolivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDiolivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAzotifigensNbrc15497Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens NBRC 15497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAzotifigensNbrc15497Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumRifoxya2full4620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFOXYA2FULL4620 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifoxya2full4620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaDavisae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cedecea davisae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CedeceaDavisae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAnimalisSubspLactisAd011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis subsp. lactis AD011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalisSubspLactisAd011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHorikoshiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horikoshii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHorikoshiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23827 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMurinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus murinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMurinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarginalisIcmp9505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis ICMP 9505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMarginalisIcmp9505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa23623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23623 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaKristinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rothia kristinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RothiaKristinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaFalseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella falsenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFalseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHeilongjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus heilongjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHeilongjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAdolescentisAtcc15703Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis ATCC 15703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentisAtcc15703Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaSativaFSpontanea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa f. spontanea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaFSpontanea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces canus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0701Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0701 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0701Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticusT34Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus T-34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticusT34Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesLiubingyangii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces liubingyangii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesLiubingyangii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumRifcsplowo202full7356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium RIFCSPLOWO202FULL7356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumRifcsplowo202full7356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusMalaysiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus malaysiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusMalaysiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusLactaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusLactaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodesmiumErythraeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichodesmium erythraeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodesmiumErythraeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaOxytocaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella oxytoca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaOxytocaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPulmonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPulmonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistrellaMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tistrella mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TistrellaMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPorcinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porcinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorcinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaatingaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caatingaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaatingaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DacryopinaxPrimogenitusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dacryopinax primogenitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DacryopinaxPrimogenitusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumCoprophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium coprophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCoprophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YooniaTamlensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yoonia tamlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YooniaTamlensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPsychraerophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium psychraerophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPsychraerophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEan1pecCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EAN1pec Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEan1pecCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesMccartyiVsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi VS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiVsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo212full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO212FULL4311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo212full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24618Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24618 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24618Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3926 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifoxyb1Full5435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYB1_FULL_54_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyb1Full5435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHumireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAp12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AP12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAp12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAsteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium asteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAsteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] symbiosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSymbiosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077532Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077532 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077532Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinopithecusRoxellanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus roxellana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusRoxellanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumZavarzinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium zavarzinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumZavarzinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_50_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusTno09006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus TNO09006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusTno09006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaSylvestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana sylvestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NicotianaSylvestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodoferaxSpLeaf274Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf274Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaS16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida S16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaS16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocAzollae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc azollae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocAzollae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorMitchellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloramator mitchellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloramatorMitchellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusClarkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] clarkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusClarkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSp68310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 68-3-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp68310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuokellaJalaludiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella jalaludinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaJalaludiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwf26230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWF2_62_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwf26230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FundulusHeteroclitus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fundulus heteroclitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FundulusHeteroclitus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTepidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasHydrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSatsumensisDsm16230Jcm12392(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis DSM 16230 JCM 12392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSatsumensisDsm16230Jcm12392", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpL74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. L74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpL74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusThailandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusThailandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 62-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumPhotometricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum photometricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodospirillumPhotometricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpCf384(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. CF384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCf384", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_50_50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpKh1p2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. kh1p2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh1p2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCuracoiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces curacoi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCuracoiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusFulvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus fulvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MyxococcusFulvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1320 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumMesophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum mesophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMesophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumUndaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium undae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumUndaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpVm5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. Vm5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VirgibacillusSpVm5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumHimb5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteralesBacteriumRifoxyb1full6716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFOXYB1FULL6716 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifoxyb1full6716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyorhinisGdl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis GDL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisGdl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumPcc7702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium PCC7702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumPcc7702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliiroseovariusCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMarinisedimentorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marinisedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMarinisedimentorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasLignilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas lignilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolumonasLignilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwc24418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWC2_44_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwc24418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistocephalusSolidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistocephalus solidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistocephalusSolidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPiriflorinigrans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigrans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpYim77859(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. YIM77859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpYim77859", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferulaSpBvorr071Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferula sp. BvORR071 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferulaSpBvorr071Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrischellaPerrara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frischella perrara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrischellaPerrara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterLanthieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter lanthieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterLanthieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpLeaf344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Leaf344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLeaf344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BabesiaBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Babesia bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BabesiaBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulforhabdusNorvegica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulforhabdus norvegica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulforhabdusNorvegica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansNbrc15126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans NBRC15126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansNbrc15126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosphaeraSpWgk6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera sp. WGK6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraSpWgk6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasNitroreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpXt11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. XT11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpXt11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaTuberolachnusSalignus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Tuberolachnus salignus) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaTuberolachnusSalignus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRhizoxinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia rhizoxinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRhizoxinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNt26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NT-26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNt26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpNciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Nci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpNciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasFlueggei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas flueggei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasFlueggei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRbg13408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG13408 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg13408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraFaineiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira fainei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraFaineiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParusMajor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parus major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParusMajor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedArchaeonA07hr60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmotaMarmotaMarmota(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marmota marmota marmota graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarmotaMarmotaMarmota", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccibacterColletis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter colletis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SiccibacterColletis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBciso3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Bciso3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBciso3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusPcc7942(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC7942 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc7942", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAnserinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia anserina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaAnserinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterMusarumSubspJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter musarum subsp. japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeucobacterMusarumSubspJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumHlucca01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium HLUCCA01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumHlucca01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumGw2011gwa24310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWA24310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwa24310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSp1485eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. 1485E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSp1485eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinophytocolaXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticirepentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora triticirepentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTriticirepentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaeiDsm21440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei DSM 21440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaeiDsm21440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusMahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusMahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiCbdb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi CBDB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiCbdb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankineaeBacteriumMt45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankineae bacterium MT45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankineaeBacteriumMt45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGingeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGingeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumProvencense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium provencense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumProvencense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CohnellaPanacarviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CohnellaPanacarviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InquilinusLimosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Inquilinus limosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "InquilinusLimosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KozakiaBaliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kozakia baliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KozakiaBaliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho202full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL4312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpLb2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLb2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFOXYC2_FULL_35_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteraceaeBacteriumAt5844(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacteraceae bacterium AT5844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacteraceaeBacteriumAt5844", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumGwa15114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium GWA1_51_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumGwa15114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgulaAerodenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella veroralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaVeroralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaMimigardefordensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Advenella mimigardefordensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdvenellaMimigardefordensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisSpNies3709Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3709 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3709Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PodosporaAnserinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Podospora anserina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PodosporaAnserinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaPalustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kocuria palustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KocuriaPalustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAuricularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus auricularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAuricularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroherpetonThalassium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroherpeton thalassium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroherpetonThalassium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusGattiiVgiiR265Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii VGII R265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptococcusGattiiVgiiR265Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilis168Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis 168 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilis168Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpSk20926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. SK20926 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpSk20926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumColicanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumColicanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSp9143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiusMediterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius mediterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusMediterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterFrateuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter frateurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GluconobacterFrateuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag624043(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:62_40_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag624043", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDmhc10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DMHC 10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDmhc10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoramibacterAlactolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoramibacter alactolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoramibacterAlactolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFalloniiLlap10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella fallonii LLAP-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaFalloniiLlap10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaMojavensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Drosophila mojavensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DrosophilaMojavensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CholoepusHoffmanni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Choloepus hoffmanni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CholoepusHoffmanni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaCurassoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma curassoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaCurassoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterMathraniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathraniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasDiversaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas diversa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasDiversaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusOleiagri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus oleiagri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusOleiagri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSpMsx33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. MSX33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpMsx33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag791Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:791 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag791Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumNigeriense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium nigeriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNigeriense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumKoreenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumDenitrificans1nes1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans 1NES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificans1nes1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaPalleroniiNbrc102513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii NBRC 102513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaPalleroniiNbrc102513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfohalobiumRetbaenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalobium retbaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfohalobiumRetbaenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalicoccusPleomorphusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalicoccus pleomorphus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalicoccusPleomorphusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSeleniigenesDsm18267(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes DSM 18267 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PelobacterSeleniigenesDsm18267", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJensenii272chn(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus jensenii 272CHN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusJensenii272chn", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedAnaerotruncusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Anaerotruncus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedAnaerotruncusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpHeron(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. Heron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHeron", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg2304021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG2_30_40_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg2304021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumIranicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium iranicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumIranicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SordariaMacrosporaKHellCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora k-hell Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SordariaMacrosporaKHellCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSphaerophysae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sphaerophysae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSphaerophysae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb1446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB1446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb1446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacterium3541Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium 3541 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacterium3541Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenothrixSpD3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenothrix sp. D3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenothrixSpD3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrionaceaeBacteriumBs12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium Bs12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacteriumBs12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRit328(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. RIT328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRit328", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiscatoriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piscatorii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiscatoriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTegetincola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumI46(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium I46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumI46", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusSpHmsc06h08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sp. HMSC06H08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusSpHmsc06h08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumOmnivorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium omnivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumOmnivorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlkalitoleransDsm16699(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans DSM 16699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardioidesAlkalitoleransDsm16699", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAncashensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella ancashensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaAncashensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSpMarseillep2143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. MarseilleP2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpMarseillep2143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingorhabdusMarinaDsm22363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina DSM 22363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingorhabdusMarinaDsm22363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusTokodaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus tokodaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfolobusTokodaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumCg1024134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_41_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1024134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFOXYD1_FULL_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTakakiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium takakiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTakakiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb24720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRileyiRcef4871Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium rileyi RCEF 4871 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRileyiRcef4871Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpNs7484Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. NS-7484 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpNs7484Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorAquibiodomusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor aquibiodomus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratireductorAquibiodomusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumInnocuum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium innocuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumInnocuum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducensTx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens TX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensTx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA1_44_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusSpretusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mus spretus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusSpretusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronomonasPharaonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas pharaonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronomonasPharaonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelinaSativa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Camelina sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CamelinaSativa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_44_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptoniumThompsoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kryptonium thompsoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KryptoniumThompsoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesIhumiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesIhumiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporomusaSphaeroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporomusaSphaeroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifoxyd1full4124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYD1FULL4124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyd1full4124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRiegeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium riegelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRiegeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpHgb0015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. HGB0015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpHgb0015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaMalaquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia malaquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaMalaquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDadabacteriaBacteriumCsp12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium CSP1-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumCsp12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaDenticariosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella denticariosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDenticariosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMageritenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mageritense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumMageritenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMegasporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces megasporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMegasporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaErectaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila erecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DrosophilaErectaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabidopsisLyrataSubspLyrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata subsp. lyrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArabidopsisLyrataSubspLyrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTubingensisCbs13448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis CBS 134.48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusTubingensisCbs13448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5620 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaPhagocytophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma phagocytophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaPhagocytophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpAc23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. AC-23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpAc23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAmyloliquefaciensDsm7Atcc23350(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DSM 7 ATCC 23350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDsm7Atcc23350", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusRubiinfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus rubiinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusRubiinfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_38_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpGm95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GM95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGm95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTetaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrinisAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp12747566Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274756.6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747566Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMeyeriSerovarHardjoStrWent5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira meyeri serovar Hardjo str. Went 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMeyeriSerovarHardjoStrWent5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBeijerinckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBeijerinckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesVulturis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces vulturis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesVulturis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_02_FULL_45_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumCarotovorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalohastaLitchfieldiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halohasta litchfieldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalohastaLitchfieldiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixNiveaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix nivea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiothrixNiveaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumDaejeonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium daejeonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDaejeonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoruegeriaSabulilitorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sabulilitoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSabulilitorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolysaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolysaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SucciniclasticumRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SucciniclasticumRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm9796(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 9796 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm9796", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumGwa24615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium GWA2_46_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumGwa24615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyperthermusButylicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyperthermus butylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyperthermusButylicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrospiraInopinataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira inopinata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraInopinataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusSpYb142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sp. YB14-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSpYb142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCoprococcusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Coprococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedCoprococcusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhizobiumPelagicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhizobium pelagicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhizobiumPelagicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaGeojensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia geojensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaGeojensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusIgniterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus igniterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusIgniterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusMicrosporusAtcc52813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus microsporus ATCC 52813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizopusMicrosporusAtcc52813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumLuteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium luteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLuteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HomeothermusArabinoxylanisolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Homeothermus arabinoxylanisolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HomeothermusArabinoxylanisolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraNanhaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribiusSalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribius salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribiusSalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaFeeleiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella feeleii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaFeeleiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusChungangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumAb4001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AB4001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAb4001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSlbn53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SLBN-53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSlbn53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedimonasAcanthamoebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracaedimonas acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacaedimonasAcanthamoebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumSpCg3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacterium4337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 43-37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusFerrarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ferrarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFerrarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf097Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF097 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf097Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquabacteriumSpNj1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquabacterium sp. NJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquabacteriumSpNj1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PragiaFontium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pragia fontium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PragiaFontium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaBombicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella bombicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilliamellaBombicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwr3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWR3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwr3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusicatenibacterSaccharivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusicatenibacter saccharivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusicatenibacterSaccharivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaetiporusSulphureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaetiporusSulphureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterColi76339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli 76339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterColi76339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumAap81bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP81b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap81bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermostaphylosporaChromogenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermostaphylospora chromogena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermostaphylosporaChromogenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprinopsisMarcescibilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis marcescibilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisMarcescibilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterZhejiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter zhejiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterZhejiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniphilumSaccharofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum saccharofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSaccharofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpOv641Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OV641 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOv641Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaMannitolilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia mannitolilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaMannitolilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterActinomycetemcomitansD7s1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans D7S1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansD7s1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachanceaMirantina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachancea mirantina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachanceaMirantina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasAquimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAquimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasUreilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas ureilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasUreilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrigamiaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strigamia maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrigamiaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpMp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpMp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeMgh78578(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae MGH 78578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeMgh78578", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumCentenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum centenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumCentenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxElongansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferax elongans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferaxElongansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesGilchristiiSlh14081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii SLH14081 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlastomycesGilchristiiSlh14081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesViscosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces viscosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesViscosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TarenayaHassleriana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tarenaya hassleriana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TarenayaHassleriana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacteriumBbd199112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium BBD 1991-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacteriumBbd199112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParambassisRanga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parambassis ranga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParambassisRanga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRhizogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rhizogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRhizogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg16399bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_39_9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16399bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg135136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DasaniaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dasania marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DasaniaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GleimiaColeocanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gleimia coleocanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GleimiaColeocanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumBeijerinckiiDsm7166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii DSM 7166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckiiDsm7166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsinibacteriumSpOr53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asinibacterium sp. OR53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsinibacteriumSpOr53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactonifactorLongoviformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactonifactorLongoviformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumMarisnigriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum marisnigri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMarisnigriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumRbg166712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium RBG_16_67_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumRbg166712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoflavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoflavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoflavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYC2_FULL_39_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitorimicrobiumTaeanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litorimicrobium taeanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitorimicrobiumTaeanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiArupensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii arupensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiArupensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilaChrysaetosChrysaetosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquila chrysaetos chrysaetos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquilaChrysaetosChrysaetosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5225(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5225", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumGordonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gordonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGordonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNubinhibens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nubinhibens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNubinhibens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumCg2303210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_32_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NannizziaGypsea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nannizzia gypsea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NannizziaGypsea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbugoLaibachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Albugo laibachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlbugoLaibachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpGm95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GM95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGm95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrapeneCarolinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrapene carolina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrapeneCarolinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesItalicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesItalicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaAquimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaAquimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HumibacterAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Humibacter albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HumibacterAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPectinophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pectinophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPectinophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumAlterfunditumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium alterfunditum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumAlterfunditumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterLatericius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter latericius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenibacterLatericius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPlatycodiSf21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi SF21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiSf21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BatrachochytriumDendrobatidisJel423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JEL423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJel423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLydicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lydicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLydicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaQuateirensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella quateirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuateirensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAnisopliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumJeikeiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeikeium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeikeiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilimicrobiotaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilimicrobiota timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilimicrobiotaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumCaucaseumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum caucaseum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumCaucaseumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsanoaIshikariensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asanoa ishikariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsanoaIshikariensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRaac2wwe31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RAAC2WWE31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRaac2wwe31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfobacillusAcidophilusDsm10332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus DSM 10332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilusDsm10332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraPilosicoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira pilosicoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraPilosicoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OgataeaParapolymorphaDl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha DL-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OgataeaParapolymorphaDl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CenarchaeumSymbiosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumMetallidurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium metallidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumMetallidurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf194Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf194 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf194Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3911 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBica17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusOpacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus opacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusOpacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisMarcescibilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis marcescibilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisMarcescibilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasSpFb6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FB-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFb6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MerionesUnguiculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meriones unguiculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MerionesUnguiculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_49_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpB72017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpB72017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumIndicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumIndicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusMaritimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus maritimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusMaritimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5065Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5065 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5065Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJhl3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesCiferriiNrrlY1031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii NRRL Y-1031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesCiferriiNrrlY1031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumFossorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium fossor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumFossorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifoxyb2full4511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB2FULL4511 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb2full4511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaDuttoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia duttonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaDuttoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabidopsisThalianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis thaliana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisThalianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaHoutenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica houtenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaHoutenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella histicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaHisticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full487Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL487 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full487Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlesiomonasShigelloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plesiomonas shigelloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlesiomonasShigelloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPseudotuberculosisC231Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis C231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosisC231Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasShengliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas shengliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasShengliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OctodonDegus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Octodon degus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OctodonDegus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumGossypiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium gossypii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EremotheciumGossypiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyriculariaOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyricularia oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyriculariaOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasElysicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas elysicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasElysicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HirundoRusticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hirundo rustica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HirundoRusticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AedesAegypti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aedes aegypti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AedesAegypti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaVallismortisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula vallismortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaVallismortisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaXyliCynodontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli cynodontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCynodontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusPersicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacillusPersicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumFlorentinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium florentinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFlorentinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterCondimentiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter condimenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CronobacterCondimentiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaMangroviensisCbs10435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis CBS 10435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KwoniellaMangroviensisCbs10435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPantholopisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pantholopis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPantholopisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUnc280mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC280MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc280mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSpMctg156Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. MCTG156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpMctg156Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxSpNbrc102024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. NBRC 102024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpNbrc102024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumAquatileDsm21506Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile DSM 21506 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumAquatileDsm21506Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_41_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaZoogloeoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaZoogloeoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu084Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU084 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu084Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaDiarizonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica diarizonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaDiarizonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPiezophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia piezophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPiezophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterYangtzensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter yangtzensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterYangtzensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisFormicicusMcS70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Mc-S-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisFormicicusMcS70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelotomaculumThermopropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum thermopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumThermopropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaMusaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora musae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaMusaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HandroanthusImpetiginosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Handroanthus impetiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HandroanthusImpetiginosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacteriumHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioVulgarisMiyazakiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Miyazaki Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisMiyazakiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumGenomosp3StrCfbp6623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. 3 str. CFBP 6623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumGenomosp3StrCfbp6623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23885Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_38_85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23885Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisH37raCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Ra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37raCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSp6626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. 66-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSp6626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasVeroniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas veronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasVeroniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaXylanovoransDsm12503Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans DSM 12503 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovoransDsm12503Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendrobiumCatenatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dendrobium catenatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DendrobiumCatenatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasKyonanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimonasKyonanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp63ed372(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 63ED37-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp63ed372", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmithellaSpScadc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. SCADC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpScadc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythruraGouldiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrura gouldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythruraGouldiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPseudospiralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella pseudospiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPseudospiralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumSanguinicancriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sanguinicancri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSanguinicancriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NadsoniaFulvescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NadsoniaFulvescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivalisW83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis W83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisW83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumUzonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum uzonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermofilumUzonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMannanilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMannanilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeratitisCapitata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ceratitis capitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CeratitisCapitata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimicrobiumPachnodae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterLovleyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter lovleyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterLovleyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumImcc26207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpA3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. A3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpA3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerpetosiphonAurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon aurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonAurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapilioXuthusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Papilio xuthus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PapilioXuthusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaSpHel133131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_33_131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel133131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMindensisDsm14500(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis DSM 14500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMindensisDsm14500", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumRifcsplowo202full6214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPLOWO202FULL6214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsplowo202full6214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcalesBacteriumSg838Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium SG8_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacteriumSg838Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusVersicolorCbs58365(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus versicolor CBS 583.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusVersicolorCbs58365", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpAg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NaumovozymaDairenensisCbs421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis CBS 421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaDairenensisCbs421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GryllotalpicolaGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gryllotalpicola ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GryllotalpicolaGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaSpAs16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. AS16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpAs16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusShackletoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shackletonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusShackletoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrancourtellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drancourtella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrancourtellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpYt30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. YT30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpYt30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterPorticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter porticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterPorticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep2538Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2538 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2538Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSchinkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia schinkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaSchinkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaThiooxydansDsm14619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans DSM 14619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OttowiaThiooxydansDsm14619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSpSo1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. SO1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumSpSo1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxParadoxusEpsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus EPS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusEpsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPristinaespiralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pristinaespiralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPristinaespiralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpKp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. Kp2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpKp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterSubterraneusDsm17957(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus DSM 17957 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneusDsm17957", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13120cm3538(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_20CM_3_53_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13120cm3538", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsukibacteriumSpMj3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium sp. MJ3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumSpMj3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCrocodyliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma crocodyli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCrocodyliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu070(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU070 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu070", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSprentiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_12_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpHpa0247Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. HPA0247 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpHpa0247Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSpAk22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. AK22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSpAk22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWeihaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus weihaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusWeihaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloplasmaContractile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloplasma contractile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloplasmaContractile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full3984Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL3984 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full3984Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter persici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichormusVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichormus variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichormusVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaVietnamiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia vietnamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaVietnamiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaStewartii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea stewartii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaStewartii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenopusLaevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenopus laevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenopusLaevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc136108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC136108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc136108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenispirillumSalinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenispirillum salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenispirillumSalinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc034a01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC034A01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc034a01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFlorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus florum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFlorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPekkaneniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pekkanenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaPekkaneniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTaiwanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taiwanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaiwanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTubiashiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tubiashii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioTubiashiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethermicoccusShengliensisDsm18856Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis DSM 18856 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethermicoccusShengliensisDsm18856Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsasporaOwczarzaki(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapsasporaOwczarzaki", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpMa067296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. MA067296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpMa067296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacteraceaeBacteriumGwc25844Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_58_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25844Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_33_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpR37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpR37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumGmi1000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum GMI1000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumGmi1000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegniliparusRotundus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rotundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRotundus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCsivCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CSIV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCsivCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocapsaAcidiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa acidiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAcidiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaKrabiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora krabiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaKrabiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusSpMm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus sp. MM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylovorusSpMm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaSpCp2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. CP2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpCp2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterAerophilusDsm13606Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus DSM 13606 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HymenobacterAerophilusDsm13606Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusLuteusDsm17002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus luteus DSM 17002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusLuteusDsm17002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacropusEugeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Macropus eugenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MacropusEugeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansBcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans BC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansBcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpYi23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. YI23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpYi23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theileria orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheileriaOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasJandaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas jandaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasJandaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusLindneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus lindneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusLindneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumSpUch001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. UCH001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpUch001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaPelagicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolamina pelagica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolaminaPelagicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrobasidiumTorrendiiFp15055Ss10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii FP15055 ss-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendiiFp15055Ss10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLavalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] lavalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLavalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo202full4813bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL4813b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full4813bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag433Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:433 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag433Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenticepsClupeoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Denticeps clupeoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DenticepsClupeoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumSimulii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smittium simulii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmittiumSimulii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpUrhd0024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHD0024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhd0024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermithiobacillusTepidarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermithiobacillus tepidarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermithiobacillusTepidarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaSedimentorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella sedimentorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaSedimentorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumGw2011od13428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium GW2011OD13428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumGw2011od13428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterButzleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter butzleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterButzleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpIso805nCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Iso805N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpIso805nCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brennerbacteria bacterium RIFOXYD1_FULL_41_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusPrevotiiDsm20548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii DSM20548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiDsm20548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocoliticaLc20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica LC20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocoliticaLc20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusMoniliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus moniliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusMoniliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumGw2011gwa13413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA13413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa13413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatirhabdiumButyrativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseorubiginosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseorubiginosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseorubiginosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumAmmoniigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaLenta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella lenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaLenta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FulvimarinaPelagiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina pelagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaPelagiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOtitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOtitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumSm2361Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SM23_61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSm2361Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumCch11d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH11D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch11d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortieraAleyrodidarumTv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum TV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumTv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisCampestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris campestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "XanthomonasCampestrisCampestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLemmy01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LEMMY01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLemmy01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifoxyd2full4310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD2FULL4310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd2full4310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KtedonobacterSp13120cm45311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter sp. 13_1_20CM_4_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterSp13120cm45311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumPullorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pullorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPullorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAmbofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces ambofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAmbofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiabellaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niabella soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiabellaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPecorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPecorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusIngluvieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ingluviei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusIngluvieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LasiusNigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lasius niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LasiusNigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisLiminatansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis liminatans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanofollisLiminatansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricellaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNe2001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NE2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNe2001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusLimicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoplanus limicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoplanusLimicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLonarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lonarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLonarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetonemaLongumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetonema longum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetonemaLongumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumFrisingense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum frisingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumFrisingense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalotaleaAlkalilentaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halotalea alkalilenta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalotaleaAlkalilentaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsplowo201full4525bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO201FULL4525b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo201full4525bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrabacterSp28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. 28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSp28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhodospiraHalochlorisStrACluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris str. A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorhodospiraHalochlorisStrACluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaRestricta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malassezia restricta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalasseziaRestricta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArsenophonusTriatominarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus triatominarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusTriatominarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGlumaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia glumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGlumaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTermitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium termitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTermitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchmidhempeliaBombi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schmidhempelia bombi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchmidhempeliaBombi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsplowo212full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPLOWO212FULL4812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsplowo212full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryziasMelastigmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryzias melastigma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryziasMelastigmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodocyclaceaeBacteriumPaddy1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodocyclaceae bacterium Paddy-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodocyclaceaeBacteriumPaddy1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusPakistanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus pakistanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusPakistanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot240(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot240", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligoflexusTunisiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oligoflexus tunisiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OligoflexusTunisiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpAl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. AL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpAl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorellaAsinigenitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorella asinigenitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorellaAsinigenitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterActiniarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumCg2303729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium CG2303729 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumCg2303729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumCopahuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum copahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumCopahuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioAespoeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio aespoeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioAespoeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomycesCerevisiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces cerevisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesCerevisiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumYl45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium YL45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumYl45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf69(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf69 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf69", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CobetiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cobetia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CobetiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CicerArietinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cicer arietinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CicerArietinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisRmscc2394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 2394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc2394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCihuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCihuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterSpGwa24521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. GWA2_45_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpGwa24521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSpCag977Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. CAG:977 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSpCag977Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioSpJcm19048Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio sp. JCM 19048 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioSpJcm19048Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreochromisNiloticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis niloticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OreochromisNiloticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg2304514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG2304514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg2304514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacteraceaeBacterium4484166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacteraceae bacterium 4484_166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacteraceaeBacterium4484166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe3009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaTurbansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia turbans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTurbansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwf23566(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWF2_35_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwf23566", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DebaryomycesHanseniiCbs767(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii CBS767 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DebaryomycesHanseniiCbs767", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpLsnobEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. LSNOB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpLsnobEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreiburgenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium freiburgense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFreiburgenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaFrederikseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia frederiksenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaFrederikseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterSpSw2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. SW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpSw2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgaricusBisporusVarBurnettiiJb137S8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus var. burnettii JB137-S8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgaricusBisporusVarBurnettiiJb137S8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IshikawaellaCapsulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ishikawaella capsulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IshikawaellaCapsulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPullorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pullorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPullorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSp9402080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. 9402080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSp9402080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithorhynchusAnatinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithorhynchus anatinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithorhynchusAnatinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisSaalfeldensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis saalfeldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSaalfeldensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSviceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sviceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSviceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSplendidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio splendidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSplendidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovisM02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis m02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovisM02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaSpJt01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. JT01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpJt01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_16b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4716bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoykebacteriaBacteriumRbg16399bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_39_9b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16399bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacterSaccharofermentansDsm14828Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans DSM 14828 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentansDsm14828Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterHoyleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter hoylei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterHoyleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XiphophorusMaculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus maculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XiphophorusMaculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusFujiensisJcm16395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis JCM 16395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusFujiensisJcm16395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpCf614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. CF614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpCf614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFutsaiiJcm17355(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii JCM 17355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFutsaiiJcm17355", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumChlorophytiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum chlorophyti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumChlorophytiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsplowo201full4816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO201FULL4816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo201full4816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusReuteriDsm20016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri DSM20016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteriDsm20016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumLychnidisdioicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum lychnidisdioicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisdioicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalleroniaRufaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Palleronia rufa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PalleroniaRufaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpBrhc9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BRHc9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBrhc9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfUnidentifiedScalySnailIsolateMonju(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified scaly snail isolate Monju graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentifiedScalySnailIsolateMonju", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumGwa1448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium GWA1448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumGwa1448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrueperaRadiovictrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Truepera radiovictrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrueperaRadiovictrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusWentiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus wentii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusWentiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria rhizophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaRhizophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg164410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_44_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg164410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:967 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UzinuraDiaspidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uzinura diaspidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UzinuraDiaspidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full5118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL5118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full5118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGrimmiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia grimmiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaGrimmiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhaeomarinobacterEctocarpi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phaeomarinobacter ectocarpi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhaeomarinobacterEctocarpi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydans621h(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans 621H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydans621h", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSkirrowiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter skirrowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSkirrowiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumRoquefortiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium roqueforti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRoquefortiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaVladivostokensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita vladivostokensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AequorivitaVladivostokensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_72_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyc2Full4719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYC2_FULL_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyc2Full4719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalimicrobiumCyclicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium cyclicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumCyclicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSp627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. 627 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesSp627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiCsThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CS Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCsThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaFryxellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella fryxellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaFryxellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpO77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. O-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpO77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpNies2104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-2104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies2104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAcidiproducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidiproducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCucumisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cucumis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCucumisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpF0557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterSpSoil728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. Soil728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpSoil728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaOtaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma otae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaOtaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumHydrothermaleDsm13146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale DSM 13146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermaleDsm13146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FenollariaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fenollaria timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FenollariaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColi536Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli 536 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColi536Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmpedobacterFalseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter falsenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterFalseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutremaSalsugineum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eutrema salsugineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EutremaSalsugineum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo202full4811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO202FULL4811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo202full4811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBoevreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella boevrei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBoevreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChoiromycesVenosus1206131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Choiromyces venosus 120613-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChoiromycesVenosus1206131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCg10264396(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CG1_02_64_396 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCg10264396", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag488Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag488Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpMm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. MM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaBpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Bp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusPortucalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocMesenteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc mesenteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocMesenteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg164224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPLOWO2_01_FULL_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsplowo201Full4332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hippea maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HippeaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaFerrariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ferrariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaFerrariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HypoxylonSpCo275Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CO27-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCo275Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EucalyptusGrandisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eucalyptus grandis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EucalyptusGrandisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasAromatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas aromatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAromatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxHaastii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apteryx haastii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApteryxHaastii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaWadei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia wadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaWadei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioCrunogenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio crunogenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioCrunogenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelliellaPelovolcani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Belliella pelovolcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BelliellaPelovolcani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAccolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium accolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAccolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_45_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterSpDsm44400(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. DSM 44400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpDsm44400", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_54_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydansH24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans H24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydansH24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaAerilataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microvirga aerilata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrovirgaAerilataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzohydromonasAustralicaDsm1124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Azohydromonas australica DSM 1124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AzohydromonasAustralicaDsm1124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterDuraquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter duraquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterDuraquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpHiyo8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Hiyo8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHiyo8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UlvibacterSpLpb0005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter sp. LPB0005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UlvibacterSpLpb0005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratiruptorTergarcusDsm16512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus DSM 16512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitratiruptorTergarcusDsm16512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraCaerulea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera caerulea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraCaerulea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusKawachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus kawachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusKawachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumCongolenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium congolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumCongolenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StachybotrysChlorohalonataIbt40285(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata IBT 40285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonataIbt40285", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriDmel1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Dmel1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDmel1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusSp15rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus sp. 15R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusSp15rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureispiraSpCcbqb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureispira sp. CCBQB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureispiraSpCcbqb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesTimonensisJc136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes timonensis JC136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesTimonensisJc136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCohniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus cohnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCohniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiphiliumAngustum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium angustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidiphiliumAngustum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFrankenforstenseDsm45800Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense DSM 45800 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstenseDsm45800Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterCrusticolaDsm16708(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola DSM 16708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DyadobacterCrusticolaDsm16708", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaSpCp2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. CP2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpCp2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaTyphimuriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhimurium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphimuriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAnaemiaeNbrc100462Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia anaemiae NBRC 100462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAnaemiaeNbrc100462Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CycloclasticusSpSymbiontOfBathymodiolusHeckeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus heckerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusHeckeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliifodinibiusRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliifodinibius roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliifodinibiusRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMacleodiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsormidiumNitensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsormidium nitens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsormidiumNitensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full4719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL4719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full4719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumHalophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium halophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumHalophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSp5h374Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. 5H374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSp5h374Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AngelakisellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Angelakisella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AngelakisellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaCaviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaCaviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasAsaccharolyticaNbrc15499(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica NBRC 15499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolyticaNbrc15499", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladusLaminosusUu774(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus UU774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MastigocladusLaminosusUu774", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaPachydermatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malassezia pachydermatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalasseziaPachydermatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusNecatorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus necator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNecatorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusPiezophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus piezophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPiezophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFeriruminatorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma feriruminatoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFeriruminatorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf172Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf172Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumNor53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium NOR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumNor53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumDtu037Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium DTU037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumDtu037Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesMerusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles merus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesMerusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot552Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root552 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot552Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxyc12full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYC12FULL3613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyc12full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSpSoil729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sp. Soil729 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSpSoil729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YokenellaRegensburgeiAtcc43003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yokenella regensburgei ATCC 43003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YokenellaRegensburgeiAtcc43003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg134015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_13_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg134015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodospiraSibiricaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodospira sibirica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiorhodospiraSibiricaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanisphaeraPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanisphaera psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanisphaeraPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrackiellaOedipodisDsm13743(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brackiella oedipodis DSM 13743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrackiellaOedipodisDsm13743", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpVt162Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. VT 162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpVt162Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsphigho212full4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL4616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiVs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi VS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiVs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliosenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliosenegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliosenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxParadoxusS110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus S110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusS110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitriliruptorAlkaliphilusDsm45188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus DSM 45188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilusDsm45188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MyxococcusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaediPagu611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi PAGU611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediPagu611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDextrinicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDextrinicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaInyonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora inyonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaInyonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofarcimenIntricatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen intricatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenIntricatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MotiliproteusSpMsk221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Motiliproteus sp. MSK22-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MotiliproteusSpMsk221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusAcidilacticiDsm20284Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici DSM20284 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PediococcusAcidilacticiDsm20284Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumCarotovorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasAcidaminiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas acidaminiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasAcidaminiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimentisphaeraCyanobacteriorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera cyanobacteriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraCyanobacteriorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinalesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaF0398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia F0398 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaF0398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumLimosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium limosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumLimosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_57_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumSetenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium setense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSetenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaW619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida W619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaW619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutimaribacterSaemankumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutimaribacter saemankumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutimaribacterSaemankumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomonasSpCacia14h2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. CACIA14H2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpCacia14h2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnormaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enorma timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnormaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitritaleaHalalkaliphilaLw7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila LW7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphilaLw7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalisDsm15212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis DSM 15212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalisDsm15212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoritellaSpPe36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. PE36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpPe36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusAcidiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acidiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcidiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcremoniumChrysogenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcremoniumChrysogenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaMaltosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida maltosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaMaltosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSpNh8b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. NH8B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpNh8b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterAlbidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter albidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconobacterAlbidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiesbergeriaAnulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giesbergeria anulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiesbergeriaAnulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCalviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCalviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaBurgdorferiB31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi B31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferiB31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterDaepoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daepoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaepoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisCinerea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisCinerea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspMasoucidaNbrc13784(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. masoucida NBRC 13784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspMasoucidaNbrc13784", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaIndicaDsm11827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serendipita indica DSM 11827 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerendipitaIndicaDsm11827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermorudisPeleaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermorudis peleae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermorudisPeleaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpRoot563(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Root563 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpRoot563", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaProductaAtcc27340Dsm2950Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta ATCC 27340 DSM 2950 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlautiaProductaAtcc27340Dsm2950Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaParvulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella parvula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaParvulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium6970Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 69-70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6970Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCylindrosporumDsm605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum DSM 605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporumDsm605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariivitaBoseongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aestuariivita boseongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AestuariivitaBoseongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumSpMb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. MB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpUsmaa24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. USMAA2-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpUsmaa24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumBranderiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium branderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBranderiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusThermodenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus thermodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusThermodenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaMansoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mansoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMansoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiosporiumApollinisCbs100218(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coniosporium apollinis CBS 100218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ConiosporiumApollinisCbs100218", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumC6a11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C6A11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC6a11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterTibetensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter tibetensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterTibetensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasNaejangsanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas naejangsanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNaejangsanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1320 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasYangmingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas yangmingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasYangmingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRubensWisconsin541255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Wisconsin 54-1255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRubensWisconsin541255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpN3c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. N3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpN3c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOvis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOvis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraJadiniiNrrlY1542(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii NRRL Y-1542 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyberlindneraJadiniiNrrlY1542", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoeseiaOceani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woeseia oceani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoeseiaOceani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetofabaAustralisIt1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnetofaba australis IT-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnetofabaAustralisIt1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulaeDsm17944(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides insulae DSM 17944 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardioidesInsulaeDsm17944", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho212full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO212FULL4311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho212full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbiconiuxSolaniNbrc106740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux solani NBRC 106740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HerbiconiuxSolaniNbrc106740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaSubspMultocidaOh4807Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida OH4807 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaOh4807Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumFaniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium faniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumFaniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJdm601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JDM601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJdm601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlcaliphilum20zCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum 20Z Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilum20zCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterAcetiAtcc23746(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti ATCC23746 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAcetiAtcc23746", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesPutredinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes putredinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesPutredinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorNaganoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysolophusPictusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chrysolophus pictus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChrysolophusPictusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKansasiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAcidiproducensDsm23148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens DSM 23148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAcidiproducensDsm23148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpMg162Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. mg162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg162Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSpCag709Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:709 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag709Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaSpAs16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. AS16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpAs16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlumeriaGraminisFSpHordeiDh14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis f. sp. hordei DH14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlumeriaGraminisFSpHordeiDh14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumGwa27335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_73_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaTimorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dietzia timorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DietziaTimorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusJilinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus jilinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusJilinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterSpYs13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. YS13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpYs13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4922b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4922b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4922b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpBls98Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BLS98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBls98Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaNorrlandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella norrlandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaNorrlandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsplowo201full5020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO201FULL5020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo201full5020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusJeddahense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus jeddahense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusJeddahense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cellulovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodiomycesAlkalinusF11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus F11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SodiomycesAlkalinusF11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaAcidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa acidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporomusaAcidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSocompensisS10bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis S10B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioSocompensisS10bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDadabacteriaBacteriumCsp12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium CSP1-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumCsp12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchicusJcm15530Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus JCM 15530 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKimchicusJcm15530Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacteriumCg1024614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrarchaeotaArchaeonCg1026051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1026051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1026051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaDavisaeDsm4568Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cedecea davisae DSM 4568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CedeceaDavisaeDsm4568Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuromonadalesBacteriumGwc26120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadales bacterium GWC2_61_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadalesBacteriumGwc26120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesFarautiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles farauti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesFarautiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPHIGHO2_12_FULL_38_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsphigho212Full389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm23733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaJasoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hippea jasoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HippeaJasoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChisholmbacteriaBacteriumRifcsphigho201full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPHIGHO201FULL4812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsphigho201full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaInulinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia inulinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaInulinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeomonachusSchauinslandi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neomonachus schauinslandi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeomonachusSchauinslandi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiDsm29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei DSM 29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiDsm29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHassiacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium hassiacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHassiacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidihalobacterFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasSpFcs9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. FCS-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpFcs9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTofieldiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tofieldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTofieldiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RamlibacterSpLeaf400Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter sp. Leaf400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RamlibacterSpLeaf400Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusTerranovensisDsm18919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis DSM 18919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensisDsm18919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixFlexilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix flexilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiothrixFlexilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetalesBacterium7110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 71-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium7110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumMinutulum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum minutulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumMinutulum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylumTricornutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaRara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella rara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioXylanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio xylanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioXylanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumStylosanthisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium stylosanthis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumStylosanthisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasMicra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas micra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvimonasMicra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasBalearica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas balearica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimonasBalearica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAquimarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus aquimarinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAquimarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRiyadhenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium riyadhense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumRiyadhenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifcsphigho201full5110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL5110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full5110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoactinomycesSpAs95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. AS95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpAs95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 28-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanioRerioCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Danio rerio Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DanioRerioCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmaVolcaniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma volcanium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaVolcaniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp10819081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1081908.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp10819081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMannanilyticusJcm10596Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus JCM 10596 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusMannanilyticusJcm10596Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full4222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL4222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full4222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNiveusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niveus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNiveusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamwhitmaniaTaraxaciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Williamwhitmania taraxaci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WilliamwhitmaniaTaraxaciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseofilumReptotaeniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseofilumReptotaeniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpYe71Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. YE71 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpYe71Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixRoseaIamM220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix rosea IAM M-220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LimnothrixRoseaIamM220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpL53140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. L53140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpL53140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCaseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium casei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCaseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpNi22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. NI22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodovulumSpNi22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumVacuolatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeishmaniaMajorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leishmania major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaMajorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetschnikowiaBicuspidata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaMuralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jiangella muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JiangellaMuralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaGranulosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola granulosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicolaGranulosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CedeceaDavisaeDsm4568(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cedecea davisae DSM 4568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CedeceaDavisaeDsm4568", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThiodiazotrophaEndolucinida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endolucinida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndolucinida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCallunaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium callunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCallunaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferulaSpBvorr071(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferula sp. BvORR071 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferulaSpBvorr071", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifoxya2Full4528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFOXYA2_FULL_45_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifoxya2Full4528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaProteobacteriumMl8f1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium ML8F1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMl8f1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifoxyc1full3818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYC1FULL3818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyc1full3818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumConspicuumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium conspicuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumConspicuumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachanceaThermotoleransCbs6340Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans CBS 6340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachanceaThermotoleransCbs6340Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSalinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSalinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFennelliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter fennelliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFennelliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpLcm4579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LCM 4579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLcm4579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumGa0074140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium Ga0074140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGa0074140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaAltunenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrinema altunense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrinemaAltunenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedLachnospiraSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Lachnospira sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedLachnospiraSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaEntomophaga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia entomophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaEntomophaga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPhyllosphaerae52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae 52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaerae52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaSpJt01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. JT01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpJt01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensisDsm45107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis DSM 45107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensisDsm45107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumCrhCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CRH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCrhCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaHarzianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma harzianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaHarzianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot552(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot552", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumD16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrooxidansAtcc23270Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC23270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc23270Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidothermusCellulolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidothermus cellulolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidothermusCellulolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BigelowiellaNatansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bigelowiella natans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BigelowiellaNatansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpCulexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Culex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpCulexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaceaeBacteriumPhil1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaPersicinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia persicina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPersicinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaLonarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaLonarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa25713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_57_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesmosporaSp8437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desmospora sp. 8437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesmosporaSp8437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaIchthyophaga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WallemiaIchthyophaga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDesertiGimn1010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium deserti GIMN1.010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDesertiGimn1010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium7064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 70-64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium7064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusIsoporae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus isoporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusIsoporae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixInsectorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix insectorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporothrixInsectorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaDuttonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia duttonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaDuttonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinimonasKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubinisphaeraBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubinisphaera brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubinisphaeraBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioGilvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CellvibrioGilvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpWsm2793(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM2793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm2793", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBerlinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema berlinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaBerlinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkelbacteriaBacteriumCg2303944Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_39_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2303944Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonRbg135212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_52_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg135212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSp99Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. 99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSp99Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusTukisamuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus tukisamuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTukisamuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpLeaf160Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf160Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumSpF0263Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0263 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpF0263Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWF2_43_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwf24332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOrbiscindensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium orbiscindens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumOrbiscindensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaSpielmaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia spielmanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaSpielmaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumChoerinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium choerinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumChoerinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpIso805n(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Iso805N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpIso805n", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaToluolicaTol2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Tol2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobaculaToluolicaTol2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaLacusDsm23236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia lacus DSM 23236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AndreprevotiaLacusDsm23236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSpDl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. DL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpDl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumGlobosumCbs14851Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium globosum CBS 148.51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumGlobosumCbs14851Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAbyssalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus abyssalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAbyssalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasNitritireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas nitritireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasNitritireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusPlantarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus plantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPlantarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipomycesStarkeyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LipomycesStarkeyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrodictiumDelaneyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium delaneyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumDelaneyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpQlwp1data2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. QLWP1DATA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpQlwp1data2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSalmoneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaAciduriciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia acidurici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaAciduriciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaF1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida F1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaF1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumKansasii732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii 732 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasii732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHalophyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora halophytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHalophyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpPamc28711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. PAMC 28711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpPamc28711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParasporobacteriumPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesColuzziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles coluzzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesColuzziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioEzuraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ezurae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioEzuraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaCellobiosiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenuloplanesJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenuloplanes japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenuloplanesJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviflexusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flaviflexus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlaviflexusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UreaplasmaParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonRbg16369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon RBG16369 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonRbg16369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaseolusVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaseolus vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaseolusVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumElkaniiWsm1741Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM1741 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm1741Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpecialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces specialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpecialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaFormicigenerans4653afaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans 4653AFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigenerans4653afaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GardnerellaVaginalis101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBlochmanniaVaferStrBvafCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blochmannia vafer str. BVAF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlochmanniaVaferStrBvafCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasFragariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas fragariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFragariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpHr7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. HR7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpHr7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumBc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum BC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumBc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChoiromycesVenosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Choiromyces venosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChoiromycesVenosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumBaderiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium baderi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumBaderiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosphaeraAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosphaera aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosphaeraAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCoubleaeNbrc108252(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia coubleae NBRC 108252 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaCoubleaeNbrc108252", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCollagenovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCollagenovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_02_FULL_48_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaFuscipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina fuscipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaFuscipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimiduiaAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Simiduia agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SimiduiaAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasVasicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVasicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TsukamurellaPulmonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPulmonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp4fEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 4F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp4fEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPasteurianusAtcc43144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus ATCC 43144 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPasteurianusAtcc43144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHydrophobicaNbrc16057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica NBRC 16057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GordoniaHydrophobicaNbrc16057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonBa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterorhabdusMucosicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus mucosicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusMucosicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydialesBacterium3826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiales bacterium 38-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydialesBacterium3826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporidiumMurisRn66(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris RN66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumMurisRn66", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSeptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea septica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSeptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KallipygaGabonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga gabonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KallipygaGabonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaRestrictaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malassezia restricta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalasseziaRestrictaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpAg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpAg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfRidgeiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMytiliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mytili Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMytiliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpDg881(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. DG881 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpDg881", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasTenaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas tenax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasTenaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb01580Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB01580 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb01580Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusTransvaalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus transvaalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusTransvaalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaeniclostridiumSordelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paeniclostridium sordellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaeniclostridiumSordelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermatophilusCongolensisDsm44180Nbrc105199Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis DSM 44180 NBRC 105199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DermatophilusCongolensisDsm44180Nbrc105199Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE2699Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2699 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2699Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChlorophenolicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusSpSoil803(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil803", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TalaromycesIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumOvolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum ovolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumOvolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PersephonellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Persephonella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PersephonellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnchocercaOchengiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca ochengi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OnchocercaOchengiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAlveiDsm29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei DSM 29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiDsm29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumThalpophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaBroomeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia broomeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaBroomeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DinothrombiumTinctoriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dinothrombium tinctorium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DinothrombiumTinctoriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusSubspTestudinumSp3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. testudinum Sp3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspTestudinumSp3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuokellaSpW9106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella sp. W9106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaSpW9106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumAmbiguumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidium ambiguum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidiumAmbiguumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_39_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpT32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. T32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpT32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptoalloteichusHindustanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptoalloteichus hindustanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptoalloteichusHindustanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoniaPhycicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesonia phycicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoniaPhycicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteroidesVaginaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilibacteroides vaginae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilibacteroidesVaginaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColinusVirginianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colinus virginianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColinusVirginianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropicimonasIsoalkanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tropicimonas isoalkanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TropicimonasIsoalkanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterArenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter arenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterArenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb00455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB00455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb00455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlr1721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALR1721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlr1721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMegateriumMsp201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium MSP201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumMsp201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalaenopteraAcutorostrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumPullulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium pullulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumPullulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParadoxum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium paradoxum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumParadoxum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusDsm15893Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus DSM 15893 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusDsm15893Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsplowo201full5024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL5024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full5024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL3713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCf080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg19ftcombo7019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG19FTCOMBO7019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg19ftcombo7019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSp2742308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia sp. 2742-308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSp2742308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterShowaeCsunswcdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CSUNSWCD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCsunswcdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpSy8519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SY8519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpSy8519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumK1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium K1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumK1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumLactosutens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium lactosutens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumLactosutens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSpOccitanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium sp. occitanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSpOccitanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaLotononidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lotononidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLotononidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 47-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeobacteroidesDsm266Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides DSM266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesDsm266Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterCapsulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter capsulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterCapsulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusRhinitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus rhinitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRhinitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAquilae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAquilae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpDi166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. DI166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpDi166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusZilligiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus zilligii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusZilligiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYC1_FULL_38_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumSoil82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium SOIL82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumSoil82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_41_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNatriegensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio natriegens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioNatriegensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BernardetiaLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bernardetia litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BernardetiaLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanotheceSpPcc7822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaDsm7271Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea DSM7271 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaDsm7271Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonodelphisDomesticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monodelphis domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonodelphisDomesticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSaelicesensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora saelicesensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSaelicesensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRbg164224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterCuniculorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter cuniculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCuniculorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyricimonasSynergisticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas synergistica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSynergisticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoolittleaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doolittlea endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoolittleaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegniliparusRugosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rugosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRugosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensDsm10105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens DSM10105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensDsm10105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMediterraneiS699(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei S699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisMediterraneiS699", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_49_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAuratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces auratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAuratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpHensoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. hensonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHensoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthamoebaCastellaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcanthamoebaCastellaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacterium1147(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 1147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium1147", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJhl3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumGasigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium gasigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGasigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalorhabdusDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiohalorhabdus denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiohalorhabdusDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVenenatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium venenatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumVenenatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisMaydisC5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BipolarisMaydisC5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusPropionicusDsm13327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus propionicus DSM 13327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PelosinusPropionicusDsm13327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMiyunensisNbrc108239Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia miyunensis NBRC 108239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaMiyunensisNbrc108239Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterVibrioidesOr37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides OR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesOr37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensQ287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Q287 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensQ287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpF366Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. F36-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpF366Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm1253Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1253 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1253Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsphigho201full5513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO201FULL5513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho201full5513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGalbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces galbus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGalbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IsoptericolaDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaMortivallis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora mortivallis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaMortivallis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaeniclostridiumSordellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paeniclostridium sordellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaeniclostridiumSordellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5053Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5053Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusFujiensisJcm16395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus fujiensis JCM 16395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusFujiensisJcm16395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAllii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea allii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaAllii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFrumentiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFrumentiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TeredinibacterTurneraeT7901Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7901Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematostellaVectensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nematostella vectensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NematostellaVectensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveraAscorbataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera ascorbata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KluyveraAscorbataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh5701Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 5701 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SynechococcusSpWh5701Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpOralTaxon431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. oral taxon 431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpOralTaxon431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSph1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaWoodyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella woodyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWoodyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylonaHeveaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylona heveae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylonaHeveaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesWuyuanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wuyuanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWuyuanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterSpM21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBouchesdurhonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bouchesdurhonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBouchesdurhonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylanimicrobiumPachnodaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopogonVinicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vinicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVinicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_42_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSp2319x1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 2319x1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp2319x1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCoahuilensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCoahuilensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwd24019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWD24019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwd24019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusSpRedseaS12B1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus sp. REDSEA-S12_B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSpRedseaS12B1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSprentiaeWsm5005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae WSM5005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiaeWsm5005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaNivaraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oryza nivara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OryzaNivaraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter concisus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterConcisus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyc2full4316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYC2FULL4316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyc2full4316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNigerAtcc1015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger ATCC 1015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusNigerAtcc1015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TalaromycesIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedFlavonifractorSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Flavonifractor sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedFlavonifractorSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KuenenbacteriaBacteriumRifcsplowo202full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPLOWO202FULL4216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsplowo202full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothermobacterSpEprm(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geothermobacter sp. EPRM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeothermobacterSpEprm", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedBlautiaSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Blautia sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedBlautiaSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumHallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumHallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisPrasinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis prasina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPrasinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusOceanisediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oceanisediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusOceanisediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpDc12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. DC12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpDc12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterSulfonivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter sulfonivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSulfonivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFOXYB1_FULL_47_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumUlvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium ulvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumUlvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YamadazymaTenuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YamadazymaTenuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphimedonQueenslandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphimedon queenslandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphimedonQueenslandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusPortucalensisFdf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis FDF-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensisFdf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnobacteriumBovisDsm14045Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis DSM 14045 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnobacteriumBovisDsm14045Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeucaenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leucaenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeucaenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraSpHjEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. HJ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpHjEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaHeveanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KwoniellaHeveanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf180Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf180Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesFriuliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes friuliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesFriuliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpNuni2hmbin001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DokdonellaImmobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella immobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DokdonellaImmobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_01_FULL_33_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo201Full3334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumSiligurienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium siliguriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSiligurienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraButanivoransNbrc103042Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera butanivorans NBRC 103042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThaueraButanivoransNbrc103042Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadaceaeBacterium4484173Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadaceae bacterium 4484_173 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadaceaeBacterium4484173Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpOk281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OK281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOk281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpA49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. A49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpA49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriumSar116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Alphaproteobacterium SAR116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriumSar116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxyd1full4224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD1FULL4224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd1full4224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp24mn13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 24MN13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp24mn13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1026051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1026051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1026051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifoxya2full3824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFOXYA2FULL3824 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifoxya2full3824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCyclitrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cyclitrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioCyclitrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCadaveris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cadaveris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCadaveris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCostaricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus costaricensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCostaricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUmwwyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWWY Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwwyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHeteromorphusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusHeteromorphusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacterFormigenesHoxblsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes HOxBLS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesHoxblsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicidaNbrc103162Dsm15088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida NBRC 103162 DSM 15088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicidaNbrc103162Dsm15088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermosubterraneusDsm16057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus DSM 16057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneusDsm16057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlycinophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glycinophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumGlycinophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmorphothecaResinaeAtcc22711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amorphotheca resinae ATCC 22711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmorphothecaResinaeAtcc22711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKorlensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus korlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusKorlensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAquilaeDsm44791(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae DSM 44791 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAquilaeDsm44791", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FuchsiellaAlkaliacetigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fuchsiella alkaliacetigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FuchsiellaAlkaliacetigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioOxyclinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio oxyclinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioOxyclinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratireductorSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaMalayiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brugia malayi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrugiaMalayiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumRbg166712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium RBG_16_67_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumRbg166712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full37110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL37110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full37110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasXanthomarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xanthomarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXanthomarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumSpLk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNidulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nidulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusNidulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfifellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afifella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfifellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpCcge1003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaSpFEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpFEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf159(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf159", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusBoritoleransDsm17298Jcm18970Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans DSM 17298 JCM 18970 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusBoritoleransDsm17298Jcm18970Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumCosmeticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium cosmeticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCosmeticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterJanthinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter janthinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterJanthinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_49_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpThb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. thb2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpThb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumEzzemoulenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum ezzemoulense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumEzzemoulenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa24512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_45_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifoxyd2full4310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD2FULL4310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd2full4310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023751(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023751", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteroidesHalobiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacteroides halobius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteroidesHalobiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpM24t3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. M24T3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpM24t3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmoebophilusSp3638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amoebophilus sp. 36-38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmoebophilusSp3638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VanderwaltozymaPolysporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VanderwaltozymaPolysporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFCircinelloides1006phlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides 1006PhL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloides1006phlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusShizuokensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CinnamomumMicranthum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CinnamomumMicranthum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EsoxLuciusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Esox lucius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EsoxLuciusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_51_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumSpCag314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. CAG:314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumSpCag314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaFidelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella fidelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFidelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusConstellatusPharyngisSk1060Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis SK1060 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisSk1060Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusChagannorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus chagannorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusChagannorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumLuteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium luteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumLuteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPHIGHO2_01_FULL_48_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterCitreusLama915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter citreus LAMA 915 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErythrobacterCitreusLama915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpTfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. TF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpTfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocGelidumJb7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum JB7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumJb7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TilletiaControversaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tilletia controversa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TilletiaControversaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSp5618Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. 56-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSp5618Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaShandongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora shandongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaShandongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerDjelfimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopiger djelfimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopigerDjelfimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspAchromogenesAs03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. achromogenes AS03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspAchromogenesAs03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpIs1590(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1590", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpMarseillep3201t(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. MarseilleP3201T graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpMarseillep3201t", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusSubspVenerealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. venerealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspVenerealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichechusManatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichechus manatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichechusManatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaConcitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia concitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaConcitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaSpRifcsphigho212full4215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coxiella sp. RIFCSPHIGHO212FULL4215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoxiellaSpRifcsphigho212full4215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGilvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gilvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGilvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusNeoformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptococcusNeoformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumThermoresistibile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium thermoresistibile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumThermoresistibile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSp22ii122f38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 22II122F38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp22ii122f38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaHydrogenitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesDenticolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces denticolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDenticolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiCsIsolateThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CS isolate Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCsIsolateThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocurvibacterAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvibacter africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvibacterAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilvanigrellaAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Silvanigrella aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SilvanigrellaAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2733 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RothiaDentocariosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rothia dentocariosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RothiaDentocariosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0400Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0400Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaichungenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taichungense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaichungenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPaurosaccharolyticusJcm15092Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus JCM 15092 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticusJcm15092Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQuintanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella quintana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaQuintanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterCorallicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter corallicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterCorallicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioProteolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioProteolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SabulitectumSilens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sabulitectum silens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SabulitectumSilens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumOvolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum ovolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumOvolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumBeijerinckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk597Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK597 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk597Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteusMirabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteus mirabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteusMirabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPseudoalcaligenesKf707Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes KF707 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesKf707Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL3811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDoosanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium doosanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDoosanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrchesellaCinctaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orchesella cincta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrchesellaCinctaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilvimarinusChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicellaActignis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicella actignis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicellaActignis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSherrisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sherrisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSherrisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHomomorphus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusHomomorphus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterDongtanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter dongtanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterDongtanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoalkalibacterFerrihydriticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter ferrihydriticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterFerrihydriticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacaSpPts2502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca sp. PTS2502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaSpPts2502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMste9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MSTE9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMste9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpS9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisH5384Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis H538.4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisH5384Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelobdellaRobusta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helobdella robusta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelobdellaRobusta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumOtitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOtitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpRit357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RIT357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpRit357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0473Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0473 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0473Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpWchac010034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. WCHAc010034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpWchac010034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriaceaeBacteriumP6a17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacteriaceae bacterium P6A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriaceaeBacteriumP6a17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaFloridanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia floridanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaFloridanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzambacteriaBacteriumRifcsplowo201full4625(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4625 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4625", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumPlurifarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium plurifarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPlurifarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeanutWitchesbroom(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peanut witchesbroom graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeanutWitchesbroom", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LewinellaPersica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lewinella persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LewinellaPersica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwd24214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD24214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd24214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaNovaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia nova Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaNovaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbsiellaDolichum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Absiella dolichum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbsiellaDolichum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumProfundumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium profundum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProfundumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag678Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:678 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag678Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeratocystisFimbriataCbs114723Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata CBS 114723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CeratocystisFimbriataCbs114723Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaRodhainiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma rodhaini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaRodhainiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocAzollaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc azollae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocAzollaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAichiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia aichiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaAichiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg135211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_52_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NoviherbaspirillumSpRoot189Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum sp. Root189 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumSpRoot189Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMacraNbrc14102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura macra NBRC 14102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraMacraNbrc14102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumBranchiophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium branchiophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBranchiophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonesiaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jonesia denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JonesiaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpWy10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. WY10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpWy10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27225Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27225 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27225Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophothermusLipocalidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus lipocalidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusLipocalidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrospermopsisRaciborskii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermopsis raciborskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CylindrospermopsisRaciborskii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4311bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4311b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4311bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaAnnulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theileria annulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheileriaAnnulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpLm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. LM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenzhouxiangellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wenzhouxiangella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WenzhouxiangellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HypholomaSublateritiumFd334Ss4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium FD-334 SS-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HypholomaSublateritiumFd334Ss4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumTag1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium TAG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumTag1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalpingoecaRosettaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salpingoeca rosetta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalpingoecaRosettaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaXyliCynodontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli cynodontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCynodontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRapamycinicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rapamycinicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRapamycinicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacaedibacterAcanthamoebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter acanthamoebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterAcanthamoebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb1140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB1140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb1140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaldieriaSulphurariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Galdieria sulphuraria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GaldieriaSulphurariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactisNbrc100932(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis NBRC 100932 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactisNbrc100932", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_43_15b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4315b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaSpUtamx2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlixibacterBellariivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prolixibacter bellariivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProlixibacterBellariivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUltunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ultunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUltunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumMela1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium MELA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumMela1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiameyensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niameyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusNiameyensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacterium4316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeomegalonemaPerideroedesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neomegalonema perideroedes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeomegalonemaPerideroedesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GolovinomycesCichoracearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces cichoracearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesCichoracearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusGammatoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus gammatolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGammatoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaichungenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taichungense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaichungenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusKekensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus kekensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusKekensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpLeaf2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Leaf2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpLeaf2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa536n21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA536N21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa536n21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumIncanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum incanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumIncanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesKanasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kanasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKanasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FontimonasThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fontimonas thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FontimonasThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpMg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Mg1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusHaemoperoxidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus haemoperoxidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHaemoperoxidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasJohnsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJohnsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaMasoucida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida masoucida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaMasoucida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichomonasVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichomonas vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichomonasVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpRc586(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. RC586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioSpRc586", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraPelophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira pelophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraPelophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPinnipediorumSubspPinnipediorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum subsp. pinnipediorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorumSubspPinnipediorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHmsc067h01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HMSC067H01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHmsc067h01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumNam1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum NAm1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumNam1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYB1_FULL_43_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumNcimb41171Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum NCIMB41171 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumNcimb41171Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovibacterPhragmitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mangrovibacter phragmitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MangrovibacterPhragmitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBornimenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium bornimense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBornimenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaProfundaAzm34c06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga profunda AZM34c06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermotogaProfundaAzm34c06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC2_34_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 36-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesSpDsm45891Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45891 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45891Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumGwa27335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_73_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaGummosaDsm723Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Derxia gummosa DSM 723 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DerxiaGummosaDsm723Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSaoudiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella saoudiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSaoudiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpAap35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. AAP35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpAap35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorghumBicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sorghum bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SorghumBicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUrmo17wk12i8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URMO17WK12I8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpUrmo17wk12i8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumSg830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetalesBacteriumActino02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterTroitsensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter troitsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenibacterTroitsensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaAdelaidensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella adelaidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaAdelaidensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaGenomosp13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_37_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoglobusAhangariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus ahangari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAhangariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumMar2010188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium MAR_2010_188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumMar2010188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CriblamydiaSequanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Criblamydia sequanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CriblamydiaSequanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full4013b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL4013b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full4013b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpPaeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. PAEUM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpPaeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterAminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminobacterAminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSpNsp11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumBacl7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegiribacteriaBacteriumMlscEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aegiribacteria bacterium MLSC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AegiribacteriaBacteriumMlscEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustrisStrTous(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus lacustris str. Tous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SynechococcusLacustrisStrTous", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpCf149Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CF149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpCf149Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag533Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:533 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag533Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UliginosibacteriumGangwonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uliginosibacterium gangwonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UliginosibacteriumGangwonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpWaoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. WAO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpWaoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAnguillisepticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas anguilliseptica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAnguillisepticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLehensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lehensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLehensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusNematophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus nematophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusNematophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHomomorphusCbs101889Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus CBS 101889 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusHomomorphusCbs101889Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeOfficinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorhizobium galegae officinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeOfficinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibularhizoctoniaSpCbs109695Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibularhizoctonia sp. CBS 109695 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibularhizoctoniaSpCbs109695Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13724(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13724 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13724", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlassbacteriaBacteriumRifcsplowo212full5811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glassbacteria bacterium RIFCSPLOWO212FULL5811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlassbacteriaBacteriumRifcsplowo212full5811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRubinfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rubinfantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRubinfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptobacterTengchongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kryptobacter tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KryptobacterTengchongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536g10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536G10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536g10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesantisbacteriaBacteriumCg1024989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1024989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1024989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthellaLentaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella lenta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaLentaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoraliomargaritaSpCag312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita sp. CAG:312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaSpCag312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumDrakei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium drakei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumDrakei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpKa00067Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. KA00067 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpKa00067Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteroidobacterDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Steroidobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SteroidobacterDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 39-19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpMst1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MSt1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMst1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumYoeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium yoelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumYoeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzoarcusSpCibEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. CIB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpCibEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumArsenaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumGwa2509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GWA2509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGwa2509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAgalactiaeLmg14747Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae LMG14747 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeLmg14747Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusVenerealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus venerealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusVenerealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorickettsiaHelminthoecaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoecaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrinickiaCaryophylliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trinickia caryophylli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrinickiaCaryophylliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PluralibacterGergoviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pluralibacter gergoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PluralibacterGergoviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_47_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536k22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536K22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536k22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag780Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:780 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag780Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpLa11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LA11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLa11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrochothrixCampestrisFslF61037Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brochothrix campestris FSL F6-1037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrochothrixCampestrisFslF61037Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasPalmitaticaJcm14374Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica JCM 14374 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitaticaJcm14374Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaIhuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIhuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SarcinaSpDsm11001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sarcina sp. DSM 11001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SarcinaSpDsm11001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGordoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGordoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc6406(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC6406 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc6406", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo201full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL4510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusEndophyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusEndophyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho212full4012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO212FULL4012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho212full4012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyronemaOmphalodesCbs100304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes CBS 100304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyronemaOmphalodesCbs100304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaMoabensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Belnapia moabensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BelnapiaMoabensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhabdusTiamateaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus tiamatea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusTiamateaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactucaSativaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactuca sativa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactucaSativaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeCc1417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumCosmeticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium cosmeticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumCosmeticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAcidiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAcidiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TissierellaPraeacutaDsm18095Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tissierella praeacuta DSM 18095 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TissierellaPraeacutaDsm18095Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisDsm18711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris DSM18711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisDsm18711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloactinosynnemaAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioDiazotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio diazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioDiazotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa015n04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA015N04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa015n04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp6736(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 67-36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6736", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaLaidlawiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma laidlawii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaLaidlawiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpLeaf404Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf404Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpSgbin1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRaac3tm71Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RAAC3TM71 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRaac3tm71Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpLm6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. LM 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpLm6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RivulariaSpPcc7116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rivularia sp. PCC7116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RivulariaSpPcc7116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyncephalastrumRacemosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syncephalastrum racemosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyncephalastrumRacemosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocapsaSulfexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfocapsa sulfexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfocapsaSulfexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalariasFasciatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salarias fasciatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalariasFasciatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixVenerupis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix venerupis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixVenerupis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteelei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella steelei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteelei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusAutotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusAutotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaVici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niastella vici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiastellaVici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeongeupiaSpUsm3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeongeupia sp. USM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeongeupiaSpUsm3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusManliponensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus manliponensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusManliponensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSporotrichioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sporotrichioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumSporotrichioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OgataeaParapolymorphaDl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha DL-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OgataeaParapolymorphaDl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansRhaa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans RhAA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansRhaa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSteynii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus steynii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSteynii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransAk01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans AK01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransAk01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaBillingiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia billingiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaBillingiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioCrunogenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio crunogenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioCrunogenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzisolibacterPropanilivorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryzisolibacter propanilivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzisolibacterPropanilivorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusDestructansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacterium51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 5-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaLitoreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola litoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicolaLitoreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpHtcc2170Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. HTCC2170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpHtcc2170Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMegasporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces megasporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMegasporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpPao19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAO19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpPao19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc2796Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC27/96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc2796Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot1203Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1203 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1203Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpP5119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P5-119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP5119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaLijiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaLijiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRiograndensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus riograndensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRiograndensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_54_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaFibrataAmlC10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata AML-C10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaFibrataAmlC10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo202full4511cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4511c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4511cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumParvulum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium parvulum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumParvulum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraHibiscaNbrc15177(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura hibisca NBRC 15177 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraHibiscaNbrc15177", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThelaziaCallipaeda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thelazia callipaeda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThelaziaCallipaeda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisSpHl130gsbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. HL130GSB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpHl130gsbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarininemaMesophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marininema mesophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarininemaMesophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisHx2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis HX2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisHx2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPanaciterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPanaciterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSediminilitoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSediminilitoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaSpAd3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Martelella sp. AD-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MartelellaSpAd3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full6019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL6019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full6019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraMoscoviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira moscoviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraMoscoviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellalikeEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coxiellalike endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoxiellalikeEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpPrm31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. PRM31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpPrm31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpHk06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. HK-06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpHk06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSp217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. 217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSp217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaAcidurici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia acidurici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaAcidurici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumChilenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chilense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChilenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwf1525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF1525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf1525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParmenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium parmense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParmenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaThermotoleransCbs6340Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans CBS 6340 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachanceaThermotoleransCbs6340Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaR5513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia R5513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaR5513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocystisViolascensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiocystis violascens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiocystisViolascensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVranovensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVranovensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a518a17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518a17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGa0077536(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077536 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077536", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLentusNbrc16444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus lentus NBRC 16444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusLentusNbrc16444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludisphaeraBorealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paludisphaera borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaludisphaeraBorealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColumbaLiviaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Columba livia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColumbaLiviaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenericutesBacteriumGwf235184Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_35_184 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf235184Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloracidobacteriumThermophilumBCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilumBCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTa06Bacterium32111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium 32_111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06Bacterium32111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorAustralicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloramator australicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloramatorAustralicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioLitoralisDsm17657(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio litoralis DSM 17657 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioLitoralisDsm17657", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesJcm10003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes JCM10003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesJcm10003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusSpJcm18860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus sp. JCM 18860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusSpJcm18860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporidiumParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLuciferensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus luciferensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLuciferensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE183(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE183", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSouthafrica7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SouthAfrica7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSouthafrica7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PachysolenTannophilusNrrlY2460Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus NRRL Y-2460 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PachysolenTannophilusNrrlY2460Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaSeohaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga seohaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSeohaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHaemophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumEmbrapenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium embrapense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumEmbrapenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMucidolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mucidolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMucidolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumJensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumJensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UstilagoMaydisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ustilago maydis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UstilagoMaydisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CanisLupusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilvimarinusPolysaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusPolysaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitritaleaHalalkaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSpCcge1002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. CCGE1002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpCcge1002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodarcisMuralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Podarcis muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PodarcisMuralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFicariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia ficaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaFicariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpMt41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. MT41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpMt41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBenthicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella benthica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBenthicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaKudriavzeviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pichia kudriavzevii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PichiaKudriavzeviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterNoctilucae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiwaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niwae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiwaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalofilumOchraceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halofilum ochraceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalofilumOchraceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumWg36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium WG36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumWg36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPrasinopilosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces prasinopilosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPrasinopilosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSegnicrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter segnicrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSegnicrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobellusRufusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobellus rufus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobellusRufusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelnapiaSpF41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Belnapia sp. F-4-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BelnapiaSpF41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeokomagataeaThailandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeokomagataeaThailandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpUrha0036(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. URHA0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpUrha0036", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynoglossusSemilaevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cynoglossus semilaevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CynoglossusSemilaevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpLmtr3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LMTR 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLmtr3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5053(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5053", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum248(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum248", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLitoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLitoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotum397Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium nepotum 39/7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumNepotum397Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumDtu079Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU079 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu079Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaAgariphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa agariphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaAgariphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumIntermediumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumIntermediumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterActinomycetemcomitansD7s1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans D7S1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansD7s1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBorbori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas borbori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBorbori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachymonasDenitrificansDsm15123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans DSM 15123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrachymonasDenitrificansDsm15123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterHiberniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter hiberniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHiberniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumJaponicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumJaponicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorickettsiaHelminthoecaStrOregonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca str. Oregon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoecaStrOregonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InsolitispirillumPeregrinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Insolitispirillum peregrinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "InsolitispirillumPeregrinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumCbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium CB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumCbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAccolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium accolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAccolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRifcsplowo201full4314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPLOWO201FULL4314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsplowo201full4314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaSubspMultocidaOh4807Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida OH4807 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaOh4807Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaTropica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinispora tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisporaTropica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaBicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laccaria bicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaccariaBicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerochaetaCoccoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta coccoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaCoccoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaSelenatireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxTemperansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax temperans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxTemperansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcusRusselliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus russellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusRusselliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brennerbacteria bacterium RIFOXYD1_FULL_41_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwt2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwt2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusIhumiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhumiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongyloidesStercoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides stercoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesStercoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApibacterMensalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apibacter mensalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApibacterMensalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium verticillioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumVerticillioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaBrevipalpisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina brevipalpis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaBrevipalpisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloplanusVescus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus vescus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloplanusVescus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreibacillusThermosphaericusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ureibacillus thermosphaericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UreibacillusThermosphaericusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc7003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC 7003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpCf8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. CF8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpCf8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwf24415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWF2_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwf24415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmatimonadetesBacteriumDc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium DC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumDc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermabacterSpHfh0086Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter sp. HFH0086 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DermabacterSpHfh0086Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat29937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumMaritimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum maritimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenovulumMaritimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforudisAudaxviator(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulforudis audaxviator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulforudisAudaxviator", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaProteobacteriumMlsd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium MLSD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMlsd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitriliruptorAlkaliphilusDsm45188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus DSM 45188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilusDsm45188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozobelliaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudozobellia thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudozobelliaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterLimosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter limosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterLimosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphothecaResinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amorphotheca resinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmorphothecaResinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumAviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioIshigakensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ishigakensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioIshigakensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifoxyc2full3525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFOXYC2FULL3525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifoxyc2full3525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpBal39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BAL39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBal39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesiotobacterExalbescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesiotobacter exalbescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesiotobacterExalbescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusMethylotrophusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus methylotrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusMethylotrophusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolineaTardaNobi1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanolinea tarda NOBI-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanolineaTardaNobi1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumTropiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tropici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTropiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasCapnocytophagoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaFijiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocolitica8081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica 8081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocolitica8081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifoxyd1full4619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYD1FULL4619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyd1full4619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSpW15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis sp. W15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSpW15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldimonasTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaAcs139vcol8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola ACS139VCol8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaAcs139vcol8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAkl11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMycetoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mycetoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMycetoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSpSos3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. SOS3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpSos3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc9022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC9022 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc9022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryctolagusCuniculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryctolagus cuniculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryctolagusCuniculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumSpZor0034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium sp. ZOR0034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSpZor0034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBastiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bastinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBastiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaTrematum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella trematum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaTrematum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumIwayamaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pythium iwayamai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PythiumIwayamaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAap83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaMelophagiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella melophagi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaMelophagiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaSpAf7305cm02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenella sp. AF73-05CM02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaSpAf7305cm02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFairfieldensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio fairfieldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFairfieldensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpEjp617Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Ejp617 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpEjp617Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterLongusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter longus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLongusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpecialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces specialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpecialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKuykendalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas kuykendallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKuykendalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGraminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGraminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudopodocesHumilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudopodoces humilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudopodocesHumilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelotomaculumThermopropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum thermopropionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumThermopropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumArcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium arcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriumArcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumFlaccumfaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium flaccumfaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumFlaccumfaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFraserbacteriaBacteriumRbg16559Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fraserbacteria bacterium RBG_16_55_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFraserbacteriaBacteriumRbg16559Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusFulgidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus fulgidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusFulgidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurispirillumIndicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispirillum indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurispirillumIndicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriCd034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri CD034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriCd034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSalivariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSalivariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpPba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. PBA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpPba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumBdw918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium BDW918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumBdw918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAlcaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlcaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaVignae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga vignae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaVignae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TigriopusCalifornicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tigriopus californicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TigriopusCalifornicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedButyricicoccusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Butyricicoccus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedButyricicoccusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PusillimonasSpT77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas sp. T77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PusillimonasSpT77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSaccharophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSaccharophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27245Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27245Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBorboriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas borbori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBorboriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSpSb3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. SB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpSb3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaeniglutamicibacterGangotriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter gangotriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterGangotriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnormaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enorma massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnormaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidisEr3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis ER-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlastomycesDermatitidisEr3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSyrphidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma syrphidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSyrphidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaitozymaPodzolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saitozyma podzolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaitozymaPodzolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2499Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2499Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaSpCua673(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CUA-673 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCua673", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhocaeicolaAbscessusCcug55929Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus CCUG 55929 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessusCcug55929Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa1377Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA1377 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa1377Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpIbunEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. IBUN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpIbunEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus constellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusConstellatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpK31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. K31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpK31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpDw54Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. DW54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpDw54Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSordidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sordidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSordidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaetiporusSulphureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaetiporusSulphureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhocae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhocae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspNattoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. natto Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspNattoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSpOr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. OR-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpOr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusLitoralisDsm5473Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus litoralis DSM 5473 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermococcusLitoralisDsm5473Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpYr527Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. YR527 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpYr527Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrospiraInopinataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira inopinata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraInopinataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpRs39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacterium448495(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448495", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEdwardsbacteriaBacteriumGwe25412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Edwardsbacteria bacterium GWE2_54_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusEdwardsbacteriaBacteriumGwe25412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CommensalibacterIntestiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter intestini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterIntestiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg19ftcombo7019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG19FTCOMBO7019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg19ftcombo7019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobinsoniellaPeoriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Robinsoniella peoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RobinsoniellaPeoriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaChitosanitabida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo212full5011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO212FULL5011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo212full5011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaSpJ72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrinema sp. J72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSpJ72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FontimonasThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fontimonas thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FontimonasThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium novyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNovyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_43_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaPulmonicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pulmonicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPulmonicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLondiniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella londiniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaLondiniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSaccharevitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena saccharevitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSaccharevitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaStibiiresistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1023713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobialesSpKi4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Thermomicrobiales sp. KI4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "ThermomicrobialesSpKi4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodomicrobiumUdaipurenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumAnimalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAnimalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAquilunaSpUbMaderosw2redCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aquiluna sp. UB-MaderosW2red Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAquilunaSpUbMaderosw2redCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasSpJm171Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. JM171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJm171Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumSinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGa0077533Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Ga0077533 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGa0077533Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTritoniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tritonius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioTritoniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassomonasActiniarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas actiniarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasActiniarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaChaffeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia chaffeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaChaffeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaParaffinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia paraffinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaParaffinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BulleidiaExtructa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bulleidia extructa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BulleidiaExtructa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaSp22iis9z10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. 22IIS9Z10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StappiaSp22iis9z10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterMarburgensisStrMarburgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis str. Marburg Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensisStrMarburgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwc12715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWC1_27_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwc12715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_49_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycisphaeraeBacteriumSm2330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaerae bacterium SM23_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraeBacteriumSm2330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSpCamponotisaundersiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotisaundersi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotisaundersiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsFumosoroseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CordycepsFumosoroseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaZeaeDsm19591(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Runella zeae DSM 19591 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RunellaZeaeDsm19591", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumErythrophleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium erythrophlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumErythrophleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot487d2yEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root487D2Y Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot487d2yEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbimonasDonghaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Albimonas donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlbimonasDonghaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematostellaVectensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nematostella vectensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NematostellaVectensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaPneumotropicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella pneumotropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaPneumotropicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaHelveticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia helvetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaHelveticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpTb67(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb67", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCecorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus cecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCecorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPseudoporcinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudoporcinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudoporcinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4620 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPhocaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus phocaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPhocaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBrumaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brumae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrumaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsphigho202full5719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumNor53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium NOR53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumNor53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonadaceaeBacteriumT822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonadaceae bacterium T82-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonadaceaeBacteriumT822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmanniiSubspFleischmanniiLu20061Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria fleischmannii subsp. fleischmannii LU2006-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaFleischmanniiSubspFleischmanniiLu20061Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovenusAranensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halovenus aranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalovenusAranensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpAnt17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Ant17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAnt17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HanseniasporaOsmophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora osmophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaOsmophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaEhrenbergiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga ehrenbergii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEhrenbergiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYr519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRustigianii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia rustigianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRustigianii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaSpUtamx2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sp. UTAMX2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSpUtamx2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiCeIsolateThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CE isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCeIsolateThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterLuteolusNbrc107841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus NBRC 107841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterLuteolusNbrc107841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMaceransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMaceransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadaceaeBacterium4484173Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadaceae bacterium 4484_173 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadaceaeBacterium4484173Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylothermusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpWkb8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpWkb8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleomorphomonasKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pleomorphomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PleomorphomonasKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAnguillarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio anguillarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioAnguillarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRbg136816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_13_68_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg136816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesFLusitanicusCbs27749Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus CBS 277.49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicusCbs27749Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenaeusVannameiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penaeus vannamei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenaeusVannameiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumLeptumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium leptum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLeptumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaUrininfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella urininfantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUrininfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwe23210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWE2_32_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwe23210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaGeojedonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kangiella geojedonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KangiellaGeojedonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSteyniiIbt23096Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus steynii IBT 23096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusSteyniiIbt23096Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIiiEuryarchaeoteCgEpi1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group III euryarchaeote CG-Epi1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiiEuryarchaeoteCgEpi1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcusLuteusModasaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus modasa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusModasaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaeroformaArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaeroformaArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpCsm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. CSM-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpCsm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusLugdunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEe36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EE36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpEe36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpKh9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KH9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKh9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumAc2031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumFructicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFructicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanoprotosteliumFungivorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planoprotostelium fungivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanoprotosteliumFungivorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonadaceaeBacteriumH1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumH1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaKristenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia kristensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaKristenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo202full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO202FULL4812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo202full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMarisflaviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMarisflaviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrabulsiellaOdontotermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trabulsiella odontotermitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrabulsiellaOdontotermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasOssibalaenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ossibalaenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromonasOssibalaenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcremoniumChrysogenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcremoniumChrysogenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermithiobacillusTepidariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermithiobacillus tepidarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermithiobacillusTepidariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaiwanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taiwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaiwanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoactinomycesSpDsm45891(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45891 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45891", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IainarchaeumAndersoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Iainarchaeum andersonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IainarchaeumAndersoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreochromisNiloticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis niloticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OreochromisNiloticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumScadc123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium SCADC1_2_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumScadc123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IlumatobacterCoccineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ilumatobacter coccineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IlumatobacterCoccineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFluviicolaRiflensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fluviicola riflensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFluviicolaRiflensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetohalobiumArabaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetohalobium arabaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetohalobiumArabaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriboliumCastaneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tribolium castaneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TriboliumCastaneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCipa165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIPA165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCipa165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSojaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sojae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferSojaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 37-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondromycesApiculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces apiculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChondromycesApiculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc9022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC9022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc9022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusSpCag917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaDumeriliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Seriola dumerili Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SeriolaDumeriliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumHassiacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium hassiacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHassiacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpPamc28711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. PAMC 28711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpPamc28711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosocosmicusExaquareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus exaquare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusExaquareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LodderomycesElongisporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LodderomycesElongisporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterSpS108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter sp. S10-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterSpS108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrococcusMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrococcus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrococcusMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaSaliphilaYim90502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila YIM 90502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphilaYim90502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumCg10237114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_37_114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg10237114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpIcm42bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. ICM42b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpIcm42bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPLOWO2_01_FULL_48_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterChinhatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter chinhatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterChinhatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesHelcogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides helcogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesHelcogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaLacustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaLacustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumLitoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium litorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumLitoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliosenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliosenegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliosenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LitorimicrobiumTaeanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litorimicrobium taeanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitorimicrobiumTaeanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpOlb3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. OLB3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpOlb3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtochlamydiaNaegleriophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia naegleriophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaNaegleriophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_54_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumStylosanthis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium stylosanthis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumStylosanthis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf176Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf176Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SharpeaAzabuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sharpea azabuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SharpeaAzabuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusDepauperatusCbs7841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus CBS 7841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptococcusDepauperatusCbs7841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2303638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaHermanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia hermannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaHermanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodonellumPsychrophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum psychrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodonellumPsychrophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium RIFCSPLOWO2_02_FULL_73_56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGa0077536Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077536 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077536Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBirtlesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella birtlesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaBirtlesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpH3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpH3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_12_FULL_47_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSchoenbuchensisR1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis R1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensisR1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicycliphilusDenitrificansBcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans BC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansBcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus allii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusKakegawensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSubterraneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSubterraneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_51_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisBriggsaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis briggsae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBriggsaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterSphaeroides241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides 241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroides241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallibacteriumScheffleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metallibacterium scheffleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetallibacteriumScheffleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubidusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubidus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubidusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSporotrichioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sporotrichioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumSporotrichioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRbg163414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RBG_16_34_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRbg163414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensisDokdo023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis DOKDO 023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensisDokdo023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaCornellensisFslF60969Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria cornellensis FSL F6-0969 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaCornellensisFslF60969Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpMn802worker(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Mn802worker graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMn802worker", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacterium4484702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_70.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifcsplowo212full3511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPLOWO212FULL3511 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsplowo212full3511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSimilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus similis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSimilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSetense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium setense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSetense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusLaterosporusDsm25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus DSM25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusDsm25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GuillardiaThetaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Guillardia theta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GuillardiaThetaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasSpJ29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. J29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJ29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EucalyptusGrandis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eucalyptus grandis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EucalyptusGrandis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRac07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. RAC07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRac07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlagellimonasFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OgataeaParapolymorphaDl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha DL-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OgataeaParapolymorphaDl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaAcs139vcol8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola ACS139VCol8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaAcs139vcol8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_34_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusSolisalsiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus solisalsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FictibacillusSolisalsiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronumThiosulfatophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiosulfatophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiosulfatophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaWadsworthiiDsm21896Atcc33877(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella wadsworthii DSM 21896 ATCC 33877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaWadsworthiiDsm21896Atcc33877", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRhodesiaeJs60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae JS60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeJs60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaAtriluteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella atrilutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaAtriluteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidicoccusFontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidicoccus fontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidicoccusFontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumDoricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium doricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDoricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterovibrioNorvegicusDsm15893(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus DSM 15893 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusDsm15893", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioLogeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio logei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliivibrioLogeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterKumamotonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter kumamotonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterKumamotonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaBraziliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leishmania braziliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaBraziliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParastrongyloidesTrichosuriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parastrongyloides trichosuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParastrongyloidesTrichosuriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YoungiibacterFragilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Youngiibacter fragilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YoungiibacterFragilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacterium6432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium 64_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacterium6432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiwaeNbrc108934Dsm45340(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niwae NBRC 108934 DSM 45340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaNiwaeNbrc108934Dsm45340", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUpsaliensisJv21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis JV21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensisJv21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_60_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAlkalescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alkalescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlkalescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 70-64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriCcug29243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri CCUG 29243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriCcug29243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisSk1076Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK1076 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk1076Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioGilvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cellvibrio gilvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CellvibrioGilvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophoarchaeumCaldariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum caldarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumCaldariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloterrigenaTurkmenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena turkmenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaTurkmenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRu33aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU33A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu33aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TistliaConsotensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tistlia consotensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TistliaConsotensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalocynthiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halocynthiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalocynthiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoclosmatiumGlobosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizoclosmatium globosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizoclosmatiumGlobosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumOlb19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium OLB19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumOlb19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusThermophilusJl18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus JL-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusJl18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpLycopersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. lycopersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpLycopersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionSr1BacteriumAalborgaaw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium AalborgAAW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumAalborgaaw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusTetradiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus tetradius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusTetradiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSp6729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 67-29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSp6729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaAdelaidensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella adelaidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaAdelaidensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferShofinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer shofinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferShofinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAlbumArsef1941Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium album ARSEF 1941 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAlbumArsef1941Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaInagensisDsm44258Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis DSM 44258 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaInagensisDsm44258Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatescibacterAnaerobiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Latescibacter anaerobius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LatescibacterAnaerobiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumInfirmum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium infirmum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumInfirmum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CosenzaeaMyxofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesantisbacteriaBacteriumCg1024989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1024989 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1024989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaBogorensisNbrc16594Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaia bogorensis NBRC 16594 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaiaBogorensisNbrc16594Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacterium13220cm5510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_2_20CM_55_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13220cm5510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaAcetivoransC2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans C2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivoransC2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesCoccineaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trametes coccinea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrametesCoccineaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PopulusTrichocarpa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Populus trichocarpa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PopulusTrichocarpa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetanaerobacteriumElongatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetanaerobacterium elongatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetanaerobacteriumElongatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusEquiSubspZooepidemicusAtcc35246Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi subsp. zooepidemicus ATCC 35246 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusEquiSubspZooepidemicusAtcc35246Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpAt0102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. AT01-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpAt0102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaScoriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola scoriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaScoriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasFormicexedensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas formicexedens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasFormicexedensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc2387Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC2387 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc2387Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaMimosarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia mimosarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMimosarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusMarinonascensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusMarinonascensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacterium3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 37-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopigerSalifodinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopiger salifodinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopigerSalifodinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaEumusae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora eumusae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaEumusae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhydrobacterAerosaccusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enhydrobacter aerosaccus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnhydrobacterAerosaccusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Henriciella litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HenriciellaLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGm21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GM21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpGm21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumParaconglomeratum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium paraconglomeratum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumParaconglomeratum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumUmmarienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium ummariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumUmmarienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh8102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaSpHeli12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. HelI12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpHeli12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChthonomonasCalidiroseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chthonomonas calidirosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChthonomonasCalidiroseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JorgensenbacteriaBacteriumGw2011gwb1499Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB1499 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb1499Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCancerogenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCancerogenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OenococcusOeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus oeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OenococcusOeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpRoot444d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root444D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot444d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCoagulans36d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 36D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans36d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenxiniaSaemankumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia saemankumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WenxiniaSaemankumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusArthromitusSpSfbTurkeyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arthromitus sp. SFB-turkey Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusArthromitusSpSfbTurkeyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_44_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full4432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraOligosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura oligospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraOligosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoaviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPseudoaviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterSpOralTaxon458StrW10330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. oral taxon 458 str. W10330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterSpOralTaxon458StrW10330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyangiumBrachysporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Polyangium] brachysporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolyangiumBrachysporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FischerellaSpPcc9605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpilithonimonasLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_44_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa2447Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrugiaTimoriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brugia timori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrugiaTimoriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaPseudobrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusHaemolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus haemolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHaemolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full5338(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL5338 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full5338", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSolitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium solitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSolitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysochlorisAsiatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chrysochloris asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChrysochlorisAsiatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP32e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P32E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP32e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NodulariaSpumigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nodularia spumigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NodulariaSpumigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumRbg19ftcombo7019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG19FTCOMBO7019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg19ftcombo7019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusPisciumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus piscium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusPisciumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho212full4012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO212FULL4012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho212full4012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaSelenatireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumHimb30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterLignolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter lignolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLignolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasHortorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas hortorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasHortorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg164813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_16_48_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg164813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifoxyb1Full5435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYB1_FULL_54_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyb1Full5435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3903Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3903 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3903Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacterialesBacteriumDnf00809Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriales bacterium DNF00809 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoriobacterialesBacteriumDnf00809Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetradesmusObliquusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetradesmus obliquus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetradesmusObliquusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConicaCcbas932Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Morchella conica CCBAS932 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MorchellaConicaCcbas932Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DechlorosomaSuillumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dechlorosoma suillum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DechlorosomaSuillumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpWkb10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSpWkb10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraSedula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera sedula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraSedula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpB1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpB1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaAldovae67083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia aldovae 670-83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaAldovae67083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaBlattaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaBlattaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlivibacterSitiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olivibacter sitiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlivibacterSitiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobiumSpCaciam14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. CACIAM14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpCaciam14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinagarivoransAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinagarivorans algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinagarivoransAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesSp494aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 494a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp494aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_54_21b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusRaffinosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus raffinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRaffinosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPsychrophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium psychrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPsychrophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWF2_42_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaMalaquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia malaquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaMalaquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSalignoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis salignorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSalignoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaDiazotrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia diazotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDiazotrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp32133Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3213.3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32133Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacterLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulochytriumProtostelioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulochytrium protostelioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulochytriumProtostelioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusHaemolyticusM21639Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21639Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBlattaOrientalisStrTarazona(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. (Blatta orientalis) str. Tarazona graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBlattaOrientalisStrTarazona", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0077534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpUrhd0024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHD0024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhd0024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumCg10247685(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_47_685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg10247685", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodocyclaceaeBacteriumPaddy1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodocyclaceae bacterium Paddy-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodocyclaceaeBacteriumPaddy1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpH105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaGracilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospinaGracilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFuchuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fuchuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFuchuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaDiversum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma diversum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaDiversum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCipa165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIPA165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCipa165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterYoungaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter youngae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterYoungaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesSpJdfr56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasLykanthroporepellensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas lykanthroporepellens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasLykanthroporepellensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhinopithecusRoxellanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus roxellana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusRoxellanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumParvulumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium parvulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumParvulumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusVersutusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus versutus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccusVersutusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho202full5616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL5616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full5616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusEquigenerosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equigenerosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquigenerosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumFossorDsm15642(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium fossor DSM 15642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopobiumFossorDsm15642", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho201full4120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO201FULL4120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho201full4120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansAtcc25259(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans ATCC25259 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansAtcc25259", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC238Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C238 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC238Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonRbg13389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG13389 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg13389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedLachnospiraSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Lachnospira sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedLachnospiraSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpLeaf359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Leaf359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLeaf359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpH133Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium sp. H133 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSpH133Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansK601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans K601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansK601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaMiroungae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Facklamia miroungae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FacklamiaMiroungae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriiaBacteriumRifoxyc2full3518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriia bacterium RIFOXYC2FULL3518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriiaBacteriumRifoxyc2full3518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiSh145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii SH145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiSh145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaSpWa102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. WA102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpWa102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcusSpD1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusSpD1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolymyxaM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3734(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3734 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3734", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriMsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri MS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriMsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4515bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4515b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4515bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPulmonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pulmonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPulmonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_37_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGraminisDsm20719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus graminis DSM 20719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGraminisDsm20719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidihalobacterFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpArr65Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ARR65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpArr65Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGwa1418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GWA1_41_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGwa1418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilaceaeBacteriumUrha0031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHA0031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrha0031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumSit11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium SIT11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumSit11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SparassisCrispa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sparassis crispa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SparassisCrispa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSenegalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium senegalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSenegalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalosaccharovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halosaccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHalosaccharovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaBenhamiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma benhamiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaBenhamiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB262Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B262 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB262Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DimargarisCristalligenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dimargaris cristalligena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DimargarisCristalligenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaAlcalifaciensR901475Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens R90-1475 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensR901475Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19056Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19056Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaEutrophaJmp134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha JMP134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaJmp134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterRodentiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter rodentium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterRodentiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa288n07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288N07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288n07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnisphaeraAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnisphaeraAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpAtcc39149Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. ATCC39149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpAtcc39149Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusSaudimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus saudimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusSaudimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Babjeviella inositovora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BabjeviellaInositovoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpUcdgkaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UCDGKA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUcdgkaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaphrinaDeformansPycc5710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans PYCC 5710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TaphrinaDeformansPycc5710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonenseHt12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense HT12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylovulumMiyakonenseHt12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpKbs0703Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. KBS0703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpKbs0703Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOulorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oulorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOulorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCg10264396Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CG1_02_64_396 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCg10264396Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevrieseaAgamarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devriesea agamarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevrieseaAgamarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasQingdaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas qingdaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasQingdaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSolventivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus solventivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSolventivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcmicro1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc7003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC 7003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KutzneriaSp744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria sp. 744 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KutzneriaSp744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterLapidariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter lapidarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterLapidariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSpRifcsplowo202full4514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. RIFCSPLOWO202FULL4514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpRifcsplowo202full4514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusThioparusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus thioparus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusThioparusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesSpCf514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. CF514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpCf514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraPilosicoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira pilosicoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraPilosicoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag403(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag403", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpMwyl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MWYL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMwyl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSiciliaeC2j(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae C2J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliaeC2j", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudosphingobacteriumDomesticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudosphingobacterium domesticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudosphingobacteriumDomesticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcetothermiaBacteriumJdfr52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArdenticatenaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ardenticatena maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArdenticatenaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterLucknowensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter lucknowensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterLucknowensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWC2_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201452450sch5900713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201452450SCH5900713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201452450sch5900713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraDaeponensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera daeponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeisingeraDaeponensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVariegatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVariegatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortieraAleyrodidarumBtbhrsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum BTBHRs Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumBtbhrsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSp24mn13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 24MN13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp24mn13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureobasidiumNamibiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumNamibiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpAntimn1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. AntiMn-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpAntimn1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusWentii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus wentii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusWentii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphusCoralliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amorphus coralli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmorphusCoralliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumScgcAaa252p10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252P10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252p10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaSanctiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sancti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSanctiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpLf2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. LF2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpLf2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSedentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sedentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSedentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpTgly2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TGLY2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTgly2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumBbd199114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium BBD 1991-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumBbd199114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpGa1199Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1199 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1199Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JonquetellaAnthropiE333e1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi E333E1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiE333e1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpRoot1272Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. Root1272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpRoot1272Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrettanomycesBruxellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces bruxellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesBruxellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperellaPyogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trueperella pyogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrueperellaPyogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteralesBacteriumHtcc2255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium HTCC2255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumHtcc2255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaMuscariaKoideBx008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amanita muscaria Koide BX008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmanitaMuscariaKoideBx008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLautus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lautus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLautus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesBrasiliensisPb18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Pb18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensisPb18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaTropicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinispora tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisporaTropicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusParainfluenzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus parainfluenzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusParainfluenzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetococcusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetococcus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetococcusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaFijiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeofilumRubicundumJcm15548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geofilum rubicundum JCM 15548 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeofilumRubicundumJcm15548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPallidipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina pallidipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaPallidipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterAnaerophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter anaerophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterAnaerophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPlurextorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus plurextorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPlurextorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasHelleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas helleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHelleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixThermoacetophilaPtEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila PT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophilaPtEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2303638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumCg1023251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1023251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1023251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp11649854Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164985.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649854Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusHalocryophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus halocryophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusHalocryophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasChlororaphis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas chlororaphis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasChlororaphis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTamiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tamiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaTamiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb14314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB14314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb14314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctopusBimaculoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Octopus bimaculoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OctopusBimaculoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilicibacterSpTrichch4bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter sp. TrichCH4B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SilicibacterSpTrichch4bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpDd10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSp73h25apEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 73H25AP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp73h25apEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifoxya2full4528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFOXYA2FULL4528 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifoxya2full4528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumThermocisternumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum thermocisternum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumThermocisternumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpHgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsplowo201full4816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO201FULL4816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo201full4816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP1xp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P1XP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP1xp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpSrsw22016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. SRSW22016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpSrsw22016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelnapiaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Belnapia rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BelnapiaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaGrammicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylaria grammica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylariaGrammicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusTetradius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus tetradius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusTetradius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpPcc7407Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC7407 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7407Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_47_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpBh333(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. BH-3-3-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpBh333", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumOphioglossoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubellimicrobiumMesophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrionaceaeBacterium1162ts0a05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium 1162TS0a05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacterium1162ts0a05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaCornellensisFslF60969Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria cornellensis FSL F6-0969 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaCornellensisFslF60969Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_43_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomycesKudriavzeviiIfo1802(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii IFO 1802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzeviiIfo1802", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChersinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora chersina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaChersinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisElegansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisElegansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutusTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opitutus terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpitutusTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSp12014mblmicdivCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. 12014MBLMicDiv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSp12014mblmicdivCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumLindaniclasticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lindaniclasticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLindaniclasticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesDistasonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides distasonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesDistasonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumLepromatosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lepromatosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLepromatosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpS62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S-6-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpImcc9063Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. IMCC9063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpImcc9063Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendroctonusPonderosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dendroctonus ponderosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DendroctonusPonderosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesBurtoniiDsm6242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii DSM 6242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesBurtoniiDsm6242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonauticusSpA7aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. A7A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSpA7aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinovumAlgicolaDg898(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinovum algicola DG 898 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinovumAlgicolaDg898", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpUrhb0020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. URHB0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpUrhb0020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaSpBbd199113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula sp. BBD 1991-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvularculaSpBbd199113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviimonasSp20v17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas sp. 20V17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DefluviimonasSp20v17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpS17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpS17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpLig30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. lig30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpLig30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RathayibacterTriticiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter tritici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RathayibacterTriticiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaDavisaeDsm4568Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cedecea davisae DSM 4568 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CedeceaDavisaeDsm4568Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StappiaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stappia indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StappiaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCimexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthocomusHoazin(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opisthocomus hoazin graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpisthocomusHoazin", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeCwl029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae CWL029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeCwl029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfOnchocercaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Onchocerca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfOnchocercaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusLactolyticusAtcc51172(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus ATCC51172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusAtcc51172", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaOralTaxonTm7xCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria oral taxon TM7x Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaOralTaxonTm7xCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisBaekryungensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis baekryungensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisBaekryungensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraMultiparaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira multipara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraMultiparaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalypteAnna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calypte anna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalypteAnna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium9400853Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 9400853 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacterium9400853Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfTrichogramma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogramma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_38_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3819", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD1_FULL_40_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp292mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 292MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp292mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifoxyc1full3814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYC1FULL3814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyc1full3814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella histicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaHisticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSp21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. 21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSp21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaLongicatenaAgr2136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena AGR2136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaAgr2136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquifexAeolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquifex aeolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquifexAeolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiaWalkeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tilletia walkeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TilletiaWalkeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPseudoporcinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudoporcinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudoporcinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumJgi0000077k19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium JGI 0000077K19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumJgi0000077k19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEprs66Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EpRS66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEprs66Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStreptomycesMassiliensisAp10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Streptomyces massiliensis AP10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStreptomycesMassiliensisAp10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOlindensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olindensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlindensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumValvarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CardiobacteriumValvarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpFc2011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. FC2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpFc2011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpAtcc6931Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. ATCC6931 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpAtcc6931Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusCristatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus cristatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusCristatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PterulaGracilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pterula gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PterulaGracilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaCoronataVarAvenaeFSpAvenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Puccinia coronata var. avenae f. sp. avenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PucciniaCoronataVarAvenaeFSpAvenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumScn6937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium SCN 69-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumScn6937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb245a520k10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a520K10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a520k10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWirthbacteriaBacteriumCg2305411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wirthbacteria bacterium CG2_30_54_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWirthbacteriaBacteriumCg2305411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwe24214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE24214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe24214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterPneumotropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter pneumotropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterPneumotropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaAcetivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina acetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaAcetivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Bacterium2013ark19iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Ark19i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013ark19iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilaceaeBacteriumUrhb0062Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0062 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0062Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_38_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxEbreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax ebreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxEbreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiWsm2783Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM2783 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm2783Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaboniaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gabonia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GaboniaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumScgcAaa252n14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252N14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252n14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraSp27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumCg10239135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium CG1_02_39_135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumCg10239135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterCrusticolaDsm16708Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola DSM 16708 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DyadobacterCrusticolaDsm16708Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivalisW83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis W83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisW83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LoktanellaHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCellulosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellulosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellulosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineActinobacteriumMedacidiG3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaGranulomatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaGranulomatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterWinghamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter winghamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterWinghamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusSpicilegusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mus spicilegus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusSpicilegusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia speluncae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpeluncaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaPickettii12j(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12J graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12j", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocurvusVexinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvus vexinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvusVexinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrotusOchrogasterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microtus ochrogaster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrotusOchrogasterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSpDsm44268Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44268 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44268Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StachybotrysChlorohalonataIbt40285Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata IBT 40285 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonataIbt40285Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpMilost1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. MilosT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpMilost1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpFb24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. FB24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpFb24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterIndolifex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter indolifex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterIndolifex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviimonasSp20v17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Defluviimonas sp. 20V17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DefluviimonasSp20v17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusPomorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus pomorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusPomorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaHansenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia hansenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaHansenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpHl58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. HL58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpHl58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCherry(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cherry graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCherry", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobiusVermicularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobius vermicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobiusVermicularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPorcinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium porcinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPorcinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumUkl133Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium UKL13-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumUkl133Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwd26328Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWD2_63_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwd26328Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrondihabitansSpPamc28766(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. PAMC 28766 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpPamc28766", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumBarkeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium barkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineActinobacteriumMedacidiG2b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho202full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO202FULL4712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho202full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavisolibacterGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiostomaFloridaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Branchiostoma floridae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BranchiostomaFloridaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParaputrificumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium paraputrificum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParaputrificumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeleagrisGallopavoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meleagris gallopavo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeleagrisGallopavoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpSeq25vCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. Seq25V Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpSeq25vCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusNatl1a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl1a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StagonosporaSpSrc1lsm3aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stagonospora sp. SRC1lsM3a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StagonosporaSpSrc1lsm3aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaLijiangensisNbrc108240Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis NBRC 108240 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaLijiangensisNbrc108240Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanoprotosteliumFungivorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planoprotostelium fungivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanoprotosteliumFungivorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMarisnigri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum marisnigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMarisnigri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumAgresteDsm44070Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum agreste DSM 44070 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumAgresteDsm44070Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionicicellaSuperfundiaDsm22317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionicicella superfundia DSM 22317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundiaDsm22317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumWce2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChaetomiumThermophilumVarThermophilumDsm1495Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum var. thermophilum DSM 1495 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChaetomiumThermophilumVarThermophilumDsm1495Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSchinkiiDsm10518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blautia schinkii DSM 10518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlautiaSchinkiiDsm10518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitritaleaHalalkaliphilaLw7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila LW7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphilaLw7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK098 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutypaLataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eutypa lata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EutypaLataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumL18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium L18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumL18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg2304142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_41_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2304142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhizobiumPelagicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhizobium pelagicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhizobiumPelagicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxiiCbs732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii CBS 732 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxiiCbs732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpDc12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. DC12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpDc12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpFxj1172(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. FXJ1.172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFxj1172", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfCtenarytainaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialemoniopsisCurvata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialemoniopsis curvata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialemoniopsisCurvata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAliena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas aliena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAliena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_33_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendrosporobacterQuercicolus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dendrosporobacter quercicolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DendrosporobacterQuercicolus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedimonasAcanthamoebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracaedimonas acanthamoebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacaedimonasAcanthamoebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimangrovimonasIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidimangrovimonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidimangrovimonasIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicronemaHongdechloris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomicronemaHongdechloris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_39_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPlantarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus plantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPlantarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanofollisEthanolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis ethanolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanofollisEthanolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPseudotuberculosisC231Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis C231 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosisC231Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusElongatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusElongatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOralisHga0225Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis HGA0225 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisHga0225Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDextrinicusDsm20335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus DSM 20335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDextrinicusDsm20335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellalesBacteriumRifcsphigho212full3511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3511 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifcsplowo202full5736(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL5736 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full5736", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaInnocuaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria innocua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaInnocuaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAwamoriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus awamori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusAwamoriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVaccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGaemokensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gaemokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGaemokensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeeksellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weeksella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeeksellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlaviramulusBasaltisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus basaltis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusBasaltisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyc12full3455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC12FULL3455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc12full3455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraElongataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraElongataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaPyrifoliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia pyrifoliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPyrifoliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMikellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mikella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMikellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProsthecochlorisAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminobacterSpRm87Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter sp. RM87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminobacterSpRm87Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE1214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf67Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf67Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaTropicalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaTropicalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHammesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHammesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_45_11c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSilesiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas silesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSilesiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidiphilusNbrc100859(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus NBRC 100859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilusNbrc100859", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusDuerdeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus duerdenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusDuerdeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumSuecicumHhb10207Ss3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum HHB10207 ss-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumSuecicumHhb10207Ss3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumM3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium M3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumM3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusMuriaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus muriaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusMuriaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpKjjEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KJJ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKjjEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5329Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5329 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5329Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusCleftensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus cleftensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCleftensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FomitopsisPinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FomitopsisPinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryotiniaNarcissicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia narcissicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaNarcissicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatulibacterMinatonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter minatonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PatulibacterMinatonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesUtahensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes utahensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesUtahensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyd2full3415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYD2FULL3415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyd2full3415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCuracoi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces curacoi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCuracoi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpTb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNaeslundiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces naeslundii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNaeslundiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumMerycicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium merycicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMerycicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpG1w1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. G1w1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpG1w1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpOl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. OL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpOl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VolvoxCarteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Volvox carteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VolvoxCarteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensisKctc13613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus siamensis KCTC 13613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSiamensisKctc13613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpAp49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumAlbumDsm18261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium album DSM 18261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumAlbumDsm18261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFlexusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus flexus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFlexusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpN418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. N418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioSpN418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPabuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pabuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPabuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumTag1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium TAG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumTag1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncaeNbrc108251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia speluncae NBRC 108251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaSpeluncaeNbrc108251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwd24019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWD2_40_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwd24019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PteropusAlectoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pteropus alecto Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PteropusAlectoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMimicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mimicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMimicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchlesneriaPaludicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schlesneria paludicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchlesneriaPaludicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinagarivoransAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinagarivorans algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinagarivoransAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisSpHtcc2633Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HTCC2633 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHtcc2633Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanaeolusCyanescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Panaeolus cyanescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PanaeolusCyanescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuricoccusIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Auricoccus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AuricoccusIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChromiireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chromiireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChromiireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaMazeiS6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei S-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaMazeiS6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarincolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarincolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCystitidisDsm20524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis DSM 20524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidisDsm20524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRbg164011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpA37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. A37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpA37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusEndophyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusEndophyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatagioenasFasciataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Patagioenas fasciata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PatagioenasFasciataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr1BacteriumGw2011Gwc14913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR1 bacterium GW2011_GWC1_49_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1BacteriumGw2011Gwc14913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpSr15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. SR1/5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpSr15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpMed152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. MED152 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpMed152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSunkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sunkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSunkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwa13716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWA1_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwa13716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumUtcpr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium UTCPR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumUtcpr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BizioniaArgentinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bizionia argentinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BizioniaArgentinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacterFormigenesHoxblsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes HOxBLS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesHoxblsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRbg166213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_62_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphopichiaBurtoniiNrrlY1933Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii NRRL Y-1933 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyphopichiaBurtoniiNrrlY1933Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumMolleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium molle Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumMolleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminobacterHydrogenoformansDsm2784Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans DSM 2784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformansDsm2784Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaMontaniterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma montaniterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaMontaniterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasileaPsittacipulmonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Basilea psittacipulmonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BasileaPsittacipulmonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAb2028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AB2028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAb2028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPratensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPratensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumPsychrophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium psychrophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPsychrophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSihwensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sihwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GordoniaSihwensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifoxyc2full4228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL4228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full4228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPiperi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiperi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPohangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pohangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPohangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiLondoniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii londoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiLondoniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinococcusLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinococcusLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesF0058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes F0058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesF0058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpOv510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. OV510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpOv510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CholoepusHoffmanniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Choloepus hoffmanni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CholoepusHoffmanniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat44921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-44921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat44921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterTandoiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tandoii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTandoiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRhodobacterLobularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodobacter lobularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodobacterLobularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsphigho201full4822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPHIGHO201FULL4822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsphigho201full4822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwf2339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWF2_33_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwf2339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full5710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL5710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full5710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaThermophilaDsm6578Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila DSM 6578 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaThermophilaDsm6578Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc2796(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC27/96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc2796", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusAcidocaldariusDsm639Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius DSM 639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusDsm639Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriaceaeBacteriumChkci005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniomycesSimplexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesSimplexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPanfs17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PANFS17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPanfs17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaBovigenitaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovigenitalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovigenitaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporobacterMobilisDsm15930Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis DSM 15930 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilisDsm15930Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpBrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. BR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpBrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumGwf23715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWF23715 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwf23715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisBenevestitus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis benevestitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBenevestitus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusXenolissoclinumPacificiensisL6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xenolissoclinum pacificiensis L6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusXenolissoclinumPacificiensisL6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo5817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_58_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo5817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaMassilioguelmaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia massilioguelmaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaMassilioguelmaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaAlgae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella algae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAlgae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumAsp1004a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium ASP10-04a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumAsp1004a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpF0131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPseudopneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudopneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudopneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTribocorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tribocorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaTribocorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumNeoaurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neoaurum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeoaurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaylyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baylyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaylyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiaSanguinegensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sneathia sanguinegens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SneathiaSanguinegensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanococcusAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanococcus atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanococcusAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpAw25m09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. AW25M09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpAw25m09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFd1xmd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. fd1xmd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFd1xmd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumZagget3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSegnis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter segnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSegnis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSpS4079(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. S4079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSpS4079", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumChlorophytiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum chlorophyti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumChlorophytiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerasakiispiraPapahanaumokuakeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terasakiispira papahanaumokuakeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerasakiispiraPapahanaumokuakeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlexanderi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alexanderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlexanderi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlexibilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flexibilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlexibilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm10914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 10914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm10914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa25110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA25110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa25110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusHippeiDsm8344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei DSM 8344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusHippeiDsm8344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpExBiomphalariaGlabrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. (ex Biomphalaria glabrata) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpExBiomphalariaGlabrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTakedensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia takedensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaTakedensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraProfundimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira profundimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraProfundimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XiphophorusMaculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus maculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XiphophorusMaculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycosphaerellaPiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycosphaerella pini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycosphaerellaPiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot239oh1446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT239OH1446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot239oh1446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlimentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlimentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKitasatonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kitasatonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKitasatonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexSeptentrionalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex septentrionalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexSeptentrionalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacterialesBacteriumAlc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium ALC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumAlc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansDsm12475Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans DSM12475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansDsm12475Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHaloduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHaloduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusUvarumCbs121591Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus uvarum CBS 121591 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusUvarumCbs121591Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPopuleti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] populeti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPopuleti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaLiquefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia liquefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaLiquefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusErwiniaHaradaeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Erwinia haradaeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusErwiniaHaradaeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasTurrisvirgataeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas turrisvirgatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTurrisvirgataeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaAquaticaFslS101188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria aquatica FSL S10-1188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaAquaticaFslS101188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumLuteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLuteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpSe50110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. SE50110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpSe50110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpKm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolamprologusBrichardiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neolamprologus brichardi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeolamprologusBrichardiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaVaviloviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea vaviloviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaVaviloviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesLutziiPb01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Pb01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesLutziiPb01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetovibrioBlakemoreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetovibrio blakemorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetovibrioBlakemoreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGastranaerophilalesBacteriumZag111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium Zag_111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumZag111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LottiaGiganteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lottia gigantea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LottiaGiganteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumFabrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium fabrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumFabrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumPropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumPropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumRectaleAtcc33656(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] rectale ATCC 33656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumRectaleAtcc33656", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GymnopilusDilepisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gymnopilus dilepis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GymnopilusDilepisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusTerreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus terreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcusTerreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaLacuscaerulensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria lacuscaerulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaLacuscaerulensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumS85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium S85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumS85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParadoxumJwYl7Dsm7308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] paradoxum JW-YL-7 DSM 7308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParadoxumJwYl7Dsm7308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrococcusCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusSpA20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. A20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpA20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararheinheimeraTexasensisDsm17496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis DSM 17496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensisDsm17496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisBenzoatilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis benzoatilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBenzoatilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaedaleaQuercina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daedalea quercina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaedaleaQuercina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVietnamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vietnamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusVietnamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumYad3003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YAD3003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYad3003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseatelesSpYr242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseateles sp. YR242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseatelesSpYr242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMf105b01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Mf 105b01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMf105b01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumSp47agom205mEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. 47AGOM205m Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSp47agom205mEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCystitidisDsm20524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis DSM 20524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidisDsm20524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFermentibacterDaniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fermentibacter daniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFermentibacterDaniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesMaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces maris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesMaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusIocasae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus iocasae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIocasae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonesiaQuinghaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jonesia quinghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JonesiaQuinghaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraDaeponensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera daeponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeisingeraDaeponensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizophyllumCommuneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schizophyllum commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchizophyllumCommuneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaSpF0422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpF0422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixVenerupisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix venerupis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixVenerupisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MustelaPutoriusFuroCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius furo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MustelaPutoriusFuroCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmpedobacterBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraSpNm10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. NM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpNm10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpX2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. X2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpX2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraOligosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura oligospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraOligosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TraorellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Traorella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TraorellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaMalonicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa malonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporomusaMalonicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis6119v5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 6119V5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis6119v5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs4331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_33_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisC5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPHIGHO2_02_FULL_34_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumImitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium imitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumImitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusIndolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus indolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusIndolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterHenriciiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter henricii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterHenriciiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPantherisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPantherisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusMaripaludisC5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGa0077554(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077554 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077554", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumLentumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium lentum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumLentumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumClostridioformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumClostridioformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpC1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. C-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpC1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriumSar116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Alphaproteobacterium SAR116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriumSar116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GleimiaColeocanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gleimia coleocanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GleimiaColeocanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonadaceaeBacteriumGwc25813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadaceae bacterium GWC2_58_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadaceaeBacteriumGwc25813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumSpCba1132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. CBA1132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpCba1132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaS16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida S16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaS16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaNiabensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga niabensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaNiabensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaWelshimeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria welshimeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaWelshimeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusPeptidifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaPurpeofusca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora purpeofusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaPurpeofusca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilibacteriumTimonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mobilibacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MobilibacteriumTimonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSetae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora setae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSetae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteralesBacteriumRifcsphigho201full7019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFCSPHIGHO201FULL7019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifcsphigho201full7019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentimicrobiumSaccharophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentimicrobium saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentimicrobiumSaccharophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDichloromethanomonasElyunquensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dichloromethanomonas elyunquensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDichloromethanomonasElyunquensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpUrha0036Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. URHA0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpUrha0036Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymoseptoriaTriticiSt99ch3d7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici ST99CH_3D7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiSt99ch3d7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4249Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4249Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofustisGlycolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaOtitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaOtitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtribacteriaBacteriumRbg19ftcombo3514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium RBG19FTCOMBO3514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumRbg19ftcombo3514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NotamacropusEugenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Notamacropus eugenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NotamacropusEugenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaFlavaNbrc102514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava NBRC 102514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaFlavaNbrc102514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumMa2020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MA2020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMa2020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyricimonasSpMarseillep2440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas sp. MarseilleP2440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSpMarseillep2440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGr602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GR 6-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGr602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaAlbidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaCorporisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella corporis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCorporisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDisiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella disiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDisiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuhomycesTanzawaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterHolothuriorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter holothuriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterHolothuriorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot483d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root483D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot483d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm44268Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44268Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium GW2011_GWA1_41_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinilactibacillusSp15r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus sp. 15R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusSp15r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpSk12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk1w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK1W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk1w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovispirillumItersoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novispirillum itersonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovispirillumItersoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIndolisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium indolis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIndolisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaCephalotaxiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha cephalotaxi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaCephalotaxiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMeningosepticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia meningoseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaMeningosepticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrellaAestuarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrella aestuarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrellaAestuarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpApg3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. APG3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitrosospiraSpApg3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumParaoxydansDh1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans DH1b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydansDh1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroococcidiopsisThermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chroococcidiopsis thermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChroococcidiopsisThermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMarseillenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marseillense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarseillenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisDaom181602daom(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM181602DAOM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602daom", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaDentocariosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rothia dentocariosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RothiaDentocariosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterAerophilusDsm13606Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus DSM 13606 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HymenobacterAerophilusDsm13606Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasNitroreducensHbp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens HBP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensHbp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusInfernusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus infernus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusInfernusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterLari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCellulosilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cellulosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCellulosilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPersimilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila persimilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPersimilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumMor1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Mor1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumMor1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaVladivostokensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita vladivostokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AequorivitaVladivostokensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAmyloliquefaciensDsm7Atcc23350Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DSM 7 ATCC 23350 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDsm7Atcc23350Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAnthracisSterneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Sterne Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisSterneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumGranuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium granuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGranuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisSorokinianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BipolarisSorokinianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioProteolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioProteolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixSpPcc11201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix sp. PCC 11201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixSpPcc11201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifoxyb1full4711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFOXYB1FULL4711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifoxyb1full4711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalisDsm15212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis DSM 15212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalisDsm15212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTimonianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium timonianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTimonianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaPseudohaemulonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Candida] pseudohaemulonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaPseudohaemulonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurisphaeraTokodaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurisphaera tokodaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurisphaeraTokodaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumSpLc103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium sp. LC103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumSpLc103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoflavonifractorCapillosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor capillosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorCapillosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full4424bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4424b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4424bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphopichiaBurtoniiNrrlY1933Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii NRRL Y-1933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyphopichiaBurtoniiNrrlY1933Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiflebacteriaBacteriumGwc2508(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riflebacteria bacterium GWC2508 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiflebacteriaBacteriumGwc2508", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAtcc13867Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ATCC 13867 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAtcc13867Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaReeseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma reesei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaReeseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_01_FULL_44_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo201Full4424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersephonellaSpKm09lau8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. KM09Lau8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpKm09lau8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumStbin12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSyngnathidarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium syngnathidarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSyngnathidarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full4914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL4914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full4914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSpCag770Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:770 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag770Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TieghemosteliumLacteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tieghemostelium lacteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TieghemosteliumLacteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaAerofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella aerofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaAerofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterAlbidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter albidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAlbidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaElongata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mortierella elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MortierellaElongata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicavibrioAeruginosavorusArl13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus ARL13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusArl13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaJalaludiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella jalaludinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaJalaludiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInterrogansSerovarLaiStr56601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira interrogans serovar Lai str. 56601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInterrogansSerovarLaiStr56601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpXs5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. XS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpXs5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_45_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesQaidamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qaidamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQaidamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasKerstersiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas kerstersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasKerstersiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterSpAbm4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. AbM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpAbm4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButtiauxellaFerragutiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot901Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot901Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BasidiobolusMeristosporusCbs93173Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus CBS 931.73 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporusCbs93173Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaphidocelisSubcapitataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Raphidocelis subcapitata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RaphidocelisSubcapitataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReyranellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Reyranella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ReyranellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSanguinisSk355(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk355", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml130454Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML130454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml130454Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusPyridinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus pyridinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusPyridinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpL74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. L74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpL74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiaceaeBacteriumSg6cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium SG6C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumSg6cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisFormicicusMcS70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Mc-S-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisFormicicusMcS70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPhaffiiGs115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataella phaffii GS115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPhaffiiGs115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAtcc31555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ATCC31555 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAtcc31555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumSpPc0866Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. PC08-66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpPc0866Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnicoccusIslandicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusIslandicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaceaeBacteriumMarseillep2826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium MarseilleP2826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumMarseillep2826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusGonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus gonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusGonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterEngbaekii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter engbaekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterEngbaekii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSpMar201089Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2010_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar201089Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaMangroviensisCbs10435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis CBS 10435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KwoniellaMangroviensisCbs10435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterPiechaudiiHleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii HLE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiHleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoelleriellaLibera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moelleriella libera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoelleriellaLibera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpLsaoa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. LSAOA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpLsaoa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenolissoclinumPacificiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenolissoclinum pacificiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenolissoclinumPacificiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusHitonicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus hitonicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHitonicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicellaMetallireducensAebCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens AeB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FervidicellaMetallireducensAebCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogulbenkianiaFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriTs44Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri TS44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriTs44Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumRivuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium rivuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumRivuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaliobacillusSpPm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus sp. PM-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusSpPm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFOXYB1_FULL_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMutansUa159(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans UA159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansUa159", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRbg166411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusPuniceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus puniceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPuniceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpMan2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. MAN2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpMan2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSpMar2010102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpWd162Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD16.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd162Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumMassiliodielmoense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium massiliodielmoense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMassiliodielmoense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosyntrophaLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumThoeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium thoenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumThoeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesClarusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides clarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesClarusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaXenovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia xenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaXenovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutansGs5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans GS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansGs5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpLf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. LF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpLf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpB29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. B29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpB29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterEuropaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter europaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterEuropaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full3914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL3914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full3914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwb1437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWB1_43_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwb1437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicoprobacterOshimaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter oshimai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldicoprobacterOshimaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrionaceaeBacterium1162ts0a05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium 1162TS0a05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacterium1162ts0a05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharothrixSpNrrlb16314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumSphagni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sphagni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSphagni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumScgcAaa160i06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA160I06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa160i06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumCg2304152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium CG2304152 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumCg2304152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaShakespeareiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella shakespearei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaShakespeareiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallorhinchusMilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Callorhinchus milii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CallorhinchusMilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpLCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarivitaHallyeonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivita hallyeonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivitaHallyeonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCns606Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNS606 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCns606Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSolani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumReichenbachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium reichenbachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumReichenbachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg10255237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_55_237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg10255237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL3913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusAminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaAnsorpii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella ansorpii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaAnsorpii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaParadisiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya paradisiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaParadisiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumHlucca01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium HLUCCA01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumHlucca01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpHl93Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL-93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl93Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumBrasilianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium brasilianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumBrasilianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpSod10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. SOD10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpSod10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa2378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGa0077543(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077543 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077543", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 39-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRhodesiaeNbb3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rhodesiae NBB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRhodesiaeNbb3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_49_67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusCaldoxylosilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus caldoxylosilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusCaldoxylosilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSophorae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sophorae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSophorae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortieraAleyrodidarumTvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum TV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumTvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensSpPamc27130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychroserpens sp. PAMC27130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychroserpensSpPamc27130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpYl58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. YL58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpYl58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumCelereCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum celere Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumCelereCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumMagnumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium magnum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMagnumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioflavicoccusMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioflavicoccus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioflavicoccusMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTypographiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia typographi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTypographiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FilamentousCyanobacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return filamentous cyanobacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FilamentousCyanobacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLup30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LUP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLup30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdvenellaMimigardefordensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Advenella mimigardefordensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdvenellaMimigardefordensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TupaiaBelangeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tupaia belangeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TupaiaBelangeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifoxyb2full487(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL487 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full487", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumCoe1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium COE1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumCoe1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaInohanensisNbrc100128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia inohanensis NBRC 100128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaInohanensisNbrc100128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterosteliumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heterostelium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeterosteliumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaBlattaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaBlattaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpKc8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. KC8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpKc8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpQssc122b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. QSSC1-22B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpQssc122b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioEthanolgignens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetivibrio ethanolgignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetivibrioEthanolgignens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSalifodinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus salifodinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusSalifodinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipheNecatorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe necator Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipheNecatorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSilageiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus silagei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSilageiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumGw2011gwa24010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA24010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa24010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasLuteoviolacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticusT34(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus T-34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticusT34", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSambucus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sambucus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSambucus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpCubenseRace1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VolvoxCarteriFNagariensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri f. nagariensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VolvoxCarteriFNagariensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RugosibacterAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rugosibacter aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RugosibacterAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaBalticaOs155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella baltica OS155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBalticaOs155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYB2_FULL_32_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterSubterraneusDsm17957Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus DSM 17957 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneusDsm17957Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc5015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC5015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc5015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag449Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:449 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag449Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumColumnareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium columnare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumColumnareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterNitrophenolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter nitrophenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterNitrophenolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMisionensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces misionensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMisionensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUvarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus uvarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusUvarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCihuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cihuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCihuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf67(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf67", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpGd7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. GD7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpGd7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCorynebacterioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus corynebacterioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCorynebacterioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TindalliaCaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tindallia californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TindalliaCaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusInfernus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus infernus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusInfernus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRifcsphigho212full5236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO212FULL5236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho212full5236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaricaulisSalignorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis salignorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSalignorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_35_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisZeicola26R13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris zeicola 26-R-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BipolarisZeicola26R13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PerlucidibacaAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFujikuroiImi58289Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi IMI 58289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumFujikuroiImi58289Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaMali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaMali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag768(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:768 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag768", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSiliginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus siliginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSiliginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoalloteichusCyanogriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus cyanogriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusCyanogriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpStbin4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaAtypicaAcs049vsch6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica ACS049VSch6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaAcs049vsch6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumUkl132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium UKL13-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumUkl132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg19ftcombo5516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG19FTCOMBO5516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg19ftcombo5516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLarrymooreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium larrymoorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLarrymooreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full5216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_52_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full5216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilioclostridiumColiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilioclostridium coli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilioclostridiumColiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterChromiiresistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chromiiresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChromiiresistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaFlabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella flabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaFlabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg134610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg134610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCiat652(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CIAT652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCiat652", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full497(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full497", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf13410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF1_34_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf13410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GardnerellaVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelatococcusDaeguensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus daeguensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusDaeguensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp01251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 0-1251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp01251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCapillatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCapillatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterPinnipediorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuraishiaCapsulataCbs1993Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kuraishia capsulata CBS 1993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KuraishiaCapsulataCbs1993Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusMucosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius mucosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMucosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteipulveratusHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHyovaginalisDsm12219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis DSM 12219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalisDsm12219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpSjsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. SJS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpSjsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSaxobsidensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus saxobsidens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSaxobsidensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hortaea werneckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HortaeaWerneckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesKatrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces katrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKatrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSubterraniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter subterrani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSubterraniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogulbenkianiaSubflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillibacteriumTimonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumTimonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaSpSe31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella sp. SE31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SciscionellaSpSe31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_50_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwf24113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWF2_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwf24113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratireductorPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratireductorPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoxodontaAfricanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loxodonta africana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoxodontaAfricanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaEpimycesCbs60696(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces CBS 606.96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaproniaEpimycesCbs60696", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpBal6xCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BAL6X Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBal6xCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMarginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella cuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCoprophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCoprophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaVincentiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema vincentii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaVincentiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetobacteriumCasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetobacterium casensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetobacteriumCasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraTigrisAltaicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris altaica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantheraTigrisAltaicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLshc420b00Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSHC420B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLshc420b00Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaSp6palisep08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. 6PALISEP08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSp6palisep08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraLatina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura latina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraLatina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwe13912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWE13912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwe13912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpCg912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. CG912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpCg912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumCommuneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium commune Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumCommuneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpChdcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ChDC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusSpChdcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalaenopteraAcutorostrataScammoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata scammoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrataScammoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpJa23baEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA23Ba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa23baEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwc14518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWC1_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwc14518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusBovimastitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus bovimastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusBovimastitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrondihabitansSpPamc28766Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. PAMC 28766 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpPamc28766Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterGangotriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter gangotriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterGangotriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlligatorSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alligator sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlligatorSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterHeidelbergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heidelbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeidelbergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFrumentiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFrumentiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpX15166bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. X15-166B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpX15166bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVaccae95051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae 95051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccae95051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmmonsiaSpCac2015aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia sp. CAC-2015a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaSpCac2015aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hn63Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HN63 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hn63Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiostomaPiceae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiostoma piceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiostomaPiceae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasMesophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinomonasMesophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium1747faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 1747FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium1747faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo212full3610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO212FULL3610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo212full3610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KallipygaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KallipygaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumRifoxya2full329Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFOXYA2FULL329 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifoxya2full329Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag156Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag156Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpTs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. TS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpTs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaSagamiharensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella sagamiharensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaSagamiharensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_36_10b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumJannaschiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumDigitatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium digitatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDigitatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl7Mag120322Bin74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 MAG-120322-bin74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Mag120322Bin74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusApachensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus apachensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusApachensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaInconspicuaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Candida] inconspicua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaInconspicuaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioflavicoccusMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioflavicoccus mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioflavicoccusMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaBigemina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Babesia bigemina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BabesiaBigemina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonasHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermomonasHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaMensalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella mensalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilliamellaMensalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaEchinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gramella echinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GramellaEchinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg10247685Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG10247685 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg10247685Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusFiliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusFiliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp4212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaOakridgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella oakridgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaOakridgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterDaepoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daepoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaepoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonticulaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fonticula alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FonticulaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24535Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24535 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24535Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSabulinigriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sabulinigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSabulinigriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalohastaLitchfieldiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halohasta litchfieldiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalohastaLitchfieldiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStationis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium stationis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStationis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinalesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc4bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ObscuribacterPhosphatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Obscuribacter phosphatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ObscuribacterPhosphatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AncylostomaCeylanicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma ceylanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCeylanicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPattaloongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pattaloongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPattaloongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPisciumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus piscium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusPisciumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHtcc2150(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2150", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAcaciae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia acaciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAcaciae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. 28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraSp28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisSpBbd199110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. BBD 1991-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpBbd199110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeochlamydiaSpEps4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neochlamydia sp. EPS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeochlamydiaSpEps4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasVirosaDsm23226(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas virosa DSM 23226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyricimonasVirosaDsm23226", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodonghicolaXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudodonghicola xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudodonghicolaXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasChironomiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas chironomi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachymonasChironomiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiae14628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae 14628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiae14628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterJaachi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter jaachi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaachi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BisonBisonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bison bison Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BisonBisonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolectaIrregularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neolecta irregularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeolectaIrregularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolumonasLignilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas lignilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolumonasLignilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter koseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterKoseriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VecturithrixGranuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vecturithrix granuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VecturithrixGranuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH073(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H073 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH073", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpBal378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BAL378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBal378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa14021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA14021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa14021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaymondbacteriaBacteriumRifoxyc2full5021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Raymondbacteria bacterium RIFOXYC2FULL5021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RaymondbacteriaBacteriumRifoxyc2full5021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterHelveticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHelveticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmoparaHalstedii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmopara halstedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmoparaHalstedii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTracheiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tracheiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTracheiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf402Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf402Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaeroformaArcticaJp610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica JP610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphaeroformaArcticaJp610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumParadoxumJwYl7Dsm7308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] paradoxum JW-YL-7 DSM 7308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParadoxumJwYl7Dsm7308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CionaIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ciona intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CionaIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOrisasini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisasini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisasini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPonticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ponticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioPonticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpAkyn10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. AKYN10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpAkyn10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusVarani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus varani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusVarani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterFlexilisDsm6793Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter flexilis DSM 6793 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlexibacterFlexilisDsm6793Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwb1385Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWB1385 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwb1385Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeckwithbacteriaBacteriumRbg13429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium RBG13429 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumRbg13429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspOzaenaeNbrc105683(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. ozaenae NBRC 105683 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspOzaenaeNbrc105683", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumArgentoratenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium argentoratense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumArgentoratenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollimonasSpOk242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumCg1025621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_56_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1025621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixSpP13c2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. P13C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpP13c2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho212full4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL4616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_38_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk569(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk569", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpD16q13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16Q13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16q13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraPerlucidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera perlucida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPerlucidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLugdunensisN920143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis N920143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisN920143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_44_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwd23614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWD2_36_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwd23614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHenryiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus henryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHenryiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag646(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag646", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLonarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLonarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSpOk283Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK283 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk283Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllofrancisellaGuangzhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allofrancisella guangzhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllofrancisellaGuangzhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp1513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp1513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusIntestiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusIntestiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaKandleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella kandleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaKandleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSaudiphocaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudiphocaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudiphocaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DraconibacteriumSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SarcinaSpDsm11001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sarcina sp. DSM 11001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SarcinaSpDsm11001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SebaldellaTermitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sebaldella termitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SebaldellaTermitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaAmazonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella amazonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAmazonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasEnteropelogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas enteropelogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasEnteropelogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwelEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWEL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwelEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDaejeonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium daejeonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDaejeonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo201full4421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO201FULL4421 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo201full4421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwt2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwt2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptobacterTengchongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kryptobacter tengchongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KryptobacterTengchongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1859Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1859Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethylopumilusPlanktonicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus planktonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusPlanktonicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusZopfiiNbrc100606Jcm9919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii NBRC 100606 JCM 9919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusZopfiiNbrc100606Jcm9919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButtiauxellaFerragutiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_34b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumMetallireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumMetallireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterRhaeticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter rhaeticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterRhaeticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAp12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AP12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAp12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacteraceaeBacteriumAb14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacteraceae bacterium AB_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OxalobacteraceaeBacteriumAb14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaFlorencae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella florencae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaFlorencae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoellerellaWisconsensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moellerella wisconsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoellerellaWisconsensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciens007c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens 007c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciens007c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_44_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElephantulusEdwardii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Elephantulus edwardii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ElephantulusEdwardii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusLaumondiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus laumondii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLaumondiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonB1br10e2g2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon B1Br10E2g2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonB1br10e2g2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCavendishii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cavendishii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCavendishii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonSg8523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SG8-52-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSg8523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaePvOryzaeKacc10331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae pv. oryzae KACC 10331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePvOryzaeKacc10331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpS2151(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. S2151 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpS2151", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAsiaticusGxpsy(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus gxpsy graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusGxpsy", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FukomysDamarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fukomys damarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FukomysDamarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypoxylonSpCi4aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CI-4A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCi4aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAnimalisSubspLactisAd011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis subsp. lactis AD011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalisSubspLactisAd011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OstreococcusTauriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus tauri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OstreococcusTauriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo201full4534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO201FULL4534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo201full4534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSuimastitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces suimastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSuimastitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbidosporaCretaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora cretacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaCretaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeocallimastixCaliforniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neocallimastix californiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeocallimastixCaliforniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CulturomicaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Culturomica massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CulturomicaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusMetallicusDsm6482Jcm9184Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus DSM 6482 JCM 9184 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfolobusMetallicusDsm6482Jcm9184Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNeoaurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neoaurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeoaurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterPickeringii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter pickeringii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterPickeringii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierellaPraeacutaDsm18095Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tissierella praeacuta DSM 18095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TissierellaPraeacutaDsm18095Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSilesiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas silesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSilesiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronococcusJeotgaliDsm18795Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali DSM 18795 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatronococcusJeotgaliDsm18795Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcusNigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcus niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcusNigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritimibacterAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niastella koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiastellaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermochlorobacteriaceaeBacteriumGbchlbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermochlorobacteriaceae bacterium GBChlB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermochlorobacteriaceaeBacteriumGbchlbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRbg163710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG_16_37_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg163710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Propionibacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Propionibacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelatoporiaSubvermisporaBCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GelatoporiaSubvermisporaBCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterLanceolatusAtcc14669Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus ATCC 14669 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CurvibacterLanceolatusAtcc14669Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMeningosepticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia meningoseptica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaMeningosepticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacteralesBacterium6714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium 67-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacterium6714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMaritimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMaritimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraMayottensis200901116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira mayottensis 200901116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMayottensis200901116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaCephalotesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atta cephalotes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AttaCephalotesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaDasiensisCbs10888Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachancea dasiensis CBS 10888 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachanceaDasiensisCbs10888Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinactinosporaThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinactinosporaThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusPiranensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus piranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusPiranensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumArsenaticumDsm13514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum DSM 13514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticumDsm13514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIec1808Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IEC1808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIec1808Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusFaeciumC68Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium C68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumC68Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LupinusAngustifolius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lupinus angustifolius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LupinusAngustifolius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_49_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpOrs3359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAquaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium aquaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAquaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSalignoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis salignorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSalignoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPsittaci10139811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 10139811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci10139811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothielavioidesTerrestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumButyricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium butyricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumButyricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolani123e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani 123E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolani123e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaElegans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holospora elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HolosporaElegans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumSpLc103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium sp. LC103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumSpLc103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CajanusCajanCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cajanus cajan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CajanusCajanCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabiaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arabia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArabiaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiellaGlossodoripedisJcm23214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis JCM 23214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedisJcm23214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 28-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsphigho201full4827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4827 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpLeaf454Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf454 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf454Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumSpScn7031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 70-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn7031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifcsplowo201full4925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMegateriumMsp201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium MSP201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumMsp201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDianthicolaNcppb3534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dianthicola NCPPB 3534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DickeyaDianthicolaNcppb3534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZygosaccharomycesBailiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa028a23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA028A23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa028a23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRu33a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU33A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu33a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPiscinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc piscinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocPiscinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacteriumKbs708Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium KBS708 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumKbs708Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophilaDsm15071Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiohalospira halophila DSM 15071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiohalospiraHalophilaDsm15071Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf125Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf125Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntomoplasmaMelaleucaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13220cm27011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM27011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm27011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumAlterfunditum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium alterfunditum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumAlterfunditum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacinutrixAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TanticharoeniaSakaeratensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlimentariusDsm20249Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius DSM 20249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlimentariusDsm20249Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOulorumJcm14966Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum JCM14966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumJcm14966Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoolittleaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doolittlea endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoolittleaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpA39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. A39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpA39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumSilenesdioicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum silenesdioicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSilenesdioicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeglectaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neglecta timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeglectaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMutabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mutabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesMutabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillibacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterAcinonychis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter acinonychis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAcinonychis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSpJl2009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. JL2009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MaricaulisSpJl2009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaNodosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia nodosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaNodosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButtiauxellaFerragutiaeAtcc51602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buttiauxella ferragutiae ATCC 51602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButtiauxellaFerragutiaeAtcc51602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSg611lCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SG61-1L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSg611lCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyprinodonVariegatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyprinodon variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyprinodonVariegatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTusciaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tusciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTusciaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnserCygnoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anser cygnoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnserCygnoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaricaulisSpW15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis sp. W15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaricaulisSpW15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsplowo202full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTyphae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus typhae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTyphae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf23869(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_38_69 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf23869", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpMh3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. MH3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpMh3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesScottEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Scott Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesScottEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaRadingaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia radingae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaRadingaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumEquinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium equinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumEquinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurisphaeraTokodaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurisphaera tokodaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurisphaeraTokodaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThecamonasTrahens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thecamonas trahens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThecamonasTrahens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAsteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium asteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAsteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterSuareziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSuareziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlagellimonasEckloniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas eckloniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasEckloniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterSpYs13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. YS13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpYs13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromatiaceaeBacterium2141tstbd0c01aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromatiaceae bacterium 2141TSTBD0c01a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromatiaceaeBacterium2141tstbd0c01aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesTritici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GaeumannomycesTritici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumEfficiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium efficiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEfficiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GimesiaMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gimesia maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GimesiaMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasProtegensCha0Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens CHA0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensCha0Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OligellaUrethralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oligella urethralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OligellaUrethralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucibacterSpKctc42545Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paucibacter sp. KCTC 42545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaucibacterSpKctc42545Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumOlb14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioProteolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioProteolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzorhizobiumDoebereineraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium doebereinerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumDoebereineraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizophyllumCommune(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schizophyllum commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchizophyllumCommune", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusMorrhuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus morrhuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusMorrhuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ag1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf125Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf125 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf125Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaFiliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holdemania filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaFiliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimentisphaeraCyanobacteriorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sedimentisphaera cyanobacteriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SedimentisphaeraCyanobacteriorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquiflexumBalticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquiflexum balticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquiflexumBalticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerpentinomonasRaicheiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas raichei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasRaicheiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobacillusMacyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus macyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusMacyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiEuryarchaeoteEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeoteEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocCarnosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc carnosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCarnosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaChahannaoensisJcm10990Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis JCM 10990 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensisJcm10990Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaSpCag521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpYr531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm6137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM6137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm6137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaPanamericanaUamh10762(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia panamericana UAMH 10762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaPanamericanaUamh10762", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceicoccusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYC1_FULL_38_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaJiangningensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga jiangningensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaJiangningensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_36_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaSpMar2009132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. MAR2009132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpMar2009132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterNataicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter nataicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterNataicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriMf28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri MF28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriMf28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSpUncmf331sha31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF331Sha3.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf331sha31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMspmpm5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MspMPM5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMspmpm5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSeohaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter seohaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSeohaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitricoccusSpCh26aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citricoccus sp. CH26A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitricoccusSpCh26aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLactaridiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lactaridi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLactaridiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaSpNcppb569Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. NCPPB569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpNcppb569Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasFloridensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas floridensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFloridensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip642(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP 64.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip642", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaSolaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaSolaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusHydrogenalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus hydrogenalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusHydrogenalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumScophthalmum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium scophthalmum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumScophthalmum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DubosiellaNewyorkensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dubosiella newyorkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DubosiellaNewyorkensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevilineaSaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levilinea saccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevilineaSaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCollinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces collinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCollinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVogelbacteriaBacteriumGwa15114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium GWA1_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumGwa15114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaLentaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaLentaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiemerellaColumbipharyngisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbipharyngis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbipharyngisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumBrasilianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium brasilianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumBrasilianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_39_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobaculumGomorrense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobaculum gomorrense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobaculumGomorrense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifcsphigho202full4214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO202FULL4214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho202full4214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBorstelensisAk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis AK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensisAk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNctc7422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCTC 7422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNctc7422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full4528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumPhyllostachyosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium phyllostachyos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPhyllostachyosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedButyricicoccusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Butyricicoccus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedButyricicoccusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermothelomycesThermophilusAtcc42464Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus ATCC 42464 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilusAtcc42464Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusSpMarseillep2731Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus sp. MarseilleP2731 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrococcusSpMarseillep2731Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatiyooniaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioCarbinoliphilusSubspOakridgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus subsp. oakridgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilusSubspOakridgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwc14715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWC14715 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwc14715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpH1nEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. H1n Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaSpH1nEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorAustralicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloramator australicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloramatorAustralicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSwingsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium swingsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSwingsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFennelliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter fennelliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFennelliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaMarshiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella marshii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMarshiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGerneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gerneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGerneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumMultivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMultivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMelonisTy(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas melonis TY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMelonisTy", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAeruginosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAeruginosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterAurescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter aurescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterAurescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaGinsenosidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niabella ginsenosidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiabellaGinsenosidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa25510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_55_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiSl33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii SL33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiSl33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LloydbacteriaBacteriumRifcsplowo202full5111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO202FULL5111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo202full5111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelistegaSpMc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelistega sp. MC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelistegaSpMc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumArcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium arcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriumArcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematobacterMissouriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter missouriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMissouriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpMa2016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. MA2016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpMa2016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraSpCag700Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:700 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag700Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterDaecheongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter daecheongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterDaecheongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusHitonicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus hitonicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHitonicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGalbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces galbus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGalbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumGa0074140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium Ga0074140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGa0074140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumViolaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium violaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumViolaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterCelticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter celticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCelticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaDiazotrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia diazotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDiazotrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177nandEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177Nand Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177nandEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCongonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides congonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCongonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaceaeBacterium457259(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetaceae bacterium 4572_59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaceaeBacterium457259", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisPretoriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis pretoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisPretoriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrisomaLimiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrisoma limi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrisomaLimiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondromycesApiculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces apiculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChondromycesApiculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThoraltensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thoraltensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThoraltensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPHIGHO2_02_FULL_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcamd5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_69_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFujikuroiImi58289Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi IMI 58289 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumFujikuroiImi58289Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3654(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3654", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaSpJg1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. JG-1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpJg1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodalisGlossinidiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sodalis glossinidius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SodalisGlossinidiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TakifuguRubripesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Takifugu rubripes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TakifuguRubripesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasSpLm091(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. LM091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpLm091", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytosporaLeucostomaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cytospora leucostoma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CytosporaLeucostomaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumAdornatus1505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum adornatus 1505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermofilumAdornatus1505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaNodosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia nodosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaNodosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliihoefleaSp2wwCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliihoeflea sp. 2WW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliihoefleaSp2wwCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DentipellisFragilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dentipellis fragilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DentipellisFragilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KangiellaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kangiella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KangiellaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrospiraNitrosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumCymbalariaeDbvpg7215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae DBVPG#7215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EremotheciumCymbalariaeDbvpg7215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpPao19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAO19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpPao19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNecrophorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusFusiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus fusiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusFusiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicavibrioAeruginosavorusEpb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus EPB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusEpb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpSa39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. SA39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpSa39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumVinckeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vinckei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVinckeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumOrbiculareMaff240422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare MAFF 240422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculareMaff240422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaAtypica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella atypica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaAtypica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippusPlexippusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus plexippus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DanausPlexippusPlexippusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeOzaenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae ozaenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeOzaenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenturiaEffusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Venturia effusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VenturiaEffusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpRoot1310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusProvencensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusProvencensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriaceaeArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliconiusMelpomeneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Heliconius melpomene Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HeliconiusMelpomeneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaInopinataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scardovia inopinata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScardoviaInopinataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChiloscylliumPunctatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chiloscyllium punctatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChiloscylliumPunctatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLongus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio longus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLongus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiyogibacteriaBacteriumRifcsplowo212full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO212FULL4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo212full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterUpsaliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusRugosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus rugosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusRugosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CommensalibacterSpMx01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter sp. MX01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterSpMx01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpAr153(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. AR 15-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpAr153", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc4aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumGwb25626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium GWB2_56_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumGwb25626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSpNh8bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. NH8B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpNh8bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRutilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rutilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRutilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermabacterVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DermabacterVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpTb64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. TB64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpTb64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpGw460121014lb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. GW460121014LB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpGw460121014lb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def QuasibacillusThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Quasibacillus thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "QuasibacillusThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NisaeaDenitrificansDsm18348Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nisaea denitrificans DSM 18348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NisaeaDenitrificansDsm18348Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaMurrelli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella murrelli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaMurrelli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioplocaIngricaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioploca ingrica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioplocaIngricaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTubingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusTubingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasVranovensisDsm16006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis DSM 16006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasVranovensisDsm16006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPaucivoransNbrc100373Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia paucivorans NBRC 100373 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaPaucivoransNbrc100373Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSpUncmf366tsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF366Tsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf366tsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaSc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa SC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaSc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumWenxiniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium wenxiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumWenxiniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthromitusSpSfbturkeyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBturkey Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbturkeyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacterium13140cm6517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_65_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaDairenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaDairenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo202full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO202FULL4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo202full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasGardneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas gardneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasGardneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumRbg16408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RBG_16_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRbg16408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMallei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mallei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMallei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaGlumipatulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza glumipatula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaGlumipatulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumKbs89Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs89Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSp6palisep08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. 6PALISEP08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSp6palisep08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumCopahuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum copahuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumCopahuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaSpSk021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sp. SK021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSpSk021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocGelidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumExtorquens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum extorquens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumExtorquens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaBermudensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula bermudensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvularculaBermudensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCeti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCeti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusHnlc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisListeriNbrc13360Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri NBRC 13360 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisListeriNbrc13360Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0801Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0801Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumKoreenseCcug49689(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense CCUG 49689 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreenseCcug49689", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusRufusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus rufus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRufusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaAsymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia asymbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaAsymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpCch5a5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. CCH5A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpCch5a5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpRoot901(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot901", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EzakiellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ezakiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EzakiellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexistipesSinusarabici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flexistipes sinusarabici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlexistipesSinusarabici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwh6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaceaeBacterium15036681Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium 15-036681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacterium15036681Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterHeyliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heylii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeyliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterHepaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hepaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHepaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaWestfalica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia westfalica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaWestfalica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoaviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPseudoaviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraCactorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora cactorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraCactorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Andersenbacteria bacterium RIFCSPHIGHO2_01_FULL_46_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiumAgarilyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium agarilyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumAgarilyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSpGj21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. GJ21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpGj21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeyerozymaGuilliermondiiAtcc6260(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii ATCC 6260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondiiAtcc6260", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedClostridiumSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridium sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiumSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesThetaiotaomicronEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides thetaiotaomicron Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesThetaiotaomicronEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDigitatumPhi26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum PHI26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliumDigitatumPhi26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterMaritimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutibacterMaritimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusIngluviei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ingluviei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusIngluviei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraConfinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara confinis) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraConfinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTyphaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus typhae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTyphaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolibacterUsitatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solibacter usitatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolibacterUsitatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPHIGHO2_02_FULL_45_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsphigho202Full4518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisTac125(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TAC125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTac125", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs836Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-836 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs836Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaSuaedae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia suaedae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSuaedae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLigniniphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ligniniphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLigniniphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiodiazotrophaEndolucinida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endolucinida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndolucinida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaVestfoldensisDsm16212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis DSM 16212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisDsm16212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFeriruminatoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma feriruminatoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFeriruminatoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccomyxaSubellipsoideaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoideaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpYl58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. YL58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpYl58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifoxya1full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYA1FULL4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxya1full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmticiciaOligotrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emticicia oligotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmticiciaOligotrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumGenavense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium genavense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGenavense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusSpMilost2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. MilosT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpMilost2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaBaltica18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica 18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CellulophagaBaltica18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCorienseDsm10284Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum coriense DSM 10284 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCorienseDsm10284Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusFf33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus FF33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusFf33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAltiarchaealesArchaeonImc4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Altiarchaeales archaeon IMC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAltiarchaealesArchaeonImc4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioEzurae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ezurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioEzurae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf164(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf164", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichomonasVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichomonas vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichomonasVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisAtcc14393Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ATCC14393 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAtcc14393Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermobacterMarburgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusOrnithinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus ornithinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusOrnithinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TupaiaChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tupaia chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TupaiaChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuricataSuricattaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Suricata suricatta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuricataSuricattaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisAlexandrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis alexandrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisAlexandrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonajaTextilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonaja textilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonajaTextilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpUnc402clcol(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. UNC402CLCol graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpUnc402clcol", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeropyrumPernix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum pernix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeropyrumPernix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaNaganishiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania naganishii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaNaganishiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf125(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf125", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_43_11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL3811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesMarneffeiAtcc18224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei ATCC 18224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TalaromycesMarneffeiAtcc18224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumPhosphoreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium phosphoreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumPhosphoreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseusSubspNoncyanogenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus subsp. noncyanogenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseusSubspNoncyanogenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaSp6418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. 64-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSp6418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FilimonasLacunaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Filimonas lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FilimonasLacunaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HathewayaProteolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HathewayaProteolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaeumannomycesGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanohaloarchaeaArchaeonSg9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon SG9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonSg9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFOXYD1_FULL_36_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifoxyd1Full3611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasBadiaDsm17552Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas badia DSM 17552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonasBadiaDsm17552Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterorhabdusMucosicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus mucosicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusMucosicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwd23811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD23811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd23811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiploscapterPachys(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diploscapter pachys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiploscapterPachys", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpGib2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. GIB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpGib2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPantherisDsm15945Jcm12539Nbrc106106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris DSM 15945 JCM 12539 NBRC 106106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPantherisDsm15945Jcm12539Nbrc106106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetranychusUrticae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetranychus urticae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetranychusUrticae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrothermarchaeotaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermarchaeota archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrothermarchaeotaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSphaericus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSphaericus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActibacteriumAtlanticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium atlanticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumAtlanticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaMacrocephali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina macrocephali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMacrocephali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiensFb03509anEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens FB03509AN Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensFb03509anEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpDs20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. DS20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpDs20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaylyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baylyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaylyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterSuperfactusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter superfactus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterSuperfactusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataellaPhaffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataella phaffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataellaPhaffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpHzmCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. HZM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpHzmCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SymbiobacterMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacter mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SymbiobacterMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSalamae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica salamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaSalamae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesBarnesiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides barnesiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesBarnesiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StoquefichusSpSb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. SB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpSb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaLacunataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lacunata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLacunataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CupriavidusTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaseoulenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraseoulense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaseoulenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasChukchiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas chukchiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasChukchiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl21Mag121220Bin10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 MAG-121220-bin10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Mag121220Bin10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaAquamarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala aquamarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaAquamarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSpTwe2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. TWE2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpTwe2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobacterStenotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacter stenotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobacterStenotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumDg741Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg741Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaitoellaComplicataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saitoella complicata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaitoellaComplicataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubglaciescolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subglaciescola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubglaciescolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SordariaMacrosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sordaria macrospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SordariaMacrosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrilyobacterAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpNxc14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NXC14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNxc14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBenthicaKt99Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella benthica KT99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBenthicaKt99Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesPombeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKururiensisM130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis M130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensisM130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMontanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus montanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMontanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGaoshouyiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gaoshouyii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGaoshouyiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_55_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaSp4814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 48-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp4814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonadalesBacteriumGwc26120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadales bacterium GWC2_61_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadalesBacteriumGwc26120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospiraSpQh2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospira sp. QH-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospiraSpQh2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusMediterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumAo1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium AO1B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumAo1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeglectaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neglecta timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeglectaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogranumGelatinilyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halogranum gelatinilyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalogranumGelatinilyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinifilumFragileJcm15579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinifilum fragile JCM 15579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinifilumFragileJcm15579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumBalustinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium balustinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBalustinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydraVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydra vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydraVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusFonticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus fonticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFonticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaSpHeli48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. HelI48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpHeli48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxSaidenbachensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax saidenbachensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxSaidenbachensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBolteae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bolteae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBolteae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeSpMortierella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae sp. Mortierella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeSpMortierella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TumebacillusFlagellatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tumebacillus flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TumebacillusFlagellatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaMatsumotoenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora matsumotoense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMatsumotoenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpP6wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. P6W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpP6wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm35210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full5410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL5410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full5410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFormosensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas formosensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFormosensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAquivivus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter aquivivus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterAquivivus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumEpidermidicanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium epidermidicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEpidermidicanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergomycesPasteurianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmergomycesPasteurianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumSubglacialeExf2481Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale EXF-2481 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumSubglacialeExf2481Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumReuteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium reuteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumReuteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StagonosporaSpSrc1lsm3aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stagonospora sp. SRC1lsM3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StagonosporaSpSrc1lsm3aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumGlycinesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium glycines Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGlycinesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoaglandellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoaglandella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoaglandellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerriphaselusAmnicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus amnicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusAmnicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpWkb10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSpWkb10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraPelophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira pelophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraPelophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KalmanozymaBrasiliensisGhg001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis GHG001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensisGhg001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpDw54Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. DW54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpDw54Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpAu20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFrigorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsplowo212full5515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1742Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1742Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaPseudomalleiK96243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei K96243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiK96243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-79 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSpRim28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerovibrioVelox(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio velox graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioVelox", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSediminumDsm21906(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sediminum DSM 21906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSediminumDsm21906", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynchytriumMicrobalumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium microbalum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynchytriumMicrobalumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaCellobiosiphilaDsm17781(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila DSM 17781 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphilaDsm17781", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensDamuponensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens damuponensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensDamuponensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutisporaThermophilaDsm19022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lutispora thermophila DSM 19022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LutisporaThermophilaDsm19022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPuniceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola punicea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPuniceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp6c8div0013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 6C8DIV0013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp6c8div0013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDadantiiEch586(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch586", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpCag368(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag368", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumNorvegicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium norvegicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumNorvegicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumGwa24915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA2_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa24915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofastidiosumMethylthiophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanofastidiosum methylthiophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanofastidiosumMethylthiophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls87Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls87Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulusDsm18846Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus DSM 18846 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulusDsm18846Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa254124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_54_124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa254124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpWb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. WB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpWb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaShayeganii871Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria shayeganii 871 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaShayeganii871Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuniculiplasmaDivulgatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cuniculiplasma divulgatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CuniculiplasmaDivulgatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TropicimonasIsoalkanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tropicimonas isoalkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TropicimonasIsoalkanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasPantelleriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas pantelleriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasPantelleriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpIhbb10380Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. IHBB 10380 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpIhbb10380Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusCelericrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus celericrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCelericrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpPcc6303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC6303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc6303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacteriaBacteriumCg10238174Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacteria bacterium CG10238174 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacteriaBacteriumCg10238174Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3654Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3654 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3654Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa15613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA15613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa15613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep2538Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2538 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2538Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusVaccinostercusDsm20634Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus DSM 20634 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercusDsm20634Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisDx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris DX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisDx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumTaa166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium TAA166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumTaa166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterCapsulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterCapsulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaAerolatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma aerolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaAerolatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwh4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SenegalimassiliaAnaerobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Senegalimassilia anaerobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SenegalimassiliaAnaerobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaAurantifoliaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma aurantifolia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAurantifoliaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSolaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaSolaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerendipitaIndicaDsm11827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serendipita indica DSM 11827 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerendipitaIndicaDsm11827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsplowo212full4426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO212FULL4426 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo212full4426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrinicoccusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Urinicoccus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrinicoccusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilaChrysaetosChrysaetosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquila chrysaetos chrysaetos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquilaChrysaetosChrysaetosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusCaliditerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus caliditerrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusCaliditerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaSpMar201075Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. MAR201075 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpMar201075Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaeBacteriumUtcfx1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacteralesBacteriumFibro01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacterales bacterium Fibro_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacteralesBacteriumFibro01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveromycesLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KluyveromycesLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasStagniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas stagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseomonasStagniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasSpF0440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisXEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis X Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisXEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MargulisbacteriaBacteriumGwf2359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWF2359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwf2359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumRifcsplowo201full4519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL4519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full4519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium6732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 67-32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KiloniellaSpongiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KiloniellaSpongiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuganellaSpRoot336d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root336D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot336d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumRifcsphigho202full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPHIGHO202FULL3913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsphigho202full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusVersutus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusVersutus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCereus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCereus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StemphyliumLycopersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stemphylium lycopersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StemphyliumLycopersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpM2012083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. M2012083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpM2012083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaStr5aAcyrthosiphonPisumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola str. 5A (Acyrthosiphon pisum) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaStr5aAcyrthosiphonPisumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaBacteriumMs0242aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS0242A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0242aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusSpTaa43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus sp. TAA 43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSpTaa43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BabesiaBigeminaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Babesia bigemina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BabesiaBigeminaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LyngbyaSpPcc8106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lyngbya sp. PCC8106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LyngbyaSpPcc8106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremblayaPrincepsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya princeps Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TremblayaPrincepsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaSp4h37ye5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. 4H37YE5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSp4h37ye5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraHampsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hampsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHampsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuribacillusStibiiarsenatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus stibiiarsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusStibiiarsenatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrucellaAbortus2308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brucella abortus 2308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrucellaAbortus2308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHokkaidonensisJcm18461(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis JCM 18461 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensisJcm18461", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDiolivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDiolivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpPa01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. PA01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpPa01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SingulisphaeraAcidiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraAcidiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSpAu1208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. AU1208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpAu1208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaBannensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bannensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBannensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaLecithinolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema lecithinolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaLecithinolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeofusicoccumParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeofusicoccumParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeotaArchaeonScgcAaa011G17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon SCGC AAA011-G17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeonScgcAaa011G17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpM26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. M26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpM26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTerreusNih2624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus terreus NIH2624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusTerreusNih2624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMeleagridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma meleagridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMeleagridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumPseudograminearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium pseudograminearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumPseudograminearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VaribaculumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumLentocellumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium lentocellum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLentocellumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSuwonensisJ42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpBa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. ba1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumSpBa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAmmoniagenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ammoniagenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAmmoniagenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterUrativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter urativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterUrativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAviariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAviariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSaguiniDsm23967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini DSM 23967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumSaguiniDsm23967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb241528o2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241528O2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528o2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumPleistocenium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium pleistocenium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumPleistocenium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotusColobopsisObliquus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusColobopsisObliquus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraBriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira briensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraBriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpKg01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KG01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKg01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobotrysFlagransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys flagrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysFlagransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumHqm9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium HQM9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumHqm9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaSennetsu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sennetsu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSennetsu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaphrinaDeformansPycc5710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Taphrina deformans PYCC 5710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TaphrinaDeformansPycc5710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpNfr13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. NFR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpNfr13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusDamnosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus damnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusDamnosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusDamuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus damuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusDamuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumBakiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium bakii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumBakiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSpC1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sp. C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSpC1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasArtemidisF0399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas artemidis F0399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasArtemidisF0399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpHeronCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. Heron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHeronCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmazonaCollaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amazona collaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmazonaCollaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaCornellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria cornellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaCornellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCl95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. cl95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCl95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusDabanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus dabanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusDabanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumCg2303520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium CG2_30_35_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumCg2303520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucoagaricusSpSymccosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucoagaricus sp. SymCcos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucoagaricusSpSymccosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpYr527(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. YR527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpYr527", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOvis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella ovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOvis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiobacterAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dethiobacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DethiobacterAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg1023112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1023112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1023112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumKhcpx20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KHCPX20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKhcpx20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolactibacillusAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaPlatycodiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asaia platycodi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsaiaPlatycodiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp32352(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32352 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32352", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomonileTiedjeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomonile tiedjei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomonileTiedjeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiumSpinosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium spinosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpinosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesCerinusSubspCerinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agromyces cerinus subsp. cerinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgromycesCerinusSubspCerinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpYr768(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YR768 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYr768", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprothermobacterPlatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter platensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterPlatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Actinomyces(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Actinomyces", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpLorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. LOR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpLorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusRubiinfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus rubiinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusRubiinfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SucciniclasticumRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SucciniclasticumRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyopneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpYi23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. YI23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpYi23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterWoliniiSh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii SH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterWoliniiSh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaZhejiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia zhejiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaZhejiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvensLd2006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens LD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvensLd2006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylibacterXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylibacter xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylibacterXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluoribacterGormaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter gormanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FluoribacterGormaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUvarumDsm19971(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum DSM 19971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusUvarumDsm19971", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusBoritolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus boritolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusBoritolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMinorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus minor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMinorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpNsp222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpNsp222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaNeapolitana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga neapolitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaNeapolitana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpAn1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. AN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpAn1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSaccharevitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena saccharevitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSaccharevitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0407Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0407 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0407Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumRbg166712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium RBG_16_67_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumRbg166712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusPleuropneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpAst10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. AST10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfurimonasSpAst10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBroomiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira broomii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBroomiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioSpOa2007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. OA-2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpOa2007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaGranulosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga granulosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGranulosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_38_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RahnellaSpY9602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella sp. Y9602 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RahnellaSpY9602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaginellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vaginella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VaginellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAntriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus antri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAntriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CompetibacterDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Competibacter denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CompetibacterDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSomnus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus somnus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSomnus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenesCect7868Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio aerogenes CECT 7868 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioAerogenesCect7868Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetofabaAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetofaba australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetofabaAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApodemiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apodemi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApodemiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumCopahuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum copahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumCopahuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3926 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumXylanolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium xylanolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumXylanolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilibacterAurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabilibacterAurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwb1446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB1446 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb1446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumLithotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum lithotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumLithotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaGratianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella gratiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaGratianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrahymenaThermophilaSb210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila SB210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrahymenaThermophilaSb210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterThiogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter thiogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterThiogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoldemaniaFiliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holdemania filiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaFiliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfAcanthamoeba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Acanthamoeba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfAcanthamoeba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHyicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus hyicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHyicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducensTx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens TX1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensTx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalonomonasRubraDsm5091Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Malonomonas rubra DSM 5091 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MalonomonasRubraDsm5091Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNageliiDsm13675(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii DSM 13675 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNageliiDsm13675", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasSpJ29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. J29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJ29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumSpMarseillep3275Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. MarseilleP3275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumSpMarseillep3275Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerGoleimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopiger goleimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopigerGoleimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusSalarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus salarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSalarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesColeocanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces coleocanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesColeocanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusParalvinellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus paralvinellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusParalvinellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoactinosporaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinospora rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoactinosporaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TurneriellaParvaDsm21527Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Turneriella parva DSM 21527 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TurneriellaParvaDsm21527Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumHydrothermaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum hydrothermale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumHydrothermaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobacillusAlkalidiazotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus alkalidiazotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusAlkalidiazotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fumarioli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFumarioliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFarraginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus farraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFarraginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMuridarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter muridarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMuridarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusMauleonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus mauleonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusMauleonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwf24415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWF24415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwf24415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodovibrioSp970Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodovibrio sp. 970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiorhodovibrioSp970Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumSpMaddingleyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. Maddingley Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMaddingleyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFructivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fructivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFructivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_43_17b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSiliginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus siliginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSiliginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraInfestansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora infestans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraInfestansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumTodarodisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum todarodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumTodarodisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxTemperansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax temperans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxTemperansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaSpNd6we1a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rothia sp. ND6WE1A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RothiaSpNd6we1a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenaeusVannamei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penaeus vannamei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenaeusVannamei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMooreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solobacterium moorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolobacteriumMooreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrahymenaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrahymenaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumCeb3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium CEB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumCeb3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterTibetensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RufibacterTibetensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpUcdkl12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpJsc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. JSC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpJsc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidiaBacteriumGa0077558Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium Ga0077558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacteriumGa0077558Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FungalSpNo14919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.14919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo14919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraSantarosaiSerovarShermaniStrLt821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira santarosai serovar Shermani str. LT 821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraSantarosaiSerovarShermaniStrLt821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiCcug35545Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CCUG 35545 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCcug35545Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharogumiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharogumia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharogumiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensisVarSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Camellia sinensis var. sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CamelliaSinensisVarSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSabaudienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sabaudiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSabaudienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_43_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrisporobacterGlycolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter glycolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterGlycolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhoenicibacterCongonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phoenicibacter congonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhoenicibacterCongonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumSpJcm19050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. JCM 19050 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJcm19050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaRuminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ruminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRuminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusLacustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaHermannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia hermannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaHermannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaChitosanitabidaAtccBaa476Nbrc102408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida ATCC BAA-476 NBRC 102408 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabidaAtccBaa476Nbrc102408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KangiellaAquimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kangiella aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KangiellaAquimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaFijiensisCirad86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis CIRAD86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensisCirad86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpOralTaxon020StrF0370Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. oral taxon 020 str. F0370 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSpOralTaxon020StrF0370Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaVietnamiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia vietnamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaVietnamiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermonemaRossianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermonema rossianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermonemaRossianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumPv82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum PV8-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumPv82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LihuaxuellaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lihuaxuella thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LihuaxuellaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSzulgaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium szulgai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSzulgaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuciliaCuprinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lucilia cuprina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuciliaCuprinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaGinsengisoliNbrc100965Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli NBRC 100965 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoliNbrc100965Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoclostridiumDifficileCd160Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile CD160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficileCd160Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SubdoligranulumSpCag314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. CAG:314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumSpCag314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoxodontaAfricanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loxodonta africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoxodontaAfricanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpVkmb2647Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. VKMB2647 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpVkmb2647Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycetalesBacteriumActino01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetales bacterium Actino_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycetalesBacteriumActino01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermanaeromonasToyohensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaSpTsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. TS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpTsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraWolbachiiSerovarCodiceStrCdcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolbachii serovar Codice str. CDC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolbachiiSerovarCodiceStrCdcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaPacificaDsm45543(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiostomaPiceaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiostoma piceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiostomaPiceaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAmericanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAmericanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StegastesPartitusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stegastes partitus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StegastesPartitusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumJosui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium josui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumJosui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpOsyseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OSYSE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOsyseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusDonghaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusDonghaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacleayaCordata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macleaya cordata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacleayaCordata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUrhb0015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URHB0015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUrhb0015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacterium4484171(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484171", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquiflexumBalticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquiflexum balticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquiflexumBalticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaphidocelisSubcapitata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Raphidocelis subcapitata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RaphidocelisSubcapitata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFluorescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohalieaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudohaliea rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudohalieaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNodensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nodensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNodensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc136108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC136108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc136108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusLaumondiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus laumondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLaumondiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NegativibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Negativibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NegativibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumYad3003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YAD3003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYad3003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KribbellaFlavida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kribbella flavida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KribbellaFlavida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumSp46296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum sp. 46_296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumSp46296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusOncorhynchiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus oncorhynchi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusOncorhynchiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimonasMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpNa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. NA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpNa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg164410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_44_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg164410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusAwamoriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus awamori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusAwamoriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_38_11b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg166485(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_64_85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166485", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumGondwanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumCamembertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium camemberti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCamembertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaDispersaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea dispersa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaDispersaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphenodonPunctatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphenodon punctatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphenodonPunctatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFurnissiiNctc11218Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio furnissii NCTC 11218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioFurnissiiNctc11218Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpA3h3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. A3H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpA3h3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LinderinaPennispora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Linderina pennispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LinderinaPennispora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAtcc13867(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ATCC 13867 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAtcc13867", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Mg1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumThoeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium thoenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumThoeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiaBacteriumCg1024814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium CG1024814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumCg1024814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaNamhaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olleya namhaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlleyaNamhaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaFrappieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga frappieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaFrappieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenuloplanesJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenuloplanes japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenuloplanesJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AidingimonasHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aidingimonas halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AidingimonasHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhenazinium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenazinium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenazinium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaColombicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atta colombica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AttaColombicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioSpJcm19062Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. JCM 19062 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpJcm19062Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfopilaAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfopilaAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HomoSapiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Homo sapiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HomoSapiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharolyticumK10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum K10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumK10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaBeijingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaBeijingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsplowo201full4813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPLOWO201FULL4813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsplowo201full4813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_54_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterTrogontum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter trogontum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTrogontum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaTaiwanensisDsm12281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis DSM 12281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensisDsm12281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TindalliaCaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tindallia californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TindalliaCaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusCurtisiiAtcc35241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC35241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc35241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WigglesworthiaGlossinidiaSpGmoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gmo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGmoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerostipesSp992a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 992a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp992a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumWenxiniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium wenxiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumWenxiniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaYangpuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora yangpuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaYangpuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeeuwenhoekiellaMarinoflavaDsm3653(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava DSM 3653 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaDsm3653", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpR11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruegeria sp. R11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuegeriaSpR11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusReuteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho202full5616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL5616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full5616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabilibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasAzotifigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas azotifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAzotifigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumFioriniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFioriniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterGeojensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter geojensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGeojensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 29_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKansasii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumWanjuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium wanjuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumWanjuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RozellaAllomycisCsf55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rozella allomycis CSF55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RozellaAllomycisCsf55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaPachydermatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malassezia pachydermatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalasseziaPachydermatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSp6526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 65-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp14657030Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1465703.0 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14657030Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomicrobiumPiriformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomicrobium piriforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomicrobiumPiriformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumTropicaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum tropicale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumTropicaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk1080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK1080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk1080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumGeorgienseDsm11526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense DSM 11526 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgienseDsm11526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTegetincolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasGotlandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas gotlandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasGotlandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLmg23823Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis LMG23823 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLmg23823Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeurosporaTetraspermaFgsc2509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma FGSC 2509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeurosporaTetraspermaFgsc2509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH053Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H053 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH053Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_52_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusObeumAtcc29174(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus obeum ATCC29174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusObeumAtcc29174", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixSpPcc7601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix sp. PCC 7601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolypothrixSpPcc7601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpDsiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dsi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDsiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpBab2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. BAB2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalobacillusSpBab2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpSt2l12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraSpBsl9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. BSL-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpBsl9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp7243faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 7243FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp7243faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpF0108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpAg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ag1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_33_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterNoctilucicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSocranskiiParedisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii paredis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiParedisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TachikawaeaGelatinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tachikawaea gelatinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TachikawaeaGelatinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioJasicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio jasicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioJasicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_37_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonAb25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon AB_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonAb25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumSomerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium somerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSomerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymomonasMobilisAtcc10988Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ATCC10988 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZymomonasMobilisAtcc10988Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumDg72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaLaeviribosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cohnella laeviribosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CohnellaLaeviribosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraHumireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera humireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraHumireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumUrinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum urinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumUrinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumPhenoliresistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium phenoliresistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumPhenoliresistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaAerilataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microvirga aerilata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrovirgaAerilataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwellbacteriaBacteriumRifcsplowo201full4810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO201FULL4810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo201full4810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriRch2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri RCH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriRch2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrincolaLacisaponensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola lacisaponensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrincolaLacisaponensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterRoseosalivariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumIslandicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium islandicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumIslandicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusSpC254Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus sp. C254 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusSpC254Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumSalpingitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium salpingitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumSalpingitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpCf079(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. CF079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpCf079", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1025068(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_50_68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025068", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpErg5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ERG5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpErg5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfTrabutinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCrevioricanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas crevioricanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCrevioricanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibaculumBaratangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutibaculum baratangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutibaculumBaratangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpNd2010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. ND2010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpNd2010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobisporaBispora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobispora bispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobisporaBispora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumAcidaminophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium acidaminophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumAcidaminophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumAviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium avium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MycobacteriumAviumAviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrospermumStagnale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermum stagnale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CylindrospermumStagnale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterHarbinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHarbinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFrumenti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFrumenti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaCaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumLinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum linum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumLinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMexicanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mexicana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaMexicanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMatruchotiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium matruchotii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMatruchotiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatalinimonasAlkaloidigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catalinimonas alkaloidigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatalinimonasAlkaloidigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaFlorencaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella florencae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaFlorencaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumSpOscr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidium sp. OSCR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidiumSpOscr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCantonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus cantonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCantonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumLimnaeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum limnaeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumLimnaeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreeseniaAngustaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Andreesenia angusta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AndreeseniaAngustaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBoroniphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus boroniphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusBoroniphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumSpPmmr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium sp. PMMR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidobacteriumSpPmmr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedEubacteriumSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Eubacterium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedEubacteriumSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_50_9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full509bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumCosmeticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium cosmeticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCosmeticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaLacustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Derxia lacustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DerxiaLacustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusYayanosii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus yayanosii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusYayanosii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit016242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 01-6242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit016242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsplowo201full4531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPLOWO201FULL4531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsplowo201full4531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpUnc363mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC363MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc363mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlutamicibacterHalophytocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter halophytocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterHalophytocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VesicomyosociusOkutaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vesicomyosocius okutanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VesicomyosociusOkutaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThraustothecaClavataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thraustotheca clavata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThraustothecaClavataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFf3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaSpSjp92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. SJP92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpSjp92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFonticolaAuap2cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola AUAP2C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaAuap2cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchleiferiaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schleiferia thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchleiferiaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSubtropicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium subtropicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSubtropicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP1xp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P1XP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP1xp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaPersica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaPersica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAa0539Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA0539 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa0539Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GynuellaSunshinyiiYc6258(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii YC6258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GynuellaSunshinyiiYc6258", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaConfusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella confusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaConfusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumCsp18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CSP1-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCsp18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFujikuroi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumFujikuroi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusMarinonascens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusMarinonascens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaAstilbisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asaia astilbis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsaiaAstilbisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitreicellaSp357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citreicella sp. 357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitreicellaSp357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAgnetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus agnetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAgnetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag354Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:354 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag354Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonisporaThiosulfatigenesDsm11270(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes DSM 11270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenesDsm11270", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMultivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaMultivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpHysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. HYS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpHysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19046(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM19046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJcm19046", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaRadingae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia radingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaRadingae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKalixensisDsm16043(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kalixensis DSM 16043 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKalixensisDsm16043", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAscendensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ascendens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAscendensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumRuminicolaJcm14822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola JCM 14822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicolaJcm14822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensMesophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens mesophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensMesophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaShahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia shahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaShahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSp209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PestalotiopsisFiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PestalotiopsisFiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferSpTw10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer sp. TW10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnsiferSpTw10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_48_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPolysaccharolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] polysaccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolysaccharolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpFd1xmdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. fd1xmd Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFd1xmdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospiraSpQh2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospira sp. QH-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospiraSpQh2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaElongataAg77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mortierella elongata AG-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MortierellaElongataAg77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevisNbrc100599Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis NBRC100599 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisNbrc100599Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeramiaOrbicularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaeramia orbicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaeramiaOrbicularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNucleicultrixAmoebiphilaFs5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nucleicultrix amoebiphila FS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNucleicultrixAmoebiphilaFs5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisAnt505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ANT505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAnt505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag167Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag167Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KingellaOralisAtcc51147Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kingella oralis ATCC 51147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KingellaOralisAtcc51147Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaDejecticolaCbs10117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola CBS 10117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KwoniellaDejecticolaCbs10117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCapitovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium capitovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCapitovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumSpMarseillep3275(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. MarseilleP3275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumSpMarseillep3275", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaCohaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia cohaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LampropediaCohaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GouaniaWilldenowiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gouania willdenowi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GouaniaWilldenowiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllokutzneriaAlbataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allokutzneria albata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllokutzneriaAlbataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19056(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19056", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpNr41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. NR 4-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpNr41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaLitoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma litorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaLitoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpA28lCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. A28L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpA28lCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FasciolaGiganticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fasciola gigantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FasciolaGiganticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Raac196(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 RAAC_196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Raac196", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistliaConsotensisUsba355(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tistlia consotensis USBA 355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TistliaConsotensisUsba355", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaAquimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kangiella aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KangiellaAquimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaOvataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa ovata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporomusaOvataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApisCeranaCerana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Apis cerana cerana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ApisCeranaCerana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifoxya2full329Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFOXYA2FULL329 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifoxya2full329Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolobusPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolobusPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumAmericanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium americanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumAmericanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlgidusDsm15638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus algidus DSM 15638 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlgidusDsm15638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeCot184oh4590Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae COT184OH4590 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonadaceaeCot184oh4590Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumCuenoti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium cuenoti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumCuenoti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus glaucus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusGlaucusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusAzorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius azorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAzorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllochromatiumWarmingii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium warmingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumWarmingii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifoxyd1full3729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYD1FULL3729 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyd1full3729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpMitacek01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Mitacek01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpMitacek01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAmyloliquefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaZoodegmatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria zoodegmatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaZoodegmatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterGlacialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterGlacialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTetanomorphumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetanomorphum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetanomorphumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriaSymbiontBfo1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusHansupusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus hansupus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcusHansupusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRifcsphigho212full389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPHIGHO212FULL389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsphigho212full389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSpSos3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. SOS3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpSos3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HugenholtziaRoseolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HugenholtziaRoseolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSpPkCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. PK Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpPkCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesBouchesdurhonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces bouchesdurhonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesBouchesdurhonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycosphaerellaPini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycosphaerella pini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycosphaerellaPini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full3819Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3819 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3819Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacterium3541Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium 35_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacterium3541Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FinegoldiaMagnaAtcc53516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC53516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc53516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSpongiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpongiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerroplasmaAcidiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferroplasma acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerroplasmaAcidiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaccariaAmethystinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laccaria amethystina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaccariaAmethystinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleurocapsaSpPcc7327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHarbinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHarbinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_48_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterCibinongensis4h1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis 4H-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterCibinongensis4h1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumSar86eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJoosteiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium joostei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJoosteiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMoraviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus moraviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMoraviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCellulosilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cellulosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCellulosilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseofilumReptotaenium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseofilumReptotaenium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusTeuberiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus teuberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VagococcusTeuberiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterTroitsensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter troitsensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterTroitsensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwa25343(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_53_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa25343", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJdr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JDR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJdr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus concavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusConcavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpIng2d1gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ING2D1G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpIng2d1gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpMed152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. MED152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpMed152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumValentinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium valentinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumValentinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumIndologenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indologenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndologenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbidosporaMongoliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora mongoliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaMongoliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpM2012083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. M2012083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpM2012083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaeBacteriumDg1235Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobiae bacterium DG1235 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaeBacteriumDg1235Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumParvumAcb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum ACB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OribacteriumParvumAcb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatitaleaTepidiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea tepidiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaTepidiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSulfidiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sulfidiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSulfidiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifoxyd1full3927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFOXYD1FULL3927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifoxyd1full3927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaeromonasToyohensisTobe(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis ToBE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensisTobe", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusProomiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus proomii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusProomiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBifermentansDsm20003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus bifermentans DSM 20003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBifermentansDsm20003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheionarchaeaArchaeonDg701(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon DG-70-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeonDg701", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVermiculataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vermiculata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaVermiculataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccalesArchaeonRumenM2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon RumEn M2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeonRumenM2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full3914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL3914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full3914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAlkalisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer alkalisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferAlkalisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusicatenibacterSaccharivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusicatenibacter saccharivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusicatenibacterSaccharivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisAlaskensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis alaskensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisAlaskensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorKristjanssonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor kristjanssonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorKristjanssonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetrotogaMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Petrotoga mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PetrotogaMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph899Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph899Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpDi166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. DI166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpDi166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpRv1423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. RV1423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpRv1423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConexibacterWoeseiDsm14684Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei DSM14684 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiDsm14684Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumAnimalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAnimalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialemoniopsisCurvataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialemoniopsis curvata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialemoniopsisCurvataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeothermobacterSpEprmEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geothermobacter sp. EPRM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeothermobacterSpEprmEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariivitaBoseongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aestuariivita boseongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AestuariivitaBoseongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusCallidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus callidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusCallidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumElkaniiWsm1741(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM1741 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm1741", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLjungdahlii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ljungdahlii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLjungdahlii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntamoebaHistolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Entamoeba histolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EntamoebaHistolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrdosporaColligataOc4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ordospora colligata OC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OrdosporaColligataOc4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporobacterTermitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporobacter termitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporobacterTermitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg2303621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAlkalescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alkalescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlkalescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacteraceaeBacterium4484166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacteraceae bacterium 4484_166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacteraceaeBacterium4484166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaTestudinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella testudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaTestudinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacterium13220cm5510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_2_20CM_55_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13220cm5510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEan1pec(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EAN1pec graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEan1pec", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumStanieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium stanieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumStanieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiPam55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii PAM55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiPam55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpF0494Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0494Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeckwithbacteriaBacteriumGw2011gwc14916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWC14916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwc14916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumIcenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium icense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumIcenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaCanimorsusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canimorsus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanimorsusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrunusYedoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prunus yedoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrunusYedoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCch5f6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCH5F6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCch5f6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalofilumOchraceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halofilum ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalofilumOchraceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasSpBiir7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. BIIR7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpBiir7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpRim11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLactisRw25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lactis RW2-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumLactisRw25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpQlwp1data2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. QLWP1DATA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpQlwp1data2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumSp4354a2faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. 4354A2FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SubdoligranulumSp4354a2faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPorphyrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas porphyrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPorphyrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot149(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot149", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo202full4516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO202FULL4516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo202full4516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumHalorespiransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespiransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13120cm25314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_20CM_2_53_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13120cm25314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpGa0074138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. Ga0074138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpGa0074138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpLeaf41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpW121067Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. W121067 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpW121067Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilisNctc9343Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis NCTC 9343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisNctc9343Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaJiangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jiangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaJiangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumPhosphoreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium phosphoreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumPhosphoreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumAsp1005a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium ASP10-05a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumAsp1005a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumSp1860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. 1860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumSp1860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonEquinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton equinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichophytonEquinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf22816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF22816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf22816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThecamonasTrahensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thecamonas trahens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThecamonasTrahensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpIdoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. IDO Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpIdoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterAntarcticusDsm21422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Maribacter antarcticus DSM 21422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MaribacterAntarcticusDsm21422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCaseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus casei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCaseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7336Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7336Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusCasseliflavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus casseliflavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterococcusCasseliflavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAssamensisDsm18201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis DSM 18201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAssamensisDsm18201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgicolaSagamiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algicola sagamiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgicolaSagamiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusEurythermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus eurythermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusEurythermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5065(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5065 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5065", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraFabianiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera fabianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraFabianiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpN324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. N324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpN324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaZobelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina zobellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaZobelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratireductorIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnditaleaAndensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anditalea andensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnditaleaAndensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumCg10239135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium CG10239135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumCg10239135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPacinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio pacinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioPacinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSp4h375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. 4H375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSp4h375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaCornellensisFslF60969(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria cornellensis FSL F6-0969 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaCornellensisFslF60969", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMagnumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium magnum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMagnumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSp90(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. 90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSp90", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoruegeriaSpSk021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sp. SK021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSpSk021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasSpHgc4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. HGC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpHgc4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSp6728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 67-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc1062Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC1062 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc1062Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumSuecicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumSuecicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumAo1cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium AO1C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumAo1cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAljt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAljt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusComes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus comes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprococcusComes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinococcusMultilocularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus multilocularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EchinococcusMultilocularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterPersicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPersicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusSpMm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus sp. MM2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylovorusSpMm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLincolnensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lincolnensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLincolnensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag552(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag552", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSatsumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSatsumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4526 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasSpWbc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas sp. WBC-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasSpWbc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierelliaBacteriumKa00581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tissierellia bacterium KA00581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TissierelliaBacteriumKa00581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydialesBacterium3826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiales bacterium 38-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydialesBacterium3826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPallidipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina pallidipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaPallidipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiostomaFloridaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Branchiostoma floridae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BranchiostomaFloridaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusSpKu2611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU2-6(11) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu2611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1986Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1986 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1986Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroplitisDemolitorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microplitis demolitor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicroplitisDemolitorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharimonasAalborgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharimonas aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharimonasAalborgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpPamc26628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMastitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mastitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMastitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyramidobacterPiscolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter piscolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterPiscolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PusillimonasNoertemanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas noertemannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PusillimonasNoertemanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaVladivostokensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita vladivostokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AequorivitaVladivostokensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_45_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf180Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf180 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf180Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCatalpaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus catalpae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCatalpaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full5423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL5423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full5423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCamporealensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium camporealensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCamporealensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpOralTaxon126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaVarigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpG161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. G161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpG161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TupaiaChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tupaia chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TupaiaChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesDarlingi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles darlingi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesDarlingi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumThailandenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium thailandense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumThailandenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaCremeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora cremea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCremeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu069(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu069", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeobacterKilaueensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter kilaueensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeobacterKilaueensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusTerranovensisDsm18919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis DSM 18919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensisDsm18919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PopulusTrichocarpaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Populus trichocarpa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PopulusTrichocarpaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetus8240(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus 8240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetus8240", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwelCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWEL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwelCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasSpDh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. DH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpDh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumLividumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Janthinobacterium lividum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JanthinobacteriumLividumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb245a518a17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518A17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518a17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAdhaerensOv14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ensifer adhaerens OV14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnsiferAdhaerensOv14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc7509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC7509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc7509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBeddingiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus beddingii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBeddingiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumRifcsplowo202full5747(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO202FULL5747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo202full5747", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAcetoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum acetoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAcetoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalieaceaeBacteriumImcc3088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halieaceae bacterium IMCC3088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalieaceaeBacteriumImcc3088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoenixDactyliferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phoenix dactylifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhoenixDactyliferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJiangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus jiangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusJiangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumPopuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum populi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumPopuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumCg1024326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CG1_02_43_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCg1024326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5421bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5421b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5421bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYD1_FULL_46_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyd1Full4619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaSpGbbuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riesia sp. GBBU Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiesiaSpGbbuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorientalisRegularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis regularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorientalisRegularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFortisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioFortisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsplowo212full4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPLOWO212FULL4520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsplowo212full4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomycesPercursusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces percursus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomycesPercursusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumRedseas34b6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS34B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas34b6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberBorchiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tuber borchii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuberBorchiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumVaccinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium vaccinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumVaccinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpQhl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. QHL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpQhl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaMesophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaMesophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusYedoensisVarNudifloraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prunus yedoensis var. nudiflora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrunusYedoensisVarNudifloraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SymbiobacterMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacter mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SymbiobacterMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonghaparkiaSpRoot332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonghaparkia sp. Root332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonghaparkiaSpRoot332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExidiaGlandulosaHhb12029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exidia glandulosa HHB12029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExidiaGlandulosaHhb12029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpLsjc280b00(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSJC280B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLsjc280b00", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetosphaeriaTurcicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Setosphaeria turcica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SetosphaeriaTurcicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterConcretionisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter concretionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterConcretionisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShuttleworthiaSatellesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shuttleworthia satelles Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShuttleworthiaSatellesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpYr568Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. YR568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpYr568Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumJilantaiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium jilantaiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumJilantaiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusSingularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus singularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSingularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonadalesBacterium66474Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 66-474 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium66474Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiellaGlossodoripedisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterArsenitoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter arsenitoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterArsenitoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GanodermaSinenseZz02141(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ganoderma sinense ZZ0214-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GanodermaSinenseZz02141", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpCl154Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. CL154 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpCl154Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNasicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces nasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNasicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeyerozymaSpJa9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meyerozyma sp. JA9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeyerozymaSpJa9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElizabethkingiaAnophelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia anophelis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaAnophelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StomatobaculumLongumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stomatobaculum longum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StomatobaculumLongumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Bacterium3363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium 336/3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Bacterium3363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCaccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCaccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScheffersomycesStipitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScheffersomycesStipitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb14412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB14412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb14412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwf13410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF13410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf13410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHalmapalusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halmapalus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHalmapalusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH073Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH073Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumSpZwu0009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. ZWU0009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpZwu0009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa300d14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA300D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa300d14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosynechococcusSpNk55aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus sp. NK55a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusSpNk55aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElaeophoraElaphi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elaeophora elaphi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElaeophoraElaphi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat28573Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28573 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28573Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0604Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0604Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBungoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bungoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBungoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaHoshinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella hoshinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaHoshinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag465Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:465 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag465Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfDactylopiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusDsm446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius DSM446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusDsm446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaIhuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella ihuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIhuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrobasidiumTorrendiiFp15055Ss10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii FP15055 ss-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendiiFp15055Ss10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1025115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharospirillumImpatiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharospirillum impatiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharospirillumImpatiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpEr1aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. ER1A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEr1aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriTs44Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri TS44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriTs44Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesBailii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParachlamydiaSpC2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia sp. C2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaSpC2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AplysiaCalifornicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aplysia californica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AplysiaCalifornicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMandeliiPd30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii PD30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandeliiPd30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpNrrlb16314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenoanaerobacteriumSaccharovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenoanaerobacterium saccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenoanaerobacteriumSaccharovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumFalciparum3d7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum 3D7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumFalciparum3d7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrimonasFerrugineaDsm30193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea DSM 30193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TerrimonasFerrugineaDsm30193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipaludibacillusAurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus aurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudophaeobacterLeonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter leonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterLeonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaFryxellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella fryxellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaFryxellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh7805Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7805 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7805Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBohemicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bohemicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBohemicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpEp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. EP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpEp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimicrobiumPachnodaeJcm13526Nbrc107786Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylanimicrobium pachnodae JCM 13526 NBRC 107786 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XylanimicrobiumPachnodaeJcm13526Nbrc107786Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasHalodenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSaudimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusCremeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus cremeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusCremeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpCch5a5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. CCH5A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpCch5a5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasSpJ29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. J29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJ29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1397(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_39_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1397", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo201full5215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL5215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full5215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThiodiazotrophaEndoloripesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endoloripes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndoloripesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaOlei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea olei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaOlei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumCg1023735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG1_02_37_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg1023735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomeilibacteriaBacteriumRifcsplowo201full5215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL5215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full5215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterAalborgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterAalborgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp360mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 360MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSp360mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonEplasmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Eplasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonEplasmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterArilaitensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter arilaitensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterArilaitensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaceaeBacteriumHl53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarinaceae bacterium HL-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaceaeBacteriumHl53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbidovulumXiamenense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Albidovulum xiamenense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlbidovulumXiamenense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNc2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaYeatsiiGm274b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii GM274B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaYeatsiiGm274b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpUrhb0020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. URHB0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpUrhb0020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgicolaSagamiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algicola sagamiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgicolaSagamiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeroglobusGeminatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeroglobus geminatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeroglobusGeminatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaDagmatisAtcc43325(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis ATCC 43325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaDagmatisAtcc43325", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArlettaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpPc13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. PC13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpPc13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorQuimbayensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloramator quimbayensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloramatorQuimbayensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusAdriaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus adriaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusAdriaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpMg162(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. mg162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg162", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_12_FULL_45_19b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_47_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AiluropodaMelanoleucaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ailuropoda melanoleuca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AiluropodaMelanoleucaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumGw2011gwa24711bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24711b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24711bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTtu2014080ascCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TTU2014-080ASC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTtu2014080ascCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkaliflexusImshenetskiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkaliflexus imshenetskii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkaliflexusImshenetskiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichomitusSqualensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dichomitus squalens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DichomitusSqualensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCl6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumCoe1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium COE1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumCoe1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasMedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas media graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasMedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasCapnocytophagoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacteralesBacteriumRifoxyb1full6716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFOXYB1FULL6716 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifoxyb1full6716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiniumEndosymbiontCbtq1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cBtQ1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCbtq1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaHenselaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella henselae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaHenselaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho201full4098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO201FULL4098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho201full4098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumMedpeswsndg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaStellulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stappia stellulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StappiaStellulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaBacilliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo202full5736Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL5736 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full5736Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumPaludisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium paludis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumPaludisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpG5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. G5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpG5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacteriumRaap1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium RAAP-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumRaap1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GillisiaSpCal575Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. CAL575 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpCal575Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiisalibacterPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiisalibacter paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiisalibacterPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag169(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag169", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAgglomeransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea agglomerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaAgglomeransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyd2full3415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYD2FULL3415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyd2full3415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreneyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freneyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFreneyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpAccc05744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ACCC05744 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpAccc05744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMobaraensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mobaraensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMobaraensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChondromycesCrocatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces crocatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChondromycesCrocatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoclostridiumPhocaeenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phocaeense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhocaeenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JatrophihabitansEndophyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jatrophihabitans endophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JatrophihabitansEndophyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaSpAngs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacterium4484255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium 4484255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacterium4484255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaLansingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella lansingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaLansingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGp183Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GP183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGp183Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaceaeBacteriumFsla50281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumSalicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum salicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSalicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolimangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solimangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSolimangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf456Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf456Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCompetibacterDenitrificansRunAD11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Competibacter denitrificans Run_A_D11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCompetibacterDenitrificansRunAD11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_41_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo2024111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaHinziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella hinzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaHinziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAmbofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces ambofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAmbofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Bacterium2013arg42iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Arg42i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013arg42iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensNz007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NZ007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNz007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WenyingzhuangiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpSk01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpLeaf216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RivulariaSpPcc7116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rivularia sp. PCC7116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RivulariaSpPcc7116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymoseptoriaTriticiIpo323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici IPO323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiIpo323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonosporaCurvataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermomonospora curvata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermomonosporaCurvataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosynechococcusSpNk55aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus sp. NK55a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusSpNk55aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpRadiciscucumerinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. radiciscucumerinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpRadiciscucumerinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumKuznetsoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum kuznetsovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumKuznetsoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSa213a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SA213A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSa213a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProtegensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasWeihenstephanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasWeihenstephanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbawacabacteriaBacteriumRbg164210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Abawacabacteria bacterium RBG164210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbawacabacteriaBacteriumRbg164210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD1_FULL_40_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriaSymbiontBfo2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutimaribacterSaemankumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutimaribacter saemankumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutimaribacterSaemankumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_37_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacterium4484171Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_171 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484171Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZavarzinellaFormosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zavarzinella formosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZavarzinellaFormosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumAethiopicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium aethiopicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAethiopicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiferrobacterThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidiferrobacter thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidiferrobacterThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlammeovirgaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaConcitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia concitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaConcitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterLongobardus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter longobardus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterLongobardus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full3939(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL3939 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full3939", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSubterraneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSubterraneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumS5a14aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S5A14a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS5a14aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPhoceensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium phoceensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPhoceensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllofustisSeminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allofustis seminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllofustisSeminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp3j1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 3J1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp3j1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpHmsc08h08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HMSC08H08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHmsc08h08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiriDsm20587Jcm5818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri DSM 20587 JCM 5818 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKefiriDsm20587Jcm5818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeinonellaPeptonophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Seinonella peptonophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SeinonellaPeptonophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumGw2011gwf24242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWF24242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwf24242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusAmylolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronococcusAmylolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumChlorophenolicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosynechococcusSphagnicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpFy07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. FY-07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpFy07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpWsm1743Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1743Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumLitoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumLitoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistophilusSomni2336Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Histophilus somni 2336 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HistophilusSomni2336Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusHnlc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrybacteriaBacteriumRifcsplowo2024220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO2024220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo2024220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpCag268Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:268 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag268Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerGoleimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopiger goleimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopigerGoleimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFjat26967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-26967 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat26967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraChibensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura chibensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraChibensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSpMar201089(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2010_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar201089", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOulorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oulorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOulorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaProwazekii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia prowazekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaProwazekii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovirgaLieniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermovirga lienii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermovirgaLieniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEvansiaMuelleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Evansia muelleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusEvansiaMuelleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusPertinax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus pertinax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusPertinax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_01_FULL_50_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_41_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4113bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransGilvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgarivoransGilvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpIhbb10380Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. IHBB 10380 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpIhbb10380Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full5017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL5017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full5017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuribacterMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muribacter muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuribacterMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGlycerinitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces glycerinitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGlycerinitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSp3cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. 3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSp3cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaPanaciterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma panaciterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaPanaciterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCaspthauma4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSpMar2010102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpUnc23mfcrub11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC23MFCrub11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc23mfcrub11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumSpTh20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium sp. TH-20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumSpTh20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LambdaproteobacteriaBacteriumRifoxyd1full5627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD1FULL5627 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd1full5627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSaburreumDsm3986(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum DSM3986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumDsm3986", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CongregibacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Congregibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CongregibacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacillusCateniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus cateniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusCateniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumUniformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium uniforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumUniformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraAerophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira aerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraAerophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaYl17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila YL17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaYl17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpBjgmmb45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. BJGMMB45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpBjgmmb45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMp13118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MP131-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMp13118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full4013bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL4013b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full4013bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumTepidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium tepidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumTepidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesHl037pa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes HL037PA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesHl037pa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaDonostiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia donostiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaDonostiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmoTruttaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmo trutta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmoTruttaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosa9a5c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa 9a5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosa9a5c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalilimnicolaEhrlichiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalilimnicola ehrlichii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalilimnicolaEhrlichiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpOa2007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. OA-2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpOa2007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusPleuropneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterVibrioidesCb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides CB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesCb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaCuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella cuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaCuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiCft073Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli CFT073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiCft073Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusAmyloliquefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus amyloliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacillusAmyloliquefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesEpiroticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles epiroticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesEpiroticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaPanamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leishmania panamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeishmaniaPanamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaGrimmiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia grimmiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGrimmiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpRoot52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraNicotianae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora nicotianae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraNicotianae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSalsilacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella salsilacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSalsilacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrucellaAbortusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brucella abortus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrucellaAbortusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlochmanniaVaferStrBvafEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blochmannia vafer str. BVAF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlochmanniaVaferStrBvafEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharothrixEspanaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix espanaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixEspanaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYD2_FULL_39_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThioglobusSingularisPs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus singularis PS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSingularisPs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterSpLpb0138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter sp. LPB0138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutibacterSpLpb0138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseatelesSpYr242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseateles sp. YR242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseatelesSpYr242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpMex14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. Mex14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpMex14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaXishanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia xishanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaXishanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaAzotonutriciumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema azotonutricium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaAzotonutriciumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumJaponicumUt26sEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium japonicum UT26S Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumJaponicumUt26sEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTyphiStrB9991cwpp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia typhi str. B9991CWPP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTyphiStrB9991cwpp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio aerogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioAerogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrleanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orleanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrleanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensNcimb11764Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NCIMB11764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNcimb11764Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerProfundus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipiger profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipigerProfundus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4748Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4748 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4748Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusSpOk042Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus sp. OK042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusSpOk042Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMendocinaNk01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina NK01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaNk01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2303621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSpWwm596Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. WWM596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpWwm596Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusTorquesAtcc27756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus torques ATCC27756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusTorquesAtcc27756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumPuteiDsm12395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei DSM 12395 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumPuteiDsm12395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumCavoleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum cavolei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumCavoleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb03911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaWeihenstephanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaWeihenstephanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioInopinatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarchaeobiusIranensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarchaeobius iranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarchaeobiusIranensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudochrobactrumSpB5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudochrobactrum sp. B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudochrobactrumSpB5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpCastelsardoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. Castelsardo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpCastelsardoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifoxyd2Full369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFOXYD2_FULL_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifoxyd2Full369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyb1full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYB1FULL4216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyb1full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumMelanogenumCbs110374(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum CBS 110374 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenumCbs110374", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo212full4526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO212FULL4526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo212full4526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaFerrariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ferrariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFerrariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAtcc12561(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium ATCC12561 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAtcc12561", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAfzeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia afzelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaAfzeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho202full4212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichobilharziaRegenti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichobilharzia regenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichobilharziaRegenti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpBv3ac4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BV3Ac4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBv3ac4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumGwc2579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc2579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusPlakortidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus plakortidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusPlakortidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusQingdaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus qingdaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusQingdaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpRoot133Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot133Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichoplaxAdhaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxAdhaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiflebacteriaBacteriumGwc2508Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riflebacteria bacterium GWC2508 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiflebacteriaBacteriumGwc2508Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumCoprostanoligenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium coprostanoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCoprostanoligenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwh6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWH6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwh6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaHackeliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella hackeliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaHackeliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp4081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 40-81 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp4081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinagarivoransAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinagarivorans algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinagarivoransAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumStellenboschense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium stellenboschense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumStellenboschense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpRc3bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc3b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc3bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaAtcc7966Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila ATCC7966 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaAtcc7966Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSimiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium simiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSimiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesSpN902109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. N902109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpN902109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OvisAriesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ovis aries Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OvisAriesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyaloscyphaBicolorEEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaBicolorEEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaParasiticaCbs22365Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica CBS 223.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaParasiticaCbs22365Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumAgaricidamnosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium agaricidamnosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumAgaricidamnosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudanabaenaSpPcc6802Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC6802 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc6802Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTolypomycinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis tolypomycina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTolypomycinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwa14424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWA14424 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwa14424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCt34(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CT34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCt34", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpLc238(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. LC238 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLc238", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAculeatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusAculeatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasAgitataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas agitata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAgitataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParmenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium parmense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParmenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaHofstadii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia hofstadii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaHofstadii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyunsoonleellaJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyunsoonleella jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyunsoonleellaJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotignumBalticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotignum balticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotignumBalticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwe23830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWE2_38_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwe23830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaSpTw09308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia sp. TW09308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaSpTw09308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusVersicolorCbs58365Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus versicolor CBS 583.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusVersicolorCbs58365Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterDelicatusNbrc14919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter delicatus NBRC 14919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CurvibacterDelicatusNbrc14919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitromicrobiumSpJl477Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JL477 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJl477Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfococcusMultivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusMultivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpStbin5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. STbin5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpStbin5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaZhejiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia zhejiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaZhejiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumGp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimonasHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limimonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimimonasHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMediterraneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMediterraneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriDsm10701Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri DSM10701 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriDsm10701Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc24220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_42_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc24220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumAcridumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium acridum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAcridumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTaibaishanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium taibaishanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTaibaishanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoflavibacterZeaxanthS86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. S86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthS86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraAlvinipulliAtcc51933Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli ATCC 51933 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulliAtcc51933Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrapeneCarolinaTriunguis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Terrapene carolina triunguis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TerrapeneCarolinaTriunguis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRifcsphigho201full6516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPHIGHO201FULL6516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsphigho201full6516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraAustraliensisBen110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Ben110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensisBen110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpLeaf420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Leaf420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLeaf420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpUnc380mfsha31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. unc380mfsha3.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpUnc380mfsha31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusOdysseyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus odysseyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusOdysseyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsasporaOwczarzakiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapsasporaOwczarzakiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineothrixAlysoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kineothrix alysoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KineothrixAlysoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumGw2011gwb24136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWB24136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwb24136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaYeatsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaYeatsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HahellaGanghwensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hahella ganghwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HahellaGanghwensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho201full5524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosediminibacterOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosediminibacter oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosediminibacterOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph298(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 298 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph298", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterNicotinovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter nicotinovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterNicotinovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumScgcAaa164e04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA164E04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa164e04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolysaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolysaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusDurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus durans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicrobiumMukohataeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium mukohataei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumMukohataeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraMeyeriSerovarHardjoStrWent5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira meyeri serovar Hardjo str. Went 5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMeyeriSerovarHardjoStrWent5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMacleodiiBlackCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Black Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiBlackCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE2699Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2699Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesPombe(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombe", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumPalustreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium palustre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumPalustreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpF0108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasParapaucimobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas parapaucimobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasParapaucimobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasYangmingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas yangmingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasYangmingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalimonasAmylolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalimonas amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalimonasAmylolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpCag318Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. CAG:318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpCag318Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Bacterium3363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium 336/3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Bacterium3363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TardiphagaSpOk245Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga sp. OK245 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TardiphagaSpOk245Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumInnocuumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium innocuum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumInnocuumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf23548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_35_48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterSpAap60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTenaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium tenax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTenaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetomicrobiumHydrogeniformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumHydrogeniformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesSpShpl14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumJb7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum JB7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumJb7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3773(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3773 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3773", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp651402Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1402 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651402Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusStipitatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus stipitatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcusStipitatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrucellaAbortus2308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brucella abortus 2308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrucellaAbortus2308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParafarraginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parafarraginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParafarraginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoeseiaOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woeseia oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoeseiaOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumAmurskyenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium amurskyense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumAmurskyenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusXylanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus xylanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusXylanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumSpCcfee5018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium sp. CCFEE 5018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumSpCcfee5018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSchubertiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas schubertii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSchubertiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SnodgrassellaAlviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasElodea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas elodea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasElodea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSalsinemorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina salsinemoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSalsinemorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedFlavonifractorSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Flavonifractor sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedFlavonifractorSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85201351886sch5428379Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201351886SCH5428379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201351886sch5428379Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCampestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSp5c6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. 5C6A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSp5c6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc24017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC24017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc24017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAmniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella amnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAmniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaSpCag521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13724Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_37_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13724Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumJdfr78(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr78", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPsychrerythraea34hCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea 34H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraea34hCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumTumefaciensF2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens F2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensF2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumCoprophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium coprophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCoprophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSp6654(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. 66-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSp6654", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoenixDactyliferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phoenix dactylifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhoenixDactyliferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSp83e34Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. 83E34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSp83e34Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthromitusSpSfbratyitCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBratYit Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbratyitCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariniradiusSaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mariniradius saccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MariniradiusSaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaHaradaeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia haradaeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaHaradaeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisBaichengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis baichengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisBaichengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaFlocculosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma flocculosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudozymaFlocculosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermofilumPendensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum pendens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermofilumPendensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesCaccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesCaccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeersiaPerrieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leersia perrieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeersiaPerrieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumFabrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium fabrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumFabrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GleimiaEuropaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gleimia europaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GleimiaEuropaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TypeBSymbiontOfPlautiaStaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Type-B symbiont of Plautia stali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TypeBSymbiontOfPlautiaStaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasWittichiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas wittichii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasWittichiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaKoehleraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella koehlerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaKoehleraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferrisomaCaminiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deferrisoma camini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeferrisomaCaminiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyripristisMurdjanEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myripristis murdjan Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyripristisMurdjanEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumDoricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium doricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDoricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCrispatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crispatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrispatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcanobacteriumHaemolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium haemolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumHaemolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumNor53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium NOR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumNor53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaTanakaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella tanakaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaTanakaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasUshuaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas ushuaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasUshuaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDiolivoransDsm14421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus diolivorans DSM 14421 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDiolivoransDsm14421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesColuzziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles coluzzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesColuzziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CionaIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ciona intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CionaIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberibacillusSpMarseillep3662(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tuberibacillus sp. MarseilleP3662 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuberibacillusSpMarseillep3662", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma palmae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaPalmae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaSp4h37ye5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. 4H37YE5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSp4h37ye5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpTb67Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb67Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumFrigidisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium frigidisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFrigidisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DichelobacterNodosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dichelobacter nodosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DichelobacterNodosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionicicellaSuperfundiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionicicella superfundia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionicicellaSuperfundiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSp47agom205mCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. 47AGOM205m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSp47agom205mCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesThermolilacinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermolilacinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermolilacinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacterKriegiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacterKriegiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpF0557Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0557 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0557Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaBalbisianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Musa balbisiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusaBalbisianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NasoniaVitripennis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nasonia vitripennis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NasoniaVitripennis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGracilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGracilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VignaRadiataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vigna radiata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VignaRadiataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HebelomaCylindrosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HebelomaCylindrosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioMytili(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mytili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMytili", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMmg1121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf23829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23829 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBombycis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus bombycis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusBombycis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solimonas aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolimonasAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumEpidermidicanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium epidermidicanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEpidermidicanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProvidenciaSiddalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Providencia siddallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusProvidenciaSiddalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumKuznetsoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum kuznetsovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumKuznetsoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrocadiaSinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpLc238Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. LC238 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLc238Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaAstilbisJcm15831Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaia astilbis JCM 15831 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaiaAstilbisJcm15831Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDechloracetivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio dechloracetivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDechloracetivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasLentaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas lenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasLentaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCaspthauma3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatishimiaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cognatishimia maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CognatishimiaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraYanagawaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira yanagawae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraYanagawaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabeoRohitaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labeo rohita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabeoRohitaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTenderiaElectrophagaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tenderia electrophaga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTenderiaElectrophagaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraEvergladensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera evergladensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraEvergladensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc4496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC44/96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc4496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPeloridisLmg23910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter peloridis LMG 23910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPeloridisLmg23910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBeijerinckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBeijerinckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaDiscariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia discariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaDiscariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaXishanensisNbrc101358(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia xishanensis NBRC 101358 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaXishanensisNbrc101358", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseolineaSerpensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseolinea serpens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseolineaSerpensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenibacteriumSpCag290Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenibacterium sp. CAG:290 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenibacteriumSpCag290Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpPkEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. PK Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpPkEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs1612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS1612 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs1612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaMajae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella majae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KiloniellaMajae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeCc1513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaRaraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella rara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRaraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaCenocepaciaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cenocepacia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCenocepaciaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusVersicolorCbs58365Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus versicolor CBS 583.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusVersicolorCbs58365Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterCelerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter celer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterCelerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg166814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_68_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumSubspAnimalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspAnimalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumGwa26437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWA2_64_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwa26437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUvarumCbs121591Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus uvarum CBS 121591 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusUvarumCbs121591Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuglansRegiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Juglans regia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JuglansRegiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumScgcAaa252a02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium SCGC AAA252A02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumScgcAaa252a02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAcidivoransNbrc108247(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia acidivorans NBRC 108247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAcidivoransNbrc108247", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HepatoplasmaCrinochetorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hepatoplasma crinochetorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HepatoplasmaCrinochetorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumOlb14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisSepedonicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis sepedonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSepedonicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurisporaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispora thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurisporaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf194(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf194 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf194", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CasaltellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Casaltella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CasaltellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobiusActivus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius activus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusActivus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCarbinoliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot264(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot264", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSubflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioFibrisolvens164Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens 16/4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvens164Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeurosporaTetraspermaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeurosporaTetraspermaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NautiliaProfundicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nautilia profundicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NautiliaProfundicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpP11g3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StegastesPartitusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stegastes partitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StegastesPartitusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpLeaf26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Leaf26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpLeaf26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaConfusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella confusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaConfusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaegleriaGruberiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Naegleria gruberi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NaegleriaGruberiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaCantharicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma cantharicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCantharicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaTetraspermaFgsc2509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma FGSC 2509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeurosporaTetraspermaFgsc2509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumHumireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumD1873(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum D 1873 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumD1873", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettaeCvd059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae CVD059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusArlettaeCvd059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensMesophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens mesophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensMesophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaSpNd16aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. ND16A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpNd16aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlexistipesSinusarabiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flexistipes sinusarabici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlexistipesSinusarabiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacterKriegiiDsm6294Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii DSM 6294 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanobacterKriegiiDsm6294Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfTevnia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Tevnia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfTevnia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphellophoraEuropaeaCbs101466Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea CBS 101466 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyphellophoraEuropaeaCbs101466Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusSolisalsi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus solisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FictibacillusSolisalsi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArh4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolamina rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolaminaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu032Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu032Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinusNbrc15237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus NBRC 15237 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusNbrc15237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippocampusComesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hippocampus comes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HippocampusComesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusKamchatkensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus kamchatkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusKamchatkensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpP18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. P1.8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpP18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratireductorSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaSympodialisAtcc42132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia sympodialis ATCC 42132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MalasseziaSympodialisAtcc42132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoflavonifractorCapillosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor capillosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorCapillosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusSp13mg44airEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus sp. 13MG44air Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JeotgalicoccusSp13mg44airEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaUdeis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia udeis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaUdeis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusHauseriAtcc700826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Proteus hauseri ATCC 700826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProteusHauseriAtcc700826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiUsda3471Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti USDA3471 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiUsda3471Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpCl154Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. CL154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpCl154Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeroarcusBurkinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeroarcus burkinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeroarcusBurkinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyb1full4015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYB1FULL4015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyb1full4015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumExBugulaNeritinaAb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatonellaMorbi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catonella morbi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatonellaMorbi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumBangladeshense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium bangladeshense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumBangladeshense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0604Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0604 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0604Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFd1xmdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. fd1xmd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFd1xmdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpF0314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLmg23823(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis LMG23823 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLmg23823", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusTellurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus telluris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusTellurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Veblenbacteria bacterium RIFOXYC2_FULL_42_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpA23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. A23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpA23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CionaSavignyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ciona savignyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CionaSavignyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizoporaParadoxaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schizopora paradoxa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchizoporaParadoxaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusThailandensisDsm22698Jcm13996Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis DSM 22698 JCM 13996 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusThailandensisDsm22698Jcm13996Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedLachnospiraSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Lachnospira sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedLachnospiraSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NoviherbaspirillumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusFumigatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusFumigatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSp770b2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. 770b2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSp770b2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwe23716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_37_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe23716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_39_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_39_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumChlorochromatiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium chlorochromatii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumChlorochromatiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAzotifigensDsm17556Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens DSM 17556 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAzotifigensDsm17556Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAnorexicamassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium anorexicamassiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAnorexicamassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaScopos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella scopos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaScopos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwd23614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWD23614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwd23614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr88Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr88Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFirestonebacteriaBacteriumRifoxya2Full408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYA2_FULL_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxya2Full408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumLactosutensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium lactosutens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumLactosutensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumEscambienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp161mfsha21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 161MFSha21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp161mfsha21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusTropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiosulfatarculusSandiegensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatarculus sandiegensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatarculusSandiegensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofervidusAuxiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfofervidus auxilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfofervidusAuxiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFaecisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFaecisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpCf125Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf125Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRbg165712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RBG_16_57_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRbg165712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMspmpm5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MspMPM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMspmpm5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasVariicolorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solimonas variicoloris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolimonasVariicolorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpMsmb0266(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. MSMB0266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpMsmb0266", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarispirochaetaAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marispirochaeta aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarispirochaetaAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusPropionicusDsm2032Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus DSM 2032 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicusDsm2032Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEquiSubspZooepidemicusAtcc35246Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi subsp. zooepidemicus ATCC 35246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusEquiSubspZooepidemicusAtcc35246Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumBact19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSubspNattoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. natto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspNattoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinococcusHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusBarophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus barophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusBarophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterPasteurianusIfo328301Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus IFO328301 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianusIfo328301Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaHuakuiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kurthia huakuii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KurthiaHuakuiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaSubspMultocidaOh4807(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida OH4807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaOh4807", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpScgcAg212e16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SCGC AG212E16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpScgcAg212e16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpDjl10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. djl-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpDjl10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterMaritimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter maritimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutibacterMaritimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaMorganii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Morganella morganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MorganellaMorganii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraHakonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSediminum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sediminum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSediminum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaceaeBacteriumFsla50209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophaceaeBacteriumCg2305814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_58_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2305814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinomonasHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalaenopteraAcutorostrataScammoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata scammoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrataScammoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatagonusWagneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catagonus wagneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatagonusWagneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusMicrocarpusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PisolithusMicrocarpusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KurthiaHuakuii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kurthia huakuii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KurthiaHuakuii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaTriticinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puccinia triticina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PucciniaTriticinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumLithotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum lithotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumLithotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHyovaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaranusKomodoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Varanus komodoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VaranusKomodoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaConchaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria conchae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaConchaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerotilusNatansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerotilus natans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerotilusNatansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHirsuta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hirsuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaHirsuta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full3511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL3511 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full3511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMinimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium minimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMinimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMannitolivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus mannitolivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMannitolivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterNanhaisediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter nanhaisediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterNanhaisediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioFischeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio fischeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliivibrioFischeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterEpoxidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter epoxidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterEpoxidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillaceaeBacteriumAsp1002aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillaceae bacterium ASP10-02a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanospirillaceaeBacteriumAsp1002aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterBorealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PedobacterBorealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluoribacterGormaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter gormanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FluoribacterGormaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaplochromisBurtoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haplochromis burtoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaplochromisBurtoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterEchinorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter echinorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterEchinorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu065Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU065 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu065Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaminaeaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jaminaea rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JaminaeaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasArsenicoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenicoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenicoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgibacterAlginicilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algibacter alginicilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAlginicilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BauldiaLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bauldia litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BauldiaLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoatesbacteriaBacteriumRbg136614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coatesbacteria bacterium RBG136614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoatesbacteriaBacteriumRbg136614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumGa0077535(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium Ga0077535 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGa0077535", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusYanchengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus yanchengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacillusYanchengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpC(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpC", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSediminumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sediminum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSediminumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsinibacteriumSpOr53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asinibacterium sp. OR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsinibacteriumSpOr53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniphilumSpEbm39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum sp. EBM-39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSpEbm39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinicolaVietnamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echinicola vietnamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EchinicolaVietnamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_41_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo212full4413bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO212FULL4413b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo212full4413bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumSpP6bsiiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum sp. P6BSIII Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumSpP6bsiiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumBarkeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium barkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosaPls229(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa PLS229 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosaPls229", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzotobacterChroococcumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifoxyd1full4619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYD1FULL4619 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyd1full4619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpBh333Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. BH-3-3-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpBh333Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsialesBacteriumExBugulaNeritinaAb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsialesBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumParmentieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium parmentieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumParmentieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyoglomusThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpM334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_44_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterPropionicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter propionicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelobacterPropionicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpSod10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. SOD10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpSod10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactonifactorLongoviformisDsm17459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis DSM 17459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactonifactorLongoviformisDsm17459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudaminobacterManganicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter manganicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterManganicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviimonasAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Defluviimonas alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DefluviimonasAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwf1496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_49_6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriSmdsemEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri SMDSEM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriSmdsemEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasCoralicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas coralicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AurantimonasCoralicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasGotlandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas gotlandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasGotlandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrivivaxGelatinosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax gelatinosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxGelatinosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_01_FULL_46_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesVulcaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides vulcani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesVulcaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLk11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LK11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLk11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpJc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. JC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpJc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg134510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_13_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg134510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthDsm18436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. DSM18436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthDsm18436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpD16q13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16Q13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16q13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumFunkei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium funkei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumFunkei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronincolaPeptidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronincola peptidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronincolaPeptidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleMariesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Maries Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleMariesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysochlorisAsiaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chrysochloris asiatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChrysochlorisAsiaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaphaeosphaeriaSporulosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraphaeosphaeria sporulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaphaeosphaeriaSporulosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SciscionellaSpSe31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella sp. SE31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SciscionellaSpSe31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNeoaurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium neoaurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumNeoaurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpSfbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KockovaellaImperataeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kockovaella imperatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KockovaellaImperataeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBadiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus badius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusBadiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPlatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces platensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPlatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenalcaligenesHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenalcaligenes hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenalcaligenesHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDrentensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus drentensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusDrentensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeJs60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae JS60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeJs60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerracoccusSp273mftsu31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Terracoccus sp. 273MFTsu31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TerracoccusSp273mftsu31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_58_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSp770b2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. 770b2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSp770b2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOxb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OxB-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOxb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFortis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioFortis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumArboris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium arboris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumArboris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AciduliprofundumSpMar08339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum sp. MAR08339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumSpMar08339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaceaeBacterium4572322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_32.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium4572322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercosporaBerteroaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cercospora berteroae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CercosporaBerteroaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GalerinaMarginataCbs33988Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Galerina marginata CBS 339.88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GalerinaMarginataCbs33988Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaFermentatiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachancea fermentati Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachanceaFermentatiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaSpPe36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. PE36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpPe36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KribbellaFlavidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kribbella flavida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KribbellaFlavidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTuaregiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus tuaregi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusTuaregiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSodomenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sodomense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSodomenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaGuangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga guangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaGuangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaBalaenopterae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella balaenopterae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaBalaenopterae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHel133143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. Hel1_33_143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpHel133143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa25412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AciduliprofundumSpMar08339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum sp. MAR08339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumSpMar08339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoheibacterSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moheibacter sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoheibacterSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaOdontolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia odontolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaOdontolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpUrhd0057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. URHD0057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUrhd0057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaSpGbbu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia sp. GBBU graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaSpGbbu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSpOralTaxonHot286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. oral taxon HOT-286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TannerellaSpOralTaxonHot286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GhiorseaBivoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ghiorsea bivora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GhiorseaBivoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpGw1013h11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. GW101-3H11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpGw1013h11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisExcentricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis excentricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisExcentricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHygroscopicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumOvolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum ovolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumOvolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumProvencenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium provencense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumProvencenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisSorokinianaNd90pr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana ND90Pr graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BipolarisSorokinianaNd90pr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCiconiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ciconiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCiconiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpWsm1253Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1253 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1253Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporobacterTermitidisDsm10068Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporobacter termitidis DSM 10068 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporobacterTermitidisDsm10068Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpDlviiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DLVIII Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDlviiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusPastorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus pastoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusPastorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumGw2011gwb1397Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1397 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1397Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAnanatisAj13355(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis AJ13355 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisAj13355", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaimiriBoliviensisBoliviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis boliviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaimiriBoliviensisBoliviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSpNrrlb16210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sp. NRRLB16210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSpNrrlb16210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraMobilisJlw8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis JLW8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilisJlw8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSp6158faact1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. 6158FAACT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TannerellaSp6158faact1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaOmnicolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia omnicolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaOmnicolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0074130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0074130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0074130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudohongiellaSpirulinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella spirulinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaSpirulinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpAcn1agCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. ACN1ag Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpAcn1agCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhytofirmansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phytofirmans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhytofirmansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterGudaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter gudaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterGudaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOk909(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ok909 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOk909", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngvpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGVp Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngvpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaNivara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oryza nivara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OryzaNivara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeocapsaSpPcc73106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC73106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc73106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSaudimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSaudimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpMits9508Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9508 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9508Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaGinsengisoliNbrc100965(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli NBRC 100965 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoliNbrc100965", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaK279aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia K279a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaK279aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumGeofontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium geofontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumGeofontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumCg1024326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CG1_02_43_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCg1024326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydansH24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans H24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydansH24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OenococcusKitaharaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus kitaharae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OenococcusKitaharaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full37110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAnisopliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSp73145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp73145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShimiaHaliotisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimia haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimiaHaliotisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiR88bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti R88b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiR88bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrospiraPlatensisC1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisC1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MustelaPutoriusFuroEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius furo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MustelaPutoriusFuroEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacillusAlimentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus alimentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusAlimentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinimicrobiumPekingenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium pekingense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumPekingenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpHb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. HB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpHb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaPuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia puris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaPuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPallidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pallidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatrinemaPallidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHygroscopicusJinggangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus jinggangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusJinggangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpKhp7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. khp7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKhp7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumHubeiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium hubeiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumHubeiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNomiusNrrl13137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nomius NRRL 13137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusNomiusNrrl13137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonJdfr21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon JdFR-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonJdfr21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaFaecimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaFaecimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3832Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3832 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3832Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoaviumNbrc100491(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium NBRC 100491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterococcusPseudoaviumNbrc100491", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024082Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024082Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHyovaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumCg2305767Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium CG2_30_57_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumCg2305767Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciensAe3010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens AE3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensAe3010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTaa486Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa486Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusCristatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusCristatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusFaecalis13sdw01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis 13SDW01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalis13sdw01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumIcense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium icense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumIcense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRifamyciniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRifamyciniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumA2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOrisPb013t23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris PB013T23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisPb013t23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSalsilacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella salsilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSalsilacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_50_50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumRubrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumRubrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaPennsylvanicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia pennsylvanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaPennsylvanicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFragariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas fragariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFragariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumPraevalensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium praevalens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumPraevalensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumUtcpr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium UTCPR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumUtcpr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumCch11d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH11D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch11d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSulciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sulci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSulciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacterium4718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 47-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSolaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSolaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusFerus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusFerus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaBlandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella blandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaBlandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonRubrumCbs118892(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum CBS 118892 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichophytonRubrumCbs118892", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpAc402Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc402Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpF0370Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0370 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0370Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpEr1aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. ER1A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEr1aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaPanaciterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma panaciterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaPanaciterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumPleistoceniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium pleistocenium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumPleistoceniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFaecis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides faecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFaecis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusPasteuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPasteuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumRiyadhenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium riyadhense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumRiyadhenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfipiaFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAutotrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia autotrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAutotrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscirickettsiaLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPseudofirmus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudofirmus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudofirmus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitaleaBiformataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea biformata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaBiformataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp22311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2231.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp22311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalimonasAmylolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalimonas amylolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalimonasAmylolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricicoccusPullicaecorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyricicoccus pullicaecorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyricicoccusPullicaecorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfidibacterTakaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpUcdthu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. UCDTHU graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpUcdthu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMerdaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium merdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMerdaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorghumBicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sorghum bicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SorghumBicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CutaneotrichosporonOleaginosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cutaneotrichosporon oleaginosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CutaneotrichosporonOleaginosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LichtheimiaCorymbiferaJmrcFsu9682(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera JMRC:FSU:9682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LichtheimiaCorymbiferaJmrcFsu9682", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat29814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthinifaciensS86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens S86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensS86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpLeaf50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusKamchatkensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus kamchatkensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusKamchatkensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivivensSpJlt3646Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivivens sp. JLT3646 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivivensSpJlt3646Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp14822926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1482292.6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14822926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiOharaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei oharae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiOharaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesJaponicusYfs275(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus yFS275 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicusYfs275", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpF3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. F-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpF3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwd23333Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWD2_33_33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwd23333Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Raac196Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 RAAC_196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Raac196Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpLeaf159Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf159 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf159Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpNfacc26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. NFACC26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpNfacc26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpU5lEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. U5L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpU5lEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaNeteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cedecea neteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CedeceaNeteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPrydzensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas prydzensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPrydzensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSp67h29bp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. 67H29BP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSp67h29bp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpT16b2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. T16B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpT16b2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFinegoldii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides finegoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFinegoldii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EcheneisNaucrates(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echeneis naucrates graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EcheneisNaucrates", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaCrassaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neurospora crassa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeurosporaCrassaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumOphioglossoidesCbs100239(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides CBS 100239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoidesCbs100239", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaetbulibacterSaemankumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixThermoacetophilaPt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila PT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophilaPt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaAnimaloris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria animaloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaAnimaloris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPersicinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia persicina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPersicinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumBarchaimiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium barchaimii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumBarchaimiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasGilardiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas gilardii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseomonasGilardiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaBryophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bryophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBryophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpPh1cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. PH1c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpPh1cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusGondwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus gondwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusGondwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterInsolitusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter insolitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterInsolitusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaDispar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaDispar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErinaceusEuropaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erinaceus europaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErinaceusEuropaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BilophilaWadsworthia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSpCag826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoniaMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesonia mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoniaMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumCdBkt12695Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum CD BKT12695 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumCdBkt12695Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusTibetensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusTibetensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwb13613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb13613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngiostrongylusCantonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Angiostrongylus cantonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AngiostrongylusCantonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaThiersiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amanita thiersii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmanitaThiersiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasThiophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas thiophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasThiophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeroformaArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaeroforma arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaeroformaArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasDonghaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasDonghaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalovivaxAsiaticusJcm14624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halovivax asiaticus JCM 14624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalovivaxAsiaticusJcm14624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioFibrisolvensDsm3071Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens DSM 3071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensDsm3071Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveraCryocrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera cryocrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KluyveraCryocrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNTMorphotypeB(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. N.t. morphotype B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EpulopisciumSpNTMorphotypeB", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaAtcc7966(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila ATCC7966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaAtcc7966", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_42_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4226Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC1051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C1051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC1051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHengshuiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hengshuiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHengshuiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaModicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma modicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaModicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisListeriNbrc13360Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri NBRC 13360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisListeriNbrc13360Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifoxyd1full4224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD1FULL4224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd1full4224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumCm5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium CM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumCm5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSpIih2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halopiger sp. IIH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalopigerSpIih2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm46786Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46786 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46786Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacteriumHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacterium halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacteriumHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobiformaLacisalsiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma lacisalsi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobiformaLacisalsiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusJannaschii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus jannaschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusJannaschii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaRwandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rwandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaRwandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FulvimarinaManganoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina manganoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaManganoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBarengoltziiG22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii G22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltziiG22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWalczuchellaMonophlebidarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Walczuchella monophlebidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWalczuchellaMonophlebidarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaistiaGranuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaistia granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaistiaGranuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumKishitaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium kishitanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumKishitaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSinopsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sinopsychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSinopsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoglobusAcetivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAcetivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsphigho212full278Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full278Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacterium6911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 69-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium6911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpBv3c26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. BV3C26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpBv3c26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWakoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus wakoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusWakoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BatrachochytriumSalamandrivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium salamandrivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumSalamandrivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumSpC3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. C3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSpC3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6754Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 67-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6754Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenarchaeotaArchaeon13140cm3535(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_53_5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm3535", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110052(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110052", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4620 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofarcimenAcetoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen acetoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenAcetoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumChocolatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium chocolatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumChocolatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioKanaloae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio kanaloae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioKanaloae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesCulicifaciesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles culicifacies Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesCulicifaciesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg164813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG164813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg164813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusHunanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus hunanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHunanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiosulfatarculusSandiegensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatarculus sandiegensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatarculusSandiegensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaAerolata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Skermanella aerolata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SkermanellaAerolata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRoot483d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root483D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot483d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumCg23041165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium CG23041165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumCg23041165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrionalesBacteriumGwa2659(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrionales bacterium GWA2_65_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrionalesBacteriumGwa2659", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBaroniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella baroniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBaroniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusFicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus ficus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HafniaAlveiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hafnia alvei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HafniaAlveiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaRupisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga rupis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaRupisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorangiineaeBacteriumNic37a2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sorangiineae bacterium NIC37A_2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SorangiineaeBacteriumNic37a2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpAl212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. AL212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpAl212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumFlavigenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium flavigenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFlavigenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusDurionisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus durionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FructobacillusDurionisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full4622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL4622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full4622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiO157h7Sakai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Sakai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Sakai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. salamae serovar 56:z10:e,n,x str. 1369-73 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumIntracellulareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium intracellulare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIntracellulareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHochsteniumAtcc700873(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium ATCC 700873 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHochsteniumAtcc700873", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCf046(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf046", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaCetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella ceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaCetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrososphaeraGargensisGa92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrososphaera gargensis Ga9.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrososphaeraGargensisGa92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumRifcsphigho202full62130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium RIFCSPHIGHO202FULL62130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumRifcsphigho202full62130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MillionellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Millionella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MillionellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusHomiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus homiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHomiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAceticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aceticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAceticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpHixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. HIX Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpHixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag609(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:609 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag609", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasKoyamae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas koyamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasKoyamae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusSanguinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sanguinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusSanguinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaPedrosoiCbs27137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi CBS 271.37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoiCbs27137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichophytonInterdigitaleMr816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale MR816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichophytonInterdigitaleMr816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumOtsza272Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium OTSzA272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumOtsza272Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaerimneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaerimneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpLs16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. LS16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLs16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumScgcAaa011l6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011L6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011l6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StoquefichusSpKle1796Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. KLE1796 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpKle1796Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_01_FULL_41_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifoxya1full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFOXYA1FULL4114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifoxya1full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterSpRoot100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. Root100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpRoot100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlucuronolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glucuronolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlucuronolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollichthysLucidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collichthys lucidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollichthysLucidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterBeijingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterBeijingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachanceaThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_39_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGuineaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guineae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuineaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythruraGouldiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrura gouldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythruraGouldiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaBrunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella brunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaBrunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesDerwentensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes derwentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesDerwentensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaRestrictaCbs7877(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia restricta CBS 7877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MalasseziaRestrictaCbs7877", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminicellaSporogenesDsm14501Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caminicella sporogenes DSM 14501 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaminicellaSporogenesDsm14501Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumIliopiscariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium iliopiscarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumIliopiscariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLuteocolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteocolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteocolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumTuscanienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium tuscaniense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTuscanienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumShigense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium shigense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumShigense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolobusProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPrunellaeJcm25354Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia prunellae JCM 25354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaiaPrunellaeJcm25354Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSpCcge1002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. CCGE1002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpCcge1002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSmaragdinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta smaragdinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSmaragdinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusPenneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Proteus penneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProteusPenneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyangiumBrachysporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Polyangium] brachysporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolyangiumBrachysporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysiogenesArsenatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chrysiogenes arsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChrysiogenesArsenatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaPipientisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia pipientis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaPipientisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterVenetianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter venetianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterVenetianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201351886sch5428379Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201351886SCH5428379 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201351886sch5428379Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpOv608Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OV608 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv608Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpHimb1321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HIMB1321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHimb1321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLeprae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium leprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLeprae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonopterusAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monopterus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonopterusAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAsiaticusGxpsyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus gxpsy Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusGxpsyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMethanolicusPb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus PB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusPb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumBohemicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium bohemicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBohemicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpCag409Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. CAG:409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpCag409Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerticilliumDahliaeVdls17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae VdLs.17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VerticilliumDahliaeVdls17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumTestaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium testaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTestaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDenitrificansDsm15936Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans DSM 15936 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificansDsm15936Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpChd6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CHD6a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpChd6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlternariaAlternata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alternaria alternata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlternariaAlternata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterJohnsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJohnsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag646Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:646 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag646Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanopyrusKandleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanopyrusKandleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisSterne(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Sterne graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisSterne", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPropinquum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium propinquum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPropinquum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumArcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium arcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumArcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumD5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaEffusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRbg166534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_65_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophiliaR5513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia R5513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaR5513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaOdontolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia odontolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaOdontolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLepraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium leprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLepraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusManasiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus manasiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusManasiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasSpDtu019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpSk37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. SK37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSpSk37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasAlkenigignensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas alkenigignens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasAlkenigignensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodiomycesAlkalinusF11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus F11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SodiomycesAlkalinusF11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusAsaccharolyticusDsm20463(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus asaccharolyticus DSM 20463 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusAsaccharolyticusDsm20463", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpDjl10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. djl-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpDjl10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumCsp17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium CSP1-7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumCsp17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobaculumLitoreumDsm18839(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum DSM 18839 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreumDsm18839", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19035 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp351mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 351MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp351mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrospermumStagnaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cylindrospermum stagnale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CylindrospermumStagnaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCrustorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crustorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrustorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycineMaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycine max Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycineMaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiaePg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae PG2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiaePg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAtcc27244Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ATCC27244 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAtcc27244Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu087Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU087 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu087Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusSpCag390Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag390Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200251163sch5372311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251163SCH5372311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251163sch5372311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioScophthalmiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio scophthalmi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioScophthalmiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacteriumWoodii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium woodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWoodii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRhamnosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rhamnosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRhamnosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFournierii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium fournierii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFournierii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumRussiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium russii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumRussiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemocanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraSojaeStrainP6497(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae strain P6497 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraSojaeStrainP6497", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc7376Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7376 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7376Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterIndonesiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBoenickeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium boenickei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBoenickeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMexicanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mexicanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMexicanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusTriatomaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus triatomae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTriatomaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpAt1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. AT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAt1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterFreundiiCfnih1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter freundii CFNIH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFreundiiCfnih1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOdoriferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus odorifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOdoriferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PichiaMembranifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pichia membranifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PichiaMembranifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpIbvss1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBrasiliensisJcm12178Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis JCM 12178 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensisJcm12178Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeromyxobacterDehalogenansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter dehalogenans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterDehalogenansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlvei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus alvei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAlvei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusCaballus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Equus caballus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EquusCaballus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumMultivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumMultivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MargulisbacteriaBacteriumGwf2359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWF2359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwf2359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaDubliniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida dubliniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaDubliniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPolynesienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium polynesiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolynesienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOralisAtcc33269Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis ATCC33269 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisAtcc33269Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpCf284(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf284", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusHospitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus hospitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusHospitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumWenxiniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium wenxiniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumWenxiniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParascardoviaDenticolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parascardovia denticolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhocaeicolaAbscessusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTubingensisCbs13448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis CBS 134.48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusTubingensisCbs13448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMinor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus minor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMinor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacellibacteroidesSpHhzsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macellibacteroides sp. HHZS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacellibacteroidesSpHhzsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesJeddahensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces jeddahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesJeddahensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiSe8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii SE8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiSe8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelcobacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helcobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelcobacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3837Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3837 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3837Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesHarbinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycomycesHarbinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseomonasRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYB1_FULL_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyb1Full4015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusDevrieseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus devriesei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDevrieseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabasTestudineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabas testudineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabasTestudineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelobdellaRobustaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helobdella robusta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelobdellaRobustaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPecorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPecorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifoxyb1full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYB1FULL4614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyb1full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc25546Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_55_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc25546Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcusAnaerobiusVpi4330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius VPI4330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobiusVpi4330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3820 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephaloticoccusCapnophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus capnophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusCapnophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesantisbacteriaBacteriumCg1023846(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1023846 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1023846", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenariaAnguillulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenaria anguillulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenariaAnguillulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag65Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag65Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterParvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter parvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterParvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaLimicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena limicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaLimicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaLupini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaLupini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRoot209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. Root209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRoot209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FuchsiellaAlkaliacetigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fuchsiella alkaliacetigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FuchsiellaAlkaliacetigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudescherichiaVulneris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudescherichia vulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudescherichiaVulneris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumInnocuumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium innocuum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumInnocuumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaemateliaEncephalaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Naematelia encephala Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NaemateliaEncephalaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTestis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus testis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusTestis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumMucronatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smittium mucronatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmittiumMucronatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudozymaHubeiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudozymaHubeiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPolarisDsm16579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas polaris DSM 16579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinomonasPolarisDsm16579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSp6654Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. 66-54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSp6654Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacterFloricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacter floricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacterFloricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaMonticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia monticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMonticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaKristinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rothia kristinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RothiaKristinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc11e11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC11E11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc11e11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpCect7735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 7735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect7735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DasypusNovemcinctusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dasypus novemcinctus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DasypusNovemcinctusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot112d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root112D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot112d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpJa33abEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA33Ab Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa33abEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaDaqingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga daqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaDaqingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumRifoxyb1full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaYamanashiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaYamanashiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacterium13140cm46819Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium 13_1_40CM_4_68_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacterium13140cm46819Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumChiriqhuchaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium chiriqhucha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumChiriqhuchaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumPh28bin88(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium PH28bin88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumPh28bin88", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TersicoccusSpBi70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus sp. Bi-70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TersicoccusSpBi70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PisolithusTinctoriusMarx270Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius Marx 270 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PisolithusTinctoriusMarx270Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasProfundimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas profundimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasProfundimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpS7Ms2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S7 MS 2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS7Ms2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaistia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaistiaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacterium3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 33-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumGrantiiDsm8605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium grantii DSM 8605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumGrantiiDsm8605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraNoguchiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira noguchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraNoguchiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb1388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb1388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGenavenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium genavense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGenavenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusOnnurineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus onnurineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusOnnurineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasChangbaiensisNbrc104936Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis NBRC 104936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensisNbrc104936Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutibacterMaritimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutibacterMaritimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_02_FULL_40_12b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusAmyloliquefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus amyloliquefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacillusAmyloliquefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAridi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer aridi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferAridi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpOmz838(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. OMZ838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpOmz838", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorticoccusHydrocarbonoclasticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porticoccus hydrocarbonoclasticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorticoccusHydrocarbonoclasticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSanfranciscensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sanfranciscensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSanfranciscensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGaetbulicolaGung47(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Gung47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicolaGung47", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeobacteroidesDsm266(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides DSM266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesDsm266", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNamucuonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia namucuonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaNamucuonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimbladiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimbladii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimbladiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGaemokensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gaemokensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGaemokensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolaciniaPaynteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia paynteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPaynteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpMtm3w52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. MTM3W5.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpMtm3w52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumAquatileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumAquatileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAc2005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AC2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAc2005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifoxyc2full4512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYC2FULL4512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyc2full4512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumYim77505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium YIM77505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumYim77505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSzulgaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium szulgai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSzulgaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaAquamarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala aquamarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaAquamarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromonasArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWeihenstephanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus weihenstephanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusWeihenstephanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_12_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpAle5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. ALE5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpAle5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzorhizobiumDoebereinerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium doebereinerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumDoebereinerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParascardoviaDenticolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parascardovia denticolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSputigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sputigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSputigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRifcsplowo201full4332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPLOWO201FULL4332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsplowo201full4332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRubi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rubi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRubi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag230(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:230 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag230", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumLindaniclasticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lindaniclasticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLindaniclasticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacteriumGilvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumGilvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit115569Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT115569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit115569Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GaleopterusVariegatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Galeopterus variegatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GaleopterusVariegatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaAerolata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Knoellia aerolata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KnoelliaAerolata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaAminovalericaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna aminovalerica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaAminovalericaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusComesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus comes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprococcusComesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterHeraklionensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter heraklionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHeraklionensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpIso899Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. Iso899 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpIso899Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlj11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolitaleaCanadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solitalea canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolitaleaCanadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc7214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentinusTigrinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentinus tigrinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentinusTigrinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSimilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter similis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSimilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaTellurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia telluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTellurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumPrausnitziiKle1255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii KLE1255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiKle1255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumGw2011od13428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium GW2011OD13428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumGw2011od13428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpYr216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSp64120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. 64-120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSp64120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasMephitisDsm12574Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas mephitis DSM 12574 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LuteimonasMephitisDsm12574Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo212full6621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGirerdiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma girerdii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGirerdiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CardiniumEndosymbiontCbtq1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cBtQ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCbtq1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaDasiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachancea dasiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachanceaDasiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanisDsm13634Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis DSM 13634 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanisDsm13634Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaPetrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga petrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaPetrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrusUnshiuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrus unshiu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrusUnshiuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GabonibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gabonibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GabonibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OkibacteriumFritillariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Okibacterium fritillariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OkibacteriumFritillariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoclostridiumPhytofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phytofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhytofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBoissieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter boissieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBoissieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifcsplowo201full3415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO201FULL3415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo201full3415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumKansasii732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii 732 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasii732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelativoransSpJ32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. J32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpJ32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifoxyc2full4228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL4228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full4228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg135114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_13_51_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg135114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasHypermegaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megamonas hypermegale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegamonasHypermegaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacteriaBacteriumGut307(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacteria bacterium GUT307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacteriaBacteriumGut307", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLablabiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium lablabi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLablabiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusJidaibacterAcanthamoebaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jidaibacter acanthamoeba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJidaibacterAcanthamoebaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CebusCapucinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cebus capucinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CebusCapucinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAcidiscabiesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces acidiscabies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAcidiscabiesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonadalesBacteriumEhc05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium EhC05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumEhc05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaBoydiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shigella boydii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShigellaBoydiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalmapalus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halmapalus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHalmapalus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumDtu054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTusciae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTusciae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_45_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpOk602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ok602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpOk602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo202full5117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL5117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full5117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidifarinaeDsm19394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae DSM 19394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinaeDsm19394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CnuellaTakakiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cnuella takakiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CnuellaTakakiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho202full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL4312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusIheyensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus iheyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusIheyensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaBatsensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola batsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanicolaBatsensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensF113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens F113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensF113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_41_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesMethylutensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasVesicatoria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vesicatoria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVesicatoria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 71-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaimiriBoliviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saimiri boliviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaimiriBoliviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusTukisamuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus tukisamuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTukisamuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCirculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus circulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCirculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUlceribovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulceribovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlceribovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpNs7484Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. NS-7484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpNs7484Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwc24211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_42_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc24211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusReuteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg2304021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG2_30_40_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg2304021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaGranulomatisDsm19156(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis DSM 19156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MannheimiaGranulomatisDsm19156", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OstreococcusLucimarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OstreococcusLucimarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBeddingiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus beddingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBeddingiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpRoot444d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root444D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot444d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasJandaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas jandaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasJandaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag465(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:465 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag465", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFructicolaNaraGc5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fructicola Nara gc5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFructicolaNaraGc5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PurpureocilliumLilacinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Purpureocillium lilacinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PurpureocilliumLilacinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheileriaOrientalisStrainShintoku(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis strain Shintoku graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TheileriaOrientalisStrainShintoku", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatirhabdiumButyrativoransDsm18734Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans DSM 18734 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativoransDsm18734Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13120cm3538Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_20CM_3_53_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13120cm3538Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumP6b14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6B14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6b14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSalegens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalegens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensFgi94Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens FGI94 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensFgi94Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCdtb01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CdTB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCdtb01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSp4h375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. 4H375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSp4h375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpPsnih2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaParvula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella parvula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaParvula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUrhb0015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URHB0015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUrhb0015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumOpportunistumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium opportunistum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOpportunistumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SnodgrassellaSpCfcc13594Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella sp. CFCC 13594 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaSpCfcc13594Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoemansiaReversaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coemansia reversa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoemansiaReversaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpShues1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. SHUES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpShues1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioRuminisCf1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis CF1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisCf1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep2415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_12_FULL_45_19b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiBulgaricusAtcc11842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus ATCC 11842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricusAtcc11842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPasteuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPasteuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPimensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus pimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPimensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpUpii135eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. UPII135E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpUpii135eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavonifractorPlautiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavonifractor plautii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavonifractorPlautiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaTrevisanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia trevisanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaTrevisanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusHospitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus hospitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusHospitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterOralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter oralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GregarinaNiphandrodes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gregarina niphandrodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GregarinaNiphandrodes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumCrithidiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium crithidii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumCrithidiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBrevicatenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brevicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrevicatenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaSpHel3a148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel3A148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel3a148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoruber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoruber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusSpMm3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus sp. MM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusSpMm3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaPalythoae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella palythoae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaPalythoae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bos indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BosIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaMimigardefordensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Advenella mimigardefordensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdvenellaMimigardefordensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrusXBretschneideriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyrus x bretschneideri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyrusXBretschneideriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacterialesBacteriumDnf00809(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriales bacterium DNF00809 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoriobacterialesBacteriumDnf00809", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NadsoniaFulvescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NadsoniaFulvescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJuripiscariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJuripiscariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPaurometabola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella paurometabola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPaurometabola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRs9916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumIndicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium indicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumIndicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusTerrigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg2305367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_53_67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2305367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaCinaraPseudotaxifoliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara pseudotaxifoliae) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraPseudotaxifoliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf274Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf274 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf274Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofusicoccumParvumUcrnp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum UCRNP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeofusicoccumParvumUcrnp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomicrobiumOkeanokoitesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium okeanokoites Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumOkeanokoitesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpHk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. HK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpHk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocKimchiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc kimchii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocKimchiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusPhosphorivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus phosphorivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FictibacillusPhosphorivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaHoronobensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurotusOstreatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PleurotusOstreatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpSoil535Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Soil535 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpSoil535Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumTimonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium timonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTimonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClostridioformeAgr2157(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] clostridioforme AGR2157 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioformeAgr2157", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPlebeiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides plebeius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPlebeiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarsonellaRuddiiPcNhv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PC NHV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPcNhv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaccinostercusDsm20634Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus DSM 20634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercusDsm20634Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4323 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNantensisDsm16982Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis DSM 16982 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNantensisDsm16982Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_42_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerbacteriaBacteriumRbg13378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fischerbacteria bacterium RBG13378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FischerbacteriaBacteriumRbg13378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TeredinibacterTurneraeT7902Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Teredinibacter turnerae T7902 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TeredinibacterTurneraeT7902Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioSpirochaetisodalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio spirochaetisodalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioSpirochaetisodalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCereusAtcc14579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus ATCC 14579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusAtcc14579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasKorlensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas korlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasKorlensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MediterraneaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mediterranea massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MediterraneaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ManihotEsculenta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Manihot esculenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ManihotEsculenta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidisRp62a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis RP62A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisRp62a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BigelowiellaNatansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bigelowiella natans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BigelowiellaNatansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidisJel423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JEL423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJel423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCellulosilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides cellulosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCellulosilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpLpb0140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LPB0140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLpb0140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpCag2416221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241_62_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag2416221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomethylicusMesodigestum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylicus mesodigestum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomethylicusMesodigestum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumUlcerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumUlcerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermosubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromycesRobustusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyces robustus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromycesRobustusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAmyloliquefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterPropionicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter propionicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelobacterPropionicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleurotusOstreatusPc15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus PC15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PleurotusOstreatusPc15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAbyssalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAbyssalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerdibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Merdibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MerdibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeotheceVerrucosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece verrucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeotheceVerrucosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HirundoRusticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hirundo rustica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HirundoRusticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumRifcsplowo201full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL3811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedOscillibacterSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Oscillibacter sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedOscillibacterSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag343Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:343 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag343Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumHimb5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumCg1025453(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG1025453 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg1025453", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCitroniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium citroniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCitroniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallipeplaSquamataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Callipepla squamata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CallipeplaSquamataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLonarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lonarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLonarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonchuraStriata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lonchura striata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LonchuraStriata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumCg2303639(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG2303639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg2303639", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLitopenaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella litopenaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLitopenaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumSb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium SB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumSb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOvisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella ovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOvisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSinuspersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sinuspersici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSinuspersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwa23836(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA23836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa23836", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavisolibacterGinsengisoliDsm18119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli DSM 18119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoliDsm18119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacterium6551Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium 65-51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacterium6551Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaSlithyformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Runella slithyformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RunellaSlithyformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaBlattae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaBlattae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRbg164519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_16_45_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg164519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeTw183Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae TW183 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeTw183Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaMucilaginosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rothia mucilaginosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RothiaMucilaginosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticirepentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora triticirepentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTriticirepentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_51_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaSainthelensi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella sainthelensi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSainthelensi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJinjuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas jinjuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJinjuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsplowo212full5515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocGelidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep3244Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP3244 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep3244Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSanticrucisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella santicrucis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSanticrucisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpImcc9063Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. IMCC9063 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpImcc9063Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpUrha0019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. URHA0019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpUrha0019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNagelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNagelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAureusSubspAureusNctc8325Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus subsp. aureus NCTC 8325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusAureusSubspAureusNctc8325Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDextrinicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDextrinicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwe23928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_39_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe23928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_43_17b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full4317bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumLlx17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium LLX17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumLlx17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NevskiaRamosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nevskia ramosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NevskiaRamosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSolanacearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodolunaPlanktonica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna planktonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodolunaPlanktonica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusJeddahenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus jeddahense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusJeddahenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumSpYo3aop1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium sp. YO3AOP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSpYo3aop1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSteckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium steckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSteckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumCg2303331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_33_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelampsoraLaricipopulina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melampsora laricipopulina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelampsoraLaricipopulina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodosporaAnserinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Podospora anserina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PodosporaAnserinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumKroppenstedtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKroppenstedtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesColeocanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces coleocanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesColeocanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrigenaNbrc13299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrigena NBRC 13299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonasTerrigenaNbrc13299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumGwa25343Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_53_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa25343Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira yanagawae serovar Saopaulo str. Sao Paulo ATCC 700523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraYanagawaeSerovarSaopauloStrSaoPauloAtcc700523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterKeddieii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter keddieii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SanguibacterKeddieii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumRifcsplowo202Full7356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium RIFCSPLOWO2_02_FULL_73_56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumRifcsplowo202Full7356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_41_86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaOdontolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia odontolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaOdontolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusProfundusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus profundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusProfundusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusMacauensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus macauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FictibacillusMacauensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuribacillusStibiiarsenatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus stibiiarsenatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusStibiiarsenatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusReuszeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus reuszeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusReuszeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VanderwaltozymaPolysporaDsm70294Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora DSM 70294 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VanderwaltozymaPolysporaDsm70294Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfopilaAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfopila aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfopilaAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full3513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpNc2002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC2002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc2002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippocampusComesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hippocampus comes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HippocampusComesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpC150Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. C150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpC150Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterSpLeaf3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter sp. Leaf3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSpLeaf3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumXerosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium xerosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumXerosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumMarseillense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium marseillense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMarseillense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusPalustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus palustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPalustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRbg133914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RBG133914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRbg133914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerinicoccusSpJlt9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus sp. JLT9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusSpJlt9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_02_FULL_39_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho202Full3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacterium5419(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 54-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium5419", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBoenickei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium boenickei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBoenickei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumUsda6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg165211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG165211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg165211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbawacabacteriaBacteriumRbg164210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Abawacabacteria bacterium RBG164210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbawacabacteriaBacteriumRbg164210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc13813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC13813 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc13813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasFuttsuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas futtsuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimonasFuttsuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpMn802workerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Mn802worker Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMn802workerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuariaChitosanitabidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriaSymbiontBfo2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisBenzoatilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis benzoatilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBenzoatilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumPhenoliresistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium phenoliresistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumPhenoliresistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaPneumophilaSubspFraseri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. fraseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspFraseri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasGranuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasGranuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SabulitectumSilensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sabulitectum silens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SabulitectumSilensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoellerellaWisconsensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moellerella wisconsensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoellerellaWisconsensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumNcimb41171(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum NCIMB41171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumNcimb41171", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpK90mixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. K90mix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpK90mixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifoxya1Full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFOXYA1_FULL_41_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifoxya1Full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumPutridalgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium putridalgicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPutridalgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpNml980116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML98-0116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml980116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopelagicusBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusContaminans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusContaminans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus allii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaAgariphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa agariphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaAgariphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumCaliforniensisDsm19288(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum californiensis DSM 19288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensisDsm19288", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaeciumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaeciumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonJgiOtu1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon JGI OTU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonJgiOtu1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumJaponicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium japonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumJaponicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpAcc21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. ACC21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpAcc21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelliellaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Belliella baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BelliellaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaphorobacterSpJ551Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diaphorobacter sp. J5-51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiaphorobacterSpJ551Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabasTestudineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabas testudineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabasTestudineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaCoronataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capronia coronata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaproniaCoronataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalotaleaAlkalilenta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halotalea alkalilenta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalotaleaAlkalilenta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:924 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpEs333Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ES3-33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEs333Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasSenticiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas senticii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimonasSenticiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaProductaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia producta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaProductaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocaceaeBacteriumR53105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostocaceae bacterium R-53105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocaceaeBacteriumR53105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumAsiaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium asiaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAsiaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAbyssalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaCtu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ctu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCtu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CystobacterFuscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter fuscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CystobacterFuscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofarcimenIntricatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofarcimen intricatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofarcimenIntricatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopostipesSuicloacalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHimalayensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter himalayensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHimalayensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasFimi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas fimi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFimi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NucleicultrixAmoebiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nucleicultrix amoebiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NucleicultrixAmoebiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSiccatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus siccatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSiccatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChytriomycesConfervaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chytriomyces confervae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChytriomycesConfervaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumG186ar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum G186AR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumG186ar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucca08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptosphaeriaMaculansJn3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans JN3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculansJn3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSenmaizukeiDsm21775Nbrc103853Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei DSM 21775 NBRC 103853 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukeiDsm21775Nbrc103853Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusCarbonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus carbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrococcusCarbonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobifidaHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotryotiniaCalthaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia calthae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaCalthaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MnemiopsisLeidyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mnemiopsis leidyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MnemiopsisLeidyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryziasLatipesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryzias latipes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryziasLatipesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterSpOralTaxon458StrW10330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. oral taxon 458 str. W10330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterSpOralTaxon458StrW10330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmatimonadetesBacterium13140cm6414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 13_1_40CM_64_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium13140cm6414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusDeserti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusDeserti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpPamc26642Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. PAMC 26642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpPamc26642Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalneolaSpEhc07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Balneola sp. EhC07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BalneolaSpEhc07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaArgentinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaArgentinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fragilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFragilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumLentocellumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum lentocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumLentocellumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAsturiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas asturiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAsturiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg166413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_64_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_36_10b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3610bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumMinutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium minutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumMinutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusCelericrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus celericrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCelericrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCg1023572Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG1_02_35_72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg1023572Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceicoccusPelagiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusPelagiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasPolarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas polaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPolarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloceraCorneaHhb12733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Calocera cornea HHB12733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaloceraCorneaHhb12733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofamiliaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neofamilia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeofamiliaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryziasMelastigma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryzias melastigma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryziasMelastigma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpH2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpH2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe3009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCag988(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CAG:988 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCag988", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiRu7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii RU7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiRu7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillerozymaFarinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Millerozyma farinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MillerozymaFarinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho2024118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho2024118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaceaeBacteriumPmp191fCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium PMP191F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumPmp191fCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucispirillumSchaedleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucispirillum schaedleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucispirillumSchaedleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNourseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces noursei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNourseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FangiaHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fangia hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FangiaHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrycteropusAferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Orycteropus afer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OrycteropusAferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterRoseosalivariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrioSpPsbb023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. PSBB023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPsbb023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyronemaOmphalodesCbs100304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes CBS 100304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyronemaOmphalodesCbs100304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo1OfFrankliniellaOccidentalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 of Frankliniella occidentalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1OfFrankliniellaOccidentalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KamptonemaFormosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kamptonema formosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KamptonemaFormosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalieaSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haliea salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalieaSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaErythraeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora erythraea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaErythraeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CytophagaFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CytophagaFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBrisouii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter brisouii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBrisouii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSeniorisDsm24302Jcm17472(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senioris DSM 24302 JCM 17472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSeniorisDsm24302Jcm17472", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBica18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulusDsm18846(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus DSM 18846 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulusDsm18846", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho212full4412b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO212FULL4412b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho212full4412b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumChaponenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium chaponense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumChaponenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPerfringens13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens 13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringens13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasDaejeonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasDaejeonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSaphenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium saphenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSaphenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquicursorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equicursoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquicursorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YarrowiaLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YarrowiaLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomascusLeucogenysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomascus leucogenys Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomascusLeucogenysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitansKin4MEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Kin4-M Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeumEquitansKin4MEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4710bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4710b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4710bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDentasiniJcm15908Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentasini JCM 15908 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDentasiniJcm15908Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthromitusSpSfbratyit(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBratYit graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbratyit", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercosporaZeina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cercospora zeina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CercosporaZeina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesAlbimanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles albimanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesAlbimanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSpF0517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_49_22b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSpCag605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesHordeovulnerisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hordeovulneris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHordeovulnerisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa1418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA1418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa1418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp6021061333Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 6021061333 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp6021061333Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumCoprophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium coprophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCoprophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllochromatiumVinosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium vinosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumVinosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusArciformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus arciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusArciformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumDesertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumDesertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomonasHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermomonasHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfipiaBirgiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia birgiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaBirgiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterNosocomialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nosocomialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNosocomialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifcsphigho202full5217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPHIGHO202FULL5217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsphigho202full5217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumRifcsplowo212full5922(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO212FULL5922 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo212full5922", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpAc466Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC466 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc466Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YokenellaRegensburgei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yokenella regensburgei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YokenellaRegensburgei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAp12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AP12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAp12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalisDsm15434(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis DSM15434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisDsm15434", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpF0314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquaspirillumSerpensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum serpens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSerpensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaWadsworthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWadsworthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterKivui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter kivui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterKivui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosigaBrevicollisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosiga brevicollis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosigaBrevicollisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VaribaculumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusFaecimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus faecimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusFaecimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaMelanogaster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila melanogaster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaMelanogaster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSp22ii122f38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. 22II122F38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSp22ii122f38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaAsperellumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma asperellum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAsperellumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSilesiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus silesiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSilesiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpLeaf363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Leaf363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLeaf363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMustelaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter mustelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMustelaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc04h06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC04H06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc04h06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliicoccusPersicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliicoccus persicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliicoccusPersicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiBerkhoffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii berkhoffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiBerkhoffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCgr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CGR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCgr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwc24544Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_45_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc24544Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSpMtp4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. MTP4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpMtp4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_39_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomagnumIshizawaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomagnum ishizawai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomagnumIshizawaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc8801Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC8801 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc8801Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWallbacteriaBacteriumGwc24935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wallbacteria bacterium GWC2_49_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWallbacteriaBacteriumGwc24935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanopyrusKandleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanopyrusKandleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwa24915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA2_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa24915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterPhenylpyruvicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter phenylpyruvicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPhenylpyruvicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4470Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4470 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4470Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterCupressiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter cupressi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCupressiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpYr375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. yr375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpYr375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full4753(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL4753 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full4753", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioParahaemolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio parahaemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioParahaemolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalonatronumSaccharophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halonatronum saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalonatronumSaccharophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag492Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:492 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag492Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CetobacteriumSomeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium somerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSomeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSabulitectumSilensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sabulitectum silens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSabulitectumSilensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf371Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf371 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf371Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasNasdaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas nasdae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNasdaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNovalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus novalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusNovalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumIntermediumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium intermedium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumIntermediumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUrinalisFb127cna2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis FB127CNA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalisFb127cna2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumPoaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium poae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumPoaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpRoot123d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. Root123D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpRoot123d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRoot700(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot700", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterCapsici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter capsici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterCapsici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenxiniaSaemankumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia saemankumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WenxiniaSaemankumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterCalcoaceticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter calcoaceticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCalcoaceticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AncylostomaCeylanicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma ceylanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCeylanicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TectomicrobiaBacteriumRifcsplowo202full7019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tectomicrobia bacterium RIFCSPLOWO202FULL7019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TectomicrobiaBacteriumRifcsplowo202full7019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaSpMs5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. MS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSpMs5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_12_FULL_44_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho212Full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsUnilateralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps unilateralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsUnilateralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNereisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nereis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioNereisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpLeaf291Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Leaf291 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpLeaf291Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XiphinematobacterSpIdaho(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xiphinematobacter sp. Idaho graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XiphinematobacterSpIdaho", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurotusOstreatusPc15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus PC15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PleurotusOstreatusPc15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusHomiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus homiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHomiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriovoraxMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacteriovorax marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriovoraxMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSteigerwaltii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei steigerwaltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSteigerwaltii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesXylanisolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides xylanisolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesXylanisolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeopsychrobacterElectrodiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geopsychrobacter electrodiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeopsychrobacterElectrodiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterHaemolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter haemolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHaemolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusClarkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] clarkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusClarkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumJilantaienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium jilantaiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumJilantaienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterForsetii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter forsetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterForsetii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpMaddingleyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. Maddingley Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMaddingleyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSd21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SD21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSd21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiPam55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii PAM55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiPam55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumNam1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum NAm1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumNam1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpXs5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. XS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpXs5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSp11andimar09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. 11ANDIMAR09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSp11andimar09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium4415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JatrophihabitansEndophyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jatrophihabitans endophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JatrophihabitansEndophyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumZor0006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ZOR0006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumZor0006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaDiclinaVs20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia diclina VS20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaDiclinaVs20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquiflexumBalticumDsm16537Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquiflexum balticum DSM 16537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquiflexumBalticumDsm16537Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaphidiopsisBrookiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Raphidiopsis brookii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RaphidiopsisBrookiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAmicalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmicalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwb1558Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWB1_55_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwb1558Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermaniaPiniformisNbrc15059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermania piniformis NBRC 15059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SkermaniaPiniformisNbrc15059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpM240Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. M240 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpM240Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpMrs7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. MRS7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpMrs7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSp52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaSp52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KazachstaniaNaganishii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania naganishii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaNaganishii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200250816sch5313054bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200250816SCH5313054b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200250816sch5313054bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KiloniellaMajaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella majae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KiloniellaMajaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UncinocarpusReesii1704Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii 1704 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UncinocarpusReesii1704Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificansPd1222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans PD1222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccusDenitrificansPd1222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaAquamarinaCbs119918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exophiala aquamarina CBS 119918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExophialaAquamarinaCbs119918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaParkeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia parkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaParkeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBiomig1n(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BIOMIG1N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBiomig1n", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaBatsensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola batsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanicolaBatsensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterHartoniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter hartonius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterHartoniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuculusCanorus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cuculus canorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CuculusCanorus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat28573(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28573", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifoxya12Full3519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA12_FULL_35_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya12Full3519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus panis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTetaniE88Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetani E88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTetaniE88Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumHafnienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium hafniense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumHafnienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSanfranciscensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sanfranciscensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSanfranciscensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot157Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root157 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot157Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpIhbb10380(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. IHBB 10380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpIhbb10380", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusOxalaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusOxalaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusLacrimalisDsm7455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis DSM 7455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalisDsm7455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp6717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 67-17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg166620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_66_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ModuliflexusFlocculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moduliflexus flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ModuliflexusFlocculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAap93Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap93Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnanasComosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ananas comosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnanasComosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumFormosenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium formosense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFormosenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSpYr522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. YR522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpYr522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsphigho202full4513bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO202FULL4513b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho202full4513bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpMccc1a10513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MCCC1A10513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSpMccc1a10513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaGlaberrimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza glaberrima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaGlaberrimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaWenyoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaWenyoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpKordi49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1025068Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_50_68 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025068Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAljtCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAljtCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpM26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. M26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpM26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodococcusDrewsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodococcus drewsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiorhodococcusDrewsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensMput9231Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Mput9231 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensMput9231Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichosporonAsahiiVarAsahiiCbs8904Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichosporon asahii var. asahii CBS 8904 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichosporonAsahiiVarAsahiiCbs8904Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumAmurskyense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium amurskyense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumAmurskyense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethylopumilusTuricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusTuricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSpDl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium sp. DL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSpDl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Struthio camelus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StruthioCamelus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferribacteralesBacteriumDeferri01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deferribacterales bacterium Deferri_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeferribacteralesBacteriumDeferri01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfospiraJoergensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfospira joergensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfospiraJoergensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrenneriaSpEnid312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brenneria sp. EniD312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrenneriaSpEnid312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FelisCatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Felis catus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FelisCatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KnoelliaSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumP7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium P7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumP7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaFSpontaneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa f. spontanea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaFSpontaneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpF0418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpF0418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpTv2a2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Tv2a2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpTv2a2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaedi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCinaedi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseicitreumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseicitreum antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseicitreumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromatiaceaeBacterium2141tstbd0c01a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromatiaceae bacterium 2141TSTBD0c01a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromatiaceaeBacterium2141tstbd0c01a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNordiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides nordii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNordiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag831Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:831 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag831Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD1_FULL_40_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd1Full4023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeropyrumPernixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum pernix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeropyrumPernixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PustulibacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pustulibacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PustulibacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaDilworthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia dilworthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDilworthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpPw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. PW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpPw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TardiphagaRobiniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga robiniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TardiphagaRobiniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlboflavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alboflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlboflavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GoniumPectoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gonium pectorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GoniumPectoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTelluritireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas telluritireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTelluritireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesDsm20611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes DSM20611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesDsm20611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCollagenovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCollagenovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriaceaeBacteriumAk24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacteriaceae bacterium AK24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyclobacteriaceaeBacteriumAk24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusCaldoxylosilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus caldoxylosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusCaldoxylosilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1388 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumInfernumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum infernum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumInfernumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3812bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3812b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3812bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpiroformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium spiroforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpiroformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopigerDjelfimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopiger djelfimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopigerDjelfimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_43_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasporobacteriumPaucivoransDsm15970(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans DSM 15970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivoransDsm15970", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa23217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_32_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa23217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesAlkalitoleransDsm16699Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans DSM 16699 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardioidesAlkalitoleransDsm16699Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaSpJg1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. JG-1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpJg1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpMc2013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_45_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAlhagiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea alhagi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaAlhagiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFlevenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium flevense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFlevenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilalesBacteriumMbrsf5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium MBRSF5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumMbrsf5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpRs39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpU41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. U41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpU41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GW2011_GWA2_52_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGw2011Gwa25212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0295Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0295Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaSp6418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. 64-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSp6418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAlcalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alcalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAlcalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusSzentirmaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaBooriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria booriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaBooriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_47_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumPseudogrignonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum pseudogrignonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumPseudogrignonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrobacterSpUrhd0082Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter sp. URHD0082 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSpUrhd0082Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterSpNb311a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. Nb-311A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSpNb311a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7524 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLentus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLentus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIhuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ihuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIhuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspDiarizonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. diarizonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspDiarizonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumGossypii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium gossypii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EremotheciumGossypii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmithellaSpM82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. M82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpM82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusGlacialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlacialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaucusCarotaSubspSativusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Daucus carota subsp. sativus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DaucusCarotaSubspSativusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermusFervidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermus fervidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermusFervidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchekmanbacteriaBacteriumRifcsplowo212full3815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schekmanbacteria bacterium RIFCSPLOWO212FULL3815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchekmanbacteriaBacteriumRifcsplowo212full3815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Giardia intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GiardiaIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr80Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr80Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumRifcsplowo212full3515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisericumExile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum exile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldisericumExile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumStrainCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium strain Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumStrainCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaParisiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella parisiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaParisiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full3410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL3410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full3410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacterSpAm169Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter sp. AM169 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccharibacterSpAm169Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBalearicaDsm6083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas balearica DSM 6083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBalearicaDsm6083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSp31syn3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 31syn3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp31syn3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinivibrionaceaeBacteriumWg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrionaceae bacterium WG-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrionaceaeBacteriumWg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotignumBalticumDsm7044Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotignum balticum DSM 7044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotignumBalticumDsm7044Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelatoporiaSubvermisporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GelatoporiaSubvermisporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisMurinaB123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina B123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PneumocystisMurinaB123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DonghicolaXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Donghicola xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DonghicolaXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBalustinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium balustinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBalustinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMethylpentosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium methylpentosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMethylpentosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacterSpAm169Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter sp. AM169 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccharibacterSpAm169Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPyogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pyogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPyogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastococcusSpUrhd0036Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. URHD0036 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpUrhd0036Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumNanhaiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum nanhaiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumNanhaiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPantholopis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pantholopis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPantholopis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansLl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans LL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansLl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSpOb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. OB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpOb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaHermsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hermsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaHermsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaLitoreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola litoreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicolaLitoreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1264Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1264 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1264Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumGp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocCarnosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc carnosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCarnosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumScgcAaa168p09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA168P09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa168p09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_42_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusJuripiscarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJuripiscarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalicatenaContortaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena contorta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaContortaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OleispiraAntarcticaRb8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oleispira antarctica RB-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OleispiraAntarcticaRb8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSaoudiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella saoudiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSaoudiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumGonidiaformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium gonidiaformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumGonidiaformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusWulumuqiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wulumuqiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWulumuqiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProsthecochlorisSpHl130gsb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. HL130GSB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpHl130gsb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllochromatiumWarmingiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium warmingii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumWarmingiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraPectinoschiza(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira pectinoschiza graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraPectinoschiza", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImtechellaHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Imtechella halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ImtechellaHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumSpOscrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidium sp. OSCR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidiumSpOscrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaOleraceaVarOleracea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea var. oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrassicaOleraceaVarOleracea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpA9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. A9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpA9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterGummiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter gummiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobacterGummiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChisholmbacteriaBacteriumRifcsphigho201full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPHIGHO201FULL4812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsphigho201full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaAurantiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kushneria aurantia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KushneriaAurantiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliterellaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliterella atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliterellaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg1023112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_31_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1023112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasBivalviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas bivalvium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasBivalviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPasteurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPasteurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonas composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonasCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110052Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110052 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110052Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpMitacek01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Mitacek01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpMitacek01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumVivaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium vivax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumVivaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaVermiferaMaff305830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serendipita vermifera MAFF 305830 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerendipitaVermiferaMaff305830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeovibrioSpL21acebesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geovibrio sp. L21AceBES Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeovibrioSpL21acebesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpNCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpNCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrahymenaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrahymenaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusMulierisAtcc35239Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC 35239 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35239Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaHospita(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia hospita graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaHospita", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenimonasSpSl110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenimonas sp. SL110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenimonasSpSl110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicoccusPhenolivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicoccus phenolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicoccusPhenolivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaEpimycesCbs60696Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capronia epimyces CBS 606.96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaproniaEpimycesCbs60696Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaCaroliniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brocadia caroliniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrocadiaCaroliniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MedicagoTruncatulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Medicago truncatula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MedicagoTruncatulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OligoflexusTunisiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oligoflexus tunisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OligoflexusTunisiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharospirillumImpatiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharospirillum impatiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharospirillumImpatiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo202full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumTestudinorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium testudinoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTestudinorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinocyclocheilusRhinocerousEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus rhinocerous Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusRhinocerousEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumL13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium L13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumL13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioVersutusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioVersutusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaPhymatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phymatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhymatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NosemaBombycisCq1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nosema bombycis CQ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NosemaBombycisCq1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaSpongiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella spongiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KiloniellaSpongiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrancourtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella drancourtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrancourtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyramidobacterPiscolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter piscolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterPiscolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGelidilacusDsm15343Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus DSM 15343 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacusDsm15343Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMycoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mycoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMycoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalanaerobiumKushneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium kushneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumKushneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumGw2011gwc2489Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC2489 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc2489Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumFunditumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium funditum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumFunditumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaViridescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella viridescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaViridescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumSpTc51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium sp. TC51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumSpTc51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsMilitarisCm01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris CM01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CordycepsMilitarisCm01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UlvibacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UlvibacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPHIGHO2_12_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaRuckeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia ruckeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaRuckeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsphigho202full3936(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPHIGHO202FULL3936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsphigho202full3936", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohongiellaActicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella acticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaActicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterosteliumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heterostelium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeterosteliumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorellaVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorella variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorellaVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesGambiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles gambiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesGambiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSpSpongeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. sponge Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpSpongeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeobacterItalicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterItalicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorObsidiansisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor obsidiansis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorObsidiansisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApisMellifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apis mellifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApisMellifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraCerevisiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera cerevisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraCerevisiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaMonticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia monticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMonticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaPlatycodiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asaia platycodi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsaiaPlatycodiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumAquidurense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquidurense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquidurense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPhragmitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium phragmitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPhragmitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelosinusFermentansJbw45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans JBW45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PelosinusFermentansJbw45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrucellaAbortus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brucella abortus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrucellaAbortus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ModestobacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPiscium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus piscium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusPiscium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRbg164519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG_16_45_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg164519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldivirgaSpMu80Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga sp. MU80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaSpMu80Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaGinsengisegetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga ginsengisegetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaGinsengisegetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHomeothermusArabinoxylanisolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Homeothermus arabinoxylanisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHomeothermusArabinoxylanisolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusSpJcm16833(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. JCM 16833 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpJcm16833", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaBooneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula boonei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaBooneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicocarpusGriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicocarpus griseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicocarpusGriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusBathoardescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus bathoardescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusBathoardescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLepromatosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lepromatosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLepromatosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConidiobolusCoronatusNrrl28638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus NRRL 28638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ConidiobolusCoronatusNrrl28638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumGwf24416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJhl9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JHL9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJhl9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GonapodyaProliferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gonapodya prolifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GonapodyaProliferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumLinens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium linens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumLinens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasCommunisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas communis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCommunisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHimastatinicusAtcc53653Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus ATCC 53653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicusAtcc53653Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag380Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:380 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag380Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAmikacinitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia amikacinitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAmikacinitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterNeustonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter neustonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterNeustonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSuccinogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSuccinogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCapitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus capitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCapitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifoxyb2full327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYB2FULL327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxyb2full327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaCherrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella cherrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaCherrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusHansupus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus hansupus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcusHansupus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobiformaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobiformaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicolaPhilippinesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Philippines Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynesporaCassiicolaPhilippinesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnaportheOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthe oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnaportheOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumCellulosolvens6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvens6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumIriomotenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium iriomotense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumIriomotenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitrellaBrassicaformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VitrellaBrassicaformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumSpRoot344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root344 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs3022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-3022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs3022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiscibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusAlbusJl83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus albus JL83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusAlbusJl83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023751Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023751Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumCg1024916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhanerochaeteCarnosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KineothrixAlysoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kineothrix alysoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KineothrixAlysoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaFormicigeneransAtcc27755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans ATCC27755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigeneransAtcc27755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaCrocinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia crocina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaCrocinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwe23121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE23121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe23121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemobosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemobos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemobosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumCryptum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium cryptum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumCryptum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaAsperellumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma asperellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAsperellumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipaludibacillusAurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium filum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallithrixJacchus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Callithrix jacchus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CallithrixJacchus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo202full4113bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO202FULL4113b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo202full4113bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacteriumUrhd0088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpHmp27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. HMP27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpHmp27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SericytochromatiaBacteriumS15bmn24cbmw12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24CBMW_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24cbmw12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph758Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH758 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph758Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaPthiripubisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pthiripubis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPthiripubisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumGwa2349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWA2349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwa2349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusBvHnlc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaMazeiS6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina mazei S-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaMazeiS6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaSpUtamx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus salinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarlitoSyrichtaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carlito syrichta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarlitoSyrichtaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpSk02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpR372017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpR372017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpGcs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. GCS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpGcs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthinifaciensDsm18436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens DSM 18436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensDsm18436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumCg1023735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG1_02_37_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg1023735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaChinhatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia chinhatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaChinhatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUrinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus urinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUrinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFlexibilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flexibilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlexibilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSalivarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus salivarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSalivarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PuniceicoccalesBacteriumVerruco02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumChlororespiransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium chlororespirans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumChlororespiransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_40_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpArr65(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ARR65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpArr65", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusPenneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Proteus penneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProteusPenneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaLaeviribosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cohnella laeviribosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CohnellaLaeviribosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HathewayaProteolyticaDsm3090(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica DSM 3090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HathewayaProteolyticaDsm3090", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnr698(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNR698 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnr698", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumBakiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium bakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumBakiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodospiraMagnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira magna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMagnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCip642Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP 64.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip642Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo212full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO212FULL4312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo212full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinatimonasHippei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas hippei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasHippei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSp117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSp117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaAtypicaKonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica KON Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaKonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MikellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mikella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MikellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratireductorIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratireductorIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolyporusArculariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polyporus arcularius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolyporusArculariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaBovineEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica BOVINE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaBovineEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSp7392Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp7392Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YoungiibacterFragilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Youngiibacter fragilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YoungiibacterFragilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Raymondbacteria bacterium RIFOXYC2_FULL_50_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRaymondbacteriaBacteriumRifoxyc2Full5021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroherpetonThalassiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroherpeton thalassium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroherpetonThalassiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumCg1023251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1023251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1023251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasCampaniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas campaniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasCampaniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAfermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium afermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAfermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumMathurenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium mathurense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMathurenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSpPamc27137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. PAMC27137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LacinutrixSpPamc27137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TersicoccusPhoenicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus phoenicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TersicoccusPhoenicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasWeihenstephanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas weihenstephanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasWeihenstephanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumHalliiVarHallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Panicum hallii var. hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PanicumHalliiVarHallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpNrrls836Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. NRRLS836 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpNrrls836Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSalinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina salinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSalinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf22910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_29_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf22910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDevrieseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus devriesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDevrieseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwb24212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumVaginaeDsm15829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae DSM15829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaeDsm15829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_41_86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasSpFbcd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FBCd graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFbcd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSp13d2w2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. 13D2W2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSp13d2w2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CentipedaPeriodontii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Centipeda periodontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CentipedaPeriodontii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpC8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusVersutusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccusVersutusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaNautarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella nautarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaNautarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaMarilimosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olleya marilimosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlleyaMarilimosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterThalassicusDsm15285Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus DSM 15285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TepidibacterThalassicusDsm15285Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaKirkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kirkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKirkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLmg23823Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis LMG23823 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLmg23823Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusObesiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusObesiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusLuminescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus luminescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusLuminescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterAsymbioticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter asymbioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterAsymbioticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rahnella aquatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RahnellaAquatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk569Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK569 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk569Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpFobrc9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaVacuolataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraHampsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hampsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHampsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpPamc21119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PAMC21119 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPamc21119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAscendens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ascendens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAscendens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpOr444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OR444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOr444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TersicoccusPhoenicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus phoenicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TersicoccusPhoenicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaFormosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poecilia formosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoeciliaFormosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSihwensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sihwensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GordoniaSihwensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpTb67Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb67Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumErythreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium erythreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumErythreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusLocisalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus locisalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusLocisalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium5246(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 52_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium5246", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAceti1023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti 1023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAceti1023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSp428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 42_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaSp428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf104 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosyntrophaLipolyticaDsm11003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica DSM 11003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolyticaDsm11003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedibacterAcanthamoebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterAcanthamoebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumDg741Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg741Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OstreococcusTauriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus tauri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OstreococcusTauriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NdongobacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ndongobacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NdongobacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpNap1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. NAP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpNap1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JohnsonellaIgnavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Johnsonella ignava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JohnsonellaIgnavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtrovirideCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma atroviride Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAtrovirideCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaSpLrs4154(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. LRS4.154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpLrs4154", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcumNcimb8003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum NCIMB 8003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AzotobacterChroococcumNcimb8003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusVerrucosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus verrucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusVerrucosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesProvencensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesProvencensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusOccultusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus occultus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronococcusOccultusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_54_21b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaOh4807(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida OH4807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaOh4807", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoheibacterSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moheibacter sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoheibacterSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BariatricusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bariatricus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BariatricusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSpT436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sp. T436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSpT436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaPhagocytophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma phagocytophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaPhagocytophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpMrs7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. MRS7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpMrs7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSuncheonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium suncheonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuncheonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichophytonRubrumCbs118892Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum CBS 118892 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichophytonRubrumCbs118892Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobellusClavatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobellus clavatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobellusClavatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCalifornicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma californicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCalifornicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_02_FULL_48_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microsporum canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrosporumCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfacinumInfernumDsm9756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum infernum DSM 9756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumInfernumDsm9756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisJsc3bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris JSC-3b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisJsc3bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacillusAlimentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusAlimentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothricoidesSpSr001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktothricoides sp. SR001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktothricoidesSpSr001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumRubensWisconsin541255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Wisconsin 54-1255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRubensWisconsin541255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TamlanaSedimentorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tamlana sedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TamlanaSedimentorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrithrixThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPerolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus perolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPerolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MinicystisRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Minicystis rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MinicystisRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpCfcc11742Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CFCC 11742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCfcc11742Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AromatoleumToluclasticumAtcc700605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum ATCC 700605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AromatoleumToluclasticumAtcc700605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpMi1205Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. MI1205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpMi1205Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaDejecticolaCbs10117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola CBS 10117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KwoniellaDejecticolaCbs10117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraSpRifcsplowo202full4514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. RIFCSPLOWO202FULL4514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpRifcsplowo202full4514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSpOh31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. OH31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylophilusSpOh31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropilaelapsMercedesae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tropilaelaps mercedesae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TropilaelapsMercedesae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel133131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_33_131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel133131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfatibacterAminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinus1366(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus 1366 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinus1366", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatellicoccusMarimammaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catellicoccus marimammalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatellicoccusMarimammaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloprofundusSedimentiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloprofundus sedimenti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloprofundusSedimentiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FolsomiaCandidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Folsomia candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FolsomiaCandidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpKbs0721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KBS0721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKbs0721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiaceaeBacteriumRaap2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiaceae bacterium RAAP-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiaceaeBacteriumRaap2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusDuerdeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus duerdenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusDuerdeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterHaemolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter haemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHaemolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GigasporaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gigaspora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GigasporaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallosphaeraYellowstonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera yellowstonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraYellowstonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpMf4836Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. MF4836 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMf4836Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpR4368Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. R4368 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpR4368Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpF52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. F52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpF52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_49_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumCg2304514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_45_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg2304514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium13140cm6619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_66_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrozanskiiLlap1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella drozanskii LLAP-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaDrozanskiiLlap1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpFb24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. FB24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpFb24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaPectinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicella pectinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicellaPectinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxyc12full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYC12FULL3613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyc12full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacificimonasFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacificimonas flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacificimonasFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCylindrosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpFa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. FA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpFa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeR6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae R6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeR6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamulariaCollocygniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ramularia collocygni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RamulariaCollocygniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanospirillumHungateiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanospirillum hungatei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanospirillumHungateiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmoSalarCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmo salar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmoSalarCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCb02923Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02923 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02923Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp21311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2131.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpUrhd0069Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHD0069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrhd0069Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumGrantiiDsm8605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium grantii DSM 8605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumGrantiiDsm8605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuricataSuricatta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Suricata suricatta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuricataSuricatta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorghumBicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sorghum bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SorghumBicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSegnisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter segnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSegnisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPelagiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pelagia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPelagiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumDentiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium dentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumDentiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumDichloroeliminansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dichloroeliminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDichloroeliminansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisSaalfeldensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis saalfeldensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSaalfeldensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifoxyd12full6137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFOXYD12FULL6137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifoxyd12full6137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full3819Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3819 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3819Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFastidiosusNbrc101226Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus NBRC 101226 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusFastidiosusNbrc101226Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionNc10BacteriumCsp15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium CSP1-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumCsp15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterNitrofigilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter nitrofigilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterNitrofigilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobiumNarugenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobium narugense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobiumNarugenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeriolaLalandiDorsalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Seriola lalandi dorsalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SeriolaLalandiDorsalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb2Full4511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB2_FULL_45_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb2Full4511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoodsholeaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woodsholea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoodsholeaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumColicanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium colicanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumColicanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseofuscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseofuscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseofuscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilumDsm16684(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum DSM 16684 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilumDsm16684", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCatenulatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium catenulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumCatenulatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSp7sr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 7SR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSp7sr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermincolaPotens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermincola potens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermincolaPotens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumScadc123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium SCADC1_2_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumScadc123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusIntermediusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus intermedius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIntermediusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimonasTaiwanensisNbrc104434(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis NBRC 104434 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensisNbrc104434", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpEur3121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. EUR3 1.2.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpEur3121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophusAciditrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus aciditrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophusAciditrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPunctiformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc punctiforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocPunctiformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaLimosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Runella limosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RunellaLimosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumRoseumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumRoseumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpBa94Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa94Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacteriaceaeBacteriumStrain(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium strain graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumStrain", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonSg8523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SG8-52-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSg8523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpRoot635Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root635 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot635Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaMalonicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa malonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporomusaMalonicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_40_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumCg2306627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_66_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2306627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCollagenovoransDsm3089(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans DSM 3089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCollagenovoransDsm3089", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiodendronMaiusZnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oidiodendron maius Zn Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OidiodendronMaiusZnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlbugoCandidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Albugo candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlbugoCandidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesJenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesJenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium5246Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 52_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium5246Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CylindrobasidiumTorrendiiFp15055Ss10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii FP15055 ss-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendiiFp15055Ss10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaSp609Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. 60_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSp609Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustrisStrTousCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus lacustris str. Tous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SynechococcusLacustrisStrTousCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavisolibacterGinsengisoliDsm18119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli DSM 18119 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoliDsm18119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpRitpie(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. RITPIe graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpRitpie", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaSpR2a130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. R2A130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSpR2a130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusParasiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusParasiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilariopsisChordaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilariopsis chorda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilariopsisChordaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesAcidifaciensJcm10556Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens JCM 10556 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciensJcm10556Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterShowaeCc57cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CC57C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCc57cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumIranicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium iranicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumIranicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSubantarcticusLmg24377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus LMG 24377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticusLmg24377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetschnikowiaSpJcm33374Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia sp. JCM 33374 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaSpJcm33374Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensF113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens F113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensF113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnicoccusIslandicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusIslandicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumMedacidig2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5050 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevrieseaAgamarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devriesea agamarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevrieseaAgamarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerfeziaBoudieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terfezia boudieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerfeziaBoudieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabilibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZymaeDsm19395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zymae DSM 19395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZymaeDsm19395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCoronafaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaJinanensisNbrc108249Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jinanensis NBRC 108249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaJinanensisNbrc108249Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterLobularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter lobularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterLobularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmazonaCollariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amazona collaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmazonaCollariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpHu2014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. HU2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpHu2014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMusc14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlatysternonMegacephalum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Platysternon megacephalum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlatysternonMegacephalum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesShahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes shahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesShahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifcsplowo201full4625Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4625 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4625Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaBrunneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marssonina brunnea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarssoninaBrunneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpCaciam22h1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. CACIAM 22H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpCaciam22h1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat28573Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28573Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisBryophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis bryophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocystisBryophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSelenitireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium selenitireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSelenitireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaFormicigenerans4653afaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans 4653AFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigenerans4653afaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisLatens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis latens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisLatens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpUnccl10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. UNCCL10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpUnccl10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaHalocynthiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria halocynthiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaHalocynthiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumCulicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smittium culicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmittiumCulicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSpDielmo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. Dielmo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KurthiaSpDielmo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothrixSoehngeniiGp6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii GP6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanothrixSoehngeniiGp6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpYim77409(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. YIM77409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermusSpYim77409", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFlocculareAtcc27399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare ATCC 27399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFlocculareAtcc27399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp141(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp141", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumisSativusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cucumis sativus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CucumisSativusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasSpCnpt3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas sp. CNPT3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromonasSpCnpt3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPestis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pestis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaPestis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomassariellaVexata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomassariella vexata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomassariellaVexata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaSeohaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga seohaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSeohaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodolunaLacicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna lacicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodolunaLacicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiangellaPhaseoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xiangella phaseoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XiangellaPhaseoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo6530Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_65_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo6530Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasSpLeaf148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaElongataSubspGlycolyticaAtcc29315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria elongata subsp. glycolytica ATCC 29315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaElongataSubspGlycolyticaAtcc29315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaSp1155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga sp. 1155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinitogaSp1155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpT16b2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. T16B2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpT16b2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMimosarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mimosarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMimosarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpUnccl28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNCCL28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUnccl28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumVincentii4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 4113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriMsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri MS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriMsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterJuniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter junii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJuniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteralesBacteriumY4i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Y4I graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumY4i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlutamicibacterSp0426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter sp. 0426 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterSp0426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf25010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_50_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf25010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSymbiosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] symbiosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusDictyosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus dictyosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusDictyosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinatimonasSpCag777Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas sp. CAG:777 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasSpCag777Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaAlbaNbrc15616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] alba NBRC 15616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaAlbaNbrc15616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusStilesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus stilesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusStilesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovermiculusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterInsuavisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insuavis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterInsuavisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GayadomonasJoobiniegeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gayadomonas joobiniege Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GayadomonasJoobiniegeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraSpAngm7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13220cm2648Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM2648 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm2648Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterIcosiumassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter icosiumassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterIcosiumassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterPetaseusNbrc106054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus NBRC 106054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseusNbrc106054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumGa0077544Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077544Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumCfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium CF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumCfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamsiaSp1138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusBidgolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus bidgolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusBidgolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0386Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0386Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaNanhaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nanhaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNanhaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloterricolaOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloterricola oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloterricolaOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaSpA37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. A37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpA37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaArvensicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga arvensicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaArvensicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynesporaCassiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynespora cassiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynesporaCassiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacacaMulattaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macaca mulatta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacacaMulattaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyroidesGuanonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myroides guanonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyroidesGuanonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusXiangfangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus xiangfangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusXiangfangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumDolichumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium dolichum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumDolichumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaStibiiresistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpOralTaxon431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. oral taxon 431 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpOralTaxon431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPseudalcaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudalcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudalcaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumCg2304417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG2304417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg2304417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OncorhynchusMykissEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oncorhynchus mykiss Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OncorhynchusMykissEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaBestiolaeCbs10118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae CBS 10118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KwoniellaBestiolaeCbs10118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumPavilionensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium pavilionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumPavilionensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgulaAerodenitrificansDsm15089(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans DSM 15089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificansDsm15089", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CF335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraMultiparaLb2003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara LB2003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaLb2003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg136212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_62_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedSup05ClusterBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UnculturedSup05ClusterBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusCarbonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus carbonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusCarbonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrispumMunicipaleDsm44069Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum municipale DSM 44069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumMunicipaleDsm44069Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CallithrixJacchusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Callithrix jacchus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CallithrixJacchusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterKomagataeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter komagatae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterKomagataeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasZehnderiOl4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi OL-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderiOl4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaTractuosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivirga tractuosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivirgaTractuosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumIndolisDsm755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] indolis DSM 755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumIndolisDsm755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanoprotosteliumFungivorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planoprotostelium fungivorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanoprotosteliumFungivorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumExtorquensAm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens AM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensAm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasVranovensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVranovensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaJaponicaGroupEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Group Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaJaponicaGroupEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixEikelboomiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix eikelboomii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiothrixEikelboomiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusHareiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus harei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusHareiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpP6b1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P6B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP6b1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSpHmsc063g07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. HMSC063G07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpHmsc063g07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotaleaMetallivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotalea metallivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotaleaMetallivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19038Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19038 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19038Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansPlanktonicusIiD5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus II-D5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicusIiD5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlomusCerebriformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glomus cerebriforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlomusCerebriformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaMimosarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia mimosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMimosarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBolteaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bolteae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBolteaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmoTruttaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmo trutta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmoTruttaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo202full5117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL5117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full5117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrusClementinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrus clementina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrusClementinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PriciaAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pricia antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PriciaAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaSpW9106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella sp. W9106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaSpW9106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpHmica12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HmicA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHmica12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPsychrosaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus psychrosaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPsychrosaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpHel13349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel13349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolaribacterSpHel13349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterLuteolus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterLuteolus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemetriaTerragena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demetria terragena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemetriaTerragena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpT28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. T28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpT28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpDfci1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DFCI1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDfci1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMaculosaOt289Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa OT 289 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaMaculosaOt289Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaceaeBacteriumHun156Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium HUN156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumHun156Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinimicrobiumSpCnj824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium sp. CNJ-824 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumSpCnj824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_44_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4422b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusObesiensisPh10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis ph10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusObesiensisPh10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumVulpinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium vulpinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumVulpinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpLeaf139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Leaf139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLeaf139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusLaevolacticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus laevolacticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusLaevolacticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaSpSsl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba sp. SSL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaSpSsl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatabacterHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catabacter hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatabacterHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumHaemolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium haemolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumHaemolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifoxyb12full5810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB12FULL5810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb12full5810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumA2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwa2359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA2359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa2359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaMinasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia minasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMinasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAsiaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium asiaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAsiaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbusAd2013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus AD2013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusAlbusAd2013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho201full3616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO201FULL3616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho201full3616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45544Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45544 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45544Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypocladiumParadoxumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium paradoxum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumParadoxumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaVagans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea vagans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaVagans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSubrubescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium subrubescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSubrubescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterSuperfactus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter superfactus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterSuperfactus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterPapayaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter papayae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPapayaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumObuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium obuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumObuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NucleicultrixAmoebiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nucleicultrix amoebiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NucleicultrixAmoebiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaFlocculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga flocculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaFlocculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreimonasSalinaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citreimonas salinaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitreimonasSalinaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovoculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovoculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovoculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyc1full3779Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYC1FULL3779 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyc1full3779Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaCaldifontisAzm44c09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga caldifontis AZM44c09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermotogaCaldifontisAzm44c09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MediterraneaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mediterranea massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MediterraneaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaGinsengisoliNbrc100965Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengisoli NBRC 100965 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengisoliNbrc100965Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreniaMetallireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orenia metallireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OreniaMetallireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThamnocephalisSphaerosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thamnocephalis sphaerospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThamnocephalisSphaerosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumBica17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbaceaeBacteriumDb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium DB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumDb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterActiniarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo212full599(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO212FULL599 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo212full599", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpUrha0020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwa25525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1025068Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_50_68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025068Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanohaloarchaeaArchaeonB1br10u2g1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAvicenniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avicenniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvicenniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygii9h2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter syzygii 9H-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterSyzygii9h2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunicoccusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptunicoccus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptunicoccusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgc07wgaepuloa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGC07WGAEpuloA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgc07wgaepuloa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc055a01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC055A01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc055a01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPylori26695Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori 26695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPylori26695Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasChromatireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas chromatireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasChromatireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusCyri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus cyri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusCyri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwb25519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWB2_55_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwb25519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaOralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kingella oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KingellaOralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMrmr6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MRMR6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMrmr6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbus7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyosteliumPurpureumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium purpureum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumPurpureumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DialisterMicroaerophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dialister microaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DialisterMicroaerophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusChilensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterFreundiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter freundii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterFreundiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpHtcc2170Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. HTCC2170 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpHtcc2170Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_12_FULL_41_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRuminococcusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Ruminococcus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedRuminococcusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZinciduransB6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zincidurans B6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasZinciduransB6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JejuiaPallidiluteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jejuia pallidilutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JejuiaPallidiluteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophusFodinaeScgcAaa011A17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophus fodinae SCGC AAA011-A17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophusFodinaeScgcAaa011A17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpKh2c16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. KH2C16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh2c16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSp12014mblmicdivEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. 12014MBLMicDiv Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterSp12014mblmicdivEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiBc1401(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi BC1401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiBc1401", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaCaballeronisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caballeronis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaballeronisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloceanibacterMethanicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter methanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterMethanicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HandroanthusImpetiginosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Handroanthus impetiginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HandroanthusImpetiginosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb1388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB1388 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb1388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. ozaenae NBRC 105683 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KribbellaCatacumbaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kribbella catacumbae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KribbellaCatacumbaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0091(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0091", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickenellaMellea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickenella mellea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickenellaMellea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumBouchesdurhonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium bouchesdurhonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumBouchesdurhonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusIhuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaJasoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hippea jasoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HippeaJasoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAnimalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JorgensenbacteriaBacteriumGw2011gwb15010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB15010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb15010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpRoot265Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root265 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot265Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaMycoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mycoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMycoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm46838Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46838Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabiaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arabia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArabiaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201350091sch5140682Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201350091SCH5140682 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201350091sch5140682Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg1024923Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_49_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1024923Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpYr620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR620 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureobasidiumSubglacialeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumSubglacialeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeNbb3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae NBB3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeNbb3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNaeslundiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces naeslundii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNaeslundiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSetenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium setense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSetenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotaleaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotalea psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotaleaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusAutotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioglobusAutotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpFcs006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumBaderiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium baderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumBaderiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErinaceusEuropaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erinaceus europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErinaceusEuropaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSpMsx33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. MSX33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpMsx33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesPombe972hCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe 972h- Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombe972hCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BaudoiniaPanamericanaUamh10762Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia panamericana UAMH 10762 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaPanamericanaUamh10762Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritaleaMyrionectaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maritalea myrionectae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaritaleaMyrionectaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaSp7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. 7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSp7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumPopuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumPopuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpSoapEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpSoapEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocaceaeBacteriumR53105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostocaceae bacterium R-53105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocaceaeBacteriumR53105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpB7740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. B7740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpB7740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorothrixHollandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorothrix hollandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorothrixHollandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosimicrobiumCellulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumGlobosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumGlobosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc5015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC5015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc5015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneatrixAlpicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Balneatrix alpica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BalneatrixAlpicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls1022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SistotremastrumNiveocremeumHhb9708Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum HHB9708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeumHhb9708Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRu3701Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ru370.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu3701Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaRufipogon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza rufipogon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaRufipogon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpPamc28756Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. PAMC 28756 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpPamc28756Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumCelatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium celatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumCelatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaWaksmanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella waksmanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWaksmanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 39-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CottopercaGobioCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cottoperca gobio Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CottopercaGobioCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifoxya2full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL4118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCatoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas catoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCatoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo212full3610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO212FULL3610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo212full3610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtribacteriaBacteriumCg2303313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium CG2303313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumCg2303313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantiiEch586Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch586Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JaapiaArgillaceaMucl33604Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Jaapia argillacea MUCL 33604 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JaapiaArgillaceaMucl33604Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumFreii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium freii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFreii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23338Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23338Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAidingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAidingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumGasigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium gasigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGasigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_47_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PestalotiopsisFici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PestalotiopsisFici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKa00344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KA00344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKa00344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPseudogenitaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudogenitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudogenitaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PurpureocilliumLilacinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Purpureocillium lilacinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PurpureocilliumLilacinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbaceaeBacteriumBrhc16aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium BRHc16a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumBrhc16aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrochothrixCampestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix campestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrochothrixCampestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella porci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPorciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NevskiaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nevskia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NevskiaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfCtenarytainaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGwa15412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GWA1_54_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGwa15412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMurinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus murinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMurinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSp20bn(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 20BN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSp20bn", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraViennensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraViennensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFabifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fabifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFabifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumAerolatumDsm21857Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum DSM 21857 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatumDsm21857Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpT32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. T32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpT32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaE681Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa E681 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaE681Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPentosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pentosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPentosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercosporaZeinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cercospora zeina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CercosporaZeinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusZopfii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusZopfii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag485Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag485Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraSpMz1tEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. MZ1T Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraSpMz1tEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalorhabdusDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiohalorhabdus denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiohalorhabdusDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumAquaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumAquaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisMaydisC5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris maydis C5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BipolarisMaydisC5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BosIndicusXBosTaurus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bos indicus x Bos taurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BosIndicusXBosTaurus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermatophilusCongolensisDsm44180Nbrc105199Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis DSM 44180 NBRC 105199 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DermatophilusCongolensisDsm44180Nbrc105199Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD2_FULL_43_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasKyonanensisDsm18153(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis DSM 18153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FerrimonasKyonanensisDsm18153", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiophoraPuteanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coniophora puteana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ConiophoraPuteanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesSilverae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces silverae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomycesSilverae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTsri0107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusJostii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus jostii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusJostii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMadurae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura madurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMadurae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HanseniasporaUvarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora uvarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaUvarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwa13910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA13910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa13910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full3710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL3710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full3710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpRuh2624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. RUH2624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpRuh2624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanisaetaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumH88Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H88 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH88Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PersephonellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Persephonella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PersephonellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusReticulitermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus reticulitermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusReticulitermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichophytonBenhamiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichophytonBenhamiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumNeopropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum neopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumNeopropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerribacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerribacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumGw2011gwb14719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWB14719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwb14719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaNamucuonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia namucuonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaNamucuonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMarinisedimentorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marinisedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMarinisedimentorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeterosteliumAlbumPn500(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Heterostelium album PN500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HeterosteliumAlbumPn500", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusPauculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pauculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPauculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisParvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocystisParvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterItalicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter italicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterItalicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumHallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Panicum hallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PanicumHallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleiagrimonasSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oleiagrimonas soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OleiagrimonasSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaMorsitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina morsitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaMorsitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumDahliaeVdls17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae VdLs.17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VerticilliumDahliaeVdls17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisInaquosorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis inaquosorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisInaquosorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusOrnithinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus ornithinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusOrnithinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpCag318(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. CAG:318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpCag318", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaitoellaComplicataNrrlY17804Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saitoella complicata NRRL Y-17804 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaitoellaComplicataNrrlY17804Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaFlavescensSk114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens SK114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensSk114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsCamponotirufipedisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps camponotirufipedis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsCamponotirufipedisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSpBf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. BF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSpBf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGordoniiMs1Dsm23371Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii MS-1 DSM 23371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGordoniiMs1Dsm23371Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesDoreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides dorei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesDoreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexilineaFlocculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flexilinea flocculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlexilineaFlocculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu053(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu053", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasJandaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas jandaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasJandaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumExtorquensAm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens AM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensAm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DactylosporangiumAurantiacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dactylosporangium aurantiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DactylosporangiumAurantiacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLugdunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseospirillumParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseospirillum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseospirillumParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKefiranofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiranofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiranofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacillusAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUrinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus urinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUrinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag508(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:508 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag508", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTubingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusTubingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD2_FULL_50_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaetiporusSulphureus9353Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus 93-53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LaetiporusSulphureus9353Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzotobacterVinelandii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter vinelandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzotobacterVinelandii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinispirillumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinispirillum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinispirillumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_38_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisDassonvilleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis dassonvillei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisDassonvilleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCloacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cloacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCloacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterWandonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter wandonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterWandonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg19ftcombo5516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG19FTCOMBO5516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg19ftcombo5516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEisenbacteriaBacteriumRbg167146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Eisenbacteria bacterium RBG_16_71_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusEisenbacteriaBacteriumRbg167146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesVaccimaxillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vaccimaxillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesVaccimaxillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHmsc067h01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HMSC067H01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHmsc067h01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaLoihica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella loihica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaLoihica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusDevrieseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus devriesei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDevrieseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesQaidamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qaidamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQaidamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasArenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas arenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasArenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeNbb3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae NBB3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeNbb3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumRifcsplowo201full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL3811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc28b08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC28B08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc28b08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaProvencensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProvencensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosphaeraAminiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterHelveticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter helveticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FranconibacterHelveticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylovulumMiyakonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGerencseriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesGerencseriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitansKin4MCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Kin4-M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeumEquitansKin4MCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaSpSsl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba sp. SSL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaSpSsl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermanaerothrixDaxensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerothrix daxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermanaerothrixDaxensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDadantii3937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii 3937 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantii3937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMageritenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mageritense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMageritenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaBeijingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia beijingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaBeijingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpWcd2001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd2001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionSr1BacteriumRaac1sr11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium RAAC1SR11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumRaac1sr11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSpM21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraHydrothermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera hydrothermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraHydrothermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa14423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_44_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa14423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpYe44Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. YE44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpYe44Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSmegmatisMc2155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis MC2155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisMc2155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaAmbifaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ambifaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAmbifaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthorchisFelineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis felineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisFelineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesImmunogenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides immunogenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesImmunogenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ManacusVitellinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Manacus vitellinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ManacusVitellinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo212full6540Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6540 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6540Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondrusCrispusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chondrus crispus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChondrusCrispusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDesertiGimn1010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium deserti GIMN1.010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDesertiGimn1010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergenciaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emergencia timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmergenciaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpP4b1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. P4B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpP4b1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocystisViolascens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiocystis violascens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiocystisViolascens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCelatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium celatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylorubrumSalsuginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum salsuginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumSalsuginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwc27318Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWC2_73_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwc27318Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichosporonAsahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichosporon asahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichosporonAsahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a519a13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_519A13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a519a13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg135136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_40_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChersinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora chersina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaChersinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRubida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rubida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRubida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumNordicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nordicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNordicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpElb17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ELB17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpElb17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full4719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full4719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAlaskensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alaskensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlaskensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumF0540Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium F0540 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumF0540Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3715 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpSe50110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. SE50110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpSe50110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAveniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas aveniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAveniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumBrhc4b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCurdlanolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus curdlanolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCurdlanolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23548(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_35_48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23548", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasSpFh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas sp. FH1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasSpFh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantisNrrlB14911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus infantis NRRL B-14911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusInfantisNrrlB14911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCf332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesToyocaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces toyocaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesToyocaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeothermarchaeotaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geothermarchaeota archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeothermarchaeotaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofustisGlycolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpRc3b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc3b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxyb1full4324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYB1FULL4324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyb1full4324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidocella aminolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidocellaAminolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpLeaf159Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf159Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpAle5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. ALE5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpAle5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraMultiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira multiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraMultiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27445(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27445 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27445", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringensAtcc13124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens ATCC13124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringensAtcc13124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaCremea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora cremea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCremea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaFiliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaFiliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSp4847faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 4847FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CollinsellaSp4847faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaSp2ht1a6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. 2HT1A6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSp2ht1a6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinithermusHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinithermus hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinithermusHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumPmmr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium PMMR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumPmmr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyripristisMurdjanCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myripristis murdjan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyripristisMurdjanCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscodesmisNigricans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ascodesmis nigricans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AscodesmisNigricans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PvcGroupBacteriumExBugulaNeritinaAb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return PVC group bacterium (ex Bugula neritina AB1) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PvcGroupBacteriumExBugulaNeritinaAb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPrimitiaZas2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAquimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aquimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAquimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaRaraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella rara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRaraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumBaderi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium baderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumBaderi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpEs010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. ES.010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpEs010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasConfluentis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas confluentis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasConfluentis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSanguineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sanguineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSanguineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbiconiuxSpYr403(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux sp. YR403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSpYr403", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHylemonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hylemonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHylemonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaInulinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia inulinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaInulinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCag988Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CAG:988 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCag988Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpTrpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. TRP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpTrpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpF0209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSobriaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sobria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSobriaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag486Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:486 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag486Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlbimonasDonghaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Albimonas donghaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlbimonasDonghaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWF2_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwf24219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph809Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH809 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph809Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaAfzeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella afzelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaAfzeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1388 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaXyliCtcb07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli CTCB07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCtcb07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpCg912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. CG912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpCg912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacearchaeotaArchaeonRbg133326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacearchaeota archaeon RBG_13_33_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacearchaeotaArchaeonRbg133326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag768Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:768 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag768Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpMarseillep2426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. MarseilleP2426 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpMarseillep2426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFh2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpAw25m09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. AW25M09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpAw25m09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldalkalibacillusThermarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldalkalibacillus thermarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldalkalibacillusThermarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumPacificumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum pacificum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumPacificumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothermobacterSpEprmCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geothermobacter sp. EPRM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeothermobacterSpEprmCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumBact13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumL18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium L18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumL18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumPaucimobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium paucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPaucimobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpAtcc39149(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. ATCC39149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpAtcc39149", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusMarisflaviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMarisflaviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaJinanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jinanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaJinanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter koseri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterKoseriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusObscurus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus obscurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusObscurus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GimesiaMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gimesia maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GimesiaMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusKhoisanaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus khoisanae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKhoisanaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumHum1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumGallicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromycesRobustusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyces robustus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromycesRobustusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpDmb20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. DMB20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpDmb20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSediminilitorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sediminilitoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSediminilitorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitibacterAlkalitoleransDsm16504Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans DSM 16504 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitoleransDsm16504Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_43_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwa23526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWA2_35_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwa23526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterGerneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gerneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGerneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumEnclenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium enclense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumEnclenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpFcs006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumGwa2528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_52_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa2528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasHussainiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas hussainii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHussainiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusPelagiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus pelagius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusPelagiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira kmetyi serovar Malaysia str. Bejo-Iso9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHeilongjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus heilongjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHeilongjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpW2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp157mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 157MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp157mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrarchaeotaArchaeonCg1025115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrarchaeotaArchaeonCg1025115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_51_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisS2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis S2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisS2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSpMe1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. ME-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpMe1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumOlb10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GigasporaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gigaspora rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GigasporaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNodosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces nodosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNodosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidiaBacteriumGa0077558(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium Ga0077558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacteriumGa0077558", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaSpNrrlb16802(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NRRLB16802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNrrlb16802", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVireti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vireti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusVireti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaSkyensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella skyensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaSkyensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlkaliphilaYim80379Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila YIM 80379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphilaYim80379Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag451Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag451Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaBoryana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya boryana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaBoryana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylovorusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylovorus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylovorusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrucibulumLaeveEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crucibulum laeve Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrucibulumLaeveEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumDtu059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBms12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BMS12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBms12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa25713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRifcsphigho202full4012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO202FULL4012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho202full4012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaConceptionensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaConceptionensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpAa4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TurneriellaParvaDsm21527(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Turneriella parva DSM 21527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TurneriellaParvaDsm21527", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifoxyb1full4711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFOXYB1FULL4711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifoxyb1full4711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeJs60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae JS60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeJs60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZhouiaAmylolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zhouia amylolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZhouiaAmylolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylothermaceaeBacteriaB42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria B42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteriaB42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelosinusFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoalkalibacterSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf23917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaNeofelifaecis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia neofelifaecis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaNeofelifaecis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRbg165712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RBG_16_57_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRbg165712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBirtlesiiIbs325(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii IBS 325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaBirtlesiiIbs325", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaLitoreaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yoonia litorea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YooniaLitoreaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSpLeaf326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. Leaf326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLeaf326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasEchinoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas echinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasEchinoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaPhototrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea phototrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaPhototrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaCoriaceae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia coriaceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaCoriaceae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotionigerCbs115572Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger CBS 115572 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotionigerCbs115572Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobicatellaSulfidifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumTumefaciensCcnwgs0286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens CCNWGS0286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCcnwgs0286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg136212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusEpidermidisAtcc12228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis ATCC12228 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisAtcc12228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPragensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pragensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPragensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpAs16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. AS16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpAs16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4513Fw928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4513 (FW-928) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4513Fw928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaAlcalifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTannerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella tannerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTannerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlvi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SnodgrassellaAlvi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusCaliditerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus caliditerrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusCaliditerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMiyunensisNbrc108239Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia miyunensis NBRC 108239 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaMiyunensisNbrc108239Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimonsiellaMuelleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Simonsiella muelleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SimonsiellaMuelleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpT6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGorillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGorillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasCommunis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas communis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCommunis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumSublineolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum sublineola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSublineolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpOv277Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. OV277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpOv277Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBrassicacearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSuccinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus succinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSuccinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClohesyomycesAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clohesyomyces aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClohesyomycesAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1024740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_47_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1024740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCg1024617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium CG1_02_46_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCg1024617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp32146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3214.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaMensalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella mensalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilliamellaMensalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRufumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rufum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRufumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumRbg19ftcombo3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RBG19FTCOMBO3910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRbg19ftcombo3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSubtropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes subtropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSubtropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumRifcsplowo201full3415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO201FULL3415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo201full3415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumGwf1657Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium GWF1_65_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumGwf1657Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxSpNbrc102024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. NBRC 102024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpNbrc102024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaAerocolonigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea aerocolonigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaAerocolonigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumLongipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium longipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumLongipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4999Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4999Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolaminaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolamina rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolaminaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpS718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S718 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombyxMori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bombyx mori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BombyxMori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesertifilumSpIppasb1220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desertifilum sp. IPPASB1220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesertifilumSpIppasb1220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsukibacteriumSpMj3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium sp. MJ3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumSpMj3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC238Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C238 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC238Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNigerienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium nigeriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNigerienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYB1_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusAminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpGfaj1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. GFAJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpGfaj1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina morsitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocFallaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocFallaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberMagnatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tuber magnatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuberMagnatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BosMutusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bos mutus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BosMutusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaSulfidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga sulfidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaSulfidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTasmaniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tasmaniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioTasmaniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinolophusFerrumequinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhinolophus ferrumequinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhinolophusFerrumequinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicronemaHongdechlorisC2206Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris C2206 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomicronemaHongdechlorisC2206Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag30730263Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:307_30_263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag30730263Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocPiscinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc piscinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocPiscinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumFioriniaePj7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae PJ7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFioriniaePj7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpMku1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. MKU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpMku1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCannabisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaSalaciaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrinema salaciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSalaciaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApteryxHaastiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apteryx haastii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApteryxHaastiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaPseudotuberculosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pseudotuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaPseudotuberculosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CavenderiaFasciculata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CavenderiaFasciculata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AngelakisellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Angelakisella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AngelakisellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusLaevolacticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus laevolacticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusLaevolacticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaDenticariosiJcm15641Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella denticariosi JCM 15641 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaDenticariosiJcm15641Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSainthelensiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella sainthelensi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSainthelensiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSpAm4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. AM4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpAm4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaMargrebowieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma margrebowiei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMargrebowieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumAStrAtcc3502Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A str. ATCC 3502 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAStrAtcc3502Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCloacimonetesBacterium457255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Cloacimonetes bacterium 4572_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCloacimonetesBacterium457255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaccharosporaIrregularisDsm2635Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis DSM 2635 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularisDsm2635Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasArboricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas arboricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasArboricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonoraphidiumNeglectum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monoraphidium neglectum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonoraphidiumNeglectum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpWriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. wRi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaSpWriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaHispanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena hispanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaHispanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesLutziiPb01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Pb01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesLutziiPb01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpPamc25486(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAMC 25486 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpPamc25486", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumF0431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium F0431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumF0431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraMobilis13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilis13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaElaeis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia elaeis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaElaeis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisBrandtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Myotis brandtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MyotisBrandtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalonomonasRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malonomonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalonomonasRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PuniceicoccalesBacteriumVerruco01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaSphaeroidesDsm2875Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides DSM 2875 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporomusaSphaeroidesDsm2875Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisF0302(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris F0302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisF0302", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMspmpm5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MspMPM5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMspmpm5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwc23612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWC2_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwc23612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_51_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full5110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBeijerinckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium beijerinckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBeijerinckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PericoniaMacrospinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Periconia macrospinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PericoniaMacrospinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SparassisCrispaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sparassis crispa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SparassisCrispaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaProteobacteriumMl8f1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium ML8F1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMl8f1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumSpS3pf19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium sp. S3PF19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumSpS3pf19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaCoxensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nonomuraea coxensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NonomuraeaCoxensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph973Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH973 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph973Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpPh3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ph3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpPh3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpD14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. D14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpD14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusRufus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus rufus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRufus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSalsinemorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina salsinemoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSalsinemorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verticillium alfalfae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerticilliumAlfalfaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4246Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4246Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusClausiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus clausii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusClausiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterHeidelbergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter heidelbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterHeidelbergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp88aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 88A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp88aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusTepidamansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus tepidamans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusTepidamansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaC102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa C102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaC102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusPcc7942Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC7942 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc7942Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusAgarilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus agarilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusAgarilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermaniaPiniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Skermania piniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SkermaniaPiniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasDaqiaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas daqiaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasDaqiaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioFischeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliivibrioFischeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpIp16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. IP16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpIp16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsasporaOwczarzakiAtcc30864(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki ATCC 30864 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CapsasporaOwczarzakiAtcc30864", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPanipatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas panipatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPanipatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterQingfengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter qingfengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterQingfengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisBaichengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis baichengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisBaichengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMongoliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium mongoliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMongoliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumBohemicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBohemicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDsm4029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DSM 4029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDsm4029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumScgcAaa027g08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027G08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027g08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasAquimarinaAtccBaa1526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina ATCC BAA-1526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychromonasAquimarinaAtccBaa1526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpMccc1a01148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacterRiflensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacter riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacterRiflensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumCg2303210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_32_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpGd7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. GD7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpGd7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hordeum vulgare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HordeumVulgareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TamlanaNanhaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tamlana nanhaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TamlanaNanhaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPenetransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma penetrans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPenetransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRubrolavendulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubrolavendulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubrolavendulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CronobacterSakazakii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter sakazakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CronobacterSakazakii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasTaeanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taeanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaeanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpMd2005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. MD2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpMd2005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumSublineola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum sublineola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSublineola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumHubeienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium hubeiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumHubeienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaHellenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella hellenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaHellenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaPml168(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia PML168 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaPml168", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpTab87Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. TAB 87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpTab87Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacebacteriaBacteriumCg2303639Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG2303639 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg2303639Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchrobactrumAnthropiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum anthropi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumAnthropiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCricetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus criceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCricetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenansDsm11527(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans DSM 11527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenansDsm11527", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaSpAd6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola sp. AD6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrincolaSpAd6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilaChrysaetosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquila chrysaetos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquilaChrysaetosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromyxobacterDehalogenansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter dehalogenans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterDehalogenansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloactinobacteriumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloactinobacterium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloactinobacteriumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusCellicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus cellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusCellicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBovoculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovoculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoraxellaBovoculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatesCalcariferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lates calcarifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LatesCalcariferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LobosporangiumTransversale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lobosporangium transversale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LobosporangiumTransversale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTerricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia terricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTerricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusGarvieaeDcc43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae DCC43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeDcc43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Streptomyces albus albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "StreptomycesAlbusAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalidrisPygmaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calidris pygmaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalidrisPygmaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPLOWO2_01_FULL_60_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsplowo201Full6018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalislikeEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sodalislike endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SodalislikeEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSalifodinaeDsm8989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus salifodinae DSM 8989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalococcusSalifodinaeDsm8989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZymaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus zymae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusZymaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisBryophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis bryophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocystisBryophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBiviaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bivia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBiviaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFjat27812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-27812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat27812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FodinicurvataFenggangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata fenggangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataFenggangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichormusSpNmc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichormus sp. NMC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichormusSpNmc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosarchaeumLimniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum limnium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumLimniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpAls9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. ALS9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpAls9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwf23566Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWF23566 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwf23566Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSp3524zxx(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 3524ZXX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp3524zxx", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6726(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6726", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIndolisDsm755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] indolis DSM 755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumIndolisDsm755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpCnt312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNT312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnt312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromyxobacterSpFw1095Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. Fw1095 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpFw1095Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllisonellaHistaminiformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allisonella histaminiformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllisonellaHistaminiformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaBellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia bellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaBellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterChironomi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chironomi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChironomi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasBalearicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas balearica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimonasBalearicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_33_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasAdhaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAdhaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpAtcc39006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. ATCC39006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAtcc39006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhlebiaCentrifugaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phlebia centrifuga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhlebiaCentrifugaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo212full6621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumUtcfx2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoperedensNitroreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoperedens nitroreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoperedensNitroreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocinitomixCatalasiticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix catalasitica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixCatalasiticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E740 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNbrc109706Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 109706 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc109706Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaMangroviensisCbs10435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis CBS 10435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KwoniellaMangroviensisCbs10435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusPinatubonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pinatubonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPinatubonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusRaoultii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus raoultii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRaoultii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaPallidulaDsm14239Acam615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola pallidula DSM 14239 ACAM 615 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPallidulaDsm14239Acam615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMimosarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mimosarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMimosarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full5124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL5124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full5124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSp6113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 61-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4519Fw2642Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4519 (FW-2642) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4519Fw2642Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaK279a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia K279a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaK279a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacaBarguzinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobaca barguzinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacaBarguzinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMegasporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces megasporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMegasporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSeriolae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia seriolae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSeriolae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusHopiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPhyllosphaeraeFa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae FA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaeraeFa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCohniiNbrc15565Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cohnii NBRC 15565 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCohniiNbrc15565Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpCl95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. cl95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpCl95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumGrantii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium grantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGrantii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkiellaCookevillensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella cookevillensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaCookevillensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpRoot136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. Root136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpRoot136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlgidusDsm15638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus algidus DSM 15638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlgidusDsm15638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaSympodialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malassezia sympodialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalasseziaSympodialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusOpacusB4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus opacus B4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusOpacusB4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWeiliiSerovarRanarumStrIcftEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira weilii serovar Ranarum str. ICFT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWeiliiSerovarRanarumStrIcftEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumGa0077528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium Ga0077528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumGa0077528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumFortuitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fortuitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFortuitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAbortusLlgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia abortus LLG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaAbortusLlgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysemysPictaBellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chrysemys picta bellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChrysemysPictaBellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferGlycinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer glycinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferGlycinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag254Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:254 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag254Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusSpMarseillep2731Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus sp. MarseilleP2731 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrococcusSpMarseillep2731Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusParviboronicapiensJcm18861Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens JCM 18861 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiensJcm18861Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFasciculatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fasciculatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumFasciculatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_02_FULL_48_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAurantiacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRbg134211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg134211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaceaeBacteriumFsla50209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPalustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioPalustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpOk665Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK665 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpOk665Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodosporidiumToruloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodosporidium toruloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodosporidiumToruloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwd23827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWD2_38_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwd23827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFf3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSpNml063099Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. NML063099 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TatumellaSpNml063099Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27986Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27986Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeropyrumPernixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum pernix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeropyrumPernixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaBacilliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria bacilliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaBacilliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaDilworthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia dilworthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaDilworthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaPhocaeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella phocaeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaPhocaeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo202full4813b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO202FULL4813b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo202full4813b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxya2full4719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYA2FULL4719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxya2full4719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidimonasTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidimonasTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpGfb01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. GFB01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpGfb01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyangiumBrachysporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Polyangium] brachysporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolyangiumBrachysporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSocranskiiVpidr56br1116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii VPIDR56BR1116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiVpidr56br1116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_36_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpOrs3428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCangingivalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas cangingivalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCangingivalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumGwa2349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWA2349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwa2349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumCb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium CB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumCb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSp9120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. 9120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSp9120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothrixFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geothrix fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeothrixFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusClarusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus clarus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizophagusClarusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaRickettsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia rickettsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaRickettsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NigeriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nigerium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NigeriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuthiaMagnificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruthia magnifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuthiaMagnificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrcinusOrcaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Orcinus orca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OrcinusOrcaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermofilumAdornatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum adornatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermofilumAdornatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSoliNbrc102451Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus soli NBRC 102451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSoliNbrc102451Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionSr1BacteriumRaac1sr11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium RAAC1SR11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumRaac1sr11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonRbg136020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_60_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg136020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeI113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae I113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeI113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenimonasSpSl110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenimonas sp. SL110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenimonasSpSl110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CadophoraSpDse1049(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cadophora sp. DSE1049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CadophoraSpDse1049", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs205Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs205Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrusSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrus sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrusSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquisalimonasAsiaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquisalimonas asiatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquisalimonasAsiaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DissulfuribacterThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dissulfuribacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DissulfuribacterThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumBacl6Mag120910Bin40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 MAG-120910-bin40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Mag120910Bin40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusLactolyticusS7113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus S7113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusS7113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpNbrc111131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NBRC 111131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNbrc111131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesDurhamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces durhamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDurhamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfamplusMagnetovallimortisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfamplus magnetovallimortis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfamplusMagnetovallimortisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPilosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pilosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPilosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetococcusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetococcus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetococcusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc6406Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC6406 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc6406Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCichorii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cichorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCichorii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpCfcc11742(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CFCC 11742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCfcc11742", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamadaeaTsunoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hamadaea tsunoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HamadaeaTsunoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSulfurreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sulfurreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterSulfurreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumGw2011Gwb1547(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium GW2011_GWB1_54_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumGw2011Gwb1547", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full5012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL5012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full5012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusHymeniacidonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus hymeniacidonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusHymeniacidonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NasuiaDeltocephalinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nasuia deltocephalinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NasuiaDeltocephalinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlysiellaCrassa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alysiella crassa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlysiellaCrassa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpCg912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. CG912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpCg912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpTnhr37bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. TNHR37B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpTnhr37bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaCardiffensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia cardiffensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaCardiffensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpXbb1001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XBB1001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXbb1001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSpDg1229(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. DG1229 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpDg1229", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFloricolaDsm23037Jcm16512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus floricola DSM 23037 JCM 16512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFloricolaDsm23037Jcm16512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEntomophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas entomophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEntomophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusPrevotiiAcs065vcol13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii ACS065VCol13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiAcs065vcol13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumSpOscrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidium sp. OSCR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidiumSpOscrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusSanguinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus sanguinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusSanguinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumAmorphaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium amorphae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAmorphaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusFrigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus frigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFrigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk1wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK1W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk1wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGyllenbergii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gyllenbergii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGyllenbergii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmataSpShpl17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmata sp. SHPL17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmataSpShpl17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpJpy347Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. JPY347 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpJpy347Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiispiraPapahanaumokuakeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terasakiispira papahanaumokuakeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerasakiispiraPapahanaumokuakeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumGwa25015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium GWA2_50_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGwa25015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumSinecaudum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium sinecaudum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EremotheciumSinecaudum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbus8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioNigripulchritudo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nigripulchritudo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioNigripulchritudo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusBendigoensisDsm12906(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tessaracoccus bendigoensis DSM 12906 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TessaracoccusBendigoensisDsm12906", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpCf384Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. CF384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCf384Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaniviriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus saniviri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSaniviriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaRuminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ruminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaRuminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaConjunctivae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma conjunctivae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaConjunctivae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaIctaluri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella ictaluri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaIctaluri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisSk255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TannerellaSpOralTaxonHot286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. oral taxon HOT-286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TannerellaSpOralTaxonHot286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc511d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusPakistanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus pakistanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusPakistanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. houtenae str. ATCC BAA-1581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspHoutenaeStrAtccBaa1581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMandelii36mfcvi11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii 36MFCvi11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandelii36mfcvi11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpS6262(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S6-262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpS6262", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterKookii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKookii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiAtcc17978Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii ATCC 17978 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiAtcc17978Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteroidesVaginae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilibacteroides vaginae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilibacteroidesVaginae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusAquimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusAquimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusCarbonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus carbonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrococcusCarbonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPseudotuberculosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterEngbaekiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter engbaekii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterEngbaekiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumGallicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSyntrophoarchaeumCaldarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum caldarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumCaldarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesDenticolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces denticolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDenticolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavigranumRuoffiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavigranum ruoffiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavigranumRuoffiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2148Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2148 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2148Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPseudintermediusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermediusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TessaracoccusAquimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusAquimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPantherisDsm15945Jcm12539Nbrc106106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris DSM 15945 JCM 12539 NBRC 106106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPantherisDsm15945Jcm12539Nbrc106106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKsb1Bacterium448487Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return candidate division KSB1 bacterium 4484_87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1Bacterium448487Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusParauberisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parauberis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParauberisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusJilinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus jilinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusJilinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumMurisRn66Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium muris RN66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumMurisRn66Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceibacteriumSpImcc21224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puniceibacterium sp. IMCC21224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PuniceibacteriumSpImcc21224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19037Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19037Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusKakegawensisNbrc103104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis NBRC 103104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensisNbrc103104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPHIGHO2_12_FULL_45_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpH1n(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. H1n graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaSpH1n", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpCzuamCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CZUAM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCzuamCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaCsv86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida CSV86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaCsv86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf69Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf69 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf69Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_44_15c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovenusAranensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halovenus aranensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalovenusAranensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaPalsarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa palsarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaPalsarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaXenobioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala xenobiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaXenobioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsplowo201full4733bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4733b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4733bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpKk3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. KK3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpKk3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacterCurvatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterCurvatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorallococcusCoralloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus coralloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorallococcusCoralloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpUrha0036Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. URHA0036 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpUrha0036Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmmonifexDegensiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ammonifex degensii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmmonifexDegensiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplodiaCorticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diplodia corticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiplodiaCorticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwc13712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC13712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc13712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinivibrioDextrinosolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrio dextrinosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrioDextrinosolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp32352Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32352 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32352Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaInopinataJcm12537Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata JCM 12537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ScardoviaInopinataJcm12537Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusSanaruensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sanaruensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSanaruensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusUliginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusUliginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioKanaloaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio kanaloae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioKanaloaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOrisC735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris C735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisC735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVanbaaleniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vanbaalenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVanbaaleniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimbladiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimbladii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimbladiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAtrophaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus atrophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAtrophaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DraconibacteriumOrientaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium orientale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumOrientaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrococcusJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpMrs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. MRS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpMrs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpRoot418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedBacteroidesSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Bacteroides sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedBacteroidesSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorocebusSabaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorocebus sabaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorocebusSabaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwf23720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWF2_37_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwf23720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FulvimarinaManganoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina manganoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaManganoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApisMelliferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apis mellifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApisMelliferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndreprevotiaChitinilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Andreprevotia chitinilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AndreprevotiaChitinilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpMedpeswcel(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. MedPESWcel graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpMedpeswcel", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaFalsenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFalsenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFrankenforstense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24387Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24387 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24387Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoculleusSpSdb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sp. SDB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSpSdb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp6378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 63-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpU5lCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. U5L Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpU5lCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFLusitanicusCbs27749Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus CBS 277.49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicusCbs27749Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DelongbacteriaBacteriumGwf24014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Delongbacteria bacterium GWF24014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DelongbacteriaBacteriumGwf24014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaReticulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poecilia reticulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoeciliaReticulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMacleodiiDeep(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Deep graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiDeep", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilimonasTropicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilimonas tropica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilimonasTropicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterIguaniorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter iguaniorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterIguaniorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasSp11bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. 11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSp11bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophusSpGwc25631Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus sp. GWC2_56_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophusSpGwc25631Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full5314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL5314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full5314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DimargarisCristalligena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dimargaris cristalligena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DimargarisCristalligena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumRubrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum rubrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumRubrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinococcusMultilocularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus multilocularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EchinococcusMultilocularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPersicinaNbrc102418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia persicina NBRC 102418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPersicinaNbrc102418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt372Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT372 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt372Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaSpMar2010147Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_147 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010147Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SparusAurataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sparus aurata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SparusAurataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSobrinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSobrinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria monocytogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaMonocytogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full4622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL4622 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full4622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CribrihabitansMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cribrihabitans marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CribrihabitansMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GonapodyaProlifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gonapodya prolifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GonapodyaProlifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AiluropodaMelanoleucaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ailuropoda melanoleuca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AiluropodaMelanoleucaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFCSPHIGHO2_01_FULL_50_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwd24214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD24214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd24214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsterYellows(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aster yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsterYellows", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb14314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB14314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb14314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfipiaSpP5210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. P5210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpP5210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa25134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_51_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusTransvaalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus transvaalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusTransvaalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLeaf155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccationiduransArizonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Siccationidurans arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SiccationiduransArizonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalsirhodobacterSpAlg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falsirhodobacter sp. alg1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalsirhodobacterSpAlg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmF4519Fw2642(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4519 (FW-2642) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4519Fw2642", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag341Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:341 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag341Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArhodomonasAquaeoleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArhodomonasAquaeoleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatranaerobiusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natranaerobius thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatranaerobiusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachanceaThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaNegevensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kingella negevensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KingellaNegevensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacterium448493Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448493Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasSpCnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas sp. CN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasSpCnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSiamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio siamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSiamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RufibacterRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RufibacterRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Veblenbacteria bacterium RIFOXYC2_FULL_42_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVeblenbacteriaBacteriumRifoxyc2Full4211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumJdfr77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1468Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1468 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1468Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaCrassaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neurospora crassa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeurosporaCrassaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TokpelaiaHoelldoblerii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tokpelaia hoelldoblerii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TokpelaiaHoelldoblerii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaHollisaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Grimontia hollisae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GrimontiaHollisaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarpegnathosSaltatorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harpegnathos saltator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarpegnathosSaltatorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciensAe3010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens AE3010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensAe3010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaGb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida GB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaGb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDri13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DRI13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDri13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpLappah95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpLappah95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CronobacterCondimentiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter condimenti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CronobacterCondimentiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitibacterAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacterium4787Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4787 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4787Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterDokdonensisDsw74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis DSW-74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensisDsw74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrogenomatusAuricolaScgcAaa011E14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Microgenomatus auricola SCGC AAA011-E14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrogenomatusAuricolaScgcAaa011E14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEdens01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Edens01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEdens01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpAna3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ANA3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpAna3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolaniAg1ib(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1ib", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBungoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bungoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBungoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidiumAmbiguumIamM71Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phormidium ambiguum IAM M-71 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhormidiumAmbiguumIamM71Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerasakiellaMagneticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terasakiella magnetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerasakiellaMagneticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAsiaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCorynebacterioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus corynebacterioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCorynebacterioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumAerolatumDsm21857(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum DSM 21857 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatumDsm21857", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPyogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pyogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPyogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChytriomycesConfervaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chytriomyces confervae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChytriomycesConfervaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFalloniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella fallonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaFalloniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Candida] auris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaAurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpC150Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. C150 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpC150Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquabacteriumSpNj1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquabacterium sp. NJ1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquabacteriumSpNj1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterTemperatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter temperatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterTemperatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3910bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3910b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3910bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTeres(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora teres graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTeres", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetrimonasMucosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Petrimonas mucosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PetrimonasMucosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpFb8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. FB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpFb8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HahellaChejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hahella chejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HahellaChejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVirginiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces virginiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesVirginiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterCorallicolaNbrc107790Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter corallicola NBRC 107790 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JanibacterCorallicolaNbrc107790Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconobacterRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumChimaera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium chimaera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumChimaera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaThermophilaTm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila TM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaThermophilaTm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit016242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 01-6242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit016242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaBurgdorferiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalitaleaCylindroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil761Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil761 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil761Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwa24315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWA2_43_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwa24315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpZg627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. ZG627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpZg627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAidingenseJcm13560(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aidingense JCM 13560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumAidingenseJcm13560", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedibacterSymbiosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter symbiosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterSymbiosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPutidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema putidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPutidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_52_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full5223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisAtcc35037Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC35037 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc35037Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArachisHypogaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arachis hypogaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArachisHypogaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusGonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus gonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusGonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisDnf00985Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis DNF00985 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisDnf00985Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSubterraniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter subterrani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSubterraniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTubiashii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tubiashii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioTubiashii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisHx2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis HX2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisHx2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensSpHeli66Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens sp. HelI66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensSpHeli66Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitiniphilusShinanonensisDsm23277Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis DSM 23277 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensisDsm23277Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumStanieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumStanieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedimonasAcanthamoebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracaedimonas acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacaedimonasAcanthamoebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRattimassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattimassiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattimassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaginellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vaginella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VaginellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterRoseosalivariusDsm11622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius DSM 11622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivariusDsm11622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusCapsulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusCapsulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusFrigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus frigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFrigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfallasArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaUsdaarsusmarc1296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenuibacillusMultivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenuibacillus multivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenuibacillusMultivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaArizonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaArizonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpOk281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OK281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOk281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeovibrioSpL21acebesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geovibrio sp. L21AceBES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeovibrioSpL21acebesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NicotianaTomentosiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tomentosiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NicotianaTomentosiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptotermesSecundus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptotermes secundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptotermesSecundus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumBarnesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum barnesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumBarnesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaAlbertiiKf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii KF1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiKf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonariusCbs121057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius CBS 121057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonariusCbs121057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluoribacterDumoffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter dumoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FluoribacterDumoffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSpNl5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nl5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNl5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpMb200Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. MB200 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpMb200Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGhanaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces ghanaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGhanaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumRadiobacterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium radiobacter Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRadiobacterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium nepotum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumNepotum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumRuminicolaJcm14822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola JCM 14822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicolaJcm14822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaElegansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella elegans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaElegansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUltunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ultunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUltunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusPersepolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus persepolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusPersepolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobacterSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobacterSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasSpHmsc065f10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC065F10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc065f10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumBrachyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium brachy Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBrachyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasSpKa00067Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. KA00067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpKa00067Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisXylanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis xylanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisXylanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesNourseiAtcc11455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces noursei ATCC 11455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesNourseiAtcc11455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaTuricensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia turicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaTuricensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisElegans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisElegans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSasangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sasangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSasangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumXanthumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xanthum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXanthumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineosporiaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kineosporia aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KineosporiaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusUrinaehominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinaehominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinaehominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOxb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OxB-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOxb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPineti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pineti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPineti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaClarridgeiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella clarridgeiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaClarridgeiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMutabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces mutabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesMutabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfBathymodiolusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlexilineaFlocculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flexilinea flocculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlexilineaFlocculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_45_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisSpSb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpVcb2006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCB2006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcb2006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseofilumReptotaeniumAo1AEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium AO1-A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseofilumReptotaeniumAo1AEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistliaConsotensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tistlia consotensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TistliaConsotensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxValerianellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax valerianellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxValerianellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpHk10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. HK10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpHk10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPachastrellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pachastrellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPachastrellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaHelicoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma helicoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaHelicoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusEutactusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus eutactus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprococcusEutactusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioMarinisediminisDsm17456(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis DSM 17456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminisDsm17456", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4416 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSp6357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 63-57 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpMrs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. MRS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpMrs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaRubidaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia rubidaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaRubidaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensDamuponensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens damuponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensDamuponensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpGw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chelatococcus sp. GW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChelatococcusSpGw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasPanacihumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas panacihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasPanacihumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisSpAc460(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc460", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVranovensisDsm16006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis DSM 16006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasVranovensisDsm16006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichurisTrichiuraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichuris trichiura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichurisTrichiuraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusFerusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ferus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusFerusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhasianusColchicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phasianus colchicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhasianusColchicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnr698Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNR698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnr698Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobacterArenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobacter arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThalassobacterArenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumCauenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cauense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCauenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPallidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPallidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorangiumCellulosumSoCe56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So ce56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSoCe56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusArctosHorribilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ursus arctos horribilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UrsusArctosHorribilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpEp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. EP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpEp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniCnb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni CNB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniCnb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylococcopsisSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dactylococcopsis salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DactylococcopsisSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetitomaculumRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetitomaculumRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RippkaeaOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rippkaea orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RippkaeaOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusVietnamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusVietnamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpJdfr02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. JdFR-02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpJdfr02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasParafulva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas parafulva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasParafulva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsbacteriaBacteriumGwe25412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edwardsbacteria bacterium GWE25412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdwardsbacteriaBacteriumGwe25412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPecorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pecorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPecorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrobacterPenzbergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrobacter penzbergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrobacterPenzbergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaInagensisDsm44258(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis DSM 44258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaInagensisDsm44258", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpJ142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. J14-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpJ142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAlginolyticus40b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus 40B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticus40b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophusAciditrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus aciditrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophusAciditrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterIguaniorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter iguaniorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterIguaniorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumH1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumH1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMethylpentosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium methylpentosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMethylpentosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSpMgh106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sp. MGH106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSpMgh106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4513Fw928Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4513 (FW-928) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4513Fw928Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcidifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium acidifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumAcidifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasGwangyangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas gwangyangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiimonasGwangyangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasSpNm33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_51_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPapyrosolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium papyrosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPapyrosolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HespelliaStercorisuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HespelliaStercorisuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBuchneriNrrlb30929Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri NRRLB30929 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBuchneriNrrlb30929Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BryobacterAggregatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bryobacter aggregatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BryobacterAggregatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmillariaGallicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armillaria gallica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmillariaGallicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiromycesSpE2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piromyces sp. E2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiromycesSpE2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpCag2416221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241_62_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag2416221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia speluncae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpeluncae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpOralTaxon212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpKc8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. KC8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpKc8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsphigho201full398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL398 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasMossiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas mossii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMossiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpOrs3324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCereusRock344Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus Rock3-44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusRock344Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasGibsoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas gibsoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGibsoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumKocuriiJcm14978(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum kocurii JCM 14978 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumKocuriiJcm14978", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioHungateiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioHungateiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumCg2306842Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium CG2_30_68_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumCg2306842Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LloydbacteriaBacteriumRifcsphigho202full5417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulierisAtcc35243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC35243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_57_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMediterraneenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium mediterraneense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMediterraneenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpRoot655(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot655", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPurisNbrc108233Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia puris NBRC 108233 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaPurisNbrc108233Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpRac05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. RAC05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRac05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalocapsaSpMl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiohalocapsa sp. ML1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiohalocapsaSpMl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpUrha0032(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0032", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa26223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_62_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromusaKysingiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromusa kysingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromusaKysingiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidihalobacterProsperus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidihalobacter prosperus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidihalobacterProsperus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAcidiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium acidiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAcidiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistesSp31syn1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synergistes sp. 31syn1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynergistesSp31syn1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFischerbacteriaBacteriumRbg13378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fischerbacteria bacterium RBG_13_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFischerbacteriaBacteriumRbg13378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterToluenoxydansJcm15764Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans JCM 15764 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacterToluenoxydansJcm15764Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiribacterCurvatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter curvatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiribacterCurvatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferSpQ7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. Q7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpQ7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopenitusMalekzadehiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopenitus malekzadehii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopenitusMalekzadehiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAcidivoransNbrc108247Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia acidivorans NBRC 108247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAcidivoransNbrc108247Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusEiseniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus eiseniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusEiseniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpL1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. L1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpL1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCochlearium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cochlearium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCochlearium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterVibrioformisDsm8776Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis DSM 8776 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformisDsm8776Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVancouverensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vancouverensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVancouverensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiSubspArupensisOk94513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii subsp. arupensis OK-94-513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaVinsoniiSubspArupensisOk94513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSlackiiAtcc49928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces slackii ATCC 49928 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSlackiiAtcc49928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeolectaIrregularisDah3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neolecta irregularis DAH-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeolectaIrregularisDah3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_01_FULL_50_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpTm1040(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. TM1040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpTm1040", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipiger marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipigerMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterMarinusDsm19753Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter marinus DSM 19753 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpongiibacterMarinusDsm19753Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodoferaxSpLeaf265(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf265", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa044d11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA044D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa044d11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSp499Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 499 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp499Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonadalesBacteriumGwc26120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadales bacterium GWC2_61_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadalesBacteriumGwc26120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_44_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOligofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOligofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoniliophthoraRoreriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora roreri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraRoreriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaAtcc25996(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa ATCC25996 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaAtcc25996", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpMku1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. MKU1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpMku1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacterium448495Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448495Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasStagniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas stagni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseomonasStagniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalisediminibacteriumHaloalkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salisediminibacterium haloalkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalisediminibacteriumHaloalkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutaceaeBacteriumTav5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraMicroaerophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira microaerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraMicroaerophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMb2021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MB2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMb2021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSchoenbuchensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpVt162Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. VT 162 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpVt162Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLautusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lautus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLautusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaIniecta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia iniecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaIniecta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacleayaCordataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macleaya cordata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacleayaCordataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumMongolenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mongolense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumMongolenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumMultiglobuliferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum multiglobuliferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumMultiglobuliferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaVacuolataZ761Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Z-761 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolataZ761Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRedseas12b4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS12B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas12b4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumHigginsianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProcaviaCapensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Procavia capensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProcaviaCapensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobacterPhocaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobacter phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobacterPhocaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaThermophilaDsm6578Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila DSM 6578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaThermophilaDsm6578Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRoot1433d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root1433D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot1433d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminobacterAmylophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminobacter amylophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminobacterAmylophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrolunatusSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPoaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas poae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPoaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisSubspTessellariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. tessellarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspTessellariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesulfofervidusAuxiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfofervidus auxilii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfofervidusAuxiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixRoseaIamM220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix rosea IAM M-220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LimnothrixRoseaIamM220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactonifactorLongoviformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactonifactorLongoviformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpAa23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. AA23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpAa23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumRifcsplowo202full7356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium RIFCSPLOWO202FULL7356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumRifcsplowo202full7356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonasFusca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermomonasFusca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4515b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4515b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4515b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HumibacterAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Humibacter albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HumibacterAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriN26808Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori N26808 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriN26808Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumImcc3088Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium IMCC3088 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumImcc3088Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaPfennigiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afifella pfennigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfifellaPfennigiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpFy07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. FY-07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpFy07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeokomagataeaThailandicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeokomagataeaThailandicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudohongiellaActicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella acticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaActicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml130628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML130628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml130628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpJa12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. JA12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpJa12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElysiaChloroticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elysia chlorotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElysiaChloroticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpBmg536(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. BMG5.36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpBmg536", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSabulinigriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sabulinigri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSabulinigriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumJensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumJensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusRadioduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus radiodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusRadioduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumScgcAaa011b20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011B20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011b20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChaniaMultitudinisentens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chania multitudinisentens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChaniaMultitudinisentens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumDecipiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium decipiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumDecipiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumEstertheticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium estertheticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumEstertheticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumVirideEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium viride Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumVirideEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudophaeobacterArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumGranulosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium granulosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumGranulosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterCuticularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter cuticularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCuticularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOlindensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olindensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlindensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalisS6c4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis S6C4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisS6c4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGasicomitatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gasicomitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGasicomitatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilalesBacteriumHum9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumContaminans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium contaminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumContaminans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpFukuswis1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. FUKUSWIS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpFukuswis1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosTaurus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bos taurus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BosTaurus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum3841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 3841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum3841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PerlucidibacaPiscinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca piscinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaPiscinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaRubidaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia rubidaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaRubidaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYC2_FULL_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyc2Full4719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioPiezophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piezophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPiezophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaMinasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia minasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMinasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterPhenanthrenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter phenanthrenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterPhenanthrenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabelaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Babela massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BabelaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaPhilomiragiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella philomiragia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPhilomiragiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaphaeosphaeriaSporulosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraphaeosphaeria sporulosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaphaeosphaeriaSporulosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpDc12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. DC12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpDc12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerribacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerribacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpongiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpongiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfohalovibrioReitneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalovibrio reitneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfohalovibrioReitneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesantisbacteriaBacteriumCg1024989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1024989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1024989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaPolaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaPolaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumA52c2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium A52C2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumA52c2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeofilumRubicundumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geofilum rubicundum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeofilumRubicundumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpOl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. OL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpOl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusIntestiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus intestini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusIntestiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansNd132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ND132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansNd132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrobacterSoliDsm22325Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter soli DSM 22325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SolirubrobacterSoliDsm22325Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSocompensisS10b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis S10B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioSocompensisS10b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarincolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marincola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarincolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumUmmariense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium ummariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumUmmariense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumPentaromativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium pentaromativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumPentaromativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KocuriaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaBestiolaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KwoniellaBestiolaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsphigho201full4522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpC561Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. C561 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpC561Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSpLeaf189Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. Leaf189 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpLeaf189Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifoxyb12full507Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFOXYB12FULL507 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifoxyb12full507Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiWsm2783(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM2783 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm2783", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisSorokinianaNd90prEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana ND90Pr Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BipolarisSorokinianaNd90prEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNasicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces nasicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNasicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumCambriense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum cambriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VaribaculumCambriense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRbg134110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RBG_13_41_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRbg134110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipotesVexilliferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lipotes vexillifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LipotesVexilliferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterUrativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter urativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterUrativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinidiaChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinidia chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinidiaChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpWy10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. WY10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpWy10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumPaxllaeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium paxllaeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumPaxllaeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaMultiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_37_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpKtr9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. KTR9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpKtr9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AhrensiaSpR2a130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. R2A130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSpR2a130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSp4h375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. 4H375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSp4h375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHeli88Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. HelI88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHeli88Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumCg2304320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2304320 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2304320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag180Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag180Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeclerciaAdecarboxylataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leclercia adecarboxylata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeclerciaAdecarboxylataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCollagenovoransDsm3089Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans DSM 3089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCollagenovoransDsm3089Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBuchneriNrrlb30929Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri NRRLB30929 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBuchneriNrrlb30929Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpYr558Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. YR558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpYr558Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NodosilineaNodulosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nodosilinea nodulosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NodosilineaNodulosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaFucicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga fucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaFucicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumArcachonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arcachonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArcachonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifcsplowo212full6540(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6540 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6540", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonasSpAp64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas sp. AP64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemmatimonasSpAp64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpOlb3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. OLB3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpOlb3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesAcidifaciensJcm10556Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens JCM 10556 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciensJcm10556Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaCantharicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma cantharicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCantharicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeriolaDumeriliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Seriola dumerili Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SeriolaDumeriliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMucidolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mucidolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMucidolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CobetiaSpUcd24cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cobetia sp. UCD-24C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CobetiaSpUcd24cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnolisCarolinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anolis carolinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnolisCarolinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrosporumGypseumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microsporum gypseum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrosporumGypseumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTakedensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia takedensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaTakedensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridioidesDifficileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides difficile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesDifficileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpTcm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TCM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTcm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TubulinosemaRatisbonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tubulinosema ratisbonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TubulinosemaRatisbonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolichospermumCircinaleAwqc131c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dolichospermum circinale AWQC131C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DolichospermumCircinaleAwqc131c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformansDsm21757Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans DSM 21757 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformansDsm21757Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaEndosymbiontOfPolyrhachisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpR43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. R43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpR43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAlsenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium alsense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAlsenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaReticulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Poecilia reticulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PoeciliaReticulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumBc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum BC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumBc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumBrhc8aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc8a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc8aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptonemaIllini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptonema illini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptonemaIllini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEquorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus equorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEquorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerticilliumNonalfalfaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verticillium nonalfalfae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerticilliumNonalfalfaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip102129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP102129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCip102129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSuwonensisJ43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusAk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus AK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusAk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrifoliumPratense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trifolium pratense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrifoliumPratense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifoxyd1full4821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFOXYD1FULL4821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifoxyd1full4821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllofustisSeminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allofustis seminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllofustisSeminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticaulisKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ponticaulis koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PonticaulisKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusAlkaliphilusDsm16010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus DSM 16010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilusDsm16010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumOmnivorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium omnivorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumOmnivorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf24151(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_41_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf24151", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensSbw25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens SBW25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensSbw25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusVineaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus vineae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusVineaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSphaericusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSphaericusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FomitiporiaMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fomitiporia mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FomitiporiaMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SericytochromatiaBacteriumS15bmn24raac196Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24RAAC_196 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24raac196Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaSp6041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moorella sp. 60_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoorellaSp6041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpFw510t8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. FW510T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpFw510t8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaAps(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola APS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAps", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpPbcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PBC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPbcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterNanhaiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenibacterNanhaiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaDonghaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia donghaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaDonghaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusDelemarRa99880Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus delemar RA 99-880 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizopusDelemarRa99880Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZunongwangiaAtlantica22ii1410f7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica 22II14-10F7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZunongwangiaAtlantica22ii1410f7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaZhangzhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaZhangzhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE1214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterPhenanthrenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter phenanthrenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterPhenanthrenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsplowo202full5111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO202FULL5111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo202full5111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5225Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5225Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerochaetaGlobosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta globosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaGlobosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumImitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium imitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumImitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsplowo212full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPLOWO212FULL4812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsplowo212full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGregariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gregarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGregariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumNiveocremeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EncephalitozoonCuniculiGbM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi GB-M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculiGbM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacillusOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixSpPcc7601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix sp. PCC 7601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolypothrixSpPcc7601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoMelanesiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho melanesiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoMelanesiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcmicro1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf151Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf151 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf151Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuokellaSpW9106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella sp. W9106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaSpW9106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranaeBrl01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nosema ceranae BRL01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NosemaCeranaeBrl01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaPorcellus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cavia porcellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaviaPorcellus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_41_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SlackiaPiriformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Slackia piriformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SlackiaPiriformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPedisStrTA4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Treponema pedis str. T A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TreponemaPedisStrTA4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpCnr923(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNR-923 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnr923", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumSimuliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smittium simulii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmittiumSimuliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpEb01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. EB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpEb01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_01_FULL_55_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyceliophthoraThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Myceliophthora thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MyceliophthoraThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFluxusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fluxus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFluxusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaQuasipneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNele67bin005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nele67Bin005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNele67bin005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaceaeBacteriumMarseillep2826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium MarseilleP2826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumMarseillep2826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpEpa45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. EPa45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpEpa45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesNiveus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niveus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNiveus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85201450255sch5639931Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201450255SCH5639931 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201450255sch5639931Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_47_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaViscosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AequorivitaViscosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsanoaIshikariensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asanoa ishikariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsanoaIshikariensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumLimosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium limosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumLimosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidomycesRichmondensisBfwEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis BFW Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidomycesRichmondensisBfwEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumLymphophilumAcs093VSch5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum ACS-093-V-SCH5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilumAcs093VSch5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsialesBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRifcsplowo201full6018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPLOWO201FULL6018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsplowo201full6018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumRaac4od11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium RAAC4OD11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumRaac4od11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimplicispiraPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Simplicispira psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SimplicispiraPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTa06Bacterium32111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium 32_111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06Bacterium32111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumPhox21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium Phox-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumPhox21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCauenseR2a7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cauense R2A-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumCauenseR2a7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpEc08061901Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. EC080619-01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpEc08061901Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerSalifodinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopiger salifodinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopigerSalifodinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumMalaysienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium malaysiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMalaysienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphopichiaBurtoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphopichiaBurtoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusAcidocaldariusDsm639(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius DSM 639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusDsm639", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag831Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:831 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag831Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpCubenseRace4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacterium4572123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuminiphilusSyltensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luminiphilus syltensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuminiphilusSyltensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusCateniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus cateniformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusCateniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpeciesTree(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="species.tree.v12.0", **kwargs
) -> Graph:
    """Return SpeciesTree graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "species.tree.v12.0"
        Version to retrieve	
		The available versions are:
			- species.tree.v11.0
			- species.tree.v11.5
			- species.tree.v12.0
    """
    return RetrievedGraph(
        "SpeciesTree", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			create_species_tree_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "tree_path": "species.tree.tsv",
		        "tree_metadata_path": "species.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraSpSoil756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera sp. Soil756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraSpSoil756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumResistensNbrc103078Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium resistens NBRC 103078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumResistensNbrc103078Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpStf2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. STF2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpStf2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumHubeienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium hubeiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumHubeienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusTorquisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus torquis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTorquisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumGaetbulicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMexicanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mexicana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaMexicanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSp2319x1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 2319x1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp2319x1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaRectivirgulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora rectivirgula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaRectivirgulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGa0077536Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077536 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077536Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpheniscorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium spheniscorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpheniscorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FimbriimonasGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fimbriimonas ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FimbriimonasGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BaumanniaCicadellinicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotryotiniaNarcissicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia narcissicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaNarcissicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSubflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria subflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSubflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaViolacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella violacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaViolacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaRighensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora righensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaRighensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKullabergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kullabergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKullabergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllisonellaHistaminiformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allisonella histaminiformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllisonellaHistaminiformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYr519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumCarboxydivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum carboxydivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumCarboxydivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_47_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSp291Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 291 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoprobacillusSp291Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBenzenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas benzenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBenzenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumRedseas02b3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS02B3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas02b3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovibacterSpMfb070Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter sp. MFB070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MangrovibacterSpMfb070Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusViretiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vireti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusViretiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensDamuponensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens damuponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensDamuponensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasSpJm171(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. JM171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpJm171", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaFortuitaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia fortuita Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaFortuitaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUterequiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium uterequi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUterequiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaJaponicaDsm16301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica DSM 16301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaDsm16301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSambucusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sambucus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSambucusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSpA13lEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. A13L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpA13lEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpWg21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. WG21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpWg21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GolovinomycesMagnicellulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces magnicellulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesMagnicellulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaSpUsdaarsusmarc1261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia sp. USDAARSUSMARC1261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSpUsdaarsusmarc1261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeofilumRubicundum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geofilum rubicundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeofilumRubicundum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensisCau28Dsm22330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis CAU 28 DSM 22330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusChungangensisCau28Dsm22330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAdp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ADP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAdp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSm2331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium SM23_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumSm2331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinor202Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor 202 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinor202Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VesicomyosociusOkutanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vesicomyosocius okutanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VesicomyosociusOkutanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerostipesSp992aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 992a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp992aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo5817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_58_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo5817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatisLmg20103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis LMG20103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisLmg20103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumTumefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNeworleansenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neworleansense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeworleansenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1285Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1285Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktothrixSpPcc11201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix sp. PCC 11201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixSpPcc11201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumHirsutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gossypium hirsutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GossypiumHirsutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMandelii36mfcvi11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii 36MFCvi11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandelii36mfcvi11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusPenaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus penaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VagococcusPenaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls1777(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1777", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumLipoferum4b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum 4B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AzospirillumLipoferum4b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpDm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. DM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpDm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPasteurianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPasteurianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonBieneusiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisF0302Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris F0302 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisF0302Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpIbvss1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesXylophagusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xylophagus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXylophagusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaMarismortuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula marismortui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaMarismortuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacterFormigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OxalobacterFormigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasSpScn70307Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas sp. SCN 70-307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasSpScn70307Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumCambrienseDsm15806Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DSM15806 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDsm15806Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsMilitarisCm01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris CM01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CordycepsMilitarisCm01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxMucosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mucosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMucosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TateyamariaOmphaliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria omphalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TateyamariaOmphaliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpCrb92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-9-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerochaetaCoccoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta coccoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaCoccoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporothrixInsectorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix insectorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporothrixInsectorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_01_FULL_45_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaPekkaneniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pekkanenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaPekkaneniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycetaceaeBacteriumMp11305Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomycetaceae bacterium MP113-05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycetaceaeBacteriumMp11305Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RouxiellaBadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella badensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RouxiellaBadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesTogonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides togonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesTogonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSpSw150Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. SW150 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSpSw150Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusCaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusCaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusChagannorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus chagannorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusChagannorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanTroglodytesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pan troglodytes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PanTroglodytesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumAmmoniigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpScn6822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. SCN 68-22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpScn6822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOzensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOzensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBackiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus backii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBackiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMangenotiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mangenotii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMangenotiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliihoefleaSp2wwEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliihoeflea sp. 2WW Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliihoefleaSp2wwEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPutrefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella putrefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPutrefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioHungatei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioHungatei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasFimiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas fimi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFimiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasFungivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas fungivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasFungivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCauense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cauense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCauense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot472d3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root472D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot472d3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusibacterSp3d3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusibacter sp. 3D3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusibacterSp3d3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAcidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia acidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAcidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusLactolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharophagusDegradansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharophagus degradans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharophagusDegradansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemocanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasNitrosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas nitrosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasNitrosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibacteriumElongatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseibacterium elongatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseibacteriumElongatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasHuabeiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas huabeiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasHuabeiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlboflavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alboflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlboflavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CastellaniellaCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HippeaJasoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hippea jasoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HippeaJasoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg165418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_54_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPestisCo92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pestis CO92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaPestisCo92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSmegmatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium smegmatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSmegmatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAeruginosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAeruginosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBovienii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus bovienii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBovienii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumArenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium arenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumArenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumGwf25010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_50_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf25010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRubrobruneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRubrobruneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergomycesPasteurianusEp9510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Ep9510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EmergomycesPasteurianusEp9510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusJuripiscariusJcm12147(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius JCM 12147 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LentibacillusJuripiscariusJcm12147", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacillusSp8254bfaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 8_2_54BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSp8254bfaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriAtcc14405(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri ATCC14405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriAtcc14405", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpScn6119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. SCN 61-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpScn6119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeadbetterellaByssophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leadbetterella byssophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeadbetterellaByssophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisAtcc35310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis ATCC35310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisAtcc35310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RouxiellaChamberiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella chamberiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RouxiellaChamberiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpUrha0041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. URHA0041 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpUrha0041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumSpMj3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium sp. MJ3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalimicrobiumSpMj3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DinoroseobacterShibaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dinoroseobacter shibae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DinoroseobacterShibaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBpaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBpaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_60_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAraiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia araii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaAraiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusProvencensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus provencensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusProvencensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LelliottiaAmnigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lelliottia amnigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LelliottiaAmnigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmotaMarmotaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marmota marmota Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarmotaMarmotaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSibiricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sibiricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSibiricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumManausenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium manausense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumManausenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterSpRs40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumSpAt1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AT1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAt1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmborellaTrichopodaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amborella trichopoda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmborellaTrichopodaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSpMh3r31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MH3R3-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMh3r31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DebaryomycesHanseniiCbs767Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii CBS767 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DebaryomycesHanseniiCbs767Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_02_FULL_45_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo202Full4511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavimarinaSpHeli48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavimarina sp. HelI48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavimarinaSpHeli48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporisoriumScitamineum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporisorium scitamineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporisoriumScitamineum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndocarponPusillumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Endocarpon pusillum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndocarponPusillumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumGasigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium gasigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGasigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaPipientisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia pipientis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaPipientisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisVariantAfricanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant africanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantAfricanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpAngs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChthonomonasCalidirosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chthonomonas calidirosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChthonomonasCalidirosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaToruloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula toruloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaToruloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSpMh3r31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MH3R3-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMh3r31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSecaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus secaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSecaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSp4847faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 4847FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CollinsellaSp4847faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarimonasRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonas rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinarimonasRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaSclerotiorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoduganellaViolaceinigraDsm15887Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra DSM 15887 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigraDsm15887Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplanusLimicolaDsm2279Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus limicola DSM 2279 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusLimicolaDsm2279Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSpVcm10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. VCM10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpVcm10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataellaPastorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataella pastoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPastorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus saliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAmicalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmicalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumJdfr77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpA3h3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. A3H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpA3h3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusPettenkoferi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pettenkoferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPettenkoferi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterExcellensHl55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter excellens HL-55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacterExcellensHl55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpFc2001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FC2001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFc2001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusCastenholzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus castenholzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusCastenholzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0077534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseicitreumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseicitreum antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseicitreumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFordii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fordii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFordii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraVanthieliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira vanthielii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraVanthieliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPallidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema pallidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPallidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumSenegalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSenegalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloglobulusMorosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloglobulus morosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloglobulusMorosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfoplanesFormicivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfoplanes formicivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfoplanesFormicivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSpMar2009124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2009_124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar2009124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumSpF0425Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0425 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0425Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE3198Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3198Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumCg2303616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG2_30_36_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg2303616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFraserbacteriaBacteriumRbg16559Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fraserbacteria bacterium RBG_16_55_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFraserbacteriaBacteriumRbg16559Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SedimenticolaSelenatireducensDsm17993Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens DSM 17993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducensDsm17993Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeorickettsiaRisticiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia risticii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaRisticiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumMcbrellneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium mcbrellneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumMcbrellneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioFibrisolvensNd3005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens ND3005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvensNd3005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpLeaf50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPhaffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataella phaffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataellaPhaffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpCcy0110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. CCY0110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpCcy0110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpYab3001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. YAB3001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpYab3001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanizomenonFlosaquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aphanizomenon flosaquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AphanizomenonFlosaquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolumonasAuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolumonas auensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolumonasAuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterNecessariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitisJcm10512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis JCM 10512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitisJcm10512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterMusarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter musarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterMusarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TamlanaAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tamlana agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TamlanaAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpIbvhs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpPamc26554Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26554 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26554Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierellaPraeacuta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tissierella praeacuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TissierellaPraeacuta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAminophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aminophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAminophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BergeyellaZoohelcum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bergeyella zoohelcum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BergeyellaZoohelcum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldivirgaMaquilingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga maquilingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaMaquilingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumRoopkundenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium roopkundense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumRoopkundenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacropusEugenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Macropus eugenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MacropusEugenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpVpap30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. VPAP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSpVpap30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterSpMhb5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. MHB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpMhb5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria rhizophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaRhizophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpBma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BMA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaParasiticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaParasiticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterLectusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algibacter lectus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgibacterLectusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm23733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasQingdaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas qingdaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasQingdaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSp119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. 1.19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSp119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_52_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOlivochromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olivochromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlivochromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplodiaCorticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diplodia corticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiplodiaCorticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OoceraeaBiroi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ooceraea biroi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OoceraeaBiroi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaFlexneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shigella flexneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShigellaFlexneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusYunnanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusYunnanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrusBergylta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrus bergylta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrusBergylta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpUrha0020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAmmoniagenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ammoniagenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAmmoniagenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpEjp617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Ejp617 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpEjp617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFuscansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas fuscans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasFuscansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRedseas39b2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. REDSEAS39B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRedseas39b2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutansGs5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans GS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansGs5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFjat27812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-27812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat27812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumA2KyotoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A2 Kyoto Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumA2KyotoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusTermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus termitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusSpT2530Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. T2.5-30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpT2530Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag724(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:724 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag724", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylophilusDsm20533Jcm1125Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus DSM 20533 JCM 1125 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAmylophilusDsm20533Jcm1125Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusSpMm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus sp. MM2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylovorusSpMm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantisNrrlB14911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus infantis NRRL B-14911 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusInfantisNrrlB14911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaBronchisepticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchiseptica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BordetellaBronchisepticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumMedpeswsndg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaSubspMultocidaStrPm70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida subsp. multocida str. Pm70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaSubspMultocidaStrPm70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidipropionibacteriumAcidipropioniciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium acidipropionici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumAcidipropioniciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterWolfeii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter wolfeii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterWolfeii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlectensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flectens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFlectensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusAquimarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus aquimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAquimarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusSk52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus SK52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusSk52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpCf385(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF385 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf385", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusOrientisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus orientis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusOrientisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAngstadtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium angstadtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAngstadtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusProfundusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus profundus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusProfundusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesInvadansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces invadans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AphanomycesInvadansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaProductaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia producta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaProductaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThelaziaCallipaedaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thelazia callipaeda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThelaziaCallipaedaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPittiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pittii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPittiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetradesmusObliquus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetradesmus obliquus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetradesmusObliquus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaAcidipaludis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia acidipaludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaAcidipaludis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpKtr9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. KTR9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpKtr9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira terpstrae serovar Hualin str. LT 11-33 ATCC 700639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum248Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum248Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusRaffinolactisNbrc100932Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis NBRC 100932 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactisNbrc100932Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaVaccimaxillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia vaccimaxillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaVaccimaxillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full4016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermogemmatisporaCarboxidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora carboxidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaCarboxidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4655(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4655", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrososphaeraGargensisGa92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrososphaera gargensis Ga9.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrososphaeraGargensisGa92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc2459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC2_45_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc2459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusBeddingii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus beddingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusBeddingii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPallensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pallens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPallensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminicellaSporogenesDsm14501(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caminicella sporogenes DSM 14501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaminicellaSporogenesDsm14501", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpAcam123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ACAM123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAcam123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumCdBkt12695Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum CD BKT12695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumCdBkt12695Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinospirillumInsulareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum insulare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumInsulareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisSpNies3708(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3708", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntamoebaHistolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Entamoeba histolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EntamoebaHistolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelomonasSpRoot662Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root662 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot662Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumBuryatense5g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense 5G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatense5g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiopsisWashingtonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tilletiopsis washingtonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TilletiopsisWashingtonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpCfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalobacter sp. CF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalobacterSpCfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioVersutus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioVersutus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesOnderdonkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes onderdonkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesOnderdonkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSyntrophoarchaeumCaldariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum caldarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumCaldariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnthophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea anthophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnthophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosphaeraStadtmanaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera stadtmanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraStadtmanaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaSpIbvhs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeofilumRubicundumJcm15548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geofilum rubicundum JCM 15548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeofilumRubicundumJcm15548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudospirillumJaponicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudospirillum japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudospirillumJaponicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTangfeifaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces tangfeifanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTangfeifaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTropici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tropici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTropici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacteraceaeBacteriumGoma1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacteraceae bacterium GOMA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacteraceaeBacteriumGoma1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FodinicurvataSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAcidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoleophilumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoleophilum album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoleophilumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosinusCarboxydivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermosinus carboxydivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermosinusCarboxydivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansDsm12475Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans DSM12475 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansDsm12475Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaTundricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicella tundricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicellaTundricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYB1_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeMgh78578Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae MGH78578 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeMgh78578Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudophaeobacterLeonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter leonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterLeonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisSk1076(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK1076 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk1076", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndersenbacteriaBacteriumRifcsphigho201full4636(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Andersenbacteria bacterium RIFCSPHIGHO201FULL4636 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AndersenbacteriaBacteriumRifcsphigho201full4636", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRuminococcusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Ruminococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedRuminococcusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaSechellia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila sechellia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSechellia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiobacterAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dethiobacter alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DethiobacterAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPseudintermediusHku1003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius HKU10-03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermediusHku1003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesFriuliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes friuliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesFriuliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCorrugata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas corrugata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCorrugata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaSelenatireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCag495Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CAG:495 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCag495Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGigeriorumDsm23908Crbip2485(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum DSM 23908 CRBIP 24.85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGigeriorumDsm23908Crbip2485", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaBangkokensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora bangkokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaBangkokensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterSp3749(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 37-49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp3749", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonopterusAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monopterus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonopterusAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAphoticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aphoticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAphoticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumSuecicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumSuecicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseofilumReptotaeniumAo1ACluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium AO1-A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseofilumReptotaeniumAo1ACluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaHoronobensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumMicromati(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium micromati graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMicromati", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumJoshi001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium JOSHI001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumJoshi001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaCeranaeBrl01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosema ceranae BRL01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NosemaCeranaeBrl01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonisDsm23387(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPhagedenisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema phagedenis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPhagedenisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasAltamirensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas altamirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasAltamirensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho202full3814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO202FULL3814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho202full3814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0337 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumScgcAaa300k03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA300K03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa300k03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpentinomonasMccroryiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas mccroryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasMccroryiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDadabacteriaBacteriumCsp12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium CSP1-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumCsp12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMassilioanorexiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilioanorexius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilioanorexiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAfermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium afermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAfermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithorhynchusAnatinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithorhynchus anatinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithorhynchusAnatinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaKandleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella kandleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaKandleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaPseudoobscuraPseudoobscuraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura pseudoobscura Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscuraPseudoobscuraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomonileTiedjeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomonile tiedjei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomonileTiedjeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaVestfoldensisSka53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella vestfoldensis SKA53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LoktanellaVestfoldensisSka53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSpL21rpuld2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. L21RPulD2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpL21rpuld2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPseudoavium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pseudoavium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPseudoavium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaCynodegmiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga cynodegmi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCynodegmiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf24317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF24317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf24317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaBissettii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella bissettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBissettii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaGinsengiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea ginsengi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaGinsengiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgarivoransAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpNd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. ND1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpNd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsplowo201full4531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPLOWO201FULL4531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsplowo201full4531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterGottschalkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter gottschalkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterGottschalkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiriformosporaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Piriformospora indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PiriformosporaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacterium13140cm6927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13140CM6927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13140cm6927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4999(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4999", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumXinjiangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriRch2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri RCH2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriRch2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA2_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaMedium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema medium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaMedium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCohnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cohnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCohnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrivivaxSpScn71131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax sp. SCN 71-131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxSpScn71131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCincinnatiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioCincinnatiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PochoniaChlamydosporia123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPurpureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces purpureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPurpureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobalesArchaeonAcd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Acd1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfolobalesArchaeonAcd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNcu2d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NCu2D-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNcu2d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPallidulaDsm14239Acam615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola pallidula DSM 14239 ACAM 615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPallidulaDsm14239Acam615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaGariniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia garinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaGariniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaChitosanitabidaAtccBaa476Nbrc102408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida ATCC BAA-476 NBRC 102408 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabidaAtccBaa476Nbrc102408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyripristisMurdjan(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myripristis murdjan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyripristisMurdjan", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpCrb92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-9-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOralisHga0225Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis HGA0225 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisHga0225Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFutsaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFutsaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusBvHnlc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopenitusMalekzadehiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopenitus malekzadehii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopenitusMalekzadehiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg135723Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_13_57_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg135723Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil763(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil763 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil763", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorumD12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum D12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumD12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanimonasSpGk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas sp. GK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSpGk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterAsburiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter asburiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterAsburiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumBuryatense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacterium13220cm2657Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_2_20CM_2_65_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13220cm2657Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRbg136816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_13_68_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg136816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasSpCnpt3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas sp. CNPT3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromonasSpCnpt3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CebusCapucinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cebus capucinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CebusCapucinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF122 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusMaritimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus maritimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusMaritimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosilyticumRuminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpCc6yy74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CC6YY74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpCc6yy74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesEgdeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes EGDe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesEgdeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnncaliiaAlgeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anncaliia algerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnncaliiaAlgeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumChkci002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium CHKCI002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumChkci002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCdtb01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CdTB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCdtb01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsphigho202full5313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPyruviciproducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pyruviciproducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPyruviciproducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaOnionYellowsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma onion yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaOnionYellowsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasDiminutaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasDiminutaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfHeteropsyllaCubanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla cubana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCubanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraMultiparaLb2003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara LB2003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaLb2003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa23816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_38_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa23816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpCulexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Culex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpCulexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpScn6718(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SCN 67-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpScn6718", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaNonliquefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella nonliquefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaNonliquefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpUnc305mfcol52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. UNC305MFCol52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUnc305mfcol52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGalatheaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium galatheae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGalatheaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwa24711b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24711b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24711b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBromiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bromii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBromiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFlorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus florum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFlorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJeojiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus jeojiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusJeojiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSelenitireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus selenitireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSelenitireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium13220cm6619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 13_2_20CM_66_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium13220cm6619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1023751Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023751Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesFinegoldii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes finegoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesFinegoldii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusNematophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus nematophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusNematophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium6137faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 6_1_37FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium6137faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosporangiumSpNrrlb3428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinosporangium sp. NRRLB3428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinosporangiumSpNrrlb3428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacteralesBacteriumUrhd0059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium URHD0059 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacteriumUrhd0059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpEan1pecEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EAN1pec Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEan1pecEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumCanariense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium canariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCanariense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcamd5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinomonasAtrocyaneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas atrocyanea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinomonasAtrocyaneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag780(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:780 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag780", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesWedmorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wedmorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWedmorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonenseHt12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense HT12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylovulumMiyakonenseHt12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMalefermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus malefermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMalefermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSpDielmoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. Dielmo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KurthiaSpDielmoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasKorlensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas korlensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasKorlensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LichtheimiaCorymbiferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LichtheimiaCorymbiferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhodospiraHalochlorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalochlorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumSolitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium solitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSolitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumArthrosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arthrosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArthrosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumQasimiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium qasimii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumQasimiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RudaeaCellulosilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rudaea cellulosilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RudaeaCellulosilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaMembranifaciensNrrlY2026Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pichia membranifaciens NRRL Y-2026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PichiaMembranifaciensNrrlY2026Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusLactolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriCd034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri CD034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriCd034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFioriniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumFioriniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaPanacisegetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella panacisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NakamurellaPanacisegetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpKhp7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. khp7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKhp7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpWsm3626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGenitaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium genitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGenitaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobiusVermicularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobius vermicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobiusVermicularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPyloriJ99Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori J99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriJ99Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPapyrosolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium papyrosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPapyrosolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumA2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpA28lEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. A28L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpA28lEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixRhusiopathiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix rhusiopathiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixRhusiopathiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxIsoporaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax isoporae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxIsoporaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalaenopteraAcutorostrataScammoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata scammoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrataScammoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLfm046(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. LFM046 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLfm046", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMendocinaEgdaq5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina EGDAQ5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMendocinaEgdaq5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaEntomophagaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia entomophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaEntomophagaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilicibacterSpTrichch4b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter sp. TrichCH4B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SilicibacterSpTrichch4b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAlbicansSc5314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans SC5314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaAlbicansSc5314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpBsc265Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. BSC265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpBsc265Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidifarinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorangiumCellulosumSoCe56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So ce56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSoCe56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa25412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpSoil777Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil777 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil777Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC238(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C238 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC238", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBohemicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bohemicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBohemicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200251163sch5372311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251163SCH5372311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251163sch5372311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSartoriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sartorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSartoriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLuteocolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteocolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteocolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaMegapolitana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia megapolitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMegapolitana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpAr710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. AR7-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpAr710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumResistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium resistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumResistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVitaminophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vitaminophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVitaminophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasJatrophaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jatrophae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJatrophaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KytococcusSedentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kytococcus sedentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KytococcusSedentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpB6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpB6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpMp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. MP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpMp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpMb200(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. MB200 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpMb200", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimonasManganoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas manganoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldimonasManganoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcaceaeBacteriumW5053(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium W5053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumW5053", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumRbg19ftcombo4210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RBG19FTCOMBO4210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRbg19ftcombo4210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifoxyb12full507(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFOXYB12FULL507 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifoxyb12full507", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLitopenaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella litopenaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLitopenaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenobacterLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenobacter luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenobacterLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFarraginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus farraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFarraginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonBa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyphaciaMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syphacia muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyphaciaMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSp6626(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. 6626 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSp6626", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraParasiticaInra310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora parasitica INRA-310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraParasiticaInra310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPasteurianusAtcc43144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus ATCC 43144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPasteurianusAtcc43144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RomboutsiaSpMt17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia sp. MT17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaSpMt17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPectinilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pectinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPectinilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusIranensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus iranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusIranensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumLimicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium limicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumLimicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml02a017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML02A017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml02a017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMaliVarPyriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Valsa mali var. pyri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ValsaMaliVarPyriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumThermocisternum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum thermocisternum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumThermocisternum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLkl04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. LKL04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLkl04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoritellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moritella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoritellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LongilineaArvoryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Longilinea arvoryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LongilineaArvoryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterFulvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter fulvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterFulvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumCynomolgi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium cynomolgi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumCynomolgi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaDysenteriaeSd197Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Sd197 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShigellaDysenteriaeSd197Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansNbrc15126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans NBRC15126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansNbrc15126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanofastidiosumMethylthiophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanofastidiosum methylthiophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanofastidiosumMethylthiophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpYy7918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. YY7918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpYy7918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobicatellaSulfidifaciensDsm15739(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens DSM 15739 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciensDsm15739", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasVeroniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas veronii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasVeroniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRbg134211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG134211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg134211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpP11g3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCaspalpha6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusSpKp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. Kp2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpKp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacillusTrivialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus trivialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusTrivialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpongiibacterSpImcc21906Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter sp. IMCC21906 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterSpImcc21906Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRifcsplowo201full4813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPLOWO201FULL4813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsplowo201full4813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCalifornicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma californicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCalifornicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusHauseri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteus hauseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteusHauseri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymobacterPalmae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymobacter palmae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymobacterPalmae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRoot1290Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root1290 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot1290Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg1025345Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_53_45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1025345Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchleiferiaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schleiferia thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchleiferiaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesSpJdfr56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpSoil535(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Soil535 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpSoil535", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusSpY3961Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. Y3961 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpY3961Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenotaleaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenotalea thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenotaleaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_02_FULL_45_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho202Full4513bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReinekeaBlandensisMed297Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Reinekea blandensis MED297 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ReinekeaBlandensisMed297Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitisRmscc2394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 2394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc2394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0039 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpMit975078Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter sp. MIT975078 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSpMit975078Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpD20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. D20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpD20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaTerraeKimAndJung2007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Kim and Jung 2007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinophagaTerraeKimAndJung2007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriDsm10701Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri DSM10701 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriDsm10701Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraKernoviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora kernoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraKernoviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSpCf118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. CF118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpCf118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisF0302Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris F0302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisF0302Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterJeongneungensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter jeongneungensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterJeongneungensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwf13135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWF1_31_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwf13135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonJgiOtu1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon JGI OTU-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonJgiOtu1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpTc228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tc2-28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTc228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobaculumGomorrenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobaculum gomorrense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobaculumGomorrenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiocystisViolascensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiocystis violascens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiocystisViolascensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4218Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4218Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsphigho202full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO202FULL4216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho202full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoodsholeaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woodsholea maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoodsholeaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFujikuroiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fujikuroi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumFujikuroiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioYellowstoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio yellowstonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioYellowstoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpKk4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKk4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAkari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia akari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAkari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzimaplasmaSpHr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Izimaplasma sp. HR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IzimaplasmaSpHr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaQuinlivanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella quinlivanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuinlivanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumGiardiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium giardinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGiardiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StoquefichusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StoquefichusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasWittichii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas wittichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasWittichii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpTm1040Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. TM1040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpTm1040Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyramidobacterSpC128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter sp. C12-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterSpC128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp54146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 54_146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp54146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseatelesDepolymeransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseateles depolymerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseatelesDepolymeransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hb70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HB70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hb70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpMarseillep3201tCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. MarseilleP3201T Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpMarseillep3201tCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAdhaerensOv14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ensifer adhaerens OV14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnsiferAdhaerensOv14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OdyssellaThessalonicensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Odyssella thessalonicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OdyssellaThessalonicensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiPcIsolateNhvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PC isolate NHV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPcIsolateNhvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polytolypa hystricis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolytolypaHystricisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilimonasTropicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilimonas tropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilimonasTropicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumKnowlesi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxoplasmaGondiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Toxoplasma gondii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ToxoplasmaGondiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpMmg1121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctodonDegusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Octodon degus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OctodonDegusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisExcentricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis excentricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisExcentricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterHormaecheiSubspXiangfangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. xiangfangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspXiangfangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCoubleaeNbrc108252Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia coubleae NBRC 108252 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaCoubleaeNbrc108252Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidiumAmbiguumIamM71(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phormidium ambiguum IAM M-71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhormidiumAmbiguumIamM71", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpHeli7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HelI7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MaribacterSpHeli7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraBriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira briensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraBriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterAnophelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter anophelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterAnophelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaShimofusensisNbrc100134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis NBRC 100134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaShimofusensisNbrc100134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip642Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP 64.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip642Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAap83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalisediminibacteriumHaloalkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salisediminibacterium haloalkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalisediminibacteriumHaloalkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 36-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLeaf127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpScn6914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 69-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn6914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpHmsc76g11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. HMSC76G11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpHmsc76g11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg165611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_56_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwe24535(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24535 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24535", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr50345(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR50345 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr50345", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkanindigesIllinoisensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges illinoisensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesIllinoisensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaSpCcfee5036Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula sp. CCFEE 5036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaSpCcfee5036Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmticiciaOligotrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emticicia oligotrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmticiciaOligotrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaInagensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaInagensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumUrinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum urinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumUrinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpLeaf183Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf183Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceibacteriumMercurialeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceibacterium mercuriale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceibacteriumMercurialeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaMarilimosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olleya marilimosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlleyaMarilimosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpKh9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KH9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKh9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSp263sspcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. 263SSPC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSp263sspcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaSpLeaf210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agreia sp. Leaf210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgreiaSpLeaf210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaStibiiresistensSb22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens SB22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistensSb22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGinsenosidimutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ginsenosidimutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGinsenosidimutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTaa204Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa204Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFukatsuiaSymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fukatsuia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFukatsuiaSymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwa25525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioZosteraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioZosteraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24726Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24726 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24726Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumKluyveri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium kluyveri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumKluyveri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylellinaHaptotylaCbs20050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dactylellina haptotyla CBS 200.50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DactylellinaHaptotylaCbs20050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisAlkaliphilaYim80379Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila YIM 80379 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphilaYim80379Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonasAcidaminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonas acidaminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacimonasAcidaminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag631(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:631 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag631", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpHyo08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. HYO08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpHyo08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterPontiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pontiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPontiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WigglesworthiaGlossinidiaSpGbrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gbr Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGbrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonBieneusiH348Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi H348 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusiH348Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringensStr13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens str. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPerfringensStr13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpAb57Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB57 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb57Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAtcc29733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ATCC29733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAtcc29733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VavraiaCulicisSubspFloridensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vavraia culicis subsp. floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VavraiaCulicisSubspFloridensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEndobugulaSertulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Endobugula sertula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusEndobugulaSertulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaSourekii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Facklamia sourekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FacklamiaSourekii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliobacteriumModesticaldumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heliobacterium modesticaldum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeliobacteriumModesticaldumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviitaleaPhaphyphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Defluviitalea phaphyphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DefluviitaleaPhaphyphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2439b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2439b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2439b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpNk3a76Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. NK3A76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpNk3a76Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4249(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4249", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVermiculataNbrc100427(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vermiculata NBRC 100427 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaVermiculataNbrc100427", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TemnothoraxLongispinosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Temnothorax longispinosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TemnothoraxLongispinosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusYedoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prunus yedoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrunusYedoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasOceanitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas oceanitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasOceanitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OerskoviaEnterophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia enterophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OerskoviaEnterophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBeveridgei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus beveridgei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusBeveridgei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLcm4573Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LCM 4573 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLcm4573Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full4115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesFlavovariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavovariabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavovariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesPutredinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes putredinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesPutredinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpHzn7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. HZN7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpHzn7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMediterraneensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mediterraneensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMediterraneensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwf236839(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF236839 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf236839", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpAap82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full4432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4432 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpSgbin2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho212full4519b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO212FULL4519b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho212full4519b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpAc402(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc402", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpS23321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. S23321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpS23321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomonosporaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomonospora alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomonosporaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrabacterSpRoot85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Root85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpRoot85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesVenezuelensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides venezuelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesVenezuelensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalusNrrlY3668Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus NRRL Y-366-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalusNrrlY3668Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidifarinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPunonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas punonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPunonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaPediculischaeffiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pediculischaeffi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPediculischaeffiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ViridibacillusArenosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Viridibacillus arenosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ViridibacillusArenosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaChukchiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia chukchiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaChukchiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUasws1009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. UASWS1009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUasws1009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAchromatiumPalustreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Achromatium palustre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAchromatiumPalustreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaceaeBacteriumPhil1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiPcIsolateNhvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PC isolate NHV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPcIsolateNhvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusParauberisKctc11537Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis KCTC11537 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisKctc11537Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitritaleaHalalkaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaBatsensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola batsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaBatsensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpSn2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. SN2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlteromonasSpSn2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwc2579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc2579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBrevisAtcc367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brevis ATCC367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrevisAtcc367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FabibacterPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumRifoxyc12full6016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium RIFOXYC12FULL6016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumRifoxyc12full6016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaMollaretii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia mollaretii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaMollaretii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFumigatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusFumigatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumContaminansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium contaminans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumContaminansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesRuminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces ruminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRuminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosumWal14163Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14163 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14163Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFOXYA2_FULL_45_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifoxya2Full4528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5329Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioTritonius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tritonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioTritonius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCaspthauma1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpIcm39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumPelagiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium pelagium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPelagiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LunatimonasLonarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lunatimonas lonarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LunatimonasLonarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasVasicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVasicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpRr217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Rr 217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpRr217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml96a049(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML96A049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml96a049", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluoribacterBozemanae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter bozemanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FluoribacterBozemanae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasArcticaDsm14288Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas arctica DSM 14288 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychromonasArcticaDsm14288Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumLipoferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumLipoferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumGlobosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum globosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumGlobosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumLactosutensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium lactosutens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumLactosutensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColobusAngolensisPalliatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colobus angolensis palliatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColobusAngolensisPalliatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm9796Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 9796 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm9796Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTimonensis4401737(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis 4401737 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensis4401737", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumCellulansJ1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans J1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulansJ1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetarhiziumAcridumCqma102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium acridum CQMa 102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAcridumCqma102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAmblyommatisStrGat30vEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis str. GAT-30V Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatisStrGat30vEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMcba15008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo212full5011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO212FULL5011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo212full5011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaShimofusensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaShimofusensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRs9916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaSpVcsm12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSM12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OlleyaSpVcsm12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSlbn53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SLBN-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSlbn53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpIp16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. IP16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpIp16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FloricoccusTropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Floricoccus tropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FloricoccusTropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpAngs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumAgarivoransYm01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans YM01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransYm01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh8102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf404(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf404", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpAb629b18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. AB629B18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpAb629b18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpAu12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DissulfuribacterThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dissulfuribacter thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DissulfuribacterThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorBasaltisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor basaltis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratireductorBasaltisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOryzifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter oryzifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOryzifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsphigho212full3830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO212FULL3830 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho212full3830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCrevioricanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas crevioricanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCrevioricanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusShizuokensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichurisMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichuris muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichurisMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaShakespearei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella shakespearei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaShakespearei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusAquatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus aquatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusAquatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NippostrongylusBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nippostrongylus brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NippostrongylusBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtrovirideImi206040Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride IMI 206040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAtrovirideImi206040Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CosenzaeaMyxofaciensAtcc19692Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens ATCC 19692 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciensAtcc19692Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp3524zxxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 3524ZXX Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp3524zxxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumZagget3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomicrobiumOkeanokoites(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium okeanokoites graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumOkeanokoites", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaDiclinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia diclina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaDiclinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpNd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. ND1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpNd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSp157mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 157MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp157mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFloricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus floricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFloricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpGwa24521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. GWA2_45_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpGwa24521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavochromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavochromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavochromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisValliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis valliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisValliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParastrongyloidesTrichosuri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parastrongyloides trichosuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParastrongyloidesTrichosuri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterPickeringiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter pickeringii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterPickeringiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpLf3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. LF3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpLf3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusMigulanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus migulanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusMigulanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonchuraStriataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lonchura striata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LonchuraStriataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaScatoligenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella scatoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaScatoligenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DimargarisCristalligenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dimargaris cristalligena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DimargarisCristalligenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesSpAs95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. AS95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpAs95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpMit016451Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT016451 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterSpMit016451Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag877Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag877Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLoiseleuriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus loiseleuriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLoiseleuriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaSpScgcAb629i23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota sp. SCGC AB629I23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaSpScgcAb629i23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFinegoldiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides finegoldii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFinegoldiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSp228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. 228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSp228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraAquaemixtaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquaemixtae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquaemixtaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPattaloongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pattaloongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPattaloongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumUndicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium undicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumUndicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudolabrysSpRoot1462Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudolabrys sp. Root1462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudolabrysSpRoot1462Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMycetoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mycetoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMycetoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymobacterPalmaeDsm10491Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Zymobacter palmae DSM 10491 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZymobacterPalmaeDsm10491Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpulaLacrymansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serpula lacrymans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerpulaLacrymansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhynchosporiumCommune(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhynchosporium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhynchosporiumCommune", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumLimnaeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum limnaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumLimnaeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa076p09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterNamhicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter namhicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterNamhicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGullanellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gullanella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGullanellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaCyaneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora cyanea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaCyaneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinkiaNeuiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winkia neuii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinkiaNeuiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenopusLaevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenopus laevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenopusLaevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroserpensJangbogonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens jangbogonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensJangbogonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeduiniMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beduini massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeduiniMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinalesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusPiezophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus piezophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPiezophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliflexusImshenetskii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkaliflexus imshenetskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkaliflexusImshenetskii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpBsw20308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. Bsw20308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpBsw20308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCohniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus cohnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCohniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsphigho201full5815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL5815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full5815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusVersicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus versicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusVersicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusYanchengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus yanchengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacillusYanchengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpRoot411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. Root411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpRoot411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp54146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 54_146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp54146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumBavaricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpPp1yEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. PP1Y Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpPp1yEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpMd27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. MD27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpMd27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSinesaloumensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sinesaloumensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSinesaloumensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaAlkaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlkaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmoricolaSpLeaf446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. Leaf446 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpLeaf446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrolobusFumariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrolobus fumarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrolobusFumariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwb14314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB14314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb14314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumThiophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum thiophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumThiophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200250816sch5313054bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200250816SCH5313054b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200250816sch5313054bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpP37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. P37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpP37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumGossipiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium gossipiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumGossipiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudacidovoraxSpRu35eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax sp. RU35E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxSpRu35eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BizioniaParagorgiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bizionia paragorgiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BizioniaParagorgiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag571Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:571 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag571Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBenzenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas benzenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBenzenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaYamanashiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaYamanashiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermanellaStibiiresistensSb22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Skermanella stibiiresistens SB22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SkermanellaStibiiresistensSb22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpCect7735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 7735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect7735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharimonasAalborgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharimonas aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharimonasAalborgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCelerecrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] celerecrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelerecrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full4528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterSolanacearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter solanacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiberibacterSolanacearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPhytoplasmaAurantifoliaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma aurantifolia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaAurantifoliaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlenkiaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klenkia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlenkiaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonJdfr11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon JdFR11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonJdfr11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaldiniaSpEc12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daldinia sp. EC12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaldiniaSpEc12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrapeneCarolinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrapene carolina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrapeneCarolinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesQinglanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qinglanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQinglanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrimonasCliftonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrimonas cliftonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrimonasCliftonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusEpidermidisAtcc12228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis ATCC12228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisAtcc12228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifoxyd2Full5815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYD2_FULL_58_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyd2Full5815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusHiraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hirae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHiraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumMs0243c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS024-3C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0243c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afifella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfifellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EptatretusBurgeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eptatretus burgeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EptatretusBurgeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpW7784(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. W7784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpW7784", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaSingaporensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha singaporensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaSingaporensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full4013bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminomonasPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminomonas paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminomonasPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaMarinoflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMacquariensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macquariensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMacquariensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPulmonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pulmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPulmonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusSpWch70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. WCH70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpWch70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSlackiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces slackii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSlackiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliothisVirescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heliothis virescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeliothisVirescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpMrs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. MRS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpMrs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd1full4023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD1FULL4023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd1full4023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpUcdkl20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. UCDKL20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpUcdkl20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaGrenadensisNbrc108939Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia grenadensis NBRC 108939 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaGrenadensisNbrc108939Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterSpLpb0142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. LPB0142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpLpb0142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpBbd19919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. BBD 1991-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpBbd19919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterAquimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAquimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrobacterSoliDsm22325(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter soli DSM 22325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SolirubrobacterSoliDsm22325", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosarchaeumLimniumSfb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosarchaeum limnium SFB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosarchaeumLimniumSfb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaSulfidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga sulfidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaSulfidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrabacterSpSoil810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Soil810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpSoil810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIThaumarchaeoteScgcAaa799D11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AAA799-D11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAaa799D11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacteriaBacteriumCg10238174Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacteria bacterium CG10238174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacteriaBacteriumCg10238174Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumGambriniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gambrini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGambriniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaSpHgh0030Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. HGH0030 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpHgh0030Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumGw2011gwb1547Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium GW2011GWB1547 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumGw2011gwb1547Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyscomitrellaPatensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Physcomitrella patens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhyscomitrellaPatensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusHydrogenalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus hydrogenalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusHydrogenalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumVulpinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium vulpinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumVulpinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoatesbacteriaBacteriumRbg136614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coatesbacteria bacterium RBG136614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoatesbacteriaBacteriumRbg136614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporumMel28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tuber melanosporum Mel28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TuberMelanosporumMel28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthorchisFelineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis felineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisFelineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MurdochiellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusXanthus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus xanthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcusXanthus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctosCinereusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctos cinereus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhascolarctosCinereusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusParasiticusSu1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus SU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusParasiticusSu1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisPotens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis potens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPotens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumGilvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium gilvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGilvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp123mfchir2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 123MFChir2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSp123mfchir2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasHaloplanktisTac125Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TAC125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTac125Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesSubtropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes subtropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSubtropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinihabitansFlavidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinihabitans flavidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinihabitansFlavidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTpa0875(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0875 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0875", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpOv219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OV219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOv219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaSpUcddsuzukiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tatumella sp. UCDDsuzukii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TatumellaSpUcddsuzukiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb24720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumAcapulenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium acapulense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAcapulenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumHimb114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IainarchaeumAndersoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Iainarchaeum andersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IainarchaeumAndersoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho202full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO202FULL4712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho202full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAraii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia araii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaAraii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiUlc007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi ULC007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiUlc007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpCag257Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag257Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusCanintestini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canintestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanintestini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHemicellulosilyticusJcm9152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus JCM 9152 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticusJcm9152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPsittaciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus psittaci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPsittaciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidaceaeBacteriumMs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidaceae bacterium MS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidaceaeBacteriumMs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LongilineaArvoryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Longilinea arvoryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LongilineaArvoryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasMephitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas mephitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasMephitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil774(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil774 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil774", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidisNbrc100137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arthritidis NBRC 100137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaArthritidisNbrc100137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaStercoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella stercoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaStercoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicoprobacterOshimaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter oshimai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldicoprobacterOshimaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephaloticoccusPrimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus primus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusPrimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesArizonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces arizonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycomycesArizonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaeromonasToyohensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpSk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. SK-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpSk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpGxf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXF4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLongbeachaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella longbeachae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaLongbeachaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGilvosporeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvosporeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvosporeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenariaAnguillulaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenaria anguillulae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenariaAnguillulaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpRac06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. RAC06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpRac06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaGuancheEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila guanche Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGuancheEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKapabacteriaThiocyanatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kapabacteria thiocyanatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKapabacteriaThiocyanatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpDdh964Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. DDH964 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpDdh964Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaGrenadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia grenadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaGrenadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpApg3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosospira sp. APG3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitrosospiraSpApg3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortieraAleyrodidarumTv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum TV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumTv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSpMar2009124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2009_124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar2009124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumAmurskyenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium amurskyense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumAmurskyenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactococcusChungangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaWexlerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blautia wexlerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlautiaWexlerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_44_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCaldiarchaeumSubterraneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caldiarchaeum subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaldiarchaeumSubterraneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwb26322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo201full4421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO201FULL4421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo201full4421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlexibacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpDsm18164Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. DSM 18164 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpDsm18164Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis05zyh33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 05ZYH33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis05zyh33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiaceaeBacteriumUrhb0013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangiaceae bacterium URHB0013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiaceaeBacteriumUrhb0013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuberDsm16370Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ruber DSM 16370 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioRuberDsm16370Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FructobacillusTropaeoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus tropaeoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FructobacillusTropaeoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfaeVams102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae VaMs.102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VerticilliumAlfalfaeVams102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaSpUcdthpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. UCDTHP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DietziaSpUcdthpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersephonellaSpIf05l8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. IF05L8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpIf05l8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosynechococcusSphagnicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpH5989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. H5989 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpH5989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg16399b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_39_9b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16399b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAquaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAquaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp135mfcol51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 135MFCol51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp135mfcol51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RobiginitaleaMyxolifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea myxolifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaMyxolifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_45_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatonellaMorbiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catonella morbi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatonellaMorbiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TannerellaForsythia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tannerella forsythia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TannerellaForsythia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSp329mfshaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 329MFSha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp329mfshaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMongolense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mongolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumMongolense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulierisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MobiluncusMulierisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobrancaCaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGinsengihumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ginsengihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGinsengihumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaWestfalicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia westfalica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaWestfalicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumDeserti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumDeserti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGr1643Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium GR16-43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGr1643Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumAquaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium aquaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumAquaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSpTu14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sp. TU-14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSpTu14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhymatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phymatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhymatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpWch70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. WCH70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpWch70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTusciaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tusciae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTusciaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2304418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSaudimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnatzschineriaLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignatzschineria larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnatzschineriaLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumMa2020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MA2020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMa2020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaFaecigallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea faecigallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaFaecigallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathymodiolusAzoricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathymodiolusAzoricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasCitreaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas citrea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasCitreaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsphigho201full388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL388 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalobiumEvestigatumZ7303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Z-7303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatumZ7303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaporthiopsisPoaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoatesbacteriaBacteriumRbg136614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coatesbacteria bacterium RBG136614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoatesbacteriaBacteriumRbg136614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPeriocalifornicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides periocalifornicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPeriocalifornicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaHypogea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga hypogea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaHypogea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Arsenicicoccus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Arsenicicoccus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BalneatrixAlpicaDsm16621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Balneatrix alpica DSM 16621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BalneatrixAlpicaDsm16621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusNatl2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpKrocy2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. KROCY2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpKrocy2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUnc438cl73tsus30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC438CL73TsuS30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc438cl73tsus30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioCellulolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetivibrioCellulolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumBrasilense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum brasilense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumBrasilense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthochromisPolyacanthusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acanthochromis polyacanthus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcanthochromisPolyacanthusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensMput9231(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Mput9231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensMput9231", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGwa26437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWA2_64_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwa26437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillisiaBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Millisia brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MillisiaBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumOrchidophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orchidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrchidophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSpRlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. RL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSpRlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermicanusAegyptiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermicanus aegyptius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermicanusAegyptiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBrassicacearumSubspBrassicacearumNfm421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum subsp. brassicacearum NFM421 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearumSubspBrassicacearumNfm421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilusPhascolarctosicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilus phascolarctosicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilusPhascolarctosicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisKc583Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis KC583 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisKc583Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumBarkeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium barkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBarkeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisHerdmaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis herdmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeminocystisHerdmaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpAg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Ag1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfatibacterAminovoransDsm17477Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans DSM 17477 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovoransDsm17477Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida parapsilosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaParapsilosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBikiniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bikiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBikiniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpUrha0032Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0032Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasSpDtu019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaCellulosilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumFrankenforstenseDsm45800(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense DSM 45800 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstenseDsm45800", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioliNbrc102428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fumarioli NBRC 102428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusFumarioliNbrc102428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisBalhimycina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis balhimycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBalhimycina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAap43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AAP43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAap43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSputiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sputi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSputiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBereziniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bereziniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBereziniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaPattaloongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pattaloongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPattaloongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViridosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermothielavioidesTerrestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg167214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_72_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg167214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusAs9601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus AS9601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusAs9601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfohalotomaculumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalotomaculum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfohalotomaculumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45543Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpUnccl117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNCCL117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnccl117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaOvataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa ovata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporomusaOvataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumStellenboschenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium stellenboschense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumStellenboschenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimicrobiiaBacteriumRedseas09b7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium REDSEAS09B7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumRedseas09b7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpFc2011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. FC2011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpFc2011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulciaMuelleriCariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri CARI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriCariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPoribacteriaBacteriumWga3gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Poribacteria bacterium WGA-3G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPoribacteriaBacteriumWga3gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnolisCarolinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anolis carolinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnolisCarolinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaAstilbisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asaia astilbis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsaiaAstilbisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusBoraciitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus boraciitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusBoraciitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentinusTigrinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentinus tigrinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentinusTigrinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobalesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobalesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumCg1023744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusDora7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus DORA7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusDora7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMoriokaenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium moriokaense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMoriokaenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNasuensisJcm17158Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis JCM 17158 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNasuensisJcm17158Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_24b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaShahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella shahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaShahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_55_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimonsiellaMuelleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Simonsiella muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SimonsiellaMuelleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag354(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag354", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaSeiffertiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasMucosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas mucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseomonasMucosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusFf33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus FF33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusFf33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumVarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium varium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumVarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusVulcaniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus vulcanius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVulcaniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraCarrioniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora carrionii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraCarrioniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomicrobiumZhouiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomicrobium zhouii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomicrobiumZhouiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpMs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpMs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasAbyssalisTar001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis TAR-001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalisTar001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusWeihaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus weihaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusWeihaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlligatorMississippiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alligator mississippiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlligatorMississippiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusDepauperatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptococcusDepauperatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaLacustrisZ7289(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina lacustris Z-7289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaLacustrisZ7289", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricisUamh7299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polytolypa hystricis UAMH7299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolytolypaHystricisUamh7299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBiviaDnf00188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia DNF00188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaDnf00188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpongiarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus spongiarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpongiarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformansDsm21757Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans DSM 21757 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformansDsm21757Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumIntermediumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum intermedium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumIntermediumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvularculaSpBbd199113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula sp. BBD 1991-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvularculaSpBbd199113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaObeumA2162Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia obeum A2-162 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlautiaObeumA2162Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSatsumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSatsumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSpSa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. SA_1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpSa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAquilunaSpUbMaderosw2redEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aquiluna sp. UB-MaderosW2red Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAquilunaSpUbMaderosw2redEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMagnumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium magnum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMagnumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaCaballeronisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caballeronis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaballeronisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium1456faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 1456FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium1456faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumGwf23715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWF2_37_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwf23715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasEucrenophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas eucrenophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasEucrenophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpF0356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. F0356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpF0356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSobrinusDsm20742Atcc33478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sobrinus DSM 20742 ATCC 33478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSobrinusDsm20742Atcc33478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavonifractorPlautiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavonifractor plautii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavonifractorPlautiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasCoralicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas coralicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AurantimonasCoralicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuminiphilusSyltensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luminiphilus syltensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuminiphilusSyltensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusAcidiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acidiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcidiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrilyobacterAtlanticusDsm19335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus DSM 19335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticusDsm19335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpTab87Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. TAB 87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpTab87Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat44921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-44921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat44921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioParahaemolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio parahaemolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioParahaemolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpVer3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. Ver3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpVer3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMmg1533Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MMG1533 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMmg1533Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAlkeniferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alkenifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlkeniferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidiprofundiDsm19306Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi DSM 19306 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundiDsm19306Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidifarinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_12_FULL_44_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSp2009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. 2009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSp2009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4572128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 4572_128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4572128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot112d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root112D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot112d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumOlb18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium OLB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumOlb18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusAntriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus antri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAntriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPHIGHO2_12_FULL_44_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsphigho212Full4417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsenicicoccusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpUnc378mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. UNC378MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpUnc378mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLydicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lydicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLydicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPyloriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pylori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPyloriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosarchaeumKoreenseMy1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense MY1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreenseMy1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSplendidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio splendidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSplendidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifcsplowo202full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFCSPLOWO202FULL4515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifcsplowo202full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWadsworthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella wadsworthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaWadsworthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UlvibacterSpLpb0005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter sp. LPB0005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UlvibacterSpLpb0005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermochlorobacteriaceaeBacteriumGbchlb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermochlorobacteriaceae bacterium GBChlB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermochlorobacteriaceaeBacteriumGbchlb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm3983Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM3983 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm3983Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEquorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus equorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEquorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesIleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ilei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesIleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasArsenitoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenitoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenitoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensMarinusS108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nonlabens marinus S1-08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NonlabensMarinusS108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAnguillisepticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas anguilliseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAnguillisepticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalobiumEvestigatumZ7303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum Z-7303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatumZ7303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag462Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:462 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag462Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrusUnshiuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrus unshiu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrusUnshiuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNc2004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosaetaHarundinacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosaetaHarundinacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumLuteolumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium luteolum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumLuteolumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInadaiSerovarLymeStr10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira inadai serovar Lyme str. 10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraInadaiSerovarLymeStr10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpSm22m07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SM22M-07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpSm22m07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusTc41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius Tc41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusTc41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAidingenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aidingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAidingenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoktanellaVestfoldensisSka53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Loktanella vestfoldensis SKA53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LoktanellaVestfoldensisSka53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaGraminisWp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodotorula graminis WP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodotorulaGraminisWp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumLimigenitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium limigenitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLimigenitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngm7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHungaricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hungaricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHungaricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterVibrioformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full588Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL588 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full588Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacteraceaeBacteriumGoma1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacteraceae bacterium GOMA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacteraceaeBacteriumGoma1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPseudosasicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium pseudosasicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPseudosasicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMayottensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira mayottensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMayottensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusGp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus GP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusGp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_51_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasSpGwf2378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. GWF2_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpGwf2378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpOv700Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV700 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv700Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumFlavigenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium flavigenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFlavigenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusTukisamuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus tukisamuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTukisamuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumIn8p8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum in8p8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumIn8p8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelcococcusSueciensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus sueciensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelcococcusSueciensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusKukulkaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus kukulkanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusKukulkaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSp14bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum sp. 14B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSp14bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh3588Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH3588 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh3588Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatoriaSpPcc10802Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria sp. PCC10802 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaSpPcc10802Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpYr710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. YR710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpYr710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraMurdochiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira murdochii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraMurdochiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaVermiculata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vermiculata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaVermiculata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumDisporicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium disporicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDisporicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolicicoccusSubflavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolicicoccus subflavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmycolicicoccusSubflavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumGa0077543Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077543 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077543Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMendocinaEgdaq5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina EGDAQ5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMendocinaEgdaq5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisSpAc460Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC460 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc460Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichobilharziaRegentiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichobilharzia regenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichobilharziaRegentiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumLuteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumLuteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusPhoenicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus phoenicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPhoenicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioParadoxus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDelicatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter delicatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDelicatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterHydrocarbonoclasticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter hydrocarbonoclasticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterHydrocarbonoclasticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaMesophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaMesophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTerreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus terreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusTerreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumScindensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium scindens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumScindensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13220cm5827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_2_20CM_58_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13220cm5827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTaeniosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium taeniosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTaeniosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NautiliaProfundicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nautilia profundicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NautiliaProfundicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GuillardiaThetaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Guillardia theta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GuillardiaThetaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpRw2a1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. RW2A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpRw2a1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalsuginibacillusKocuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salsuginibacillus kocurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalsuginibacillusKocuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioCholeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterCrescentusOr37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus OR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusOr37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsplowo201full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeMaculicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae maculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeMaculicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusXiangfangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus xiangfangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusXiangfangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe23121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE23121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe23121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalitaleaSaponilacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalitalea saponilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalitaleaSaponilacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCapricolum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCapricolum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcidifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium acidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumAcidifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensMput9231Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Mput9231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensMput9231Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaLongibrachiatumAtcc18648(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum ATCC 18648 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatumAtcc18648", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriSdmlacCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri SDMLAC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriSdmlacCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacteriumRbg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluoribacterBozemanaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter bozemanae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FluoribacterBozemanaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc5015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC5015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc5015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSecaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus secaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSecaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthocheilonemaViteae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acanthocheilonema viteae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcanthocheilonemaViteae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaeraeDsm18581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae DSM 18581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioRhizosphaeraeDsm18581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAmmonioxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia ammonioxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAmmonioxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanomethylicusOleusabulumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus oleusabulum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusOleusabulumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBreve(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium breve graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBreve", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzotobacterChroococcum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniomycesSimplex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesSimplex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaJogaejeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella jogaejeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaJogaejeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpPrwf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PRwf1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPrwf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaSpHfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia sp. HF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaSpHfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_63_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full6320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhodospiraHalochlorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalochlorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpBa93Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa93Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumArsenaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforudisAudaxviatorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulforudis audaxviator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulforudisAudaxviatorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumMathurense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium mathurense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMathurense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSpErvv1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. ErVv1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpErvv1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NereidaIgnavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nereida ignava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NereidaIgnavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaKrabiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora krabiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaKrabiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtrovirideImi206040(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma atroviride IMI 206040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAtrovirideImi206040", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumRedseas09b7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium REDSEAS09B7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumRedseas09b7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpPacm27299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. PACM 27299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpPacm27299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGwa15412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GWA1_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGwa15412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumHigginsianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxLentusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxLentusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixLacustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix lacustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiothrixLacustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizoporaParadoxa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schizopora paradoxa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchizoporaParadoxa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisIl1403(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis Il1403 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisIl1403", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAcetobutylicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetobutylicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetobutylicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSpKl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. KL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpKl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCollinoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus collinoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCollinoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpecialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces specialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpecialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaVermiferaMaff305830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serendipita vermifera MAFF 305830 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerendipitaVermiferaMaff305830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothiobacillusSpLs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. LS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpLs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGraminisDsm20719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus graminis DSM 20719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGraminisDsm20719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRhodolunaPlanktonica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodoluna planktonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodolunaPlanktonica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatitaleaSpBrhc12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea sp. BRHc12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaSpBrhc12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaConspicuaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea conspicua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaConspicuaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalsuginibacillusKocurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salsuginibacillus kocurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalsuginibacillusKocurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsplowo212full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPLOWO212FULL4812 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsplowo212full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr80Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr80Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo212full5011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO212FULL5011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo212full5011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraChibensisNbrc106107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura chibensis NBRC 106107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraChibensisNbrc106107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaLacteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella lactea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NakamurellaLacteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPerorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus peroris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPerorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCaecimurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caecimuris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaecimurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaprevotellaXylaniphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella xylaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaXylaniphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyosteliumPurpureum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium purpureum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumPurpureum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinusCanariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serinus canaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerinusCanariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaWaywayandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea waywayandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaWaywayandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata var. bicuspidata NRRL YB-4993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaArgentinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula argentinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaArgentinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaccariaBicolorS238nH82(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Laccaria bicolor S238N-H82 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LaccariaBicolorS238nH82", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioTubiashiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tubiashii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioTubiashiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialocephalaSubalpinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala subalpina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaSubalpinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaSuimastitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia suimastitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaSuimastitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUvarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus uvarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusUvarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMimicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mimicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMimicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemonchusPlaceiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemonchus placei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemonchusPlaceiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaW619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida W619 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaW619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAlkaliphilum121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum 12/1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilum121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaCheerisanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora cheerisanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KitasatosporaCheerisanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararheinheimeraTexasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomycesMinteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryomyces minteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryomycesMinteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusGauvreauiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gauvreauii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGauvreauiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VolvoxCarteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Volvox carteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VolvoxCarteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterCibinongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter cibinongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterCibinongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterFormicigenesDsm15518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes DSM 15518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TepidibacterFormicigenesDsm15518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumIntermediumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum intermedium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumIntermediumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterAcetatoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter acetatoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterAcetatoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusDoucetiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus doucetiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusDoucetiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAld1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALD1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAld1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumCaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum californiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaePxo99a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae PXO99A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePxo99a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasChromatireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas chromatireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasChromatireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. arizonae serovar 62:z4,z23:- Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasSpNm33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanibaculumIndicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum indicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumIndicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpStflb209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. StFLB209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpStflb209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisBiprosthecum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis biprosthecum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBiprosthecum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpXpd2006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XPD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXpd2006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFirestonebacteriaBacteriumRifoxya2Full408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYA2_FULL_40_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxya2Full408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GullanellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gullanella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GullanellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymobacterPalmaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymobacter palmae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymobacterPalmaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCollinoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus collinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCollinoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRbg164410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG164410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg164410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSpMz1tCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. MZ1T Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraSpMz1tCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrapeneCarolinaTriunguisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Terrapene carolina triunguis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TerrapeneCarolinaTriunguisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1024740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1024740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1024740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOeniDsm19972Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oeni DSM 19972 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOeniDsm19972Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh7805Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7805 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7805Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHomomorphusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus homomorphus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusHomomorphusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesCellulosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellulosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellulosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraViscosaTufc12733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Calocera viscosa TUFC12733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaloceraViscosaTufc12733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHel185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMuproteobacteriaBacteriumRbg166534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_65_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiUmn026(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli UMN026 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiUmn026", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSaudimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSaudimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumCg2303331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_33_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg135518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_13_55_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg135518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpCag317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaWenyoniiStrMassachusettsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii str. Massachusetts Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaWenyoniiStrMassachusettsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumScardoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium scardovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumScardoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMiyunensisNbrc108239(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia miyunensis NBRC 108239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaMiyunensisNbrc108239", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterNecessariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full4211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL4211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full4211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifcsplowo201full4825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4825 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaSpOralTaxon928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemella sp. oral taxon 928 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemellaSpOralTaxon928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaldiniaSpEc12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daldinia sp. EC12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaldiniaSpEc12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraParasiticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora parasitica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraParasiticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpP5210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. P5210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpP5210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasGadeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas gadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasGadeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzohydromonasAustralicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azohydromonas australica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzohydromonasAustralicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumCg2304320(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_43_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2304320", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophusGentianaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus gentianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophusGentianaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCamporealensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium camporealensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCamporealensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpPm2p129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. PM2P129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpPm2p129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocystisAeruginosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microcystis aeruginosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrocystisAeruginosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom181602daomCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM181602DAOM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602daomCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumSpF0552Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum sp. F0552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSpF0552Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpLeaf261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFluviicolaRiflensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fluviicola riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFluviicolaRiflensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusSpM41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus sp. M41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusSpM41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedSup05ClusterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedSup05ClusterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterAnophelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter anophelis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterAnophelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAmaraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amarae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmaraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaBuccalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia buccalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaBuccalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHygroscopicusSubspHygroscopicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus subsp. hygroscopicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusSubspHygroscopicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacterRiflensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacter riflensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacterRiflensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSalamaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica salamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaSalamaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusVillosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumMathurenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium mathurense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMathurenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasPhyllosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas phyllosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasPhyllosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaphniaMagna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daphnia magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaphniaMagna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaLacteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella lactea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NakamurellaLacteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpUrhe0023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHE0023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhe0023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VittaformaCorneae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vittaforma corneae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VittaformaCorneae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg104632Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_46_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104632Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumPseudolongumGlobosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum globosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumGlobosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpW2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogemmatisporaOnikobensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora onikobensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaOnikobensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDentisani7747Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7747 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7747Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumMicromatiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium micromati Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMicromatiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpPh1cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. PH1c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpPh1cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreiburgense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium freiburgense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFreiburgense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_69_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHalophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHalophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenimonasThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenimonas thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenimonasThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilaceaeBacteriumUrhb0062(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0062", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodonellumPsychrophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum psychrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodonellumPsychrophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarthrobacterChlorophenolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter chlorophenolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterChlorophenolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusLentulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus lentulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusLentulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterSpW10330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. W10330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSpW10330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaOrthopsilosisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida orthopsilosis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaOrthopsilosisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeomargaritaLithophoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeomargaritaLithophoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacterium4484255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium 4484255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacterium4484255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycomycesBlakesleeanusNrrl1555Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus NRRL 1555(-) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanusNrrl1555Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSteyniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter steynii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSteyniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldibacillusDebilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldibacillus debilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldibacillusDebilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyorhinisSk76(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis SK76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisSk76", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioMarinisediminisDsm17456Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis DSM 17456 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminisDsm17456Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NegativicoccusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Negativicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NegativicoccusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSp21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. 21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSp21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVulnerisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium vulneris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumVulnerisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumPsychroaquaticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium psychroaquaticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPsychroaquaticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesCerinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces cerinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesCerinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDendritiformisC454(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis C454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformisC454", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag709(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:709 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag709", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 28-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis2F0392Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis 2 F0392 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitis2F0392Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterCryohalolentisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cryohalolentis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCryohalolentisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetalesBacterium457213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4572_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium457213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsplowo2024220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO2024220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo2024220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpX12014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. X1(2014) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpX12014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumRifoxya2full4310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFOXYA2FULL4310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifoxya2full4310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaDairenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaDairenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusNeutrinimicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus neutrinimicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusNeutrinimicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomonasBhubaneswarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas bhubaneswarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomonasBhubaneswarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea longicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaLongicatena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParasanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlcaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHimb058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpLc2012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. lc2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpLc2012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DokdonellaKoreensisDs123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella koreensis DS-123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DokdonellaKoreensisDs123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdiutrixIntracellularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adiutrix intracellularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdiutrixIntracellularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReyranellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Reyranella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ReyranellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExidiaGlandulosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exidia glandulosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExidiaGlandulosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSoliNbrc106424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Variovorax soli NBRC 106424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VariovoraxSoliNbrc106424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSchinkiiDsm10518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blautia schinkii DSM 10518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlautiaSchinkiiDsm10518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovispirillumItersonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novispirillum itersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovispirillumItersonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannocystisExedensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nannocystis exedens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NannocystisExedensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusPaucihalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus paucihalophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusPaucihalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScheffersomycesStipitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScheffersomycesStipitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpM334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFeeleii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella feeleii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaFeeleii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusXylanilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus xylanilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusXylanilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumSpMlsbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. MLSB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpMlsbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKsb1Bacterium448487Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division KSB1 bacterium 4484_87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1Bacterium448487Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistoplasmaCapsulatumH88Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H88 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH88Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_47_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpAr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. AR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpAr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GadusMorhua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gadus morhua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GadusMorhua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpRha55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. RHA_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpRha55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSyntrophoarchaeumButanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Syntrophoarchaeum butanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSyntrophoarchaeumButanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaLimosaDsm17973Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Runella limosa DSM 17973 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RunellaLimosaDsm17973Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSubvibrioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas subvibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSubvibrioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSolanacearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSolanacearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolobusProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterSpAzwk3b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. AzwK3b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpAzwk3b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteccherinumOchraceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Steccherinum ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SteccherinumOchraceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpBnl1100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BNL1100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBnl1100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHochsteniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumHochsteniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusTestudinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus testudinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusTestudinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp141Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp141Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumGossypiiAtcc10895Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii ATCC 10895 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EremotheciumGossypiiAtcc10895Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMinorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus minor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMinorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpAr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. AR2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitrosopumilusSpAr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpUcdkl21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpermophilusDauricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spermophilus dauricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpermophilusDauricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusAmylolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus amylolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronococcusAmylolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpNk2b42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. NK2B42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpNk2b42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBorboriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas borbori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBorboriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacterium13220cm6814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 13_2_20CM_68_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium13220cm6814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAdetyCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. AdeTY Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAdetyCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusSpKu26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusUrinaehominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinaehominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinaehominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaChitosanitabidaAtccBaa476Nbrc102408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mitsuaria chitosanitabida ATCC BAA-476 NBRC 102408 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MitsuariaChitosanitabidaAtccBaa476Nbrc102408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSpPcc6303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC6303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc6303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenesDsm13106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes DSM 13106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenesDsm13106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpScgcAaa288l16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. SCGC AAA288L16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpScgcAaa288l16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1026051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_60_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1026051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusRhinitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus rhinitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRhinitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumAlamiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium alamii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAlamiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonIplasmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Iplasma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonIplasmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumThermoresistibileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium thermoresistibile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumThermoresistibileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoniliophthoraPerniciosaFa553Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa FA553 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosaFa553Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JoostellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Joostella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JoostellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuriculariaDelicataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Auricularia delicata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AuriculariaDelicataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterVibrioformisDsm8776Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis DSM 8776 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformisDsm8776Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpCcge1003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwf13135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWF1_31_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwf13135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporidiumMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacteraceaeBacteriumGwc25520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_55_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumMtc7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium MTC7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumMtc7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusCerbereusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus cerbereus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusCerbereusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium13220cm6619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 13_2_20CM_66_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium13220cm6619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophobacterFumaroxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter fumaroxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterFumaroxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusReuteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharolobusSolfataricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharolobus solfataricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharolobusSolfataricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelghirimycesThermohalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melghirimyces thermohalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelghirimycesThermohalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumAgarivoransYm01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans YM01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransYm01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpBab2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacillus sp. BAB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalobacillusSpBab2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaDrozanskiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella drozanskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrozanskiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichormusVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichormus variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichormusVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpNi22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodovulum sp. NI22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodovulumSpNi22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dadantii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaDadantiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaStellulataDsm5886(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stappia stellulata DSM 5886 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StappiaStellulataDsm5886", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusResistens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus resistens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusResistens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSpSd62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. SD62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpSd62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasGingivicanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivicanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivicanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSaudimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSaudimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumJaponicumUsda124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaTimonensisCris5cb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis CRIS5CB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensisCris5cb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDelongbacteriaBacteriumGwf24014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Delongbacteria bacterium GWF2_40_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDelongbacteriaBacteriumGwf24014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasNasdaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas nasdae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasNasdaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KordiimonasGwangyangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas gwangyangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiimonasGwangyangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaSqualenifaciensDsm18772Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens DSM 18772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciensDsm18772Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumLavalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] lavalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLavalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumExpansum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium expansum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumExpansum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpB6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. B6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpB6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpEr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. ER2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpEr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpCg2304434Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. CG2_30_44_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpCg2304434Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetalesBacteriumSpiro07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumPhlei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium phlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumPhlei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumUndicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium undicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumUndicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaNativaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nativa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNativaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpNoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. No. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpNoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialophoraAmericanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialophora americana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAmericanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylumTricornutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaHispanicaCriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hispanica CRI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaHispanicaCriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho202full5012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL5012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full5012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeotrichumCandidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geotrichum candidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeotrichumCandidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GallibacteriumGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasMalthae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas malthae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMalthae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoolittleaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doolittlea endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoolittleaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200251163sch5372311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251163SCH5372311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251163sch5372311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpCf514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. CF514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpCf514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaSpCag521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentolepisNana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentolepis nana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentolepisNana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpZor0009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. ZOR0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZor0009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ItalianClover(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Italian clover graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ItalianClover", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StanieriaCyanosphaeraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stanieria cyanosphaera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StanieriaCyanosphaeraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaNonliquefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella nonliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaNonliquefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloprofundusMarisrubriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloprofundus marisrubri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloprofundusMarisrubriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AndersenbacteriaBacteriumRifcsphigho201full4636Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Andersenbacteria bacterium RIFCSPHIGHO201FULL4636 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AndersenbacteriaBacteriumRifcsphigho201full4636Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag460Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag460Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSinduriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sinduriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSinduriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMucilaginosus3016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus 3016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosus3016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumRuminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrococcusCaseolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus caseolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCaseolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatusPharyngisC1050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis C1050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisC1050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusTerrigenaDsm22685(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena DSM 22685 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigenaDsm22685", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumIslandicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium islandicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumIslandicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpR1200b2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. R1200B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpR1200b2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinococcusGranulosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus granulosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EchinococcusGranulosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTetaniE88(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium tetani E88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTetaniE88", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSubflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiXiangfangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei xiangfangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiXiangfangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSimulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus simulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSimulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHaemophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUrha0014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. URHA0014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUrha0014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpEc33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ec33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpEc33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterPsychrotoleransDsm18569Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans DSM 18569 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HymenobacterPsychrotoleransDsm18569Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterMucosalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter mucosalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterMucosalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarithrixSpCanyon246Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marithrix sp. Canyon 246 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarithrixSpCanyon246Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WalczuchellaMonophlebidarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Walczuchella monophlebidarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WalczuchellaMonophlebidarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumCg1023722(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium CG1023722 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumCg1023722", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisciDsm44792(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci DSM 44792 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisciDsm44792", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerohalosphaeraLusitana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerohalosphaera lusitana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerohalosphaeraLusitana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpQssc122bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. QSSC1-22B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpQssc122bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FructobacillusFiculneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus ficulneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFiculneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaPaurometabolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucothrixMucor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucothrix mucor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucothrixMucor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesSpNrrlb16210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces sp. NRRLB16210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycomycesSpNrrlb16210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphiprionOcellaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion ocellaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphiprionOcellaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpUpii135eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. UPII135E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpUpii135eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilaceaeBacteriumUrha0031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHA0031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrha0031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApibacterMensalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apibacter mensalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApibacterMensalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterShowaeCc57cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CC57C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCc57cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaLoihiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina loihiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaLoihiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiA2165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii A2165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiA2165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicusStrDeltaH(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus str. Delta H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicusStrDeltaH", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergomycesPasteurianusEp9510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Ep9510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EmergomycesPasteurianusEp9510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusSzentirmaiiDsm16338(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii DSM 16338 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaiiDsm16338", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus glaucus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusGlaucus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC2_FULL_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc2Full3612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloceanibacterSteviniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter stevinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterSteviniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OstreococcusLucimarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OstreococcusLucimarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalimicrobiumAerophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium aerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumAerophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumAtrosepticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium atrosepticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumAtrosepticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumMassiliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumMassiliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAkariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia akari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAkariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaInefficaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia inefficax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaInefficaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwc27318Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWC2_73_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwc27318Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChisholmbacteriaBacteriumRifcsphigho201full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPHIGHO201FULL4812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsphigho201full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxXenomutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax xenomutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxXenomutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeronosporaEffusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peronospora effusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeronosporaEffusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBatumiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas batumici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBatumiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCcmmd2014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CCMMD2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCcmmd2014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaNeteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cedecea neteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CedeceaNeteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumThermosaccharolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium thermosaccharolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumThermosaccharolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSp6413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. 64-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaSp6413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxya1full4011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYA1FULL4011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxya1full4011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpBv3p1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BV3P1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBv3p1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaAldovaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia aldovae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaAldovaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumRbg136414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_64_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpNor37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. NOR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpNor37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAzureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio azureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioAzureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacibacillusPorcorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacillus porcorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacibacillusPorcorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaBestiolaeCbs10118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae CBS 10118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KwoniellaBestiolaeCbs10118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrobacterXylanophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter xylanophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrobacterXylanophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumLp2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium LP2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumLp2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnobacterSpMed105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. MED105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpMed105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolaniAg1iaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1iaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NannizziaGypseaCbs118893(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nannizzia gypsea CBS 118893 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NannizziaGypseaCbs118893", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfocurvusVexinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvus vexinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvusVexinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMongolienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium mongoliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMongolienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaPneumophilaSubspPasculleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. pascullei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspPasculleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsialesBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfolunaSpongiiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfoluna spongiiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfolunaSpongiiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf402(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf402", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaAlbidocapillataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea albidocapillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaAlbidocapillataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NadsoniaFulvescensVarElongataDsm6958(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens var. elongata DSM 6958 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NadsoniaFulvescensVarElongataDsm6958", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_49_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSaccharovorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum saccharovorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSaccharovorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonSmtz145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon SMTZ1-45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonSmtz145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReichenbachiellaAgariperforans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella agariperforans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaAgariperforans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpJha19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasHypermegale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megamonas hypermegale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegamonasHypermegale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusFijiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaHaliotis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimia haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimiaHaliotis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_51_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaHofmanniiPcc7110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmannii PCC 7110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ScytonemaHofmanniiPcc7110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc5600Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5600 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5600Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GleimiaEuropaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gleimia europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GleimiaEuropaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDidelphisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus didelphis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDidelphisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot494Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root494 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot494Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaEumusaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora eumusae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaEumusaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurovumRiftiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum riftiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumRiftiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerBermudensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipiger bermudensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipigerBermudensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacrostomumLignano(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macrostomum lignano graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacrostomumLignano", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot708Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root708 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot708Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSteigerwaltiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei steigerwaltii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSteigerwaltiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalohastaLitchfieldiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halohasta litchfieldiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalohastaLitchfieldiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa076p13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3610bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3610b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3610bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RutstroemiaSpNjr2017aWrk4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a WRK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aWrk4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAnserinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia anserina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaAnserinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinusAz3aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus AZ3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinusAz3aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusDepauperatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptococcusDepauperatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OgataeaParapolymorphaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OgataeaParapolymorphaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaArizonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica arizonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaArizonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls1022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1022 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumParafortuitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium parafortuitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumParafortuitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe14915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_49_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe14915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPseudoalcaligenesAd6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes AD6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesAd6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMarginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_35_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminomonasPaucivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminomonas paucivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminomonasPaucivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumNodulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium nodulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumNodulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisDiscipulorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis discipulorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisDiscipulorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSpF0381Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0381 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0381Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacaBermudensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca bermudensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PelagibacaBermudensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfohalobiumRetbaense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalobium retbaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfohalobiumRetbaense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiochaetaLigniaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaLigniaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagnetobacteriumCasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magnetobacterium casensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagnetobacteriumCasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacaBarguzinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobaca barguzinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacaBarguzinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicaulisSpHtcc2633(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. HTCC2633 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpHtcc2633", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusSpCag917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacacaNemestrinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macaca nemestrina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacacaNemestrinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus niger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusNigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUrealyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium urealyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUrealyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp4212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusColihominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus colihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusColihominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiBulgaricus2038(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus 2038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricus2038", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusRifietoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus rifietoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusRifietoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHeilmanniiAsb14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii ASB1.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterHeilmanniiAsb14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobifidaCellulosilyticaTb100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica TB100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilyticaTb100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulosiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] cellulosi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulosiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPaucimobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas paucimobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPaucimobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensisDsm11113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis DSM 11113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensisDsm11113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesScabrisporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabrisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabrisporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusBarophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus barophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusBarophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasBivalviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas bivalvium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasBivalviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAlaskensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alaskensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlaskensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumCg1024134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_41_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1024134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumCaliforniensisDsm19288Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum californiensis DSM 19288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensisDsm19288Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph809(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH809 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph809", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBorealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBorealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioAlginolyticusNbrc15630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus NBRC15630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticusNbrc15630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BarnesiellaIntestinihominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella intestinihominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaIntestinihominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterMarinusDsm19753(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spongiibacter marinus DSM 19753 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpongiibacterMarinusDsm19753", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaVermiferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serendipita vermifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerendipitaVermiferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmatalesArchaeonEplasmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Eplasma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonEplasmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division ZIXI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionZixiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag568Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:568 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag568Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusPropionicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseospirillumParvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseospirillum parvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseospirillumParvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAlligatorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alligatoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlligatorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcoidesMethylutensMm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens MM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutensMm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumMedicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium medicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMedicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomycesKudriavzeviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzeviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo212full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO212FULL4712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo212full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumMangenotiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mangenotii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMangenotiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusClausii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus clausii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusClausii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpM313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. m313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpM313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusVannieliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus vannielii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVannieliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg164113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WenyingzhuangiaFucanilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia fucanilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaFucanilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHalodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Schekmanbacteria bacterium RIFCSPLOWO2_12_FULL_38_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetakosakoniaMassiliensisJc163(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis JC163 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensisJc163", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoturnixJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coturnix japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoturnixJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterGinsenosidimutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ginsenosidimutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterGinsenosidimutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat29937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterUreolyticusRigs9880Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus RIGS 9880 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUreolyticusRigs9880Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChthonomonasCalidiroseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chthonomonas calidirosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChthonomonasCalidiroseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRbg134211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG134211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg134211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpSlbn35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. SLBN-35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSlbn35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo2024220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_02_42_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo2024220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdhaeribacterAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adhaeribacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdhaeribacterAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolineaTardivitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolinea tardivitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolineaTardivitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesTimonensisJc136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes timonensis JC136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesTimonensisJc136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo201full379Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL379 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full379Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacterialesBacteriumUtchb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteriales bacterium UTCHB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacterialesBacteriumUtchb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpWch70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. WCH70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpWch70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpT9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot495Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root495 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot495Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrilyobacterAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeBacteriumPbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium PBA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacteriumPbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmittiumMegazygosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smittium megazygosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmittiumMegazygosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphenodonPunctatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphenodon punctatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphenodonPunctatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumCg2306842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium CG2_30_68_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumCg2306842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaePvTagetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae pv. tagetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePvTagetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12747610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274761.0 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrobacterAplysinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrobacter aplysinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrobacterAplysinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpZor0019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ZOR0019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpZor0019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematocidaParisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nematocida parisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NematocidaParisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacterium4920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 49-20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesIhumii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesIhumii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyceliophthoraThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Myceliophthora thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MyceliophthoraThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusGenomosp3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusGenomosp3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu087Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU087 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu087Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudochrobactrumSpB5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudochrobactrum sp. B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudochrobactrumSpB5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpPamc26628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrumPuertoriconensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solirubrum puertoriconensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolirubrumPuertoriconensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpZym1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. ZYM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpZym1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSpSpongeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. sponge Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpSpongeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGr1643Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium GR16-43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGr1643Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusHirae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hirae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHirae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaCenocepaciaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cenocepacia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCenocepaciaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobiArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaBicolorataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agreia bicolorata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgreiaBicolorataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCedrina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cedrina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCedrina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelidibacterMesophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter mesophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GelidibacterMesophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaWallisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea wallisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaWallisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpL21syrabCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. L21SyrAB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpL21syrabCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PicrophilusTorridus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Picrophilus torridus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PicrophilusTorridus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMrmd2014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MRMD2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMrmd2014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaAlsatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella alsatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaAlsatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlternariaAlternataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alternaria alternata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlternariaAlternataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24535Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_45_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24535Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpBc26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. BC26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpBc26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionisporaSp2237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionispora sp. 2/2-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionisporaSp2237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaGlebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusEquuliSubspEquuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus equuli subsp. equuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusEquuliSubspEquuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrochothrixCampestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix campestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrochothrixCampestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpUnc305mfcol52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. UNC305MFCol52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpUnc305mfcol52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpR4368(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. R4368 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpR4368", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumOlb11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SebaldellaTermitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sebaldella termitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SebaldellaTermitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopelagicusSpRedseas31b2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus sp. REDSEAS31B2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusSpRedseas31b2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasTranslucensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas translucens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasTranslucensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaFuscipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina fuscipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaFuscipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusPahari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mus pahari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusPahari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeF0167Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae F0167 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeF0167Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpLc5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. LC5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLc5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArsenophonusTriatominarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus triatominarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusTriatominarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12747610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1274761.0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12747610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaSpPf2b19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. PF2B19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpPf2b19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpSg55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. SG55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpSg55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsplowo212full4010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO212FULL4010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo212full4010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquincolaTertiaricarbonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquincola tertiaricarbonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquincolaTertiaricarbonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFallaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium fallax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFallaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaLaidlawii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma laidlawii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaLaidlawii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavusDsm17758(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus concavus DSM 17758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusConcavusDsm17758", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCip562Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIP56.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCip562Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMutansGs5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans GS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansGs5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterAlpinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter alpinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterAlpinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaPelagicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolamina pelagica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolaminaPelagicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumWg36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium WG36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumWg36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusScotoductusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus scotoductus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusScotoductusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLitopenaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella litopenaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLitopenaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr7277(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR7277 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr7277", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr78Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-78 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr78Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaMaltosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida maltosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaMaltosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellalesBacteriumRifcsphigho212full3714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionellales bacterium RIFCSPHIGHO212FULL3714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellalesBacteriumRifcsphigho212full3714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScardoviaInopinataJcm12537Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata JCM 12537 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ScardoviaInopinataJcm12537Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EvansiaMuelleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Evansia muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EvansiaMuelleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDextrinicusDsm20335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus DSM 20335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDextrinicusDsm20335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumRbg13429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RBG_13_42_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRbg13429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaIvanoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria ivanovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaIvanoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterMetallireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter metallireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterMetallireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaSp2812bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 2812B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp2812bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraYegresiiCbs114405(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii CBS 114405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraYegresiiCbs114405", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterQingfengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter qingfengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterQingfengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumIriomotenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium iriomotense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumIriomotenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaodelphaxStriatellusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laodelphax striatellus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaodelphaxStriatellusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisCinereaOkayama7130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea okayama7#130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoprinopsisCinereaOkayama7130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaPtyseosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tatumella ptyseos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TatumellaPtyseosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpCetp13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. CETP13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpCetp13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaedimonasVaricaedensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caedimonas varicaedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaedimonasVaricaedensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAld1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALD1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAld1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwb26322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumGw2011gwc2489(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC2489 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc2489", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprothermobacterPlatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter platensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterPlatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElsinoeAustralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elsinoe australis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElsinoeAustralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMontpellierensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSpObrc55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. OBRC5-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpObrc55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_01_FULL_52_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo201Full5215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpCc9902Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9902 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9902Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaPickettii12jCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12jCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpMg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Mg1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCcgela001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCGELA001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCcgela001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonesiaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jonesia denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JonesiaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full4630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL4630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full4630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeliponaQuadrifasciata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melipona quadrifasciata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeliponaQuadrifasciata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4534bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4534b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4534bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eremococcus coleocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EremococcusColeocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus alvei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAlveiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusNigrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus nigrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusNigrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacacaFascicularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macaca fascicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacacaFascicularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusOshimaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus oshimai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusOshimaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumRifcsphigho202full4012b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO202FULL4012b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho202full4012b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraHyodysenteriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hyodysenteriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHyodysenteriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiumMinutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusPentosaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus pentosaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusPentosaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumLitorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLitorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpKgw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus sp. KGW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSpKgw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa1418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA1418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa1418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRobertsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium robertsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRobertsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsConfragosaRcef1005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps confragosa RCEF 1005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CordycepsConfragosaRcef1005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticaulisKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ponticaulis koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PonticaulisKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopococcusTabaciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopococcus tabaci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopococcusTabaciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraAlvinipulli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMoraviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas moraviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMoraviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliagarivoransMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliagarivoransMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColeofasciculusChthonoplastes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coleofasciculus chthonoplastes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColeofasciculusChthonoplastes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacillusGlycogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacillus glycogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacillusGlycogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterWinghamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter winghamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterWinghamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBombycisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus bombycis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusBombycisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg10247685Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_47_685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg10247685Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HadesarchaeaArchaeonYnp45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon YNP_45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeonYnp45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpIs2118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. IS2118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpIs2118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumCaspactino5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaElongataAg77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mortierella elongata AG-77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MortierellaElongataAg77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_39_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterMedellinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter medellinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterMedellinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaTropicalisMya3404Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis MYA-3404 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaTropicalisMya3404Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiCeThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CE Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCeThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTa06Bacterium32111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium 32_111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06Bacterium32111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfaeVams102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae VaMs.102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VerticilliumAlfalfaeVams102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusIniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus iniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisF0423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris F0423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisF0423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitromicrobiumSpJl477(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JL477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJl477", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumNor53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium NOR53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumNor53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosynechococcusSphagnicolaSy1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola sy1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicolaSy1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonJdfr11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon JdFR11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonJdfr11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPlantarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus plantarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPlantarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaromycesIngoldiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acaromyces ingoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcaromycesIngoldiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpT3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. T3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpT3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpNbrc102024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. NBRC 102024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpNbrc102024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwa24315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWA24315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwa24315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalisaetaLongaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salisaeta longa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalisaetaLongaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpScn6821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SCN 68-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpScn6821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdinarchaeotaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Odinarchaeota archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OdinarchaeotaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumCg23050142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium CG2_30_50_142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCg23050142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixNiveaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix nivea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiothrixNiveaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYokosukanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yokosukanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYokosukanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobacteroidesCellulosolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteroides cellulosolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobacteroidesCellulosolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumMizutaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium mizutaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumMizutaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaFradiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria fradiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaFradiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalalkalibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halalkalibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalalkalibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapilioMachaonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Papilio machaon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PapilioMachaonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBrevisX23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis X23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisX23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidilobusSaccharovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidilobus saccharovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidilobusSaccharovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg164923(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_49_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164923", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActibacteriumAtlanticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium atlanticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumAtlanticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalusDomesticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malus domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalusDomesticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp2714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 27_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCapraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCapraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHtcc2150Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HTCC2150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHtcc2150Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKimchicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichantheliumOligosanthesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dichanthelium oligosanthes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DichantheliumOligosanthesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpUnc378mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. UNC378MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpUnc378mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb1140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB1140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb1140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctobacteriumSpCag207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFragiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fragi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFragiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacibacteriumNormanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacterium normanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacibacteriumNormanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil736Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil736 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil736Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpYr375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. yr375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpYr375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusClarusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus clarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizophagusClarusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPertussisTohamaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis Tohama Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussisTohamaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSimiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium simiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSimiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasViridiflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas viridiflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasViridiflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus viridans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusViridans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumHydrothermale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterMillerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter millerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterMillerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMohniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mohnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMohniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AncylobacterRudongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ancylobacter rudongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AncylobacterRudongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyceliophthoraThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Myceliophthora thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MyceliophthoraThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudozymaBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpKh32c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. KH32C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpKh32c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSpDsm45219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. DSM 45219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpDsm45219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpLpb0137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LPB0137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLpb0137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaceaeBacteriumKa00182Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium KA00182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumKa00182Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DinothrombiumTinctorium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dinothrombium tinctorium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DinothrombiumTinctorium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrogenedentesBacteriumCg1024214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrogenedentes bacterium CG1_02_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrogenedentesBacteriumCg1024214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumCentrolobiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium centrolobii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCentrolobiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPrunellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asaia prunellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsaiaPrunellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFryxellicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fryxellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFryxellicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium284Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 284 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium284Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumVirideCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium viride Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumVirideCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicropelagosThuwalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micropelagos thuwalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicropelagosThuwalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusAlimentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusAlimentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusRiograndensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus riograndensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRiograndensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RisungbinellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Risungbinella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RisungbinellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpRoot630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis2159bfaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 2159BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis2159bfaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PogonaVitticepsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pogona vitticeps Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PogonaVitticepsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CamelusDromedariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Camelus dromedarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CamelusDromedariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCamelliaeDsm22697Jcm13995(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae DSM 22697 JCM 13995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCamelliaeDsm22697Jcm13995", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccationiduransArizonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Siccationidurans arizonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SiccationiduransArizonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxRadicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax radicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxRadicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho202full4420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO202FULL4420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho202full4420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IctalurusPunctatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ictalurus punctatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IctalurusPunctatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PvcGroupBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return PVC group bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PvcGroupBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpCag514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EquusAsinusAsinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Equus asinus asinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EquusAsinusAsinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicellaTundricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicella tundricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicellaTundricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasElongata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasElongata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusMicrotiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus microti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMicrotiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg166485Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_64_85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166485Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SenegalimassiliaAnaerobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Senegalimassilia anaerobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SenegalimassiliaAnaerobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumBdw918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium BDW918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumBdw918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpYr216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCaspalpha2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusPentosaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus pentosaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusPentosaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaPalythoaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella palythoae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaPalythoaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexZetekiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex zeteki Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexZetekiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full5124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL5124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full5124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioides7600Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides 7600 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumVerticillioides7600Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosarchaeumLimniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum limnium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumLimniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_33_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterLutiphocaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter lutiphocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterLutiphocaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr78Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr78Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg2305367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_53_67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg2305367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4620 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp1andimar09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 1ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp1andimar09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumPlataniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium platani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPlataniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobacillusComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobacillus composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobacillusComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaTrachomatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumNoncentrifugens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium noncentrifugens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumNoncentrifugens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpKpr6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. kpr-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpKpr6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpVm5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. Vm5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VirgibacillusSpVm5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorciDsm25326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moraxella porci DSM 25326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoraxellaPorciDsm25326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccoglossusKowalevskiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccoglossus kowalevskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccoglossusKowalevskiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaceaeBacteriumIbvucb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisCinereaT4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea T4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaT4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumSg841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanomethylicusOleusabulumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus oleusabulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusOleusabulumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChamaesiphonMinutusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chamaesiphon minutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChamaesiphonMinutusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AedesAlbopictusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aedes albopictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AedesAlbopictusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumKoreenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaPacificaDsm45543Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella washoeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaWashoeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CutibacteriumAcnesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium acnes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAcnesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PunicaGranatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Punica granatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PunicaGranatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollimonasPratensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasPratensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAggregataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia aggregata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAggregataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpBp7605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. Bp7605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpBp7605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusSpBica19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BICA1-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBica19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpR2019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. R2019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpR2019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwa24212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegamonasRupellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Megamonas rupellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MegamonasRupellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterMinnesotensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter minnesotensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterMinnesotensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodiscusSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelodiscus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelodiscusSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaCoronariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marssonina coronariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarssoninaCoronariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumProfundum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium profundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumProfundum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full3410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL3410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full3410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAlbicansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida albicans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaAlbicansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg135114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_13_51_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg135114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriaceaeBacteriumAk24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacteriaceae bacterium AK24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyclobacteriaceaeBacteriumAk24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterGlycinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter glycinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterGlycinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelopsittacusUndulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melopsittacus undulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelopsittacusUndulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpPml113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PML113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPml113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpBa94Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa94Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterPasteuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter pasteurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPasteuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyd2Full3512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYD2_FULL_35_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyd2Full3512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGlobisporusC1027Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces globisporus C-1027 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGlobisporusC1027Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusAcidilacticiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusAcidilacticiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwb16080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_60_80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb16080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoduganellaViolaceinigra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaParisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nematocida parisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NematocidaParisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumNovyiNtEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi NT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiNtEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpMarseilleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. Marseille Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpMarseilleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumKb13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium KB13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumKb13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_38_12b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpJa33abCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. JA33Ab Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpJa33abCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriellaXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriella xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriellaXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaTriticiSt99ch3d7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici ST99CH_3D7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiSt99ch3d7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumSg824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium SG8_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumSg824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpPamc21119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PAMC21119 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPamc21119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot482(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root482 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot482", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBacteroidesPeriocalifornicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus [Bacteroides] periocalifornicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBacteroidesPeriocalifornicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PisolithusMicrocarpus441(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus 441 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PisolithusMicrocarpus441", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlyciniphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glyciniphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlyciniphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaitoellaComplicata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saitoella complicata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaitoellaComplicata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusVersutusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus versutus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusVersutusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisNigrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis nigrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisNigrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpPf2b19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. PF2B19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpPf2b19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3820 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpMb2005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MB2005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMb2005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFrigoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporobacterMobilisDsm15930(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis DSM 15930 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilisDsm15930", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesMarseilloanorexicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes marseilloanorexicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesMarseilloanorexicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndolissoclinumFaulkneriL2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisNcppb382Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis NCPPB382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisNcppb382Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberMagnatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tuber magnatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuberMagnatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusDoucetiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus doucetiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusDoucetiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13140cm6927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13140CM6927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13140cm6927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidophilusNcfm(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus NCFM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilusNcfm", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAquimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aquimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAquimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus anthracis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAnthracisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpVcb2006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCB2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcb2006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynchytriumMicrobalum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium microbalum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynchytriumMicrobalum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpChd6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. CHD6a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpChd6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesStercorirosorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercorirosoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesStercorirosorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumSb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium SB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumSb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YamadazymaTenuisAtcc10573Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis ATCC 10573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YamadazymaTenuisAtcc10573Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NectriaHaematococca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nectria haematococca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NectriaHaematococca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPhoceensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium phoceensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPhoceensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaclostridiumBifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraclostridium bifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaclostridiumBifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterMelonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter melonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterMelonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacteriumGwa27335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_73_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterGangjinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter gangjinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterGangjinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpBolea5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. BoleA5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpBolea5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusHippeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusHippeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusObesiensisPh10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis ph10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusObesiensisPh10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaCellobiosiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumM181Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium M181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumM181Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brennerbacteria bacterium RIFOXYD1_FULL_41_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrennerbacteriaBacteriumRifoxyd1Full4116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaCrassa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neurospora crassa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeurosporaCrassa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenibacterAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFf3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumTf0111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TF01-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTf0111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusLitoralisDsm5473(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus litoralis DSM 5473 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermococcusLitoralisDsm5473", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaFerrariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ferrariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaFerrariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipaludibacillusAgaradhaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus agaradhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAgaradhaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OgataeaParapolymorphaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OgataeaParapolymorphaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArsenophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaSpEg49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora sp. EG49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaSpEg49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GM2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpSynace01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. SynAce01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpSynace01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgreiaPratensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agreia pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgreiaPratensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasJatrophaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jatrophae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJatrophaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KazachstaniaNaganishiiCbs8797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii CBS 8797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaNaganishiiCbs8797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_44_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAquilaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aquilae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAquilaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopelagicusBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaBicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laccaria bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaccariaBicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKazanBacteriumRbg13509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RBG_13_50_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRbg13509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDenticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella denticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDenticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa2407b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA2_40_7b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa2407b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSticklandiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sticklandii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSticklandiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas testosteroni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasTestosteroniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMeyeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira meyeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMeyeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkanindigesIllinoisensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges illinoisensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesIllinoisensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpDg881Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. DG881 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpDg881Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhaeomarinobacterEctocarpiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phaeomarinobacter ectocarpi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhaeomarinobacterEctocarpiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumCeleriflavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium celeriflavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCeleriflavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesPutredinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes putredinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesPutredinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterSpT28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. T28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpT28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisCinereaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisCinereaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumCuenotiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium cuenoti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumCuenotiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasDiminuta4704Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta 4704 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasDiminuta4704Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilodermaCroceumF1598Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Piloderma croceum F 1598 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PilodermaCroceumF1598Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifoxyb2full4511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB2FULL4511 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb2full4511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasHofstadiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasHofstadiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKisonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKisonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMagna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella magna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMagna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumU91i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium U9-1i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumU91i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreochromisAureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis aureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OreochromisAureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaMarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella marensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaMarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrocadiaSinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsphigho202full3917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL3917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full3917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumMaritimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum maritimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMaritimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwf1327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWF1_32_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwf1327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaCruziEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaCruziEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumOlb7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmoricolaScoriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola scoriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaScoriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRifamyciniDsm43936Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini DSM 43936 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRifamyciniDsm43936Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiLrivu41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi lrivu41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiLrivu41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumImmobileAtcc35973(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile (ATCC 35973) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobileAtcc35973", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusParasiticusSu1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus SU-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusParasiticusSu1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchwartziaSuccinivoransDsm10502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans DSM 10502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchwartziaSuccinivoransDsm10502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr477Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr477Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMethanolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis methanolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMethanolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioOstreicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ostreicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioOstreicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces alni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12Mg1655(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 MG1655 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12Mg1655", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumFlavidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium flavidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumFlavidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMmlr14006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumSpYo3aop1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium sp. YO3AOP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSpYo3aop1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpRoot1471Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root1471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot1471Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatulibacterAmericanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PatulibacterAmericanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcalesBacterium6820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium 68-20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacterium6820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrientalis21f2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orientalis 21F-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterOrientalis21f2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWb2n11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Wb2n-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWb2n11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumPyruvativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium pyruvativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPyruvativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumCg1025453Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG1_02_54_53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg1025453Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusDepauperatusCbs7841Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus CBS 7841 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptococcusDepauperatusCbs7841Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAbyssalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAbyssalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphacelomaMurrayae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaceloma murrayae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphacelomaMurrayae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAmblyommatisStrGat30vCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis str. GAT-30V Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatisStrGat30vCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVarsoviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces varsoviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVarsoviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomicrobiumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobium mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAlbaNbrc108234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia alba NBRC 108234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAlbaNbrc108234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGastricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGastricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAsteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia asteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAsteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RunellaZeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Runella zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RunellaZeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobiumSpPcc7001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. PCC7001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpPcc7001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuriculariaDelicataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Auricularia delicata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AuriculariaDelicataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusSuccinogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus succinogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusSuccinogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumAgreste(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum agreste graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumAgreste", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusVannielii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus vannielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVannielii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterArboriphilusAnor1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus ANOR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilusAnor1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesEuropaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces europaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesEuropaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocladiumSpEchbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocladium sp. ECHB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocladiumSpEchbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRectale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium rectale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRectale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPthiripubisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riesia pthiripubis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiesiaPthiripubisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMucosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMucosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberMagnatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tuber magnatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuberMagnatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraCactorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora cactorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraCactorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpD20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. D20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpD20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpSm22m07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. SM22M-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpSm22m07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasJatrophae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas jatrophae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasJatrophae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc2459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC2_45_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc2459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCaseinilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus caseinilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCaseinilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaSpT8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumHum9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfovibrioSalsuginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio salsuginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioSalsuginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full4711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NegativicoccusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Negativicoccus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NegativicoccusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSuwonensis111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis 111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensis111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JidaibacterAcanthamoebaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jidaibacter acanthamoeba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JidaibacterAcanthamoebaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsphigho202Full4711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPHIGHO2_02_FULL_47_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsphigho202Full4711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyorhinisSk76Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis SK76 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisSk76Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscochytaRabieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ascochyta rabiei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AscochytaRabieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumViciae3841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae 3841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciae3841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaHulunbeirensisJcm10989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis JCM 10989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensisJcm10989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpK24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. K24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpK24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCurieaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curieae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurieaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenatarsenatisSf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis SF-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatisSf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa536n21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA536N21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa536n21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusGp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus GP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusGp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicellaMetallireducensAebEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens AeB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FervidicellaMetallireducensAebEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveraAscorbata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera ascorbata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KluyveraAscorbata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacteriumScn7022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium SCN 70-22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumScn7022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonariusCbs121057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius CBS 121057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonariusCbs121057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumPapyrosolvensDsm2782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens DSM 2782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensDsm2782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumMacuxienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium macuxiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMacuxienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspNatto(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. natto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspNatto", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RappaportIsraeli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rappaport israeli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RappaportIsraeli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMellisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMellisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgb11wgaepuloa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGB11WGAEpuloA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgb11wgaepuloa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphilophusCitrinellus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphilophus citrinellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphilophusCitrinellus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full5223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL5223 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full5223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpCf468Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF468 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf468Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarssoninaBrunneaFSpMultigermtubiMbM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marssonina brunnea f. sp. multigermtubi MB_m1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarssoninaBrunneaFSpMultigermtubiMbM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasSpScn6556Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas sp. SCN 65-56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasSpScn6556Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAkibaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus akibai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAkibaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAlkalitelluris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alkalitelluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAlkalitelluris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisLikeEndosymbiontOfProechinophthirusFluctus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sodalis-like endosymbiont of Proechinophthirus fluctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SodalisLikeEndosymbiontOfProechinophthirusFluctus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpCubenseRace4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterMediterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter mediterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMediterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParahaemolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus parahaemolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParahaemolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CulturomicaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Culturomica massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CulturomicaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratireductorPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJuripiscariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJuripiscariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlumeriaGraminisFSpHordeiDh14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis f. sp. hordei DH14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlumeriaGraminisFSpHordeiDh14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaHackeliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella hackeliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaHackeliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasidiobolusMeristosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerfeziaBoudieriAtccMya4762Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Terfezia boudieri ATCC MYA-4762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TerfeziaBoudieriAtccMya4762Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzobacteroidesPseudotrichonymphaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azobacteroides pseudotrichonymphae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzobacteroidesPseudotrichonymphaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaMarinoflavaDsm3653Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava DSM 3653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaDsm3653Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph2100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH2100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph2100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3713 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg19ftcombo6917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO6917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo6917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioStylochiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio stylochi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioStylochiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag382(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag382", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpKordi100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumRifcsplowo202full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPLOWO202FULL4216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsplowo202full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FloricoccusTropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Floricoccus tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FloricoccusTropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus anthracis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAnthracis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaHydrogenitoleransDsm16785(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans DSM 16785 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitoleransDsm16785", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumL21thd2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium L21THD2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumL21thd2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaRufipogonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza rufipogon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaRufipogonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerosceptrumFracticalcis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerosceptrum fracticalcis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerosceptrumFracticalcis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyc1full3779(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYC1FULL3779 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyc1full3779", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpF0131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcococcusKunzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus kunzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelcococcusKunzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_41_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasGuineae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guineae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuineae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSpDiamantEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Diamant Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpDiamantEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumSg847(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg847", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia marcescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaMarcescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaColombica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atta colombica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AttaColombica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpN54mgs139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. N54MGS139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpN54mgs139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaMaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaMaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGlobisporusC1027(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces globisporus C-1027 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGlobisporusC1027", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaNitratireducenticrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga nitratireducenticrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaNitratireducenticrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterNyackensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter nyackensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterNyackensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisSubspCapsiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. capsici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspCapsiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaestuariivitaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudaestuariivita atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudaestuariivitaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusPhoeniculicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus phoeniculicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPhoeniculicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSp5c6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. 5C6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSp5c6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpCag241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. CAG:241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpCag241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterDelicatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter delicatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurvibacterDelicatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusHitonicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus hitonicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHitonicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BizioniaArgentinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bizionia argentinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BizioniaArgentinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusEnclensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus enclensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEnclensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk268(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk268", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GhiorseaBivoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ghiorsea bivora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GhiorseaBivoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 CBMW_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasArtemidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas artemidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasArtemidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAnanatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea ananatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnanatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCohniiNbrc15565Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cohnii NBRC 15565 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCohniiNbrc15565Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpH050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaSpW5c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. W5C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpW5c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FukatsuiaSymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fukatsuia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FukatsuiaSymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumMassiliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum massiliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumMassiliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpCf299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterParvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterParvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraSantarosaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira santarosai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSantarosaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpHmsc072f04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC072F04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc072f04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasOssibalaenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ossibalaenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromonasOssibalaenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumHolothuriorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum holothuriorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumHolothuriorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumPoaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumPoaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusIngluvieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ingluviei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusIngluvieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSp174(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. 174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSp174", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumRobustum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium robustum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumRobustum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSubantarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFonticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia fonticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaFonticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TanticharoeniaSakaeratensisNbrc103193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis NBRC 103193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensisNbrc103193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpMg133(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MG133 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg133", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnicellularCyanobacteriumSu2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium SU2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UnicellularCyanobacteriumSu2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yoonia rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YooniaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumChlorochromatiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium chlorochromatii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumChlorochromatiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRubrolavendulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rubrolavendulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRubrolavendulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaBryophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bryophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBryophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinocladiellaMackenzieiCbs65093(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei CBS 650.93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhinocladiellaMackenzieiCbs65093", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHenryiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus henryi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHenryiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumCambrienseDora20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DORA20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDora20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobiumRoseumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermomicrobium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermomicrobiumRoseumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumGelidilacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OperophteraBrumataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Operophtera brumata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OperophteraBrumataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterSpYe315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. YE315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpYe315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitriliruptorAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacacaFascicularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macaca fascicularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacacaFascicularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumEquinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium equinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumEquinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatirosaKalamazoonesis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatirosa kalamazoonesis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatirosaKalamazoonesis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpKrocy2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. KROCY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpKrocy2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterLanceolatusAtcc14669Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus ATCC 14669 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CurvibacterLanceolatusAtcc14669Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsphigho212full3830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO212FULL3830 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho212full3830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPolytrichastriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter polytrichastri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPolytrichastriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumGwa24615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium GWA2_46_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumGwa24615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtelocyanobacteriumThalassaAlohaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa ALOHA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaAlohaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapraHircusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capra hircus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapraHircusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxRadicisN35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax radicis N35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxRadicisN35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSodomense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sodomense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSodomense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSputi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sputi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GordoniaSputi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaRhizoxinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia rhizoxinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaRhizoxinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full3826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwf1327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWF1_32_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwf1327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaWadsworthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWadsworthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonBenhamiaeCbs112371Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae CBS 112371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichophytonBenhamiaeCbs112371Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSaburreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LechevalieriaAerocolonigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria aerocolonigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LechevalieriaAerocolonigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaprevotellaXylaniphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella xylaniphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaXylaniphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalisGambiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina palpalis gambiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlossinaPalpalisGambiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenophonusEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arsenophonus endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArsenophonusEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerofustisStercorihominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerofustis stercorihominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerofustisStercorihominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasFlavigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas flavigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasFlavigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusZilligii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus zilligii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusZilligii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaGariniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella garinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaGariniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StoquefichusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StoquefichusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOrisasiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisasini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisasiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PortnoybacteriaBacteriumRifcsplowo201full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPLOWO201FULL4311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsplowo201full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BubalusBubalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bubalus bubalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BubalusBubalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OdinarchaeotaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Odinarchaeota archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OdinarchaeotaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeoasaiaChiangmaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neoasaia chiangmaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeoasaiaChiangmaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrischellaPerraraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frischella perrara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrischellaPerraraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelcococcusSueciensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus sueciensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelcococcusSueciensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VolvoxCarteriFNagariensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Volvox carteri f. nagariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VolvoxCarteriFNagariensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaoerskoviaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraoerskovia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaoerskoviaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho202full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL3613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalpingoecaRosettaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salpingoeca rosetta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalpingoecaRosettaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiSh145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii SH145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiSh145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAa0539(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA0539 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa0539", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaBooneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula boonei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaBooneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasExtremaustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas extremaustralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasExtremaustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumVirgatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Panicum virgatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PanicumVirgatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephalotusFollicularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cephalotus follicularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CephalotusFollicularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumHuakuii7653r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii 7653R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuii7653r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansDsm642Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans DSM642 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansDsm642Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKitasatonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kitasatonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKitasatonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraMethylohalidivoransDsm14336Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans DSM 14336 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivoransDsm14336Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusFulvus124b02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus 124B02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvus124b02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpYik11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. YIK11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpYik11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag793Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag793Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaeniaAsiaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taenia asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaeniaAsiaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp6910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 69-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSpNsp11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsasporaOwczarzakiAtcc30864Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki ATCC 30864 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CapsasporaOwczarzakiAtcc30864Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeratocystisFimbriataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeratocystisFimbriataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3734Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3734 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3734Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpFa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. FA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpFa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45543Cns863Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 CNS-863 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543Cns863Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SingulisphaeraSpGp187Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera sp. GP187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraSpGp187Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNamurensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNamurensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasProtegensCha0Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens CHA0 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensCha0Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IshikawaellaCapsulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ishikawaella capsulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IshikawaellaCapsulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumCg1023251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1023251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1023251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaBalticaOs145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina baltica OS145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaBalticaOs145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterNitrofigilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter nitrofigilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterNitrofigilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4186(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4186 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4186", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonascusPurpureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monascus purpureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonascusPurpureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpNml980116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML98-0116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml980116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaApicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella apicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilliamellaApicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRaac3Tm71(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RAAC3_TM7_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRaac3Tm71", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_38_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAcidisoliDsm12555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidisoli DSM 12555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcidisoliDsm12555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpBsw11ivEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BSW11IV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBsw11ivEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFurnissiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio furnissii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioFurnissiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumOtitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium otitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOtitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlsr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALSr1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlsr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrypanosomaBruceiBruceiTreu927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma brucei brucei TREU927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaBruceiBruceiTreu927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimonasVoraiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimonas voraii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimonasVoraiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMiricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia miricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ElizabethkingiaMiricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCapraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caprae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCapraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilimonasLacunae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Filimonas lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FilimonasLacunae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPosidonicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas posidonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPosidonicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatoriaNigroviridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria nigroviridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaNigroviridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusBidgolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus bidgolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusBidgolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculusVarScolymus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cynara cardunculus var. scolymus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CynaraCardunculusVarScolymus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GulbenkianiaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gulbenkiania indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GulbenkianiaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusSuccinogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusSuccinogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSoldanellicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soldanellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoldanellicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RomboutsiaLituseburensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumChocolatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium chocolatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumChocolatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenbacteriaBacteriumRbg167146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eisenbacteria bacterium RBG167146 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EisenbacteriaBacteriumRbg167146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb24422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaDaqingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga daqingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaDaqingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2303638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPrydzensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas prydzensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPrydzensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumLepraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium leprae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLepraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp11mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 11MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp11mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaAtlantaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella atlantae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaAtlantaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifoxyc2full3812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFOXYC2FULL3812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifoxyc2full3812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCholeraeO395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpSeq25vEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. Seq25V Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpSeq25vEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaCopri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella copri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCopri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumOl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium OL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumOl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonSg8523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SG8-52-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSg8523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuthiaMagnificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruthia magnifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuthiaMagnificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaTriticiSt99ch3d7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici ST99CH_3D7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiSt99ch3d7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSenmaizukeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senmaizukei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSenmaizukeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPseudospumae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pseudospumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPseudospumae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPentosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pentosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPentosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinusNbrc15237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus NBRC 15237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusNbrc15237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterWiegelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter wiegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterWiegelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_43_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterLappiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter lappiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterLappiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaStr5aAcyrthosiphonPisum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola str. 5A (Acyrthosiphon pisum) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaStr5aAcyrthosiphonPisum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumSpZwu0011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. ZWU0011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpZwu0011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasMacrotermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas macrotermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMacrotermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusTelluris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus telluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusTelluris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethylopumilusPlanktonicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus planktonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusPlanktonicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa254124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_54_124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa254124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusStrNatl2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. NATL2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrNatl2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalispirochaetaAlkalicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus elongatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusElongatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusIhuaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihuae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhuaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifoxyd1full5236Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYD1FULL5236 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyd1full5236Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeliocybeSulcataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heliocybe sulcata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeliocybeSulcataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCny243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNY243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCny243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSpOcn003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. OCN003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpOcn003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolineaTarda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolinea tarda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolineaTarda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSp6729Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 67-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSp6729Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlterileibacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alterileibacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlterileibacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho212full4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL4616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiodiazotrophaEndoloripes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endoloripes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndoloripes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloglobulusMorosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloglobulus morosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloglobulusMorosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kangiella koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KangiellaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecropsobacterRosorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter rosorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterRosorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RummeliibacillusStabekisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rummeliibacillus stabekisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RummeliibacillusStabekisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_47_48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4748", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusStrModasa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Micrococcus luteus str. modasa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrococcusLuteusStrModasa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo202full6764Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL6764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full6764Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu065Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU065 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu065Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMcba15001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyberlindneraJadiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraJadiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobiospirillumSucciniciproducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobiospirillum succiniciproducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobiospirillumSucciniciproducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRobertsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium robertsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumRobertsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc7375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylophilusDsm20533Jcm1125(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus DSM 20533 JCM 1125 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAmylophilusDsm20533Jcm1125", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumSpCag7458120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:74_58_120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag7458120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPeraridilitoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus peraridilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPeraridilitoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag590Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:590 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag590Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSymbiosumWal14163Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium symbiosum WAL14163 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumWal14163Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrondihabitansSpPamc28766Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. PAMC 28766 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpPamc28766Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpNci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Nci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpNci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeHs11286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae HS11286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeHs11286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaTaiwanensisDsm12281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis DSM 12281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensisDsm12281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSputiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sputi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSputiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudacidovoraxSpRu35eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudacidovorax sp. RU35E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudacidovoraxSpRu35eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251961sch5331710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251961SCH5331710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251961sch5331710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusXenolissoclinumPacificiensisL6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xenolissoclinum pacificiensis L6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusXenolissoclinumPacificiensisL6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfPedicinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgarivoransGilvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agarivorans gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgarivoransGilvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpFcs014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MizuhopectenYessoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mizuhopecten yessoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MizuhopectenYessoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMalodoratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus malodoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMalodoratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolanumTuberosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solanum tuberosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolanumTuberosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaConceptionensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaConceptionensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusTerrigenaDsm22685Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Algoriphagus terrigena DSM 22685 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlgoriphagusTerrigenaDsm22685Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifcsphigho202full5217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPHIGHO202FULL5217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsphigho202full5217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteribacillusIranensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus iranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusIranensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwc25713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc25713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChthoniobacterFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chthoniobacter flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChthoniobacterFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermabacterSpHfh0086Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter sp. HFH0086 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DermabacterSpHfh0086Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo2124711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_47_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo2124711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumAap38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium AAP38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumAap38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaOtitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaOtitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaromycesIngoldiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acaromyces ingoldii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcaromycesIngoldiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusQingdaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus qingdaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusQingdaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobellusClavatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobellus clavatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobellusClavatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosotenuisUzonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis uzonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisUzonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOkinawensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter okinawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOkinawensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaSpHeli48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. HelI48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpHeli48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonauticusSpA7a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. A7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSpA7a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHyointestinalisSubspHyointestinalisLmg9260Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis subsp. hyointestinalis LMG 9260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalisSubspHyointestinalisLmg9260Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeoglobusAcetivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus acetivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAcetivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DromaiusNovaehollandiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dromaius novaehollandiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DromaiusNovaehollandiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypholomaSublateritiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HypholomaSublateritiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntestinibacterBartlettiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intestinibacter bartlettii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntestinibacterBartlettiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHistidinilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas histidinilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHistidinilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpChdc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ChDC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusSpChdc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusMarisnigri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus marisnigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusMarisnigri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusAmylolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusAmylolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaAlcalifaciensR901475(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens R90-1475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensR901475", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumMola814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium MOLA814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumMola814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisiiAtcc43063(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC43063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc43063", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusAeolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus aeolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusAeolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpBmg512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBmg512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpR37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpR37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantisAtcc700779(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis ATCC700779 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisAtcc700779", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaLimnaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gillisia limnaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GillisiaLimnaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumPsychrophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium psychrophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPsychrophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho202full5216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL5216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full5216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_44_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp15544247Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1554424.7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp15544247Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFloricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus floricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFloricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteroidesHalobiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacteroides halobius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteroidesHalobiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CompleteString(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="physical.links.full.v12.0", **kwargs
) -> Graph:
    """Return CompleteString graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "physical.links.full.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- links.v11.0
			- links.detailed.v11.0
			- links.full.v11.0
			- physical.links.v11.0
			- physical.links.detailed.v11.0
			- physical.links.full.v11.0
			- enrichment.terms.v11.5
			- links.v11.5
			- links.detailed.v11.5
			- links.full.v11.5
			- physical.links.v11.5
			- physical.links.detailed.v11.5
			- physical.links.full.v11.5
			- enrichment.terms.v12.0
			- links.v12.0
			- links.detailed.v12.0
			- links.full.v12.0
			- physical.links.v12.0
			- physical.links.detailed.v12.0
			- physical.links.full.v12.0
    """
    return RetrievedGraph(
        "CompleteString", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumGw2011gwe23830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWE23830 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwe23830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcanobacteriumUrinimassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium urinimassiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumUrinimassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Martelella mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MartelellaMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpS4c9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S4C9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS4c9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumAlbumDsm18261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium album DSM 18261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumAlbumDsm18261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusChristenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus christensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusChristenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg2304652Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_46_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2304652Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf22910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_29_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf22910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioAespoeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio aespoeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioAespoeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solimonas soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolimonasSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag3212622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:321_26_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag3212622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNc2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsphigho201full3637Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL3637 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full3637Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaLucivoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaLucivoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumArsenaticumDsm13514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum DSM 13514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticumDsm13514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumBlastocrithidiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium blastocrithidii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumBlastocrithidiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaBalbisianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Musa balbisiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusaBalbisianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumLongisporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verticillium longisporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerticilliumLongisporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaE681(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa E681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaE681", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaPseudohaemulonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Candida] pseudohaemulonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaPseudohaemulonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StegodyphusMimosarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stegodyphus mimosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StegodyphusMimosarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsplowo201full4525b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO201FULL4525b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo201full4525b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioThiophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio thiophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioThiophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa2319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_31_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa2319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpCcgela001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCGELA001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCcgela001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusZhangzhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus zhangzhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusZhangzhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrateuriaSpSoil773(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frateuria sp. Soil773 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrateuriaSpSoil773", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella washoeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaWashoeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumGwa2509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GWA2509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGwa2509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpD16r12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16R12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16r12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxya2Full4315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA2_FULL_43_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya2Full4315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9302(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9302", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaXenovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia xenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaXenovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfobacillusAcidophilusDsm10332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus DSM 10332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilusDsm10332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumCg1023722Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium CG1_02_37_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumCg1023722Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavusDsm17758Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus concavus DSM 17758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusConcavusDsm17758Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira terpstrae serovar Hualin str. LT 11-33 ATCC 700639 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraTerpstraeSerovarHualinStrLt1133Atcc700639Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NevskiaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nevskia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NevskiaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesOctosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces octosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesOctosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpJha26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumCg2306027Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium CG2_30_60_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumCg2306027Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaLingualeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma linguale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLingualeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovermiculusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumMunicipaleDsm44069(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum municipale DSM 44069 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumMunicipaleDsm44069", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumCg1024331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG1024331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg1024331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPasteurianusAtcc43144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus ATCC 43144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPasteurianusAtcc43144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpAb134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Ab134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpAb134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KordiaAlgicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordia algicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiaAlgicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpHmica12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HmicA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHmica12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnchocercaVolvulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca volvulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OnchocercaVolvulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosphaerulaPalustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaerula palustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosphaerulaPalustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSp5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HungateiclostridiumClariflavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium clariflavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumClariflavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerovibrioAcidaminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio acidaminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioAcidaminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpP11g3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasJohnsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas johnsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJohnsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpMtm3w52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. MTM3W5.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpMtm3w52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcmicro4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParaphrohaemolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paraphrohaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParaphrohaemolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmotaMarmotaMarmotaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marmota marmota marmota Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarmotaMarmotaMarmotaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRbg13408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG13408 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg13408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaPhaffiiCbs4417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii CBS 4417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffiiCbs4417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumVa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium VA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumVa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcalesBacteriumSg838Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium SG8_38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacteriumSg838Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEbm40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium EBM-40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumEbm40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterSiccitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter siccitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSiccitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaFlavaJlt2011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gramella flava JLT2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GramellaFlavaJlt2011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriDsm10701(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri DSM10701 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriDsm10701", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HuchoHuchoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hucho hucho Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HuchoHuchoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumClariflavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clariflavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClariflavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaSpMctg156Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. MCTG156 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpMctg156Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa2407bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA2_40_7b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa2407bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatitaleaTepidiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea tepidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaTepidiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSuisStrIllinoisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma suis str. Illinois Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSuisStrIllinoisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaAmblyommatisStrGat30v(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis str. GAT-30V graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatisStrGat30v", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioAxinellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio axinellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAxinellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RamlibacterSpLeaf400(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter sp. Leaf400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RamlibacterSpLeaf400", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxSp22iis10s(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax sp. 22IIs10s graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RoseivivaxSp22iis10s", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParalimentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParalimentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordonibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordonibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAllii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus allii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAllii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24668Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_46_68 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24668Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraSpB5022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira sp. B5-022 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSpB5022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTaeniosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium taeniosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTaeniosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsplowo212full3822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO212FULL3822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo212full3822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGordoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGordoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesMerusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles merus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesMerusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDadantiiEch586Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech586 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch586Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeijerinckiaSp28yea48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia sp. 28YEA48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaSp28yea48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRbg133615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RBG133615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRbg133615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa024d14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA024D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa024d14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpTks(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TKS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTks", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPorcinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema porcinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPorcinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiellaLustricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coniella lustricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConiellaLustricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KtedonobacterRacemiferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter racemifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterRacemiferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumGwc23926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_39_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc23926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumYrb3002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium YRB3002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumYrb3002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdobenusRosmarus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Odobenus rosmarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OdobenusRosmarus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitisViniferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vitis vinifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VitisViniferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HadesarchaeaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrooxidansAtcc23270(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC23270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc23270", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LobosporangiumTransversaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lobosporangium transversale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LobosporangiumTransversaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluoribacterGormanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter gormanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FluoribacterGormanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrellaSpEs10322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrella sp. ES10-3-2-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrellaSpEs10322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaViswanathiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida viswanathii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaViswanathiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WickerhamomycesCiferriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesCiferriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpPamc26605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaHutchinsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga hutchinsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CytophagaHutchinsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSoudanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas soudanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSoudanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifoxya1Full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYA1_FULL_40_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxya1Full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesChartreusis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces chartreusis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesChartreusis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDaliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus daliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusDaliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriNctc12419Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori NCTC12419 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriNctc12419Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolaciniaPaynteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia paynteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPaynteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptobacillusRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full3928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL3928 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full3928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiphonobacterAquaeclaraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Siphonobacter aquaeclarae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SiphonobacterAquaeclaraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpKjj(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KJJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKjj", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSeoulenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium seoulense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSeoulenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosaetaHarundinaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosaetaHarundinaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLutaoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lutaoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLutaoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusTestudinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus testudinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusTestudinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpGxs13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXS13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxs13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumGraminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGraminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSmegmatisMc2155(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis MC2155 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisMc2155", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpAngr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpGpe39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. GPE 39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpGpe39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMmlr14006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaMaltophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema maltophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaMaltophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitrellaBrassicaformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vitrella brassicaformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VitrellaBrassicaformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasPolymorphaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas polymorpha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasPolymorphaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGleumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gleum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGleumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBlochmanniaVaferStrBvaf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blochmannia vafer str. BVAF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlochmanniaVaferStrBvaf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoodsholeaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woodsholea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoodsholeaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusMicroti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus microti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMicroti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRifcsplowo202full6214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPLOWO202FULL6214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsplowo202full6214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNanopusillusAcidilobiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nanopusillus acidilobi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNanopusillusAcidilobiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusFonticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus fonticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFonticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OgataeaParapolymorpha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ogataea parapolymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OgataeaParapolymorpha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpDh1fCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. DH1f Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpDh1fCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumJosuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium josui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumJosuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpUnc451mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC451MF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc451mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumPropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium propionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumPropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaCaviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaCaviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpB2m1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. B2M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpB2m1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KnoelliaSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpSpb78(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SPB78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSpb78", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensNrl30031h210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens NRL30031H210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensNrl30031h210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSputi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sputi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSputi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SarcophilusHarrisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sarcophilus harrisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SarcophilusHarrisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallaecimonasPentaromativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas pentaromativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasPentaromativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconobacterRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TursiopsTruncatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tursiops truncatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TursiopsTruncatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedTermiteGroup1BacteriumPhylotype(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotype", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesScabiei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces scabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesScabiei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerroglobusPlacidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferroglobus placidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerroglobusPlacidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecatorAmericanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Necator americanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NecatorAmericanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisPorri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botrytis porri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotrytisPorri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMaduraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura madurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMaduraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpOralTaxon920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpOv279Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV279 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv279Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNakamuraiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus nakamurai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusNakamuraiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaRestrictaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malassezia restricta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalasseziaRestrictaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRifcsphigho201full6516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPHIGHO201FULL6516 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsphigho201full6516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasBoliviensisLc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas boliviensis LC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasBoliviensisLc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpGm95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GM95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGm95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasPhaseoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasPhaseoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HanseniasporaOsmophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora osmophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaOsmophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumIslandicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum islandicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumIslandicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicidaNbrc103162Dsm15088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida NBRC 103162 DSM 15088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicidaNbrc103162Dsm15088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPseudoobscuraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscuraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_40_58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortieraAleyrodidarumBtBHrsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum BT-B-HRs Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumBtBHrsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumNitrativoransNl23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans NL23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativoransNl23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpsilonproteobacteriaBacteriumTcs49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epsilonproteobacteria bacterium tcs-49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpsilonproteobacteriaBacteriumTcs49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FulvimarinaPelagiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina pelagi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaPelagiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiellaLustricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coniella lustricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConiellaLustricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxobacterPfennigiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oxobacter pfennigii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OxobacterPfennigiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAkiainvivensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium akiainvivens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAkiainvivensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeiaOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leeia oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeeiaOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NannocystisExedensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nannocystis exedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NannocystisExedensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_40_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa24010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterMarburgensisStrMarburgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis str. Marburg Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensisStrMarburgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBalearicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas balearica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBalearicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusColeohominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coleohominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusColeohominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionispiraArborisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionispira arboris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionispiraArborisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaOculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma oculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaOculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DasypusNovemcinctusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dasypus novemcinctus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DasypusNovemcinctusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpW2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YaniellaHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yaniella halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YaniellaHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMesoamericanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium mesoamericanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMesoamericanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotorhabdusThracensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus thracensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusThracensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasJaponicaNbrc103040Dsm22348(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas japonica NBRC 103040 DSM 22348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasJaponicaNbrc103040Dsm22348", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPaciniiDsm19139Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio pacinii DSM 19139 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioPaciniiDsm19139Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFabifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fabifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFabifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaeanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taeanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaeanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumSpIppasb1200Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. IPPASB1200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpIppasb1200Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_40_58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumW5053Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium W5053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumW5053Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpY57(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Y57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpY57", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldithrixAbyssi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldithrixAbyssi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumGordonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gordonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGordonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolituusThermophilusDsm23256Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus DSM 23256 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporolituusThermophilusDsm23256Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTaiwanensisDsm21401(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis DSM 21401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensisDsm21401", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_12_FULL_44_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumSgbin7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusMetalliredigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus metalliredigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusMetalliredigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA2_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaSaulgeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania saulgeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaSaulgeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusGelatiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gelatini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusGelatiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaYeatsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaYeatsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterAerogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter aerogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAerogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJiangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jiangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaJiangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc8aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc8a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc8aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraButanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera butanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraButanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterWoliniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterWoliniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusFischeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus fischeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusFischeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedosphaeraParvulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedosphaeraParvulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeocapsaSpPcc7428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC7428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc7428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DothistromaSeptosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dothistroma septosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DothistromaSeptosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCoubleaeNbrc108252Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia coubleae NBRC 108252 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaCoubleaeNbrc108252Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaceaeBacterium15036681(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium 15-036681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacterium15036681", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrancourtellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drancourtella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrancourtellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisC5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfifellaPfennigii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afifella pfennigii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfifellaPfennigii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensFgi94Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens FGI94 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensFgi94Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSpWkb8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpWkb8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaimiriBoliviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saimiri boliviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaimiriBoliviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDielmoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dielmoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusDielmoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpM24t3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. M24T3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpM24t3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsphigho202full5118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL5118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full5118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBrevisAtcc367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brevis ATCC367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrevisAtcc367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPollutisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pollutisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPollutisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwf13135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWF13135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwf13135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaLaterculaDsm2041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina latercula DSM 2041 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLaterculaDsm2041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WesteberhardiaCardiocondylaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Westeberhardia cardiocondylae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WesteberhardiaCardiocondylaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtheneCuniculariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Athene cunicularia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtheneCuniculariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOrisrattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisrattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaFryxellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loktanella fryxellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoktanellaFryxellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_37_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full3713b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaedaleaQuercinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daedalea quercina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaedaleaQuercinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaOligospermaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala oligosperma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaOligospermaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaPlymuthicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia plymuthica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaPlymuthicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterTundripaludum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter tundripaludum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacterTundripaludum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat28004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpT9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_59_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllofustisSeminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allofustis seminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllofustisSeminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLarrymoorei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium larrymoorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLarrymoorei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumMelA1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium MEL.A1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumMelA1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEndophyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas endophytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEndophyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeganemaPerideroedesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Meganema perideroedes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MeganemaPerideroedesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaParvumStrIndianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma parvum str. Indiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaParvumStrIndianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaGonorrhoeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthobacterSp126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter sp. 126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthobacterSp126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag192Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:192 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag192Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSanxanigenens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanxanigenens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanxanigenens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KamptonemaFormosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kamptonema formosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KamptonemaFormosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpMt2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MT2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpMt2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTachikawaeaGelatinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tachikawaea gelatinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTachikawaeaGelatinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFrigidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio frigidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFrigidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRadiopugnansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces radiopugnans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRadiopugnansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpAnt17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Ant17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAnt17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonasPhototrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas phototrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasPhototrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasJatrophae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jatrophae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJatrophae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomycesKudriavzeviiIfo1802Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii IFO 1802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzeviiIfo1802Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpLf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. LF1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpLf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesPhilippinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes philippinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesPhilippinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumSpZor0034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium sp. ZOR0034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSpZor0034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PannonibacterPhragmitetusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pannonibacter phragmitetus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PannonibacterPhragmitetusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SneathiaAmniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sneathia amnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SneathiaAmniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthiaAtcc49260(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia ATCC49260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthiaAtcc49260", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCarbinoliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMargulisbacteriaBacteriumGwd239127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWD2_39_127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwd239127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumPhsc20c1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium PHSC20C1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumPhsc20c1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseofuscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseofuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseofuscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaNelsoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nelsoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNelsoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRiegelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium riegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRiegelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1025541(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_55_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025541", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacteraceaeBacterium501b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacteraceae bacterium 501b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthobacteraceaeBacterium501b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacteriumColombienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium colombiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumColombienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAcidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSpMar2010147Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella sp. MAR_2010_147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaSpMar2010147Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmatalesArchaeonBrna1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon BRNA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonBrna1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpNr41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. NR 4-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpNr41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimicrobiumThiodismutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldimicrobium thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldimicrobiumThiodismutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaWillistoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila willistoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaWillistoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasChangbaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpHh01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. HH01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpHh01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaSennetsuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sennetsu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSennetsuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumPutei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumPutei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopumilusTuricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusTuricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot901Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root901 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot901Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4655Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4655 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4655Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterWinogradskyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter winogradskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrobacterWinogradskyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KushneriaAvicenniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kushneria avicenniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KushneriaAvicenniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaTrachomatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHimalayensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter himalayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHimalayensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSaphenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium saphenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSaphenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumNematocidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium nematocida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumNematocidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCl2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSp29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. 2.9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusSp29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHumireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusElgiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus elgii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusElgiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSp174Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. 174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSp174Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusFumigatusAf293(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fumigatus Af293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusFumigatusAf293", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraPectinoschizaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira pectinoschiza Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraPectinoschizaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumCymbalariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EremotheciumCymbalariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaEquifetale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma equifetale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaEquifetale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantii3937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii 3937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantii3937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusRaffinolactis4877Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis 4877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactis4877Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusMediterraneensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus mediterraneensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusMediterraneensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophiliaPml168Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia PML168 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaPml168Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StappiaSp22iis9z10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. 22IIS9Z10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StappiaSp22iis9z10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumGbs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium GBS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumGbs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpMm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. MM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumRifcsphigho212Full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EikenellaSpHmsc073a11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. HMSC073A11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpHmsc073a11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioSalmonicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliivibrio salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AliivibrioSalmonicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FilamentousCyanobacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return filamentous cyanobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FilamentousCyanobacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltosporidiumMagnivoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium magnivora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumMagnivoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusYunnanensisNbrc103083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis NBRC 103083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusYunnanensisNbrc103083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasParafulvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas parafulva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasParafulvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpMku1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. MKU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpMku1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TilletiariaAnomalaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tilletiaria anomala Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TilletiariaAnomalaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_33_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DraconibacteriumSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterInhibensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter inhibens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterInhibensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabidopsisLyrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisLyrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusSpJchs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus sp. JCHS_4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusSpJchs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumAutotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumAutotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaVerecundumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma verecundum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaVerecundumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PteropusAlectoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pteropus alecto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PteropusAlectoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucunaPruriensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucuna pruriens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucunaPruriensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthobacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaTriticina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puccinia triticina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PucciniaTriticina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsphigho201full4817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL4817 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full4817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurivirgaCaldicuralii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurivirga caldicuralii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurivirgaCaldicuralii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpF0581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasAmylolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAmylolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSpMarseillep2143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. MarseilleP2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpMarseillep2143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHirsutaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hirsuta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaHirsutaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifcsplowo201full4811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPLOWO201FULL4811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsplowo201full4811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LindowbacteriaBacteriumRifcsplowo212full6227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lindowbacteria bacterium RIFCSPLOWO212FULL6227 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LindowbacteriaBacteriumRifcsplowo212full6227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumExtorquensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum extorquens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumExtorquensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IainarchaeumAndersonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Iainarchaeum andersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IainarchaeumAndersonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EudoraeaAdriatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eudoraea adriatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EudoraeaAdriatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaTimoriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brugia timori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrugiaTimoriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrumPuertoriconensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solirubrum puertoriconensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolirubrumPuertoriconensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasEchinoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas echinoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasEchinoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemonchusPlacei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemonchus placei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemonchusPlacei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpBa94Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA94 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa94Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusTellurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus telluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusTellurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynchytriumMicrobalumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium microbalum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynchytriumMicrobalumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FischerellaSpNies3754Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. NIES-3754 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpNies3754Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusThermophilusHb27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxaSc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa SC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaSc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpHh13063007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. HH130630-07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpHh13063007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpNcr5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. NCR5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpNcr5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacimicrobiumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacimicrobium alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacimicrobiumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Camellia sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CamelliaSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalotheceSpPcc7418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothece sp. PCC7418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalotheceSpPcc7418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyramidobacterSpC128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter sp. C12-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterSpC128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb1437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB1437 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb1437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterMilleraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter millerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterMilleraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChoanephoraCucurbitarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Choanephora cucurbitarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChoanephoraCucurbitarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CajanusCajan(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cajanus cajan graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CajanusCajan", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasHankookensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas hankookensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHankookensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpGa1841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc1062(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC1062 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc1062", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusAurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusAurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_01_FULL_41_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldivirgaSpMu80(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga sp. MU80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaSpMu80", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaSpTg14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. TG14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpTg14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr80(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr80", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaTsutsugamushiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orientia tsutsugamushi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrientiaTsutsugamushiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlligatorMississippiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alligator mississippiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlligatorMississippiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcoidesBurtoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesBurtoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferacaceaeArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumFc4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium FC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumFc4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpGhaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Gha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGhaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpLeaf307Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Leaf307 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpLeaf307Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusHoronobensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus horonobensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusHoronobensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKnackmussii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas knackmussii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKnackmussii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemocanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil764Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil764 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil764Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumP6a3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6A3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6a3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizophyllumCommuneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schizophyllum commune Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchizophyllumCommuneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaHaliotisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa haliotis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaHaliotisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KorarchaeumCryptofilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Korarchaeum cryptofilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KorarchaeumCryptofilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacificibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacificibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacificibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumGw2011gwa14161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium GW2011GWA14161 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumGw2011gwa14161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFOXYA2_FULL_38_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpKmsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. KMS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpKmsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaAequoreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola aequoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaAequoreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaLatipinna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poecilia latipinna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoeciliaLatipinna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6726Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6726Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSp2g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. 2G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSp2g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaCandidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea candida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaCandidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenoanaerobacteriumSaccharovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenoanaerobacterium saccharovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenoanaerobacteriumSaccharovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJs42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JS42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJs42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaeniglutamicibacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBryantiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema bryantii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaBryantiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTaa486Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA486 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa486Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumSpMesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. MES Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumSpMesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCucumisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cucumis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCucumisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktothrixTepidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix tepida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixTepidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg163611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_36_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg163611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_43_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumBranchiophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium branchiophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBranchiophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumSubterraneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium subterraneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSubterraneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaTolypothrichoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPHIGHO2_12_FULL_36_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumMedpeswsndg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusNakamurai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus nakamurai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusNakamurai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisLiminatans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis liminatans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanofollisLiminatans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa24512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_45_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMacleodiiBlack(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Black graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiBlack", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulibacterBethesdensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulibacter bethesdensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulibacterBethesdensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisSk255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTribocorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tribocorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaTribocorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusHopiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfPedicinusBadii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Pedicinus badii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfPedicinusBadii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRadiobacter(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium radiobacter graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRadiobacter", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterOskolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter oskolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RathayibacterOskolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaDenticariosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella denticariosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDenticariosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumDamselaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium damselae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumDamselaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsplowo212full4211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO212FULL4211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo212full4211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBovisDsm19482Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis DSM 19482 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumBovisDsm19482Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMcba15001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonisporaThiosulfatigenesDsm11270Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes DSM 11270 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenesDsm11270Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusVestibularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus vestibularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusVestibularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumGw2011gwb1547Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium GW2011GWB1547 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumGw2011gwb1547Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HomeothermusArabinoxylanisolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Homeothermus arabinoxylanisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HomeothermusArabinoxylanisolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosarcinaFibrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaFibrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusHareiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus harei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusHareiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydatigeraTaeniaeformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydatigera taeniaeformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydatigeraTaeniaeformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscirickettsiaLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesXylophagus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xylophagus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXylophagus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBastinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bastinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBastinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpHv1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Hv1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpHv1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaMuscicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fischerella muscicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FischerellaMuscicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GalerinaMarginataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Galerina marginata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GalerinaMarginataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpSbi22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. SBI22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpSbi22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWA2_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumLarrymoorei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymoorei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAncashensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella ancashensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaAncashensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumAustralicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium australicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAustralicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisTb64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TB64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTb64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho212full429Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL429 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full429Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosigaBrevicollisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosiga brevicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosigaBrevicollisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisiiAtcc35241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC35241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc35241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPaciniiDsm19139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio pacinii DSM 19139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioPaciniiDsm19139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwf1518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_51_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlegusellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olegusella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlegusellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSaccharolyticusDsm5350Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus DSM 5350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticusDsm5350Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifcsplowo201full6413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL6413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full6413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnthophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea anthophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnthophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMaricopensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus maricopensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMaricopensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellvibrionaceaeBacterium1162ts0a05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium 1162TS0a05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacterium1162ts0a05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpA4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. A4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpA4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxHaloduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHaloduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumPropionicumDsm1682(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum DSM 1682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerotignumPropionicumDsm1682", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolosicoccusPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dolosicoccus paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DolosicoccusPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0384Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0384 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0384Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhoceenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phoceense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhoceenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumAutotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum autotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumAutotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumCambrienseDora20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DORA20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDora20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium1456faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 1456FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium1456faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscoideaRubescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ascoidea rubescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AscoideaRubescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusSediminisNbrc103570Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis NBRC 103570 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmphibacillusSediminisNbrc103570Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusNatl2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaPersicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella persica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPersicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPanacis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas panacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPanacis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPutealisDsm16056Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis DSM 16056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPutealisDsm16056Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFutsaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFutsaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesDavawensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces davawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesDavawensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetus8240Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus 8240 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetus8240Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumAStrAtcc3502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A str. ATCC 3502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAStrAtcc3502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCarbinoliphilusSubspOakridgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio carbinoliphilus subsp. oakridgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCarbinoliphilusSubspOakridgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterWinogradskyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter winogradskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrobacterWinogradskyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraNoguchii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira noguchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraNoguchii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterGelidistatuariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter gelidistatuariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SanguibacterGelidistatuariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumSpScc3193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium sp. SCC3193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumSpScc3193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraChlorobenzoicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera chlorobenzoica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraChlorobenzoicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAnaemiaeNbrc100462Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia anaemiae NBRC 100462 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAnaemiaeNbrc100462Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumRifcsplowo212full3515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaMazeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina mazei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaMazeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumVignaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium vignae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumVignaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaSimulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drosophila simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSimulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisBrenneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis brenneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBrenneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSp20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. 20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSp20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaBorealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia borealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaBorealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptosporangiumRoseumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium roseum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumRoseumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20218(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20218", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSp11kri321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. 11kri321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KurthiaSp11kri321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa13921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA13921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa13921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSp7321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. 73-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSp7321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliglacieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliglaciei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliglacieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaS028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia S028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaS028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClonorchisSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clonorchis sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClonorchisSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAlbilineansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas albilineans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAlbilineansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobaculumMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPratensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pratensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPratensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMarimammalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarimammalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSpMe1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. ME-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpMe1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterFormicigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidibacterFormicigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirschiaMaritimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hirschia maritima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HirschiaMaritimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaBaltica18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica 18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CellulophagaBaltica18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusAminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAc2024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AC2024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAc2024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPiscinaleCena21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nostoc piscinale CENA21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NostocPiscinaleCena21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusXylanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus xylanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusXylanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsilocybeCyanescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psilocybe cyanescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsilocybeCyanescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeophyllumTrabeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeophyllumTrabeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosarchaeumLimniumSfb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosarchaeum limnium SFB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosarchaeumLimniumSfb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenedentesBacteriumCg1024214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium CG1024214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumCg1024214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho201Full4622bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaParisiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella parisiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaParisiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSonorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sonorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSonorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzoarcusSpKh32cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. KH32C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpKh32cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaTuricataeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia turicatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaTuricataeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeutenbergiaCavernaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beutenbergia cavernae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeutenbergiaCavernaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisVer097(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Ver097 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisVer097", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpDabal43b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. DABAL43B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpDabal43b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterPseudonitzschiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pseudonitzschiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPseudonitzschiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwb14719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWB1_47_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwb14719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiophoraBrassicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodiophora brassicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiophoraBrassicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumArcisJcm13916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum arcis JCM 13916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumArcisJcm13916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VignaRadiataVarRadiataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vigna radiata var. radiata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VignaRadiataVarRadiataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaAviumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella avium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaAviumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumFortuitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium fortuitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumFortuitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterRhizovicinusDsm16549Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus DSM 16549 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinusDsm16549Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusSendaiensisNbrc100866(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis NBRC 100866 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensisNbrc100866", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMirum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma mirum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaMirum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDidelphisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus didelphis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDidelphisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothermothrixSpDtu029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix sp. DTU029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixSpDtu029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat44921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-44921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat44921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg134015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_13_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg134015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpCf059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAeruginosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAeruginosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhodospiraHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelopsittacusUndulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melopsittacus undulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelopsittacusUndulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd12full3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD12FULL3317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd12full3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusChitonophagus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus chitonophagus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusChitonophagus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusPersicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus persicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacillusPersicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumCg1024331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG1024331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg1024331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusMarinonascensNbrc14363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens NBRC 14363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusMarinonascensNbrc14363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KozakiaBaliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kozakia baliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KozakiaBaliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf22816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF22816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf22816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpTd01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. TD01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpTd01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioVulgarisHildenboroughEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Hildenborough Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisHildenboroughEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpThb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. thb2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpThb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag776Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:776 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag776Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_56_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylococcusCapsulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylococcus capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylococcusCapsulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadalesBacteriumTw7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium TW7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumTw7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGa0074130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0074130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0074130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd12full3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD12FULL3317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd12full3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaParasiticaCbs22365(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica CBS 223.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaParasiticaCbs22365", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterCaesariensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter caesariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterCaesariensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpGfb01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. GFB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpGfb01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YangiaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yangia pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YangiaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full5410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL5410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full5410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrahymenaThermophilaSb210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrahymena thermophila SB210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrahymenaThermophilaSb210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRadioresistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter radioresistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRadioresistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioPiger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio piger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPiger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaMegapolitanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia megapolitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMegapolitanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioBrasiliensisJcm12178(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis JCM 12178 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensisJcm12178", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaParvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theileria parva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheileriaParvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermicanusAegyptiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermicanus aegyptius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermicanusAegyptiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBacilliformisVer097Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Ver097 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisVer097Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpOv329Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV329 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv329Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDonghicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter donghicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDonghicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCellulosilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides cellulosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCellulosilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSimulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSimulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumEscambienseDsm10707Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense DSM 10707 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambienseDsm10707Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterSpSg02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. SG02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpSg02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatagioenasFasciataMonilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Patagioenas fasciata monilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PatagioenasFasciataMonilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSputigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sputigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSputigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaRochalimaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rochalimae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaRochalimaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat27264Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27264Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioLitoralisDsm17657Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio litoralis DSM 17657 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioLitoralisDsm17657Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteroidesHalobius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacteroides halobius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteroidesHalobius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumCapsulatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium capsulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumCapsulatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLigniniphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ligniniphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLigniniphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisHaa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris HaA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisHaa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSonorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sonorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSonorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumPopuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumPopuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAkagiiDsm12554Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium akagii DSM 12554 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAkagiiDsm12554Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwb24517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharospirillumImpatiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharospirillum impatiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharospirillumImpatiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium3157faact1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3157FAACT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3157faact1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAnimalisSubspLactisAd011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium animalis subsp. lactis AD011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAnimalisSubspLactisAd011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLinyingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas linyingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLinyingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterSpLeaf185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaTaeniospiralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpRd62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. RD6.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpRd62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTribocorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tribocorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaTribocorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaProwazekiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia prowazekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaProwazekiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpEr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. ER2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpEr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyaloscyphaBicolorECluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaBicolorECluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaEnzanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora enzanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaEnzanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasTaeanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas taeanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasTaeanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasPolarisDsm16579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas polaris DSM 16579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinomonasPolarisDsm16579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParmense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium parmense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParmense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterCorallicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter corallicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterCorallicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenicicoccusBolidensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus bolidensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArsenicicoccusBolidensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwf2339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWF2_33_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwf2339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu075(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU075 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu075", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumHolothuriorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum holothuriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumHolothuriorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocosphaeraSubtropica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crocosphaera subtropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrocosphaeraSubtropica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeotogaPetraeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geotoga petraea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeotogaPetraeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil750Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil750 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil750Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PatulibacterAmericanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PatulibacterAmericanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrybacteriaBacteriumRifcsphigho201full5815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL5815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full5815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaPnomenusaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pnomenusa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPnomenusaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaFerrariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ferrariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFerrariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBackiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus backii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBackiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasRuminantiumAb3002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AB3002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAb3002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUpsaliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSegnicrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter segnicrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSegnicrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpAmp6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus sp. amp6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CupriavidusSpAmp6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorexAraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sorex araneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SorexAraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerriphaselusAmnicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus amnicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusAmnicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpMits9508(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9508 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9508", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumLitoraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium litorale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumLitoraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19038Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19038Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisDaom(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPlatycodiSf21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi SF21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiSf21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaeraeDsm18581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae DSM 18581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioRhizosphaeraeDsm18581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOdoratitofuiDsm19909Jcm15043Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui DSM 19909 JCM 15043 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofuiDsm19909Jcm15043Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSuaedaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia suaedae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSuaedaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasHistidinilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas histidinilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHistidinilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusMigulanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus migulanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusMigulanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolbachiiSerovarCodiceStrCdc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolbachii serovar Codice str. CDC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolbachiiSerovarCodiceStrCdc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpRoot563Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Root563 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpRoot563Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanifilumFulgidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planifilum fulgidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanifilumFulgidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaMorbiroseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tatumella morbirosei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TatumellaMorbiroseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc26514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_65_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc26514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorarchaeotaArchaeonSmtz145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon SMTZ145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonSmtz145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckiiExf2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hortaea werneckii EXF-2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HortaeaWerneckiiExf2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumVenenatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium venenatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumVenenatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterPaludis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter paludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPaludis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacterRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinibacter ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinibacterRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesUtahensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesUtahensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaSeeligeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria seeligeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaSeeligeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlutamicibacterArilaitensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter arilaitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterArilaitensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusArgenteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus argenteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArgenteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpHimb1321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. HIMB1321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpHimb1321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymoseptoriaTriticiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumClostridioformeAgr2157Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] clostridioforme AGR2157 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioformeAgr2157Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumGenospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium genosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumGenospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusMucosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusMucosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesSk182bjcviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes SK182BJCVI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesSk182bjcviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinispiraMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Succinispira mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuccinispiraMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat14578Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-14578 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat14578Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeospirillumFulvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum fulvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumFulvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpYy7918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. YY7918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpYy7918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasGilvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas gilvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasGilvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaViridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora viridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaViridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaMacacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaMacacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifoxyc2full3812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFOXYC2FULL3812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifoxyc2full3812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasGingeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGingeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumZucineumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium zucineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumZucineumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag288Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:288 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag288Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialophoraAmericanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialophora americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAmericanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaAntimicrobicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora antimicrobica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaAntimicrobicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RegiellaInsecticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Regiella insecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RegiellaInsecticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterTerrenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter terrenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterTerrenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_40_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodictyonLuteolumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon luteolum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelodictyonLuteolumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedBacteroidesSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Bacteroides sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedBacteroidesSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantAfricanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant africanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantAfricanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGalactosidilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus galactosidilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGalactosidilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_69_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterMathraniiSubspMathraniiStrA3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii subsp. mathranii str. A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathraniiSubspMathraniiStrA3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumGw2011gwa14311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA14311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa14311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbus7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNigerAtcc1015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger ATCC 1015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusNigerAtcc1015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacteralesBacteriumUrhd0059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium URHD0059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacteriumUrhd0059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt360Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT360 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt360Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGa0077527Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077527 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077527Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StomoxysCalcitrans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stomoxys calcitrans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StomoxysCalcitrans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KandleriaVitulinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kandleria vitulina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KandleriaVitulinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterLatericiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter latericius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenibacterLatericiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaIgnava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Facklamia ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FacklamiaIgnava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusPleuropneumoniae14074Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 1 4074 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae14074Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasCommodaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonas commoda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonasCommodaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5411bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5411b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5411bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPametensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pametensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPametensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TermitomycesSpJ132Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Termitomyces sp. J132 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TermitomycesSpJ132Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonRbg13389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG13389 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg13389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaPassalidarumNrrlY27907Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum NRRL Y-27907 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpathasporaPassalidarumNrrlY27907Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusThermomutatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus thermomutatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusThermomutatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaCyaneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora cyanea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaCyaneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumGenomosp3StrCfbp6623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium genomosp. 3 str. CFBP 6623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumGenomosp3StrCfbp6623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWmmb322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOvisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOvisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MizugakiibacterSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mizugakiibacter sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MizugakiibacterSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpJb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. JB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpJb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwf1496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_49_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BremiaLactucaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bremia lactucae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BremiaLactucaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasBadiaDsm17552(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas badia DSM 17552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonasBadiaDsm17552", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpRim47Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim47Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsplowo212full5210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO212FULL5210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo212full5210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasAlkenigignensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas alkenigignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasAlkenigignensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_02_FULL_38_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonBa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesParvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomycesParvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumLevicorallinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium levicorallinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLevicorallinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiyogibacteriaBacteriumRifcsplowo202full4513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO202FULL4513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo202full4513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SoleaferreaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Soleaferrea massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SoleaferreaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaedaleaQuercinaL15889Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Daedalea quercina L-15889 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DaedaleaQuercinaL15889Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringens13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringens13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryctolagusCuniculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryctolagus cuniculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryctolagusCuniculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTestudinoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium testudinoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTestudinoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFrigidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio frigidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFrigidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc26514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_65_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc26514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusPrevotiiAcs065vcol13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii ACS065VCol13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiAcs065vcol13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosakoniaCowanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia cowanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KosakoniaCowanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPapayaeJcm25143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter papayae JCM 25143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPapayaeJcm25143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaArthritidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arthritidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArthritidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdoribacterLaneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter laneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OdoribacterLaneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusCremeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus cremeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusCremeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf164Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf164 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf164Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterJejuni81176Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 81176 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterJejuni81176Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpUrha0056Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHA0056 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrha0056Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3837Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3837 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3837Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusPomorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus pomorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusPomorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusPlantarumNbrc100936Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus plantarum NBRC 100936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusPlantarumNbrc100936Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaEpimyces(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capronia epimyces graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaproniaEpimyces", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisus13826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus 13826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisus13826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterToluenoxydansJcm15764(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans JCM 15764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacterToluenoxydansJcm15764", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium9143bfaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 9143BFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium9143bfaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tuber melanosporum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuberMelanosporumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumOxidotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium oxidotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumOxidotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpLeaf222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Leaf222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpLeaf222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RappaportIsraeliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rappaport israeli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RappaportIsraeliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMontanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas montana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMontanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesMerdae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides merdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMerdae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full4711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRhizogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rhizogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRhizogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpYim77409Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. YIM77409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermusSpYim77409Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_12_FULL_44_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo212Full4426Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumJdfr85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrechmeriaConiosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drechmeria coniospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrechmeriaConiosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumScgcAaa011b20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011B20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011b20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematospirillumJordaniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haematospirillum jordaniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaematospirillumJordaniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeauveriaBassianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BeauveriaBassianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumGbs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium GBS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumGbs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def QuadrisphaeraSpDsm44207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Quadrisphaera sp. DSM 44207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "QuadrisphaeraSpDsm44207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaplochromisBurtoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haplochromis burtoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaplochromisBurtoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlantibacterSpLeaf314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter sp. Leaf314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlantibacterSpLeaf314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraHampsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira hampsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraHampsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterRhizovicinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltibacterLentusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altibacter lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltibacterLentusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSp63713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. 63-713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSp63713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg1024390(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_43_90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1024390", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSpLeaf354(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. Leaf354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSpLeaf354", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumVulgareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifoxya1Full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYA1_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxya1Full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelftiaAcidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Delftia acidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DelftiaAcidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpMccc1a10513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sp. MCCC1A10513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSpMccc1a10513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpDmb20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. DMB20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpDmb20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumInsubricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium insubricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumInsubricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom197198wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 197198w Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom197198wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRoot1257Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root1257 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot1257Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasFungiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas fungiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasFungiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOrisC735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris C735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisC735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumRifcsphigho212full4911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL4911 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full4911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRiograndensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus riograndensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRiograndensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusKyotonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus kyotonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusKyotonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFf12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FF12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFf12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwb26316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumW1481Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum W1481 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumW1481Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSphaeroidesAtcc17025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides ATCC17025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroidesAtcc17025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaDentiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dentiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDentiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAssamensisDsm18201Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis DSM 18201 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAssamensisDsm18201Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf22816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF22816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf22816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5525 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0801(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0801", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TupaiaBelangeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tupaia belangeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TupaiaBelangeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLongumNcc2705Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium longum NCC2705 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumLongumNcc2705Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiWj10621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii WJ10621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiWj10621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacterKriegiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacterKriegiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasCommodaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonas commoda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonasCommodaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClariflavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clariflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClariflavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_44_15c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSp513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. 5.13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSp513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu070Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu070Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterPedocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pedocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPedocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusYeeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus yeei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusYeeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovivaxRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halovivax ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalovivaxRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumChabaudiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium chabaudi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumChabaudiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemofelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemofelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemofelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifoxyd1full4124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYD1FULL4124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyd1full4124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGastranaerophilusPhascolarctosicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilus phascolarctosicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilusPhascolarctosicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpizellomycesPunctatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpizellomycesPunctatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumPlexicaudatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium plexicaudatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPlexicaudatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumGwa26018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium GWA2_60_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumGwa26018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaBp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Bp graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceibacterAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceibacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceibacterAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumClostridioforme2149faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme 2149FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioforme2149faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpMg162Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. mg162 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg162Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionNc10BacteriumRifcsplowo202full6622Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium RIFCSPLOWO202FULL6622 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumRifcsplowo202full6622Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusEquinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEquinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NisaeaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nisaea denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NisaeaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_69_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CnuibacterPhyscomitrellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cnuibacter physcomitrellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CnuibacterPhyscomitrellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterGlycinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter glycinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterGlycinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusPoinarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusPoinarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. F0108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpF0108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSp6158faact1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. 6158FAACT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TannerellaSp6158faact1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia marcescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaMarcescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenibacterCertesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter certesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenibacterCertesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StachybotrysChlorohalonataIbt40285Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata IBT 40285 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonataIbt40285Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp166amftsuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 166amftsu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSp166amftsuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeobacterSpCect5382Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 5382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect5382Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrovumSpPnj185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. PNJ185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpPnj185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpL53140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. L53140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpL53140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr477(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR477 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr477", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSpBisph1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. Bisph1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpBisph1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromicrobiumLacuslunaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromicrobium lacuslunae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromicrobiumLacuslunaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixJangbogonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix jangbogonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixJangbogonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanopyrusKandleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanopyrusKandleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisH5384(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis H538.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisH5384", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return candidate division ZIXI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionZixiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllomycesMacrogynusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allomyces macrogynus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllomycesMacrogynusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HafniaAlveiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hafnia alvei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HafniaAlveiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaAmylovoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia amylovora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaAmylovoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml02a017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML02A017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml02a017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutibacterOricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter oricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LutibacterOricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusYunnanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus yunnanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusYunnanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanohaloarchaeaArchaeonB1br10u2g1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimonasHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limimonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimimonasHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOdoratitofuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFh2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpCect5382Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 5382 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect5382Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NipponiaNipponCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nipponia nippon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NipponiaNipponCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasMacleodiiDeepEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas macleodii Deep Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlteromonasMacleodiiDeepEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassolituusOleivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassolituus oleivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassolituusOleivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCircumdentariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas circumdentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCircumdentariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VicugnaPacosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vicugna pacos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VicugnaPacosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinactinosporaThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinactinosporaThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumSpBv2f7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. BV2F7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumSpBv2f7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumCag3125820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CAG:312_58_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCag3125820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBay1663Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BAY1663 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBay1663Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FragariaVescaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fragaria vesca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FragariaVescaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpCb01531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. CB01531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpCb01531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraMacraNbrc14102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura macra NBRC 14102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraMacraNbrc14102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachionusPlicatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachionus plicatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachionusPlicatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPragensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pragensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPragensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSphaeroidesAtcc17025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides ATCC17025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroidesAtcc17025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgaricusBisporusVarBurnettiiJb137S8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agaricus bisporus var. burnettii JB137-S8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgaricusBisporusVarBurnettiiJb137S8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSp11kri321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kurthia sp. 11kri321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KurthiaSp11kri321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraAraneosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaera araneosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraAraneosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHarveyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio harveyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioHarveyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa26142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_61_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpJl475Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. JL475 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpJl475Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpZxy2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ZXY-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpZxy2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMisasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus misasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMisasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpAcs4054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiostomaPiceaeUamh11346(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ophiostoma piceae UAMH 11346 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OphiostomaPiceaeUamh11346", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriaSymbiontBfo1OfFrankliniellaOccidentalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo1 of Frankliniella occidentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo1OfFrankliniellaOccidentalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethylopumilusPlanktonicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus planktonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusPlanktonicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterCrusticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterCrusticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc23714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC23714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc23714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaRupis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga rupis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaRupis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumOceanosedimentumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium oceanosedimentum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumOceanosedimentumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAmyloliquefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpGxt6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. GXT6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpGxt6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaGracilis3211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina gracilis 3/211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitrospinaGracilis3211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaAtrinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kocuria atrinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KocuriaAtrinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelatoclostridiumRamosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelatoclostridium ramosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErysipelatoclostridiumRamosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumMortiferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium mortiferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMortiferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaMeyeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaalia meyeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaaliaMeyeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBuccaeAtcc33574(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccae ATCC33574 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccaeAtcc33574", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansLl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans LL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansLl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmaeJ233(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma palmae J233 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaPalmaeJ233", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaAlcalifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaCastelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma castellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaCastelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumAlcoholivoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alcoholivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlcoholivoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaSp5064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. 50_64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSp5064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaCohaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia cohaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LampropediaCohaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCl6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanoplasmaTermitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoplasma termitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoplasmaTermitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSpCnr923Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNR-923 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnr923Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudothermotogaLettingaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga lettingae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaLettingaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpMc2013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. MC2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpMc2013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSeleniipraecipitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas seleniipraecipitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSeleniipraecipitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMultisaccharivoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multisaccharivorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultisaccharivoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPonticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ponticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioPonticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinolophusFerrumequinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhinolophus ferrumequinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhinolophusFerrumequinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRossiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rossiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRossiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusOncorhynchiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus oncorhynchi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusOncorhynchiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumSaccharolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium saccharolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSaccharolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpGas231Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. GAS231 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpGas231Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusPanacihumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus panacihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusPanacihumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCarsonellaRuddiiCsIsolateThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CS isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCsIsolateThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CamelinaSativaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Camelina sativa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CamelinaSativaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGasseri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gasseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGasseri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesBrasiliensisPb18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Pb18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensisPb18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeeksellaVirosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weeksella virosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeeksellaVirosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAcidianusCopahuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acidianus copahuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcidianusCopahuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRbg19ftCombo367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_19FT_COMBO_36_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg19ftCombo367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPabuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pabuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPabuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasBacteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas bacteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasBacteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumLuteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLuteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar92BacteriumBacl16Mag120619Bin48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 MAG-120619-bin48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16Mag120619Bin48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensNz007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NZ007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNz007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf454(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf454 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf454", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNele67bin005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nele67Bin005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNele67bin005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwb25519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWB2_55_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwb25519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinococcusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusVillosusKin24T80(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus KIN24-T80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosusKin24T80", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumArcisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum arcis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumArcisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusFervensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus fervens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusFervensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FomitopsisRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudopelagicolaGijangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudopelagicola gijangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudopelagicolaGijangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_45_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm16704Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM16704 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm16704Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpUsmaa24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. USMAA2-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpUsmaa24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeophocaenaAsiaeorientalisAsiaeorientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis asiaeorientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalisAsiaeorientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag273Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:273 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag273Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaVafer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia vafer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaVafer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasMesophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas mesophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinomonasMesophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpPao19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. PAO19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpPao19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaFungorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia fungorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFungorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpZg627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. ZG627 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpZg627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycetocolaSaprophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola saprophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycetocolaSaprophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterIrgensiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter irgensii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterIrgensiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumCg1023721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaCarbekii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea carbekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaCarbekii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTianmuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tianmuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTianmuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGlumae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia glumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGlumae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusYedoensisVarNudifloraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prunus yedoensis var. nudiflora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrunusYedoensisVarNudifloraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpF3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. F-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpF3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinibacillusContaminansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus contaminans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusContaminansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpizellomycesPunctatusDaomBr117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spizellomyces punctatus DAOM BR117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpizellomycesPunctatusDaomBr117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSaxobsidens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus saxobsidens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSaxobsidens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumScgcAaa252m02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium SCGC AAA252M02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumScgcAaa252m02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusPoinariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusPoinariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpCf038(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. CF038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpCf038", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_56_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaShayeganii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria shayeganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaShayeganii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpSoil803Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil803 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil803Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipigerThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salipiger thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalipigerThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsphigho202full4912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesObesiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes obesi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesObesiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaThiersiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amanita thiersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmanitaThiersiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAeruginosaPao1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa PAO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAeruginosaPao1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterSp302Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. 302 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSp302Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteScgcAaa799D11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AAA799-D11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAaa799D11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaetiporusSulphureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaetiporusSulphureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSullae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sullae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSullae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReyranellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Reyranella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ReyranellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronococcusJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterUrativoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter urativorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterUrativoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachanceaThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFlectens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas flectens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFlectens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbB17019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHB B 17019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbB17019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimicrobiumAcidiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimicrobium acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimicrobiumAcidiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurisporaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispora thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurisporaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSaguini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSaguini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumJohnsoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium johnsoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumJohnsoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntomoplasmaLucivorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaLucivorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHimb058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HIMB058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHimb058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RufibacterRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RufibacterRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoemansiaReversaNrrl1564Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coemansia reversa NRRL 1564 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoemansiaReversaNrrl1564Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyc2full3612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC2FULL3612 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc2full3612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VecturithrixGranuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vecturithrix granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VecturithrixGranuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBackii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus backii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBackii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaCinereaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria cinerea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCinereaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaAminovalericaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna aminovalerica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaAminovalericaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_37_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumSpPsu2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium sp. PSU-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSpPsu2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumUrhd0017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium URHD0017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumUrhd0017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniclasticumRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniclasticum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniclasticumRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaAlbicansSc5314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida albicans SC5314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaAlbicansSc5314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HepatobacterPenaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hepatobacter penaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HepatobacterPenaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhydraLutrisKenyoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enhydra lutris kenyoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnhydraLutrisKenyoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp7f3div0205Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 7F3DIV0205 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp7f3div0205Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa26395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_63_95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa26395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusQuebecensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus quebecensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusQuebecensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosynechococcusSphagnicolaSy1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola sy1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicolaSy1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatabacterHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catabacter hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatabacterHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_35_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full3513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc23210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC23210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc23210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4186Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4186 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4186Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSputigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sputigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSputigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaAmylovoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia amylovora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaAmylovoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusShackletoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shackletonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusShackletoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusCarbonariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPneumoniaeFhCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae FH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeFhCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteococcusJaponicusLspLj1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Luteococcus japonicus LSP_Lj1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LuteococcusJaponicusLspLj1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAlhagiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea alhagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaAlhagiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFordiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFordiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasInfelixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas infelix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasInfelixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFCSPHIGHO2_01_FULL_50_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifcsphigho201Full5025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomycesGilchristiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomycesGilchristiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusShenzhenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus shenzhenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusShenzhenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpPh3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ph3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpPh3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasViridiflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas viridiflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasViridiflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSabaudiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sabaudiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSabaudiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLipolyticusBf04cf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus BF04CF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusBf04cf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAggregataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina aggregata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAggregataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloracidobacteriumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0473(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0473 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0473", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterActiniarumDsm19842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter actiniarum DSM 19842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PontibacterActiniarumDsm19842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCatalpaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus catalpae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCatalpaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenitrobacteriumDetoxificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Denitrobacterium detoxificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DenitrobacteriumDetoxificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaPutida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia putida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaPutida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusXylanexedensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus xylanexedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusXylanexedensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesLimnophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces limnophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesLimnophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpTx077308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. TX077308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrancisellaSpTx077308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumNodosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium nodosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumNodosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotiiLm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii LM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridioidesMangenotiiLm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSpPcc7108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. PCC7108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpPcc7108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPerfringensStr13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium perfringens str. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPerfringensStr13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbturkey(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBturkey graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbturkey", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HippocampusComes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hippocampus comes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HippocampusComes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropicibacterNaphthalenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tropicibacter naphthalenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TropicibacterNaphthalenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpPw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. PW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpPw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_42_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAbortusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia abortus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAbortusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumLuteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium luteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLuteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_47_33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpNe3005(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. ne3005 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpNe3005", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioFurnissiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio furnissii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioFurnissiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaSpongicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga spongicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSpongicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwc24220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC24220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc24220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusBombycisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus bombycis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusBombycisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrientiaChuto(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orientia chuto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrientiaChuto", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesKebangsaanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kebangsaanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKebangsaanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumChkci001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGubbeenenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gubbeenense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGubbeenenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSpOr53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. OR53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSpOr53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAmblyommatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovibacillusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novibacillus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovibacillusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumPaludicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium paludicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPaludicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumSubtropicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium subtropicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSubtropicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UncinocarpusReesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UncinocarpusReesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OxalobacterFormigenesHoxbls(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes HOxBLS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesHoxbls", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumCulicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smittium culicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmittiumCulicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacterium4572351(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_35.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572351", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTokpelaiaHoelldobleriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tokpelaia hoelldoblerii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTokpelaiaHoelldobleriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumAe2021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AE2021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAe2021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpSc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. Sc1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpSc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonJdfr21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon JdFR-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonJdfr21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEprs66Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EpRS66 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEprs66Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMobile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mobile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMobile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full4732Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL4732 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full4732Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BisonBison(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bison bison graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BisonBison", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumYim77505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium YIM77505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumYim77505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnasPlatyrhynchosPlatyrhynchosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anas platyrhynchos platyrhynchos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnasPlatyrhynchosPlatyrhynchosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisDaom181602daomEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM181602DAOM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602daomEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSalsinemoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina salsinemoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSalsinemoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaKrabiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora krabiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaKrabiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensBurtonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens burtonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensBurtonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpartinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas spartinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpartinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsiellaDolichumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Absiella dolichum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbsiellaDolichumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesPhilippinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes philippinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesPhilippinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpJha19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAbyssalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAbyssalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlassbacteriaBacteriumRifcsplowo212full5811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glassbacteria bacterium RIFCSPLOWO212FULL5811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlassbacteriaBacteriumRifcsplowo212full5811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusInfluenzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus influenzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusInfluenzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlleyaSpVcsa23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olleya sp. VCSA23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlleyaSpVcsa23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCaspalpha6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMethylpentosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium methylpentosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMethylpentosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpS60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. S60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpS60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumCg2303729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium CG2303729 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumCg2303729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaAgariphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa agariphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaAgariphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacaedibacterSymbiosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracaedibacter symbiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacaedibacterSymbiosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpAsf356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpAsf356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp32133Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3213.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32133Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfacinumInfernumDsm9756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum infernum DSM 9756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumInfernumDsm9756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpCag298Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:298 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag298Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallbacteriaBacteriumGwc24935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wallbacteria bacterium GWC24935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WallbacteriaBacteriumGwc24935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransAk01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans AK01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransAk01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovirgaLienii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermovirga lienii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermovirgaLienii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4558(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4558 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4558", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermusFervidusDsm2088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermus fervidus DSM 2088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanothermusFervidusDsm2088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaHypogeiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia hypogeia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHypogeiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpNuni2hmbin003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaDsm15696(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eremococcus coleocola DSM15696 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EremococcusColeocolaDsm15696", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_49_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUrhc0008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHC0008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrhc0008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSuccinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus succinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSuccinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlagellimonasEckloniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas eckloniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasEckloniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisMusacearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris musacearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisMusacearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa23623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiUmn026Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli UMN026 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiUmn026Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCiconiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ciconiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCiconiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaDistributa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta distributa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaDistributa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpC105kso13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. C105KSO13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpC105kso13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpMl3wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ML3W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpMl3wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumBranchiophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium branchiophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBranchiophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasLevii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas levii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasLevii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterPseudonitzschiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pseudonitzschiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPseudonitzschiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraCerevisiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera cerevisiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraCerevisiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaHominisCcug36813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis CCUG 36813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FacklamiaHominisCcug36813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxKoreenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax koreense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxKoreenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusSolitariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusSolitariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgreiaPratensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agreia pratensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgreiaPratensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaAnisaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella anisa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaAnisaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaMayoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia mayonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaMayoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterLongus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter longus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLongus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaceaeBacteriumIbvucb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanisaetaMoutnovskiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta moutnovskia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaMoutnovskiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteribacillusIranensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus iranensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusIranensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterMarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter marensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterMarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterTriticiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter tritici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RathayibacterTriticiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosocosmicusOleophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus oleophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusOleophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaPtyseos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella ptyseos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TatumellaPtyseos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistesJonesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synergistes jonesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynergistesJonesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumFormosenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium formosense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFormosenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseochromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseochromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KorarchaeumCryptofilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Korarchaeum cryptofilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KorarchaeumCryptofilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconobacterJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMultiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOkhensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus okhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusOkhensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioDechloracetivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio dechloracetivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDechloracetivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusObeumAtcc29174Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus obeum ATCC29174 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusObeumAtcc29174Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiodendronMaiusZnEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oidiodendron maius Zn Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OidiodendronMaiusZnEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSmithii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus smithii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSmithii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsukibacteriumIkkenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium ikkense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumIkkenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCellulolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaMegalochromosomata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia megalochromosomata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaMegalochromosomata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesAtroroseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces atroroseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAtroroseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOligofermentansDsm15707Lmg22743Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans DSM 15707 LMG 22743 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOligofermentansDsm15707Lmg22743Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumImcc26256Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26256 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26256Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenalcaligenesHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenalcaligenes hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenalcaligenesHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpAbg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ABG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAbg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpHgf2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HGF2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpHgf2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVanbaaleniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vanbaalenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVanbaaleniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraWolffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaMagadii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba magadii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaMagadii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusEthanolidurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus ethanolidurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusEthanolidurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4432 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpPcc9228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC 9228 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc9228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineActinobacteriumMedacidiG2aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifoxyd1full4124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYD1FULL4124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyd1full4124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaecalisV583(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus faecalis V583 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusFaecalisV583", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom181602Daom197198Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 181602=DAOM 197198 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602Daom197198Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCf386Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. cf386 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCf386Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaValaisianaTom4006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana Tom4006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaTom4006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSiliginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus siliginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSiliginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg164921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_49_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg164921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcamd2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaxillusRubicundulusVe082h10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Ve08.2h10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaxillusRubicundulusVe082h10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreicellaSp357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citreicella sp. 357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitreicellaSp357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FomitopsisPinicolaFp58527Ss1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola FP-58527 SS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FomitopsisPinicolaFp58527Ss1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassolituusOleivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassolituus oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassolituusOleivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpHl111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. HL-111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpHl111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifoxyd1full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYD1FULL4714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyd1full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusMarisflaviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius marisflavi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMarisflaviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSaccharolyticusJop10301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus JOP 1030-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticusJop10301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaSanguinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella sanguinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemellaSanguinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VaribaculumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosphaeraAminiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBenthica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella benthica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBenthica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatishimiaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cognatishimia maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CognatishimiaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsphigho2024316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO2024316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho2024316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TarenayaHasslerianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tarenaya hassleriana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TarenayaHasslerianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohalieaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudohaliea rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudohalieaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaPlatycodi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asaia platycodi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsaiaPlatycodi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMonteilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas monteilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMonteilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpAtcc6931(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. ATCC6931 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpAtcc6931", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpNb77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiumSpR2a62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobium sp. R2A62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobiumSpR2a62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaPallidulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola pallidula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPallidulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGuillouiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter guillouiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGuillouiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpCcge1003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwa2478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_47_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa2478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpUsba49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. USBA 49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpUsba49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusHauseriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteus hauseri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteusHauseriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6726Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6726 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6726Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpHmsc062g07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. HMSC062G07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpHmsc062g07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSepticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium septicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSepticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaGranularumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma granularum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaGranularumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TraorellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Traorella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TraorellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysiphePulchraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe pulchra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysiphePulchraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysiphePulchra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe pulchra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysiphePulchra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SordariaMacrosporaKHell(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sordaria macrospora k-hell graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SordariaMacrosporaKHell", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumChubuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chubuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumChubuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorDanielii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor danielii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorDanielii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpPsnih1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumHumicireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum humicireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHumicireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot404Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root404 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot404Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag169Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:169 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag169Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusJuripiscariusJcm12147Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius JCM 12147 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LentibacillusJuripiscariusJcm12147Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumOlb4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermanaerovibrioAcidaminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio acidaminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioAcidaminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliterellaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliterella atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliterellaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HistophilusSomni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Histophilus somni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HistophilusSomni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcremoniumChrysogenumAtcc11550Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum ATCC 11550 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcremoniumChrysogenumAtcc11550Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesOctosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces octosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesOctosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusSpMv1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. MV1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusSpMv1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Babjeviella inositovora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BabjeviellaInositovora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg135819Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_58_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135819Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWallbacteriaBacteriumGwc24935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wallbacteria bacterium GWC2_49_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWallbacteriaBacteriumGwc24935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumThermocisternumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum thermocisternum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumThermocisternumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DichomitusSqualensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dichomitus squalens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DichomitusSqualensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterArcticusA12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter arcticus A12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PedobacterArcticusA12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat28004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpGxs13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXS13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxs13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfobacillusAcidophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb02488Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB02488 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb02488Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo212full3610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO212FULL3610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo212full3610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpAtcc39006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. ATCC39006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAtcc39006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumBuryatenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPlatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces platensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPlatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocSpPcc7120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPullorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pullorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPullorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeromyscusManiculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusWentiiDto134e9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus wentii DTO 134E9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusWentiiDto134e9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpTc228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tc2-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTc228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusSendaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaSoliDsm19436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kaistia soli DSM 19436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KaistiaSoliDsm19436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_39_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaAusteniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina austeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaAusteniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacimicrobiumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacimicrobium alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacimicrobiumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBplanCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPLAN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBplanCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemolyticusM21621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PerlucidibacaPiscinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca piscinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaPiscinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAmaraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amarae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmaraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusJannaschiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus jannaschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusJannaschiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusLarvaeSubspLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus larvae subsp. larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusLarvaeSubspLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpTth04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TTH0-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTth04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpNbc371Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. NBC371 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpNbc371Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaHenselaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella henselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaHenselaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacteriumCsp16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium CSP1-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumCsp16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPachastrellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pachastrellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPachastrellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicoprobacterFaecalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicoprobacter faecalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicoprobacterFaecalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospiraTrueperiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospira trueperi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospiraTrueperiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLatercula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina latercula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLatercula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisSk970(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK970 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk970", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterPiechaudiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSepticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium septicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSepticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChrysolophusPictus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chrysolophus pictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChrysolophusPictus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaF0398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia F0398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaF0398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAustraliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma australiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAustraliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonghaparkiaSpRoot332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonghaparkia sp. Root332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonghaparkiaSpRoot332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumCg2303166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_31_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwc14715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWC1_47_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwc14715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldanaerovirgaAcetigignensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerovirga acetigignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldanaerovirgaAcetigignensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KryptolebiasMarmoratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kryptolebias marmoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KryptolebiasMarmoratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumSpTc51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium sp. TC51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumSpTc51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterSp38128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 38-128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp38128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPullorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPullorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrycteropusAferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Orycteropus afer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OrycteropusAferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumWolinskyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium wolinskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumWolinskyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRbg166411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RBG_16_64_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRbg166411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisOryzaeAtcc44560(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae ATCC 44560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BipolarisOryzaeAtcc44560", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmmonsiaCrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia crescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaCrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumUasb270Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacterium UASB270 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriumUasb270Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat22090(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-22090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat22090", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumKomanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium komanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumKomanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviScgcAb598o02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi SCGC AB598O02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviScgcAb598o02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtelocyanobacteriumThalassaIsolateAlohaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atelocyanobacterium thalassa isolate ALOHA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtelocyanobacteriumThalassaIsolateAlohaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTurcosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus turcosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusTurcosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3812 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterSuareziiNbrc16159(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sanguibacter suarezii NBRC 16159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SanguibacterSuareziiNbrc16159", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamicrosporidiumSaccamoebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paramicrosporidium saccamoebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParamicrosporidiumSaccamoebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpHzm(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. HZM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpHzm", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisVancoresmycinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis vancoresmycina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisVancoresmycinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumHydrocarbonoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hydrocarbonoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHydrocarbonoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumSpGwf24489(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. GWF2_44_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpGwf24489", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumPhotometricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum photometricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodospirillumPhotometricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidimonasTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidimonasTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeCc1513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpK4410mgs306Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. K4410MGS306 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpK4410mgs306Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFluorescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaBarkeriFusaroCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Fusaro Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriFusaroCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PichiaMembranifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pichia membranifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PichiaMembranifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterLimosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter limosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterLimosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterSpOr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. OR-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpOr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSpPcc7103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusKoppenhoeferiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus koppenhoeferi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKoppenhoeferiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSanguineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sanguineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSanguineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_02_FULL_45_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo202Full4513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMarincola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas marincola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMarincola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumNeutrophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum neutrophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumNeutrophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaNiwae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niwae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiwae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothrixSoehngeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix soehngenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothrixSoehngeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProtochlamydiaAmoebophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia amoebophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaAmoebophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep2415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP2415 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep2415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaPaurometabolicaYim90007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica YIM 90007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolicaYim90007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaPersicinaNbrc102418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erwinia persicina NBRC 102418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPersicinaNbrc102418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioMimicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mimicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMimicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogeometricumRufumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum rufum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumRufumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioSpMilost1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MilosT1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMilost1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Candida] intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpongiarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus spongiarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpongiarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenariaAnguillulaePl171(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Catenaria anguillulae PL171 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CatenariaAnguillulaePl171", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCapitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus capitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCapitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolymorphaCephalotaxi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha cephalotaxi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaCephalotaxi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumRifoxya2full4310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFOXYA2FULL4310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifoxya2full4310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumAmmoniigenesNbrc101786(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes NBRC 101786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenesNbrc101786", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAbyssalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces abyssalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAbyssalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumZag111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium Zag_111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumZag111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SingulisphaeraSpGp187Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera sp. GP187 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraSpGp187Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusShacheensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shacheensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusShacheensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNanhaiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNanhaiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConidiobolusCoronatusNrrl28638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus NRRL 28638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ConidiobolusCoronatusNrrl28638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlkalitoleransDsm16699Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans DSM 16699 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardioidesAlkalitoleransDsm16699Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceaniovalibusGuishaninsula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceaniovalibus guishaninsula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceaniovalibusGuishaninsula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthamoebaCastellaniiStrNeffEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii str. Neff Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcanthamoebaCastellaniiStrNeffEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFicariaNbrc102596Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia ficaria NBRC 102596 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaFicariaNbrc102596Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDielmoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dielmoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusDielmoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpDw54(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. DW54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpDw54", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinophytocolaXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifcsphigho202full5326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPHIGHO202FULL5326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsphigho202full5326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiUsda3471(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti USDA3471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiUsda3471", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu073Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU073 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu073Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAurimucosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aurimucosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAurimucosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaIchthyophagaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WallemiaIchthyophagaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FontimonasThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fontimonas thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FontimonasThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSpEs052(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sp. ES.052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSpEs052", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermopetrobacterSpTc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermopetrobacter sp. TC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermopetrobacterSpTc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGlaucescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces glaucescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlaucescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumChubuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chubuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChubuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyb1full4015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYB1FULL4015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyb1full4015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusIners(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus iners graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusIners", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaLijiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia lijiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaLijiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiMandapamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi mandapamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiMandapamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CamelinaSativaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Camelina sativa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CamelinaSativaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrozanskiiLlap1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella drozanskii LLAP-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaDrozanskiiLlap1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacillusSpCag605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumChlorophenolicumL1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum L-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicumL1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesBurtoniiDsm6242Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii DSM 6242 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesBurtoniiDsm6242Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusMoniliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus moniliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusMoniliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho202Full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraDaeponensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leisingera daeponensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeisingeraDaeponensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterGhanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ghanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterGhanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPurpureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces purpureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPurpureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumMelA1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium MEL.A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumMelA1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophothermusSpDtu052(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus sp. DTU052 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusSpDtu052", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOryzifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter oryzifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOryzifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisAustraliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis australiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisAustraliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpNb77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag1031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpHpa0247(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. HPA0247 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpHpa0247", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrococcusRivularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrococcusRivularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobaculumTepidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum tepidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumTepidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutaceaeBacteriumTav5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwf25713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_57_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf25713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraTerpenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera terpenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraTerpenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot186Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root186 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot186Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisPvCampestrisStrAtcc33913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris pv. campestris str. ATCC 33913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisPvCampestrisStrAtcc33913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumRifcsplowo201full5028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPLOWO201FULL5028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsplowo201full5028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSp67h29bpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. 67H29BP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSp67h29bpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSymbiosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] symbiosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSymbiosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvibaculumLavamentivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvibaculum lavamentivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvibaculumLavamentivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterPapayaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter papayae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterPapayaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo212full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO212FULL4311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo212full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRenaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium renale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRenaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBica18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaprevotellaXylaniphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraprevotella xylaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaprevotellaXylaniphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumKansasiiAtcc12478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii ATCC12478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasiiAtcc12478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSpongiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina spongiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaSpongiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumSpCag1138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:1138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag1138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaGlyceriniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moorella glycerini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoorellaGlyceriniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpCf136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfiporiaCocosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfiporia cocos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfiporiaCocosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TindalliaCaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tindallia californiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TindalliaCaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPecorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pecorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPecorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGenitaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium genitalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGenitaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumKuroshiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium kuroshium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumKuroshiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterRuminantiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter ruminantium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterRuminantiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwb16080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_60_80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb16080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGinsenosidimutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ginsenosidimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGinsenosidimutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsicumAnnuumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capsicum annuum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapsicumAnnuumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EgrettaGarzettaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Egretta garzetta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EgrettaGarzettaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSpXm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. XM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpXm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MinicystisRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Minicystis rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MinicystisRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMikamiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mikamii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaMikamiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUw4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. UW4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUw4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpCsm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. CSM-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpCsm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpXs5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. XS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpXs5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubritaleaSqualenifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuritaleaHydrogenivoransSk43hEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans sk43H Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivoransSk43hEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AidingimonasHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aidingimonas halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AidingimonasHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusLaterosporusLmg15441Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus LMG15441 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusLmg15441Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPelagiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pelagia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPelagiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUvarumDsm19971Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum DSM 19971 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusUvarumDsm19971Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpSka58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SKA58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSka58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumFormicicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium formicicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumFormicicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpCf108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaJiangsuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia jiangsuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaJiangsuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpongiicolaDsm21749Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola DSM 21749 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysobacterSpongiicolaDsm21749Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp5ratimar09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 5RATIMAR09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp5ratimar09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 46-16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPallidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pallidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatrinemaPallidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocellaConradii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocella conradii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocellaConradii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina morsitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararhizobiumPolonicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pararhizobium polonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PararhizobiumPolonicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassomonasViridans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas viridans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasViridans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaSpF41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Belnapia sp. F-4-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BelnapiaSpF41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HuchoHucho(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hucho hucho graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HuchoHucho", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoplanesSinuspersiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoplanes sinuspersici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoplanesSinuspersiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OreniaMetallireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orenia metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OreniaMetallireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylococcusCapsulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylococcus capsulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylococcusCapsulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalmapalusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halmapalus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHalmapalusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaplasmaMarginaleMariesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Maries Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleMariesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpC150(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. C150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpC150", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum californiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaPaludivivensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella paludivivens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPaludivivensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraCaeruleaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera caerulea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraCaeruleaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaEffusaAp103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa AP103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusaAp103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusThioreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus thioreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusThioreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaSaanichensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tatumella saanichensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TatumellaSaanichensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensCha0(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens CHA0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensCha0", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSedentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sedentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSedentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYr519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraPhenolivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera phenolivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraPhenolivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsUnilateralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps unilateralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsUnilateralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusSomnusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus somnus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSomnusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraPseudotaxifoliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara pseudotaxifoliae) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraPseudotaxifoliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_38_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViridochromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridochromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MyxococcusSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag403Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:403 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag403Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTaa204(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa204", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisSk255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphiprionOcellarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion ocellaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphiprionOcellarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratireductorPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratireductorPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho202full4011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO202FULL4011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho202full4011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumGwf24514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDesertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium deserti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDesertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaSpEbm43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta sp. EBM-43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaSpEbm43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaediEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCinaediEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumGw2011gwa14429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA14429 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa14429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRbg134211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_42_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg134211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrinaliumEpipsammum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crinalium epipsammum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrinaliumEpipsammum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniKf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni KF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniKf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaMinorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella minor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaMinorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocebusMurinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microcebus murinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrocebusMurinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChauvoeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium chauvoei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumChauvoeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusThioparus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus thioparus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusThioparus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpHot20860m813i02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813I02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813i02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AptenodytesForsteri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aptenodytes forsteri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AptenodytesForsteri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19055(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM 19055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19055", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FundulusHeteroclitusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fundulus heteroclitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FundulusHeteroclitusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpJcm19060Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. JCM 19060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpJcm19060Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasResinovoransDsm21078Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans DSM21078 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransDsm21078Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StoquefichusSpKle1796Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. KLE1796 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpKle1796Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricanaCbs2517Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana CBS 2517 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaAfricanaCbs2517Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaetiporusSulphureus9353(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus 93-53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LaetiporusSulphureus9353", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0430Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0430 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpF0430Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia avium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho202full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL4312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampbellbacteriaBacteriumGw2011od13428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium GW2011OD13428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumGw2011od13428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCellostaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellostaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellostaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusContaminansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus contaminans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusContaminansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusIbericusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ibericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusIbericusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasAquimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas aquimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAquimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full5011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL5011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full5011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelativoransSpBnc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. BNC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpBnc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixAgardhiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix agardhii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixAgardhiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumGa0077559Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077559 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077559Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRbg16378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaSpongicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga spongicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSpongicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsPolyrhachisFurcataBcc54312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachis-furcata BCC 54312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisFurcataBcc54312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDaejeonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDaejeonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilalesBacteriumLsucc0135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium LSUCC0135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumLsucc0135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsphigho201full4349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO201FULL4349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho201full4349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasAutotrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas autotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasAutotrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterKyonggiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kyonggiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKyonggiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocapsaAcidiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAcidiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumThalpophilumDsm11723Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum DSM 11723 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilumDsm11723Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSpPro95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. PRO95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpPro95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidocella aminolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidocellaAminolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyc2full398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL398 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMa2020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MA2020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMa2020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterAscidiaceicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter ascidiaceicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAscidiaceicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAchromatiumPalustre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Achromatium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAchromatiumPalustre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpUnccl20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. UNCCL20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpUnccl20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpFukuswis1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. FUKUSWIS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpFukuswis1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClonorchisSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clonorchis sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClonorchisSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAsturiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas asturiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAsturiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSpMctg156Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. MCTG156 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpMctg156Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumScgcAaa160i06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA160I06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa160i06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumGypseumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microsporum gypseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrosporumGypseumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpOr37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. OR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpOr37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpM2012083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. M2012083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpM2012083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsphigho202Full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaGummosaDsm723(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Derxia gummosa DSM 723 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DerxiaGummosaDsm723", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterAnophelisNbrc107843(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter anophelis NBRC 107843 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JanibacterAnophelisNbrc107843", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaBelliiOsu85389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii OSU85389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiOsu85389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterAkesuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter akesuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterAkesuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgathobaculumDesmolans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agathobaculum desmolans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgathobaculumDesmolans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesDsm20611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes DSM20611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesDsm20611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAdolescentisAtcc15703(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium adolescentis ATCC 15703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumAdolescentisAtcc15703", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansLl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans LL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansLl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaAk(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ak graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAk", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusAquimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus aquimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusAquimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZimmermannellaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zimmermannella alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZimmermannellaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacterKivuiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter kivui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterKivuiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMiyunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia miyunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaMiyunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraCerevisiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera cerevisiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraCerevisiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4733 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusIbericusCbs121593Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ibericus CBS 121593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusIbericusCbs121593Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusMulierisAtcc35243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC35243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasSpOralTaxon110StrF0139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parvimonas sp. oral taxon 110 str. F0139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParvimonasSpOralTaxon110StrF0139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XiphophorusCouchianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus couchianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XiphophorusCouchianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpOlga172Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. OLGA172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpOlga172Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpF0494Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0494 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0494Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CytophagaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaeroarchaeumSulfurireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaeroarchaeum sulfurireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaeroarchaeumSulfurireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp292mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 292MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp292mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpAap58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. AAP58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpAap58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpFlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Fl Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpFlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCaseiBl23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei BL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiBl23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaSchlechtendaliaChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Schlechtendalia chinensis) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSchlechtendaliaChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoelleriellaLiberaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moelleriella libera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoelleriellaLiberaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxoplasmaGondiiVeg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Toxoplasma gondii VEG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ToxoplasmaGondiiVeg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVersmoldensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus versmoldensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVersmoldensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesCryophilusOy26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus OY26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilusOy26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusGobiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus gobiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGobiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritimibacterAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maritimibacter alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaritimibacterAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbmousenlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseNL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousenlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusKakegawensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus kakegawensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusKakegawensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoenicibacterCongonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phoenicibacter congonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhoenicibacterCongonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterLanthieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter lanthieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterLanthieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NicotianaTabacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana tabacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NicotianaTabacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumColombienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium colombiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumColombienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterHeparinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter heparinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterHeparinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumSpP6bsiii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum sp. P6BSIII graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumSpP6bsiii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLongaSw024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina longa SW024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLongaSw024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaXishanensisNbrc101358Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia xishanensis NBRC 101358 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaXishanensisNbrc101358Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumButyricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium butyricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumButyricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpFxj1172Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. FXJ1.172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpFxj1172Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumIndicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumIndicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacteriumYongneupenseDsm18731Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense DSM 18731 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupenseDsm18731Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpK31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. K31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpK31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSp228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. 228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSp228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFo5176(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Fo5176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFo5176", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAlsense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium alsense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAlsense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasitellaParasiticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parasitella parasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParasitellaParasiticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AndreprevotiaLacusDsm23236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia lacus DSM 23236 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AndreprevotiaLacusDsm23236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpA03Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. A03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpA03Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalarsenatibacterSilvermanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halarsenatibacter silvermanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalarsenatibacterSilvermanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterSpImcc21906Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter sp. IMCC21906 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterSpImcc21906Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiscibacillusSalipiscariusJcm13188Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius JCM 13188 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscariusJcm13188Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasGadei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas gadei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasGadei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAlaskensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alaskensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlaskensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe3004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumSpWn1359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. WN1359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CarnobacteriumSpWn1359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaCincinnatiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella cincinnatiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaCincinnatiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumChkci001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumMicromatiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium micromati Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMicromatiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesNdongoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ndongoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNdongoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCoagulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coagulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCoagulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TorrubiellaHemipterigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Torrubiella hemipterigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TorrubiellaHemipterigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemoglobinophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus haemoglobinophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusHaemoglobinophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSolventivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus solventivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSolventivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicolaFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidicola ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidicolaFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAminovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchracea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaOchracea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumHungatei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium hungatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumHungatei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp651402Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1402 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651402Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAuratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces auratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAuratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanomonosporaSphaerica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planomonospora sphaerica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanomonosporaSphaerica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGd11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GD11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpGd11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpGj21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. GJ21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpGj21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf456(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf456 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf456", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpKiost1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. KIOST1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpKiost1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMastitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mastitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMastitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSp47agom205m(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. 47AGOM205m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSp47agom205m", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGigasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gigas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGigasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAzotoformansLmg9581Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus azotoformans LMG 9581 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAzotoformansLmg9581Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlareaLozoyensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glarea lozoyensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlareaLozoyensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorSaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorSaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaSpT8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterLappiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter lappiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterLappiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpP6a1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. P6A1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpP6a1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaEnoeca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella enoeca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaEnoeca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc13813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC13813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc13813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaObeumA2162(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blautia obeum A2-162 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlautiaObeumA2162", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediculusHumanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediculus humanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediculusHumanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaGlobosaCbs7966Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Malassezia globosa CBS 7966 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MalasseziaGlobosaCbs7966Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonRubrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichophytonRubrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimonasVoraiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimonas voraii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimonasVoraiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaSpAd3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Martelella sp. AD-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MartelellaSpAd3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumCaspactino2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaNigrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella nigrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaNigrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumMolle(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium molle graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumMolle", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumCeti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium ceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumCeti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermarchaeotaArchaeonJdfr18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermarchaeota archaeon JdFR-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermarchaeotaArchaeonJdfr18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldilineaAerophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldilinea aerophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldilineaAerophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviflexusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flaviflexus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlaviflexusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TulasnellaCalospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tulasnella calospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TulasnellaCalospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMirabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMirabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsialesBacteriumAc37b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Ac37b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacteriumAc37b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpTomc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. TomC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpTomc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpEl159(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. EL159 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpEl159", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaBajacaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta bajacaliforniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaBajacaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacterium6911(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 69-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium6911", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RivulariaSpPcc7116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rivularia sp. PCC7116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RivulariaSpPcc7116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusConcavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus concavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusConcavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraFlavalbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura flavalba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraFlavalbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDianthicolaNcppb3534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dianthicola NCPPB 3534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DickeyaDianthicolaNcppb3534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberBorchii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tuber borchii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuberBorchii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaEnhydra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia enhydra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaEnhydra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpMor2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. Mor2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpMor2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCaecimurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caecimuris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaecimurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaTundricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicella tundricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicellaTundricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNamurensisDsm19117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis DSM 19117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNamurensisDsm19117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HepatobacterPenaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hepatobacter penaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HepatobacterPenaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo201Full5118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_01_FULL_51_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo201Full5118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClariflavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clariflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClariflavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinimonasChungwhensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinimonas chungwhensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinimonasChungwhensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsplowo201full4813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPLOWO201FULL4813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsplowo201full4813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusPohliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pohliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusPohliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumSubspPolymorphumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. polymorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspPolymorphumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrabulsiellaOdontotermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trabulsiella odontotermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrabulsiellaOdontotermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaDaqingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena daqingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaDaqingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_41_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypholomaSublateritium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HypholomaSublateritium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusAbyssi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusAbyssi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacterAutotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter autotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthobacterAutotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StanieriaCyanosphaera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stanieria cyanosphaera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StanieriaCyanosphaera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNiger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNiger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesTriticiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GaeumannomycesTriticiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelesiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solemya velesiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelesiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc5015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC5015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc5015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Babesia bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BabesiaBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumGw2011Gwa14610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium GW2011_GWA1_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumGw2011Gwa14610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumVincentii3136a2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 3136A2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii3136a2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSuncheonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium suncheonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuncheonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonenseHt12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense HT12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylovulumMiyakonenseHt12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDianthicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dianthicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaDianthicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonJdfr11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon JdFR-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonJdfr11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeliponaQuadrifasciataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melipona quadrifasciata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeliponaQuadrifasciataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaPorcellusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cavia porcellus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaviaPorcellusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMarinisedimentorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marinisedimentorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMarinisedimentorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisCloacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis cloacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisCloacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoldemanellaBiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holdemanella biformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoldemanellaBiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTasmaniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tasmaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTasmaniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycisphaeraeBacteriumSm2330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaerae bacterium SM23_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraeBacteriumSm2330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisUniversalisFam5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis FAM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisFam5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexSeptentrionalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex septentrionalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexSeptentrionalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaHarzianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma harzianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaHarzianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumGraminearumPh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum PH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumGraminearumPh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaLacunaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia lacunae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaLacunaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiTs15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei TS15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiTs15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfifellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afifella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfifellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHarveyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio harveyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioHarveyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumDg72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaGamsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma gamsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaGamsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasArabiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas arabiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasArabiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaGranulomatisDsm19156Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis DSM 19156 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MannheimiaGranulomatisDsm19156Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpIbvss1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoturnixJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coturnix japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoturnixJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumPerfoetens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium perfoetens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPerfoetens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusMicrosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus microsporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopusMicrosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevirhabdusPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevirhabdus pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevirhabdusPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromyxobacterSpFw1095(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. Fw1095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpFw1095", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsasporaOwczarzakiAtcc30864Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki ATCC 30864 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CapsasporaOwczarzakiAtcc30864Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusMuriaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus muriaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusMuriaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungatellaHathewayi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungatella hathewayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungatellaHathewayi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriaceaeBacteriumAk24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyclobacteriaceae bacterium AK24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyclobacteriaceaeBacteriumAk24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumVinckei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vinckei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVinckei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaDiuraphisNoxiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Diuraphis noxia) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaDiuraphisNoxiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnionYellowsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Onion yellows Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OnionYellowsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhodospirillumPhotometricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pararhodospirillum photometricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PararhodospirillumPhotometricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythiumUltimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pythium ultimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PythiumUltimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAlexandrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alexandrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlexandrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFrigidicarnis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium frigidicarnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFrigidicarnis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAnserinaEsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia anserina Es Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaAnserinaEsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaBergeriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemella bergeriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemellaBergeriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp63Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp63Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaHispanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hispanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaHispanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaCsv86Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida CSV86 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaCsv86Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylacidiphilumInfernorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum infernorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumInfernorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium3818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 38-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium3818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium3157faact1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3157FAACT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3157faact1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusGammatolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus gammatolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGammatolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfatatorIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSp228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. 228 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSp228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaInsidiosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia insidiosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaInsidiosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumMinutulumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum minutulum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumMinutulumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslp40081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLP40081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslp40081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProtochlamydiaNaegleriophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Protochlamydia naegleriophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusProtochlamydiaNaegleriophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParacollinoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracollinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacollinoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesVulcaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesVulcaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp103mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 103mf Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSp103mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasDaqiaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas daqiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasDaqiaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaVacuolataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumHibernumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hibernum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHibernumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpAu12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. AU12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpAu12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaSedimentorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella sedimentorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaSedimentorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium3146faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3146FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3146faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloropiconPrimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloropicon primus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloropiconPrimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumGw2011gwa2378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA2378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa2378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRbg167010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_16_70_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg167010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumCg10239135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium CG10239135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumCg10239135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumParadoxumJwYl7Dsm7308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] paradoxum JW-YL-7 DSM 7308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParadoxumJwYl7Dsm7308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusVannieliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus vannielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVannieliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRuminisAtcc27782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ruminis ATCC27782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRuminisAtcc27782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobinsoniellaPeoriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Robinsoniella peoriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RobinsoniellaPeoriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromohalobacterSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioFibrisolvens164Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio fibrisolvens 16/4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioFibrisolvens164Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumCg2303639Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG2303639 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg2303639Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSydowiiCbs59365(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sydowii CBS 593.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusSydowiiCbs59365", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusFulvus124b02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus 124B02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvus124b02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterDokdonensisDsw5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis DSW-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolaribacterDokdonensisDsw5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElectrophorusElectricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Electrophorus electricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElectrophorusElectricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrantaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brantae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrantaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathycoccusPrasinosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathycoccus prasinos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathycoccusPrasinosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAgilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus agilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAgilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhoceaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phocea massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhoceaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumSpCag239Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. CAG:239 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpCag239Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpIso805nEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Iso805N Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpIso805nEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCulicicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma culicicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCulicicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterCapsiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter capsici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterCapsiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumMelanogenumCbs110374Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum CBS 110374 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenumCbs110374Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricicoccusPullicaecorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyricicoccus pullicaecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyricicoccusPullicaecorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaDalianensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava dalianensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaDalianensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumAcamd5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acAMD5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcamd5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumVariabileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum variabile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumVariabileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumLongisporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verticillium longisporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerticilliumLongisporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinophytocolaXanthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xanthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXanthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminicellaSporogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caminicella sporogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaminicellaSporogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeoasaiaChiangmaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neoasaia chiangmaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeoasaiaChiangmaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRoquefortiFm164(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium roqueforti FM164 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRoquefortiFm164", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxWautersiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax wautersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxWautersiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgulaAerodenitrificansDsm15089Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans DSM 15089 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificansDsm15089Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110053Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110053 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110053Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RutstroemiaSpNjr2017aWrk4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a WRK4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aWrk4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaMediocidicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora mediocidica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaMediocidicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusSpMucl43196Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus sp. MUCL 43196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizophagusSpMucl43196Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonasCommoda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonas commoda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonasCommoda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacterium448493Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448493Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpFobrc6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. FOBRC6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpFobrc6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUnc358mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC358MFTsu51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc358mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumAutotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum autotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumAutotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCaribbeanicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio caribbeanicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioCaribbeanicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilaceaeBacteriumUrhb0048Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHB0048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrhb0048Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaTheileriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma theileri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaTheileriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonadalesBacteriumTw7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium TW7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumTw7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacterium6432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium 64_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacterium6432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthobacteraceaeBacterium501bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacteraceae bacterium 501b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthobacteraceaeBacterium501bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr3Bacterium4484211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium 4484_211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3Bacterium4484211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium cuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusUliginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusUliginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteinernemaCarpocapsaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Steinernema carpocapsae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SteinernemaCarpocapsaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaSpHeli48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella sp. HelI48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaSpHeli48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumParaoxydansDh1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans DH1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydansDh1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucusCbs51665Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus glaucus CBS 516.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusGlaucusCbs51665Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsterYellowsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aster yellows Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsterYellowsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusCaldusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlrhCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALRh Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlrhCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusGenomosp3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. 3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusGenomosp3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterLudwigiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter ludwigii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLudwigiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacearchaeotaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacearchaeota archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacearchaeotaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferYueqingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer yueqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferYueqingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpLm3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. LM3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLm3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpT8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumRosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium rosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumRosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaporthiopsisPoaeAtcc64411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae ATCC 64411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoaeAtcc64411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasAdhaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAdhaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterPhenanthrenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter phenanthrenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterPhenanthrenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPneumoniaeD39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae D39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeD39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfRidgeiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotryotiniaCalthaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botryotinia calthae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotryotiniaCalthaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumYoeliiYoeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium yoelii yoelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumYoeliiYoeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGelidilacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoelleriellaLiberaRcef2490(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moelleriella libera RCEF 2490 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoelleriellaLiberaRcef2490", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusNecatorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus necator Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNecatorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MustelaPutoriusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mustela putorius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MustelaPutoriusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGirerdiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma girerdii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGirerdiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpOralTaxon414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. oral taxon 414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpOralTaxon414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasHofstadiiJcm17038Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas hofstadii JCM 17038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasHofstadiiJcm17038Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpOv219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. OV219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpOv219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusStrNatl2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. NATL2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrNatl2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumDichloroeliminansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dichloroeliminans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDichloroeliminansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenibacteriumSpCag290(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenibacterium sp. CAG:290 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenibacteriumSpCag290", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaInyonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora inyonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaInyonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuisR61Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis R61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisR61Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTuaregi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tuaregi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTuaregi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaLyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga lytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaLyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifoxyb2full327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYB2FULL327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxyb2full327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacteriumScn7022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium SCN 70-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumScn7022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumCg2305937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_59_37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2305937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00274(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00274", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaTyphimuriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhimurium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphimuriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAcidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia acidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAcidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHalstedii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces halstedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHalstedii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasCupida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas cupida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasCupida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilodermaCroceumF1598(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Piloderma croceum F 1598 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PilodermaCroceumF1598", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronovibrioHydrogenovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio hydrogenovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioHydrogenovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSp6728Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 67-28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6728Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrithrixThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwe23937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE23937 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe23937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthiaCatenaformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthia catenaformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthiaCatenaformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaeromonasToyohensisTobeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis ToBE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensisTobeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrolunatusSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpathasporaPassalidarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpathasporaPassalidarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonRbg166727Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_16_67_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg166727Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMjm8645(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MJM8645 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMjm8645", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurocapsaSpPcc7327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasJatrophaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas jatrophae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasJatrophaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumSubtropicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium subtropicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSubtropicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalidrisPygmaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calidris pygmaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalidrisPygmaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilibacterTermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pilibacter termitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PilibacterTermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsphigho202full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO202FULL4216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho202full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MageeibacillusIndolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mageeibacillus indolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MageeibacillusIndolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc136108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC136108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc136108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterPiechaudii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterPiechaudii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaEutrophaJmp134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha JMP134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaJmp134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellvibrioJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCoprocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpKordi52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola str. Hc (Homalodisca coagulata) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm46838(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46838 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46838", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaSpPp2459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. PP2-459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpPp2459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRoot61Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot61Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferaxMucosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mucosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMucosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusCatusGd7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus catus GD/7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoprococcusCatusGd7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAvermitilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avermitilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvermitilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaPallens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pallens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPallens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpUnccl20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. UNCCL20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpUnccl20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpRac04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. RAC04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpRac04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusPortucalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FasciolaGigantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fasciola gigantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FasciolaGigantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrauserellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prauserella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrauserellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PajaroellobacterAbortibovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pajaroellobacter abortibovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PajaroellobacterAbortibovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE1747Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1747Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSoliNbrc102451(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus soli NBRC 102451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSoliNbrc102451", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisKunsanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis kunsanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisKunsanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpTcuhl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TCUHL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTcuhl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwc23922Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWC2_39_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwc23922Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0425(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0425", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyc12full3455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC12FULL3455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc12full3455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSp638Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. 638 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSp638Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCacaonumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCacaonumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg16399bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16399b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16399bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterAntibioticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter antibioticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterAntibioticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidiphilusMargaritiferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidiphilus margaritifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidiphilusMargaritiferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrachymyrmexCornetzi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex cornetzi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexCornetzi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterJanthinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter janthinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterJanthinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotignumPropionicumDsm1682Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum DSM 1682 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerotignumPropionicumDsm1682Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GanodermaSinenseZz02141Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ganoderma sinense ZZ0214-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GanodermaSinenseZz02141Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusRaffinolactis4877(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis 4877 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusRaffinolactis4877", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacticigeniumNaphtae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacticigenium naphtae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacticigeniumNaphtae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesClavuligerus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces clavuligerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesClavuligerus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGlycinesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium glycines Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGlycinesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PochoniaChlamydosporia170Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 170 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia170Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full5012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL5012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full5012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRbg16408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RBG_16_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRbg16408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphiprionPerculaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphiprion percula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphiprionPerculaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterHamburgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter hamburgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrobacterHamburgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaDrancourtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella drancourtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrancourtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusDisparEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus dispar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDisparEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPinihumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPinihumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusSubspVenerealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. venerealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspVenerealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp10a9div0425Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 10A9DIV0425 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp10a9div0425Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusSolfataricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus solfataricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfolobusSolfataricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipaludibacillusAurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasArtemidisF0399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas artemidis F0399 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasArtemidisF0399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusaAcuminataSubspMalaccensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata subsp. malaccensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MusaAcuminataSubspMalaccensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PisolithusMicrocarpus441Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pisolithus microcarpus 441 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PisolithusMicrocarpus441Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasSpDtu018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaProwazekiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia prowazekii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaProwazekiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpK31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. K31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpK31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumVacuolatumDsm3385(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum DSM 3385 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatumDsm3385", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaKristenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia kristensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaKristenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusTaiwanensisDsm21401Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis DSM 21401 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensisDsm21401Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg23070394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_70_394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg23070394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe3009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogulbenkianiaFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNidulansFgscA4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans FGSC A4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusNidulansFgscA4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPinihumiDsm23905Jcm16419Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi DSM 23905 JCM 16419 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPinihumiDsm23905Jcm16419Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterMallensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter mallensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterMallensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaAsterYellowsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma aster yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaAsterYellowsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumGw2011gwa2378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA2378 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa2378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivivensSpJlt3646Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivivens sp. JLT3646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivivensSpJlt3646Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConsotaellaSalsifontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Consotaella salsifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConsotaellaSalsifontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSteyniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus steynii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSteyniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumWasabiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium wasabiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumWasabiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HammondiaHammondiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hammondia hammondi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HammondiaHammondiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNk4a136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpDg881Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. DG881 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpDg881Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnaporthiopsisPoaeAtcc64411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae ATCC 64411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoaeAtcc64411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 CBMW_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Cbmw12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslh80548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH80548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh80548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumVinckeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vinckei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVinckeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusPsychroduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychroduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerfeziaBoudieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terfezia boudieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerfeziaBoudieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterGhanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ghanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterGhanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpScgc07wgaepuloa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. SCGC07WGAEpuloA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpScgc07wgaepuloa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgareSubspVulgare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare subsp. vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HordeumVulgareSubspVulgare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_45_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumSm2331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium SM23_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumSm2331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematostellaVectensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nematostella vectensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NematostellaVectensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BudviciaAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Budvicia aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BudviciaAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaFibrata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosarcinaFibrata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyriculariaOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyricularia oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyriculariaOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaPomeroyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria pomeroyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaPomeroyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb243498i20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_498I20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243498i20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSp32owCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32OW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32owCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HylemonellaGracilisAtcc19624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis ATCC19624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisAtcc19624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg164410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG164410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg164410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS920 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroherpetonThalassiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroherpeton thalassium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroherpetonThalassiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHlucco18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAgarilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucothrixMucorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucothrix mucor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucothrixMucorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumKctc3527Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum KCTC3527 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumKctc3527Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalibacteriumQingdaonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salibacterium qingdaonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalibacteriumQingdaonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaCoronataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puccinia coronata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PucciniaCoronataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSpMz1t(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera sp. MZ1T graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraSpMz1t", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMjm8645Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MJM8645 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMjm8645Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPLOWO2_12_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTubingensisCbs13448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus tubingensis CBS 134.48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusTubingensisCbs13448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumJenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium jensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumJenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSp4636(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. 46_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSp4636", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PunctulariaStrigosozonata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Punctularia strigosozonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PunctulariaStrigosozonata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedSup05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedSup05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophusSpGwc25631(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus sp. GWC2_56_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophusSpGwc25631", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumRm5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium RM5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumRm5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasSpScn6556(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas sp. SCN 65-56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasSpScn6556", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7Edl933Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 EDL933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Edl933Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterFarmeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter farmeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFarmeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSeniorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senioris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSeniorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesVulturisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces vulturis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesVulturisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSuisStrIllinois(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma suis str. Illinois graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSuisStrIllinois", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaUsmarc1296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesVenezuelensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides venezuelensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesVenezuelensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GanodermaSinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ganoderma sinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GanodermaSinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconobacterOxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf236839Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF2_36_839 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf236839Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpSfd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliaeetusLeucocephalus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haliaeetus leucocephalus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaliaeetusLeucocephalus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpJs23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. JS23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpJs23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusNurukiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus nuruki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNurukiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpCf038Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. CF038 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpCf038Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GullanellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gullanella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GullanellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloiococcusOtitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloiococcus otitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloiococcusOtitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbmousejapanCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBmouseJapan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbmousejapanCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full4825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL4825 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full4825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopropionibacteriumPropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudopropionibacterium propionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudopropionibacteriumPropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumAqs3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium AqS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumAqs3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaAstilbisJcm15831(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaia astilbis JCM 15831 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaiaAstilbisJcm15831", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantMicroti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant microti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantMicroti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpJs23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. JS23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpJs23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeCc1513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMucogenicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mucogenicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMucogenicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactonifactorLongoviformisDsm17459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis DSM 17459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactonifactorLongoviformisDsm17459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfPolyrhachisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagnetotacticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumBrhc36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium BRHc36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumBrhc36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_35_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaBroomeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia broomeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaBroomeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminimonasQiaohouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminimonas qiaohouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminimonasQiaohouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSalmoneumNbrc103935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum NBRC 103935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneumNbrc103935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WenyingzhuangiaFucanilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia fucanilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaFucanilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumCellulolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellulolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellulolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSmegmatisJs623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis JS623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisJs623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGinsenosidimutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ginsenosidimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGinsenosidimutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt318Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT318 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCnt318Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNanhaiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNanhaiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Muproteobacteria bacterium RIFCSPHIGHO2_01_FULL_65_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMuproteobacteriaBacteriumRifcsphigho201Full6516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpKw12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. KW12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpKw12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdoribacterSplanchnicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter splanchnicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OdoribacterSplanchnicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FungalSpNo11243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.11243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo11243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumFb2012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium FB2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumFb2012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaHaematobium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma haematobium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaHaematobium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpNrrls836(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. NRRLS836 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpNrrls836", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12SubstrMg1655Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. MG1655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrMg1655Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumSpB510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. B510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpB510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OttowiaThiooxydansDsm14619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans DSM 14619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OttowiaThiooxydansDsm14619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium6137faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 6_1_37FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium6137faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalalkalicoccusJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halalkalicoccus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalalkalicoccusJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoclavibacterHelvolus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter helvolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterHelvolus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobaculumAquaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobaculum aquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobaculumAquaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematomicrobiumSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haematomicrobium sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaematomicrobiumSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCatarrhalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpCulex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Culex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpCulex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLondiniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella londiniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaLondiniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrenneriaGoodwiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brenneria goodwinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrenneriaGoodwiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpragueaLophiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spraguea lophii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpragueaLophiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgiphilusAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algiphilus aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgiphilusAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMiyunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia miyunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaMiyunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaDiscariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia discariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaDiscariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpJs614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. JS614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJs614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalieaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haliea rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalieaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CercosporaBerteroaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cercospora berteroae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CercosporaBerteroaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaBombycisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nosema bombycis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NosemaBombycisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpGwc16184(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. GWC1_61_84 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpGwc16184", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRcc307Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RCC307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRcc307Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmilianiaHuxleyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Emiliania huxleyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmilianiaHuxleyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacterium7018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 70-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium7018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiusActivusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius activus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusActivusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaYakubaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Drosophila yakuba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DrosophilaYakubaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaPinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga pinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaPinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSalariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorselliaAnophelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thorsellia anophelis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThorselliaAnophelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpOv096(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. OV096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpOv096", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconacetobacterDiazotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter diazotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterDiazotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesLutziiPb01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides lutzii Pb01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesLutziiPb01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpAb134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. Ab134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpAb134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveromycesLactisNrrlY1140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis NRRL Y-1140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KluyveromycesLactisNrrlY1140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAlexandriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alexandrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlexandriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferDonghaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer donghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferDonghaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumKnowlesiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasidiobolusMeristosporusCbs93173(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus CBS 931.73 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporusCbs93173", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumAnimalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum animalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAnimalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusPittmaniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarboxydothermusPertinaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus pertinax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusPertinaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriumGlomeransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coriobacterium glomerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriumGlomeransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumGwb24920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_49_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb24920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls340Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls340Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScyliorhinusTorazameEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scyliorhinus torazame Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScyliorhinusTorazameEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleStEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale St. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleStEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumDtu027Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium DTU027 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumDtu027Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaAfricanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorvusBrachyrhynchosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corvus brachyrhynchos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorvusBrachyrhynchosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSpOh31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. OH31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylophilusSpOh31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcalesBacterium72143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 72-143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium72143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumCg23041165(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_41_165 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg23041165", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPhagedenis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema phagedenis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPhagedenis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KytococcusSedentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kytococcus sedentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KytococcusSedentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1023915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_39_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterSpTr13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter sp. TR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterSpTr13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MixiaOsmundaeIam14324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae IAM 14324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MixiaOsmundaeIam14324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxEbreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax ebreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxEbreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysaccharea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaPolysaccharea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusLaterosporusLmg15441Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus LMG15441 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusLmg15441Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosalibacterSpNd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. ND1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerosalibacterSpNd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpSa39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. SA39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpSa39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaGlobosaCbs7966(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia globosa CBS 7966 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MalasseziaGlobosaCbs7966", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspMasoucidaNbrc13784Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. masoucida NBRC 13784 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspMasoucidaNbrc13784Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisCitri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisCitri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaNs342(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea NS342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaNs342", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpAt0102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. AT01-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpAt0102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterWuianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter wuianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterWuianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiellaPusillaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella pusilla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaPusillaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinidiaChinensisVarChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinidia chinensis var. chinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinidiaChinensisVarChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacacaNemestrina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macaca nemestrina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacacaNemestrina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaWaywayandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea waywayandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaWaywayandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaInagensisDsm44258Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis DSM 44258 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaInagensisDsm44258Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_43_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMacraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura macra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMacraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterGangotriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter gangotriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterGangotriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAnthracisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus anthracis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAnthracisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYB1_FULL_39_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YoungiibacterFragilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Youngiibacter fragilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YoungiibacterFragilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRifcsphigho202full4313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPHIGHO202FULL4313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsphigho202full4313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminispirochaetaBajacaliforniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta bajacaliforniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaBajacaliforniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusClavatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus clavatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusClavatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiisalibacterPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiisalibacter paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiisalibacterPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5517 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumSpOr53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium sp. OR53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSpOr53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium1456faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 1456FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium1456faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumXylanophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium xylanophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumXylanophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpRv15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. RV15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRv15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusParviboronicapiensJcm18861Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens JCM 18861 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiensJcm18861Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriumSalinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacterium salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriumSalinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMcba15008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpNc3005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC3005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc3005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpUcdkl12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpCf299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_36_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo202full4511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO202FULL4511 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo202full4511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DialisterPneumosintesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister pneumosintes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterPneumosintesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus constellatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusConstellatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumCetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumCetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumCg1024416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024416 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpEr4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. ER4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpEr4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium GW2011_GWA1_40_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumGw2011Gwa1409Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaTuberolachnusSalignusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Tuberolachnus salignus) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaTuberolachnusSalignusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CicerArietinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cicer arietinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CicerArietinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLongaSw024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina longa SW024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLongaSw024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythonBivittatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Python bivittatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PythonBivittatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag1295924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:129_59_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1295924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumSpWn1359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. WN1359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CarnobacteriumSpWn1359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixDisciformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix disciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiothrixDisciformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCatoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas catoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCatoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpRs40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_54_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaVirilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila virilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaVirilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospirillumFerriphilumMl04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum ML-04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilumMl04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichurisMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichuris muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichurisMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFalloniiLlap10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Legionella fallonii LLAP-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LegionellaFalloniiLlap10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusKaustophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus kaustophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusKaustophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichloromethanomonasElyunquensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dichloromethanomonas elyunquensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DichloromethanomonasElyunquensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntomoplasmaMelaleucaeAtcc49191Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae ATCC 49191 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucaeAtcc49191Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls87(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls87", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae subsp. similipneumoniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniaeSubspSimilipneumoniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo201full4724Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4724 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4724Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusAzygosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus azygosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopusAzygosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedAcidilobusSpMgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. MG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpMgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaOdoriferaDsm4582(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia odorifera DSM 4582 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaOdoriferaDsm4582", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiechaudiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piechaudii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiechaudiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsplowo201full4519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL4519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full4519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumSpCag239Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. CAG:239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpCag239Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesMarseilloanorexicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes marseilloanorexicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesMarseilloanorexicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwe23937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE23937 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe23937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaBooriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria booriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaBooriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylellaFastidiosa9a5cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa 9a5c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosa9a5cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarispirochaetaAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marispirochaeta aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarispirochaetaAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosmotogaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KosmotogaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSwuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSwuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgulaAerodenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirgula aerodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgulaAerodenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaDilworthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia dilworthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDilworthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpOv174Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. OV174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpOv174Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrospiraNitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira nitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraNitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpB05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. B05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpB05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumSpIppasb1200Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. IPPASB1200 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpIppasb1200Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOzensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOzensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomicrobiaArchaeonDtu008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon DTU008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonDtu008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloterrigenaMahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena mahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaMahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpRd272(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Rd 27.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpRd272", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpM313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. m313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpM313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaLupiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaLupiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaPoulsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma poulsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaPoulsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full4010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JoostellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Joostella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JoostellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_36_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full3615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSegnisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter segnis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSegnisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothermarchaeotaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geothermarchaeota archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeothermarchaeotaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaKunkeliiCr23xCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii CR2-3x Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaKunkeliiCr23xCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg2304411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaBalticaOs145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina baltica OS145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaBalticaOs145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiosporiumApollinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coniosporium apollinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConiosporiumApollinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMacedonicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macedonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMacedonicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusAgarilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusAgarilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeratocystisFimbriataCbs114723Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata CBS 114723 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CeratocystisFimbriataCbs114723Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaCompniacensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Baudoinia compniacensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BaudoiniaCompniacensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNovofumigatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusNovofumigatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusPhosphorivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus phosphorivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FictibacillusPhosphorivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfTrichogrammaPretiosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma pretiosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaPretiosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TilletiariaAnomalaUbc951Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tilletiaria anomala UBC 951 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TilletiariaAnomalaUbc951Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumAtcc25586(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum ATCC25586 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAtcc25586", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusVillosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusProteolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusProteolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirundoRusticaRusticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hirundo rustica rustica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HirundoRusticaRusticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaDiazotrophicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia diazotrophica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaDiazotrophicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatenaAgr2136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena AGR2136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaAgr2136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacterium6813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium 68-1-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacterium6813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeroarcusBurkinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeroarcus burkinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeroarcusBurkinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumScophthalmumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium scophthalmum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumScophthalmumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLemmy01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LEMMY01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLemmy01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_69_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSp20bnCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 20BN Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSp20bnCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemofelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemofelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemofelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiae2603vRCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae 2603V/R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiae2603vRCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1024082Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024082Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogeometricumLimiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum limi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumLimiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitaleaMyxolifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea myxolifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaMyxolifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaRestrictaCbs7877Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Malassezia restricta CBS 7877 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MalasseziaRestrictaCbs7877Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifoxya2full4528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFOXYA2FULL4528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifoxya2full4528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapilioXuthus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Papilio xuthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PapilioXuthus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSatsumensisDsm16230Jcm12392Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus satsumensis DSM 16230 JCM 12392 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSatsumensisDsm16230Jcm12392Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifoxyd12full5919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYD12FULL5919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyd12full5919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlesiocystisPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plesiocystis pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlesiocystisPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquincolaTertiaricarbonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquincola tertiaricarbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquincolaTertiaricarbonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConicaCcbas932(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Morchella conica CCBAS932 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MorchellaConicaCcbas932", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaePvOryzaeKacc10331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae pv. oryzae KACC 10331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePvOryzaeKacc10331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaeramiaOrbicularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaeramia orbicularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaeramiaOrbicularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalidrisPugnaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calidris pugnax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalidrisPugnaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_02_FULL_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeMaculicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae maculicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeMaculicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetonemaLongum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetonema longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetonemaLongum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpBl107Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. BL107 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpBl107Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterUlvicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter ulvicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterUlvicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcalesBacterium72143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 72-143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium72143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeersiaPerrieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leersia perrieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeersiaPerrieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4216 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorellaEquigenitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorella equigenitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorellaEquigenitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumLacustreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumLacustreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSviceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sviceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSviceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaGonorrhoeaeFa1090Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae FA 1090 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeaeFa1090Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusBasilensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus basilensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusBasilensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_48_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaTenuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida tenuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaTenuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumCaseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium casei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumCaseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidophilusNcfmCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus NCFM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilusNcfmCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumAquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasMexicana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas mexicana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasMexicana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpentinomonasMccroryiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas mccroryi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasMccroryiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPraediiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus praedii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPraediiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SebaldellaTermitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sebaldella termitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SebaldellaTermitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp11000297Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1100029.7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11000297Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpJgi0001016m12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. JGI 0001016M12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpJgi0001016m12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaDermatitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaDermatitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisRemaneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis remanei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisRemaneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoactinomycesSpDsm45891Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45891 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45891Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiastellaViciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niastella vici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiastellaViciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf236131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF236131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf236131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaNorimbergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea norimbergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaNorimbergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistalesBacterium5424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 54_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaliphilaJab1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila JAB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphilaJab1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaLalandiDorsalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Seriola lalandi dorsalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SeriolaLalandiDorsalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindariusDsm2278Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanolobus tindarius DSM 2278 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanolobusTindariusDsm2278Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpAc402Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC402 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc402Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSoliNbrc106424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax soli NBRC 106424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VariovoraxSoliNbrc106424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalanaerobiumSalsuginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSalsuginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasOryziterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas oryziterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasOryziterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumU91iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium U9-1i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumU91iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasIssachenkonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas issachenkonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasIssachenkonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PerlucidibacaAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumDiernhoferiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium diernhoferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDiernhoferiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpLappah108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLappah108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusHaloduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusHaloduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSenegalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSenegalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumMelanogenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium melanogenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumMelanogenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSpVm5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Virgibacillus sp. Vm5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VirgibacillusSpVm5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphimedonQueenslandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphimedon queenslandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphimedonQueenslandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaeniaAsiaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taenia asiatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaeniaAsiaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_48_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAa4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusHominisSk119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis SK119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisSk119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumAurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag474Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag474Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLentusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLentusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumInterjectumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium interjectum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumInterjectumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBohemicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bohemicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBohemicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusErythropolisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus erythropolis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusErythropolisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumQingshengiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium qingshengii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumQingshengiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoahuilensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCoahuilensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBiflexaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira biflexa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBiflexaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full4811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL4811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full4811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusPomorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus pomorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusPomorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatenaDsm13814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena DSM13814 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaDsm13814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTuberumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tuberum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTuberumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCandidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus candidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusCandidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaDoshiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella doshiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaDoshiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixHimadriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix himadriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixHimadriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlexanderiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alexanderi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlexanderiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesJohnsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelidibacterMesophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter mesophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GelidibacterMesophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRectaleAtcc33656Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] rectale ATCC 33656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumRectaleAtcc33656Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesMassiliensisDnlkv3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis dnLKV3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisDnlkv3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallemiaIchthyophagaExf994Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga EXF-994 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WallemiaIchthyophagaExf994Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterAilurogastricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter ailurogastricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAilurogastricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_49_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesDsm20611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes DSM20611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesDsm20611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomonasSpAap53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. AAP53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpAap53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSp627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. 627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesSp627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferAdhaerensOv14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ensifer adhaerens OV14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnsiferAdhaerensOv14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaCaldariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema caldarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaCaldariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJeoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jeonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJeoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetrotogaMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Petrotoga mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PetrotogaMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterLuteolusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterLuteolusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisFormicicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisFormicicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpBa94(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa94", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinocladiellaMackenzieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhinocladiellaMackenzieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDactylopiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpY57Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Y57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpY57Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaymondbacteriaBacteriumRifoxyc2full5021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Raymondbacteria bacterium RIFOXYC2FULL5021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RaymondbacteriaBacteriumRifoxyc2full5021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodococcusSpAk35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiorhodococcus sp. AK35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiorhodococcusSpAk35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccomyxaSubellipsoideaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoideaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAviariusSubspAraffinosusDsm20653Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius subsp. araffinosus DSM 20653 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAviariusSubspAraffinosusDsm20653Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpAf1440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArcobacterSpAf1440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrinickiaSymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trinickia symbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrinickiaSymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpSeq25v(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. Seq25V graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpSeq25v", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa14423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_44_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa14423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpTb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho201full5524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHeilmannii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHeilmannii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachionusPlicatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachionus plicatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachionusPlicatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpKiost1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. KIOST1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpKiost1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterJohnsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJohnsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaumanniaCicadellinicolaStrHcHomalodiscaCoagulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola str. Hc (Homalodisca coagulata) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicolaStrHcHomalodiscaCoagulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusChitonophagusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus chitonophagus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusChitonophagusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoefleaPhototrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea phototrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaPhototrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterFiliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterFiliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumRbg166630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG166630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg166630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSordelliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sordellii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSordelliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioAscidiaceicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio ascidiaceicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAscidiaceicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusBrumalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polyporus brumalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolyporusBrumalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaGraminisFSpTriticiCrl75367003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis f. sp. tritici CRL 75-36-700-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PucciniaGraminisFSpTriticiCrl75367003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumThermoresistibileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium thermoresistibile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumThermoresistibileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_46_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag486Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:486 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag486Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusLutimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius lutimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusLutimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumPrausnitziiA2165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii A2165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiA2165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusPersicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prunus persica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrunusPersicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe3004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulochytriumProtostelioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulochytrium protostelioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulochytriumProtostelioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_36_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 39-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxParadoxusS110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus S110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusS110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCorienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum coriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCorienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistophilusSomniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Histophilus somni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HistophilusSomniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDelongbacteriaBacteriumGwf24014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Delongbacteria bacterium GWF2_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDelongbacteriaBacteriumGwf24014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UlvibacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UlvibacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsMilitarisCm01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cordyceps militaris CM01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CordycepsMilitarisCm01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasSpLw13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. LW13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSpLw13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithinimicrobiumSpCnj824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium sp. CNJ-824 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumSpCnj824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNk4a144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusMiurensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus miurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusMiurensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpWcc10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. WCC10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpWcc10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPeloridisLmg23910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter peloridis LMG 23910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPeloridisLmg23910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidimonasFonticaldiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas fonticaldi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidimonasFonticaldiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HericiumAlpestreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hericium alpestre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HericiumAlpestreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpSgdv85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. SGDV85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpSgdv85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm46786(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46786", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpWmma185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. WMMA185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpWmma185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaAvicenniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAvicenniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg164224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_42_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusFructosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus fructosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFructosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpEs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ES1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpEs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CnuibacterPhyscomitrellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cnuibacter physcomitrellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CnuibacterPhyscomitrellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycineMaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycine max Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycineMaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaTularensisNovicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis novicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisNovicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAichiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia aichiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaAichiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesocricetusAuratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesocricetus auratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesocricetusAuratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumSgbin9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL3913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKapabacteriaThiocyanatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kapabacteria thiocyanatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKapabacteriaThiocyanatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifcsphigho202full5326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPHIGHO202FULL5326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsphigho202full5326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaMaculosaOt289(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa OT 289 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaMaculosaOt289", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpNd2010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. ND2010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpNd2010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumJoshi001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium JOSHI001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumJoshi001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpV48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. V48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpV48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MinicystisRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Minicystis rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MinicystisRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaHisticolaF0411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella histicola F0411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaHisticolaF0411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiaceaeBacteriumUrhb0013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangiaceae bacterium URHB0013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiaceaeBacteriumUrhb0013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaSqualenifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaStercorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella stercoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaStercorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HadesarchaeaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGhanensisDsm18630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis DSM 18630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGhanensisDsm18630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterOricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter oricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutibacterOricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSpCaAtcc33047(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. CA ATCC 33047 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpCaAtcc33047", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremellaMesentericaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tremella mesenterica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TremellaMesentericaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FolsomiaCandidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Folsomia candida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FolsomiaCandidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpFc2018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. FC2018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpFc2018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa26395Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_63_95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa26395Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaOtitidiscaviarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaseoulense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraseoulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaseoulense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrapeneCarolina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrapene carolina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrapeneCarolina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpSt2l12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFjat27812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-27812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat27812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaceaeBacterium457259Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetaceae bacterium 4572_59 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaceaeBacterium457259Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpYr620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR620 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPalustreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium palustre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPalustreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GuillardiaTheta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Guillardia theta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GuillardiaTheta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmithellaSpM82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. M82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpM82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisSpRac08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis sp. RAC08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisSpRac08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusGinsengihumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ginsengihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGinsengihumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelonobacterOrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelonobacter oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelonobacterOrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchrobactrumIntermedium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumIntermedium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuthiaMagnifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruthia magnifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuthiaMagnifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_12_FULL_45_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo212Full4526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusCollinsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus collinsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichococcusCollinsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParachlamydiaAcanthamoebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia acanthamoebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaAcanthamoebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantiiEch703(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch703", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAcetireducensDsm10703(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetireducens DSM 10703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcetireducensDsm10703", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumAlcaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaCarbonaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora carbonacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCarbonaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpWsm3224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampbellbacteriaBacteriumRifcsplowo2023512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campbellbacteria bacterium RIFCSPLOWO2023512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampbellbacteriaBacteriumRifcsplowo2023512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WirthbacteriaBacteriumCg2305411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wirthbacteria bacterium CG2305411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WirthbacteriaBacteriumCg2305411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisCinereaBcdw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea BcDW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaBcdw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaBissettiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella bissettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBissettiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFermentansM64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma fermentans M64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFermentansM64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaValaisianaVs116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana VS116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaVs116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpPbcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PBC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPbcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpCmfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpCmfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisBryophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis bryophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocystisBryophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScardoviaWiggsiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scardovia wiggsiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScardoviaWiggsiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpMum116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MUM 116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMum116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriA1501Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri A1501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriA1501Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TamlanaNanhaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tamlana nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TamlanaNanhaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusGarvieaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBuchneriAtcc11577(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri ATCC11577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriAtcc11577", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRoot700Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root700 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot700Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquisalimonasAsiaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquisalimonas asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquisalimonasAsiaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AplysiaCalifornica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aplysia californica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AplysiaCalifornica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriSdmlac(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri SDMLAC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriSdmlac", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpLeaf222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Leaf222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpLeaf222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrauserellaRugosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prauserella rugosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrauserellaRugosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc511d10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacalesArchaeonDl31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Haloferacales archaeon DL31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "HaloferacalesArchaeonDl31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpQlwp1data2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. QLWP1DATA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpQlwp1data2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParascrofulaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parascrofulaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumParascrofulaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GalbibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Galbibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GalbibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisAtcc903(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis ATCC903 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisAtcc903", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitromicrobiumBathyomarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citromicrobium bathyomarinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitromicrobiumBathyomarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaBicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laccaria bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaccariaBicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumScgcAaa298d23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium SCGC AAA298D23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumScgcAaa298d23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaIhumiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIhumiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimimaricolaCinnabarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola cinnabarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaCinnabarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaAerolataKacc11604Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Skermanella aerolata KACC 11604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SkermanellaAerolataKacc11604Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpOr37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. OR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpOr37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_51_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumSpMj3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salimicrobium sp. MJ3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalimicrobiumSpMj3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucco07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumHwasookiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium hwasookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumHwasookiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumIslandicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium islandicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumIslandicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumCulicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium culicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCulicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumTag1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium TAG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumTag1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200210029sch5224772Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200210029SCH5224772 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200210029sch5224772Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_01_FULL_51_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcyrthosiphonPisum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acyrthosiphon pisum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcyrthosiphonPisum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusGilvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGilvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltiarchaealesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altiarchaeales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltiarchaealesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriovoraxMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacteriovorax marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacteriovoraxMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaSoesokkakensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita soesokkakensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSoesokkakensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusStearothermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus stearothermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusStearothermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterMethanicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter methanicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterMethanicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf89(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf89", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterNosocomialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nosocomialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNosocomialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TinamusGuttatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tinamus guttatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TinamusGuttatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumHalophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium halophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumHalophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaShandongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia shandongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaShandongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaladaptatusSpR4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus sp. R4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusSpR4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumPlurifariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium plurifarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPlurifariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusFicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus ficus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RisungbinellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Risungbinella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RisungbinellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusSaudimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus saudimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusSaudimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusIntestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus intestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusIntestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroserpensJangbogonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroserpens jangbogonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroserpensJangbogonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFischerbacteriaBacteriumRbg13378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fischerbacteria bacterium RBG_13_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFischerbacteriaBacteriumRbg13378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCatenulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces catenulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCatenulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinimonasAmylolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinimonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinimonasAmylolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifoxyc2full4316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYC2FULL4316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyc2full4316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAsaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAsaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSclerotialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriiaBacterium4080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriia bacterium 40-80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriiaBacterium4080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaSeeligeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria seeligeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaSeeligeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetakosakoniaMassiliensisJc163Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis JC163 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensisJc163Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusCallidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus callidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusCallidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaSqualenifaciensDsm18772(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens DSM 18772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciensDsm18772", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella haemolysans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemellaHaemolysans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil764Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil764 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil764Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAziziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus azizii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAziziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOv118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ov118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaJaponicaA8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica A8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaA8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonRbg135212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG135212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg135212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitellibacterAquimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vitellibacter aquimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VitellibacterAquimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWalczuchellaMonophlebidarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Walczuchella monophlebidarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWalczuchellaMonophlebidarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaThalassocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella thalassocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaThalassocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full4711(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4711 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4711", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBarengoltziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumHydrocarbonoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium hydrocarbonoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHydrocarbonoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTerricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia terricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTerricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermarchaeotaArchaeonJdfr18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermarchaeota archaeon JdFR-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermarchaeotaArchaeonJdfr18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpRoot123d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. Root123D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpRoot123d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag594Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:594 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag594Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumDenitrificans1nes1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans 1NES1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificans1nes1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaCorrodensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eikenella corrodens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EikenellaCorrodensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimonasManganoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas manganoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldimonasManganoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParachlamydiaSpC2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia sp. C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaSpC2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusMachipongonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus machipongonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMachipongonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpM47t1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M47T1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpM47t1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumChoerinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium choerinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumChoerinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaApisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella apis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaApisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrleanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orleanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrleanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphenodonPunctatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphenodon punctatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphenodonPunctatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumLychnidisDioicaeP1a1Lamole(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum lychnidis-dioicae p1A1 Lamole graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisDioicaeP1a1Lamole", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChinchillaLanigera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chinchilla lanigera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChinchillaLanigera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKnackmussiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas knackmussii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKnackmussiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full6413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL6413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full6413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariprofundusMicoguttaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus micogutta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MariprofundusMicoguttaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolaciniaPaynteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia paynteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPaynteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPacaense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pacaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPacaense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinopsTelfairiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echinops telfairi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EchinopsTelfairiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaYakuba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila yakuba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DrosophilaYakuba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb243495d8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_495D8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243495d8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumM181(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium M181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumM181", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumSubspAnimalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspAnimalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPabuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pabuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPabuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpAs2mbin001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. AS2MBin001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpAs2mbin001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf99(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf99", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuscaDomesticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Musca domestica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuscaDomesticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNecrophorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSclerotialusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sclerotialus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSclerotialusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2080(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2080 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2080", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasMuralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas muralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasMuralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeCc1417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPseudospiralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella pseudospiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPseudospiralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterCrescentusOr37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus OR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusOr37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NipponiaNipponEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nipponia nippon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NipponiaNipponEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophaceaeBacteriumCg2305814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_58_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2305814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocGelidumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocGelidumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumArachidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arachidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArachidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NadsoniaFulvescensVarElongataDsm6958Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nadsonia fulvescens var. elongata DSM 6958 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NadsoniaFulvescensVarElongataDsm6958Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaUsmarc1296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumBacl21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumSpDsm25559Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. DSM 25559 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpDsm25559Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumSm2339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium SM23_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumSm2339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThioglobusSingularisPs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thioglobus singularis PS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThioglobusSingularisPs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LishizheniaTianjinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lishizhenia tianjinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LishizheniaTianjinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomassiliicoccusLuminyensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_01_FULL_45_25b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf117 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicoprobacterFaecalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicoprobacter faecalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicoprobacterFaecalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasResinovoransDsm21078Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans DSM21078 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransDsm21078Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSalsilacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella salsilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSalsilacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriCcug29243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri CCUG 29243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriCcug29243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeofilumRubicundumJcm15548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geofilum rubicundum JCM 15548 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeofilumRubicundumJcm15548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixSchenckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix schenckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporothrixSchenckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxOweniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apteryx owenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApteryxOweniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovispirillumItersoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novispirillum itersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovispirillumItersoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallaecimonasXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubeoparvulumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubeoparvulum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubeoparvulumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSp23gom1509mCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 23GOM1509m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasSp23gom1509mCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusGalactosidilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus galactosidilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGalactosidilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIakyrusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces iakyrus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesIakyrusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaPhaffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalodesulfovibrioMarinisediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxya2full4315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA2FULL4315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya2full4315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwc23313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWC23313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwc23313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpBmg51109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG51109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg51109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaFlorencaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella florencae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaFlorencaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinum202fEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum 202F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinum202fEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpCf108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSpJc8e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. JC8E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KurthiaSpJc8e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorchellaConicaCcbas932Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Morchella conica CCBAS932 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MorchellaConicaCcbas932Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSkirrowiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter skirrowii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSkirrowiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AplysiaCalifornicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aplysia californica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AplysiaCalifornicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full4028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL4028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full4028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSilesiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas silesiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSilesiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumNonalfalfaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verticillium nonalfalfae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerticilliumNonalfalfaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaCellobiosiphilaDsm17781Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila DSM 17781 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphilaDsm17781Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusManganicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus manganicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusManganicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_01_FULL_34_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlenkiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klenkia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlenkiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterMucosalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter mucosalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterMucosalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaSedimentorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella sedimentorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaSedimentorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusEhimensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusEhimensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidesmisPriestleyiBc1401Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi BC1401 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiBc1401Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerasakiellaMagneticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella magnetica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaMagneticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_33_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full3321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_40_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPhoceensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium phoceensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPhoceensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTaihuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taihuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaihuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaXylanovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKazanBacteriumRifcsplowo201full4813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPLOWO201FULL4813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsplowo201full4813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspXiangfangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. xiangfangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspXiangfangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifoxyd1full4714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYD1FULL4714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyd1full4714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbyssisolibacterFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Abyssisolibacter fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbyssisolibacterFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EumetaJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eumeta japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EumetaJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo212full5210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO212FULL5210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo212full5210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsphigho212full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO212FULL4422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho212full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanisDsm13634Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis DSM 13634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanisDsm13634Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaDasanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moritella dasanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoritellaDasanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB2_FULL_45_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumJlt2015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium JLT2015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumJlt2015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasLinyingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas linyingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLinyingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaOtitidiscaviarumIfm11049Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum IFM 11049 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarumIfm11049Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full487Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL487 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full487Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreicellaSp357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citreicella sp. 357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitreicellaSp357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAsaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas asaccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAsaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaIsraelensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella israelensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaIsraelensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCaenarcanumBioreactoricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caenarcanum bioreactoricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaenarcanumBioreactoricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DromaiusNovaehollandiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dromaius novaehollandiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DromaiusNovaehollandiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdeonellaSakaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ideonella sakaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdeonellaSakaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumGw2011gwa13716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWA13716 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwa13716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4748Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4748 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4748Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium4423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 44-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium4423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioAlginolyticusNbrc15630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus NBRC15630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticusNbrc15630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusCoprophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCoprophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpZagget8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. Zagget8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZagget8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumCosmeticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium cosmeticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumCosmeticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterIndonesiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprothermobacterPlatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter platensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterPlatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraCrunogenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira crunogena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraCrunogenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumVrystaatenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium vrystaatense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumVrystaatenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumYsb2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsb2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesIsraeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces israelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesIsraeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumRoquefortiFm164Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicillium roqueforti FM164 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRoquefortiFm164Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1024740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_47_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1024740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WohlfahrtiimonasLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRifcsplowo201full6018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPLOWO201FULL6018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsplowo201full6018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilisYch46Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis YCH46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisYch46Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumCeb3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium CEB3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumCeb3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusSolitariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusSolitariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSchubertiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas schubertii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSchubertiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaribacterHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laribacter hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaribacterHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMendocinaEgdaq5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina EGDAQ5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMendocinaEgdaq5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FukatsuiaSymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fukatsuia symbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FukatsuiaSymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxya1full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYA1FULL4018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxya1full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaHeimbachaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia heimbachae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaHeimbachaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4328Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4328Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmithellaSpScadcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. SCADC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpScadcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusSpRedseas12b1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus sp. REDSEAS12B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSpRedseas12b1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusFamiliarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus familiaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CanisLupusFamiliarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGwa1418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GWA1418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGwa1418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumOranimenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium oranimense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumOranimenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsobaculumMelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Isobaculum melis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IsobaculumMelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpTx077308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. TX077308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrancisellaSpTx077308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaMellicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wallemia mellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WallemiaMellicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusThermophilusLmd9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMD9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmd9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifcsplowo201full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4717 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaScoposCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella scopos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaScoposCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumGb30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum GB30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumGb30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusIntestini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusIntestini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisDassonvillei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis dassonvillei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisDassonvillei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGraminisolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides graminisolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGraminisolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasLentaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas lenta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasLentaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_02_FULL_45_10c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo202Full4510cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpLeaf324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaedibacterAcanthamoebaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter acanthamoebae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaedibacterAcanthamoebaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumFossor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium fossor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumFossor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPLOWO2_01_FULL_44_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsplowo201Full4418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumNamnetenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Propionibacterium] namnetense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumNamnetenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GadusMorhuaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gadus morhua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GadusMorhuaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251961sch5331710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251961SCH5331710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251961sch5331710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalostagnicolaSpA56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola sp. A56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaSpA56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAssamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAssamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NegativicoccusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Negativicoccus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NegativicoccusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SanguibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag1295924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:129_59_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1295924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NioellaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nioella nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NioellaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpMf4836Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. MF4836 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMf4836Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmaVolcaniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma volcanium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaVolcaniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSalivarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSalivarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAltamirensisNbrc108246Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia altamirensis NBRC 108246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAltamirensisNbrc108246Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesColeocanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces coleocanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesColeocanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVitaminophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vitaminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVitaminophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminiphilusCircumscriptus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminiphilus circumscriptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminiphilusCircumscriptus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosisCdc317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis CDC317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaParapsilosisCdc317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioLipolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio lipolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioLipolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpTarazonaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Tarazona Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpTarazonaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumGiardiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium giardinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGiardiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaMeningitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria meningitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMeningitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterHoyleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janibacter hoylei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanibacterHoyleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNanopusillusAcidilobiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nanopusillus acidilobi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNanopusillusAcidilobiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaFlorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma florum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaFlorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumCanariasense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium canariasense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCanariasense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp21331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2133.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EgrettaGarzettaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Egretta garzetta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EgrettaGarzettaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumUlcerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumUlcerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioIshigakensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ishigakensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioIshigakensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterStanieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter stanieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterStanieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GryllotalpicolaGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gryllotalpicola ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GryllotalpicolaGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMontanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas montana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMontanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFormosensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas formosensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFormosensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusHominickii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus hominickii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusHominickii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpNe3005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. ne3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpNe3005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosinusCarboxydivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermosinus carboxydivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermosinusCarboxydivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JonquetellaAnthropiDsm22815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi DSM22815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiDsm22815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumAesculapiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium aesculapii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAesculapiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verticillium alfalfae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerticilliumAlfalfaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermanaeromonasToyohensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaccariaAmethystinaLaam081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Laccaria amethystina LaAM-08-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LaccariaAmethystinaLaam081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAc2005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AC2005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAc2005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAtribacteriaBacteriumRbg19ftCombo3514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium RBG_19FT_COMBO_35_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumRbg19ftCombo3514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusHarenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus harenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusHarenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMelonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas melonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMelonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliflexusImshenetskiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkaliflexus imshenetskii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkaliflexusImshenetskiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumLimicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium limicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumLimicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumSpRifrc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. RIFRC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpRifrc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllomycesMacrogynusAtcc38327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus ATCC 38327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AllomycesMacrogynusAtcc38327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BibersteiniaTrehalosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bibersteinia trehalosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BibersteiniaTrehalosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaConceptionensis9403948(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis 9403948 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaConceptionensis9403948", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpPh3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ph3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpPh3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeijerinckiaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaSorghiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puccinia sorghi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PucciniaSorghiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpilithonimonasLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersicobacterSpJzb09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Persicobacter sp. JZB09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PersicobacterSpJzb09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSeosinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia seosinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSeosinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusVanfongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus vanfongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusVanfongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLongwoodensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces longwoodensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLongwoodensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeB728aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae B728a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeB728aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumBarchaimii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium barchaimii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumBarchaimii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUrealyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium urealyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUrealyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBromii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bromii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBromii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23885Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_38_85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23885Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlectobacillusMajorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flectobacillus major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlectobacillusMajorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_12_FULL_47_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho212Full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb1140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB1140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb1140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSpHeli90(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. HelI90 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSpHeli90", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpLeaf139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Leaf139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLeaf139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBrevisX23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis X23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisX23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrimonasCliftonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrimonas cliftonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrimonasCliftonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoritellaViscosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moritella viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoritellaViscosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsphigho202full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL4114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full4414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSpNml063099(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. NML063099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TatumellaSpNml063099", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpSc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. Sc1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpSc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusGattiiVgiiR265Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii VGII R265 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptococcusGattiiVgiiR265Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil736(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil736 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil736", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiCiii1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CIII1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCiii1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaVervactiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea vervacti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaVervactiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxya12full5229Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA12FULL5229 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya12full5229Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusStrMit9303Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. MIT 9303 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrMit9303Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPorcinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porcinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorcinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrcinusOrcaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Orcinus orca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OrcinusOrcaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumOrale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumOrale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 66-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesWedmorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wedmorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWedmorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpBp7605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. Bp7605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpBp7605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYs1r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YS1r graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYs1r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacropusEugeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Macropus eugenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MacropusEugeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumPaucimobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium paucimobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPaucimobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBrhc8a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc8a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc8a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg16437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpCm6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. CM6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpCm6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasCapnocytophagoidesDsm22835(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides DSM 22835 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoidesDsm22835", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClonorchisSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clonorchis sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClonorchisSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaIniectaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia iniecta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaIniectaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylorubrumSalsuginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumSalsuginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTianmuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tianmuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTianmuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaFarcinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia farcinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaFarcinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfocapsaSulfexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfocapsa sulfexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfocapsaSulfexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterFerrugineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter ferrugineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterFerrugineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtelocyanobacteriumThalassaIsolateAloha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atelocyanobacterium thalassa isolate ALOHA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtelocyanobacteriumThalassaIsolateAloha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabisPvPhaseoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis pv. phaseoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCannabisPvPhaseoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHalioticoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio halioticoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioHalioticoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhodospiraHalochloris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorhodospiraHalochloris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpDg25aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplorickettsiaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_47_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThorselliaAnophelisDsm18579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thorsellia anophelis DSM 18579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThorselliaAnophelisDsm18579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag202Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:202 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag202Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSantoriniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter santoriniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSantoriniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClohesyomycesAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clohesyomyces aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClohesyomycesAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusZilligiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus zilligii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusZilligiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB262Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB262Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumSpJkg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. JKG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpJkg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumCelatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium celatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumCelatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSp108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. 108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaSp108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusCaldoxylosilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus caldoxylosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusCaldoxylosilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumRifcsplowo201full4818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO201FULL4818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo201full4818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriFusaro(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Fusaro graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriFusaro", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2439bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2439b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2439bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarsonellaRuddiiCeThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CE Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCeThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaHofmanni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmanni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmanni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedTermiteGroup1BacteriumPhylotypeRsD17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Rs-D17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeRsD17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumSpMarseillep3275Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. MarseilleP3275 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumSpMarseillep3275Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterItalicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterItalicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatimeriaChalumnaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Latimeria chalumnae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LatimeriaChalumnaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH073Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H073 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH073Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterNeptuniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter neptunius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterNeptuniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinibacteriumSpPamc21357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinibacterium sp. PAMC 21357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinibacteriumSpPamc21357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterGuttiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter guttiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGuttiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporomusaAcidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporomusa acidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporomusaAcidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumTodarodisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum todarodis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumTodarodisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpX1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. X1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpX1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpScn5710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SCN 57-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpScn5710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusEthanoliduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus ethanolidurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusEthanoliduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHoaglandellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hoaglandella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHoaglandellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomycesMinteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryomyces minteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryomycesMinteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamwhitmaniaTaraxaci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Williamwhitmania taraxaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WilliamwhitmaniaTaraxaci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQuintana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella quintana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaQuintana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4152b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4152b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4152b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasMexicanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas mexicana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasMexicanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomonasSpFb6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FB-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFb6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioEthanolgignensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetivibrio ethanolgignens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetivibrioEthanolgignensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAap1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriaceaeArchaeon41258Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon 41_258 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeon41258Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg16488Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_48_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg16488Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusKodakarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus kodakarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusKodakarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonquetellaAnthropiE333e1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi E333E1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiE333e1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumChocolatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium chocolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumChocolatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterRoseusDsm17521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter roseus DSM 17521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PontibacterRoseusDsm17521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MnemiopsisLeidyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mnemiopsis leidyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MnemiopsisLeidyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesAcidifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides acidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesAcidifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full5118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_51_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full5118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraAquimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraAquimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaGracilis3211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina gracilis 3/211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitrospinaGracilis3211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSenegalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium senegalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSenegalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesAtroroseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces atroroseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAtroroseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterEuropaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterEuropaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaDiminutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma diminutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaDiminutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEquiSubspZooepidemicusAtcc35246(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus equi subsp. zooepidemicus ATCC 35246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusEquiSubspZooepidemicusAtcc35246", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsphigho201full4522Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4522 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4522Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeomicrobiumSpJcm19037(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM19037 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19037", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesChristyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles christyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesChristyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferSpWsm1721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. WSM1721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpWsm1721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpAp23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. AP23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAp23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiansivirgaZeaxanthinifaciensCcSamt1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens CC-SAMT-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCcSamt1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerothrixDaxensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerothrix daxensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermanaerothrixDaxensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastopirellulaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastopirellula marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastopirellulaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexSeptentrionalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex septentrionalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexSeptentrionalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiemerellaColumbipharyngis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbipharyngis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbipharyngis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesStipitatusAtcc10500(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus ATCC 10500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TalaromycesStipitatusAtcc10500", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAstaxanthinifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas astaxanthinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAstaxanthinifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmaeJ233Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma palmae J233 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaPalmaeJ233Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpNc2002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC2002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc2002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacterialesBacteriumUtchb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteriales bacterium UTCHB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacterialesBacteriumUtchb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelidibacterAlgens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter algens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GelidibacterAlgens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf427Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf427 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf427Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosTaurusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bos taurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BosTaurusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpKk3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. KK3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpKk3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ByssochlamysSpectabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Byssochlamys spectabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ByssochlamysSpectabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaSpHeli12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. HelI12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpHeli12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkaliphilusTransvaalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus transvaalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusTransvaalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumSulfidifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum sulfidifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumSulfidifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaCarbekiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea carbekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaCarbekiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAcidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia acidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAcidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumThermosaccharolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium thermosaccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumThermosaccharolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumOxalicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium oxalicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumOxalicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpPaeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. PAEUM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpPaeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaGuangxiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga guangxiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaGuangxiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasZehnderi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm3535Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_53_5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm3535Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_12_FULL_42_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo212Full4211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpHjm029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HJM029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHjm029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpilithonimonasTenaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas tenax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasTenaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusCurdlanolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus curdlanolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCurdlanolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterSp4d4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter sp. 4D4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FabibacterSp4d4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtribacteriaBacteriumCg2303313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium CG2303313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumCg2303313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaJaponicaGroupCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Group Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaJaponicaGroupCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacimonetesBacteriumScgcAaa252p10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252P10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252p10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag10605727(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060_57_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag10605727", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisIgneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris igneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisIgneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGigeriorumDsm23908Crbip2485Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum DSM 23908 CRBIP 24.85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGigeriorumDsm23908Crbip2485Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_12_FULL_38_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifoxyb1full5412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYB1FULL5412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyb1full5412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaAlniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia alni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaAlniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo212full5210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO212FULL5210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo212full5210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaMultilocaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacaBarguzinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobaca barguzinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacaBarguzinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopumilusTuricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus turicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusTuricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSporothermodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sporothermodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSporothermodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaMensalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella mensalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilliamellaMensalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasSpLeaf427(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf427 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf427", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaAlsaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella alsatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaAlsaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesMelas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles melas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesMelas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCcge510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CCGE510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCcge510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterDuraquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter duraquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterDuraquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTaihuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taihuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaihuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriumSar116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Alphaproteobacterium SAR116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriumSar116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLemurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium lemurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLemurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVeteranaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia veterana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaVeteranaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenophonusTriatominarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus triatominarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusTriatominarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NodosilineaNodulosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nodosilinea nodulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NodosilineaNodulosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliglacieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliglaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliglacieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCapitisSubspCapitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis subsp. capitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCapitisSubspCapitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpM412017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. M41(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpM412017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonadaceaeBacteriumScn6820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium SCN 68-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumScn6820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesantisbacteriaBacteriumCg1023846Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1023846 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1023846Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPhaeoluteigriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces phaeoluteigriseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPhaeoluteigriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnteractinococcusHelveticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enteractinococcus helveticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnteractinococcusHelveticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCetorumMit995656Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT995656 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit995656Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMaddingleyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Maddingley Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMaddingleyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumLymphophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumMesophilicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaMonacensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia monacensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaMonacensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumAzadirachtaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium azadirachtae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAzadirachtaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGuangdongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas guangdongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGuangdongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanidioschyzonMerolae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FulvimarinaManganoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina manganoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaManganoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella porci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPorciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa076p09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaElarraichensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solemya elarraichensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolemyaElarraichensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPiriflorinigransCfbp5888(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans CFBP 5888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigransCfbp5888", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterActinomycetemcomitansHk1651(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans HK1651 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansHk1651", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCaballiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus caballi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCaballiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarvinbryantiaFormatexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marvinbryantia formatexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarvinbryantiaFormatexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaMinutaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenella minuta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMinutaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar324ClusterBacteriumSar324ctd7bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium SAR324CTD7B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumSar324ctd7bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeomargaritaLithophora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeomargaritaLithophora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpSk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. SK-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpSk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaediCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCinaediCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterInsuavis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insuavis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterInsuavis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177NandIi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177/Nand II graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177NandIi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCapricolumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma capricolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCapricolumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophobacterFumaroxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter fumaroxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterFumaroxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterAscidiaceicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter ascidiaceicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAscidiaceicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumBarnesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum barnesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumBarnesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAbietaniphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas abietaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAbietaniphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelusAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Struthio camelus australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StruthioCamelusAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylella taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylellaTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SneathiaAmnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sneathia amnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SneathiaAmnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc7509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC7509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc7509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphacelomaMurrayaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaceloma murrayae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphacelomaMurrayaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumSpLk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasAtrocyaneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas atrocyanea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinomonasAtrocyaneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraVersatilis301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphellophoraEuropaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyphellophora europaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyphellophoraEuropaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterVinelandiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter vinelandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzotobacterVinelandiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalioglobusPacificusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus pacificus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalioglobusPacificusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacebacteriaBacteriumRifoxyd1full3927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFOXYD1FULL3927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifoxyd1full3927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium durum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfTevniaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Tevnia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfTevniaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CottopercaGobioEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cottoperca gobio Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CottopercaGobioEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiaeNem316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae NEM316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeNem316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpHw567Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HW567 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHw567Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus saccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdiutrixIntracellularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adiutrix intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdiutrixIntracellularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabeoRohitaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labeo rohita Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabeoRohitaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumGaetbulicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium gaetbulicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGaetbulicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagirhabdusAlkalitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagirhabdus alkalitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagirhabdusAlkalitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorKristjanssoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor kristjanssonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorKristjanssoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumAlamii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium alamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAlamii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccipiterNisusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accipiter nisus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccipiterNisusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaTaeniospiralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jacksonbacteria bacterium RIFOXYA2_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJacksonbacteriaBacteriumRifoxya2Full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKisonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKisonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltonellaDefensa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hamiltonella defensa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HamiltonellaDefensa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasBeringensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas beringensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasBeringensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBgiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bgi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBgiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusCaroli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mus caroli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusCaroli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAridiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer aridi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferAridiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp6c8div0013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 6C8DIV0013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp6c8div0013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacaceaeArchaeonB1Br10E2g22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon B1-Br10_E2g22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeonB1Br10E2g22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_45_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0381Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0381 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0381Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusSolfataricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus solfataricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfolobusSolfataricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFOXYC2_FULL_35_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifoxyc2Full3525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSwingsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium swingsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSwingsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPanisDsm6035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus panis DSM 6035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPanisDsm6035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSpLeaf369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. Leaf369 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpLeaf369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JonesiaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jonesia denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JonesiaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSomaliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces somaliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSomaliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpCmf222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf 22.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpCmf222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpBp1148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BP1-148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBp1148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor3BacteriumSm2342Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR_3 bacterium SM23_42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionWor3BacteriumSm2342Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaGoodfellowiiDsm19756(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii DSM 19756 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowiiDsm19756", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPhlei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium phlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPhlei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaMalaysiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora malaysiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaMalaysiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag1031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumParaputrificumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium paraputrificum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParaputrificumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraSpPhs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. PHS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpPhs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_61_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumLinensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium linens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumLinensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaAlbertiiTw07627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii TW07627 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiTw07627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp6910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 69-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumCg2305937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG2_30_59_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg2305937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumCaliforniensisDsm19288Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum californiensis DSM 19288 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensisDsm19288Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadalesBacteriumBs08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium BS08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumBs08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaScoposEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella scopos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaScoposEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpongiarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus spongiarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpongiarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaccharosporaIrregularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaOh4807Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida OH4807 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaOh4807Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleMaries(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Maries graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleMaries", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxBoronicumulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax boronicumulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxBoronicumulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumOryziradicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryziradicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryziradicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusFaecimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus faecimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusFaecimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpTunpsc045i4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. TunPSC045I4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpTunpsc045i4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpR372017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. R37(2017) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpR372017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesKatraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces katrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKatraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFh2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinibacterTainanensisDsm15459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis DSM 15459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinibacterTainanensisDsm15459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpDsm25559(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. DSM 25559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpDsm25559", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NegativibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Negativibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NegativibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisSpCib2401Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. CIB 2401 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpCib2401Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumHigginsianumImi349063(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum IMI 349063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianumImi349063", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumCanisCbs113480Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microsporum canis CBS 113480 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrosporumCanisCbs113480Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMegateriumQmB1551Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium QM B1551 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumQmB1551Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaInyonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora inyonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaInyonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArachidicoccusRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGallinarumDsm18171Jcm13658(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum DSM 18171 JCM 13658 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesGallinarumDsm18171Jcm13658", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpAntH11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant H11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpAntH11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSpQh12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. QH-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpQh12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMste9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MSTE9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMste9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansM341Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans M341 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansM341Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaPhenoliruptrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenoliruptrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenoliruptrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpUasws1009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. UASWS1009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUasws1009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_60_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_12_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRedseas39b2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. REDSEAS39B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRedseas39b2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspLactaridiLmg23825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lactaridi LMG 23825 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLactaridiLmg23825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus anginosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAnginosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp88a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 88A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp88a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRac05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. RAC05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRac05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FraserbacteriaBacteriumRbg16559Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fraserbacteria bacterium RBG16559 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FraserbacteriaBacteriumRbg16559Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriNctc12419(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori NCTC12419 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriNctc12419", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFrumentiDsm13145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti DSM 13145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFrumentiDsm13145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaVaferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia vafer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaVaferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusChoshinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus choshinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusChoshinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPolarisDsm16579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas polaris DSM 16579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinomonasPolarisDsm16579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph3623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH 3623 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph3623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensSpongiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpongiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzovibrioRestrictusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azovibrio restrictus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzovibrioRestrictusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaGranularum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma granularum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaGranularum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumGalatii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium galatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumGalatii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraTerpstrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira terpstrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraTerpstrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpNp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. NP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NesterenkoniaSpNp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumAcnesKpa171202(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes KPA171202 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesKpa171202", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharicrinisFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharicrinis fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharicrinisFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumFormicicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium formicicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumFormicicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuritaleaHydrogenivoransSk43h(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans sk43H graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivoransSk43h", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh7803(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7803", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterPectenicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter pectenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterPectenicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGa0077533(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Ga0077533 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGa0077533", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriellaXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriella xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriellaXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaHulunbeirensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSingulareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium singulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSingulareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSalanitronisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salanitronis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalanitronisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CephaloticoccusPrimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus primus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusPrimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShigellaBoydiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shigella boydii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShigellaBoydiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslh70326Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70326 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70326Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRoseochromogenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliosenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliosenegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliosenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23827 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumSp1860Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. 1860 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumSp1860Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSpMar2009124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2009_124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar2009124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaStagnalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia stagnalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaStagnalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumFe2018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium FE2018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumFe2018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSp5139bfaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. 5139BFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusSp5139bfaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu064(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU064 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu064", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpSt04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. ST04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpSt04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEhc04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EhC04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpEhc04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaPopuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niastella populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiastellaPopuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelonobacterOris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelonobacter oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelonobacterOris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho2024316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO2024316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho2024316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapaverSomniferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Papaver somniferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PapaverSomniferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HadesarchaeaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpMits9509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf141(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf141", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpEur3121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. EUR3 1.2.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpEur3121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumMetallireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium metallireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumMetallireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaGoodfellowiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSp5618Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. 56-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSp5618Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStationisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium stationis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStationisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium7064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 70-64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium7064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumUrhe0068Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium URHE0068 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumUrhe0068Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesLianchengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides lianchengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLianchengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpPcc7375Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7375 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7375Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NotamacropusEugeniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Notamacropus eugenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NotamacropusEugeniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifcsplowo212full6140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO212FULL6140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo212full6140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumHydrogeniformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium hydrogeniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumHydrogeniformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1024989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_49_89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1024989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusObesiPh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi ph1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusObesiPh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmantichitinumUrsilacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amantichitinum ursilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmantichitinumUrsilacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiNt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi NT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiNt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrococcusCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterArboriphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibaculumRodentiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibaculum rodentium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibaculumRodentiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusAidingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus aidingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusAidingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterUlvicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter ulvicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterUlvicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FilifactorAlocis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Filifactor alocis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FilifactorAlocis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusMumeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prunus mume Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrunusMumeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr1BacteriumGw2011Gwc14913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return candidate division CPR1 bacterium GW2011_GWC1_49_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1BacteriumGw2011Gwc14913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpSn2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alteromonas sp. SN2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlteromonasSpSn2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesLuti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides luti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesLuti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConchiformibiusSteedaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius steedae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusSteedaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetaceaeBacteriumBa112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetaceae bacterium BA112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycetaceaeBacteriumBa112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumMiliaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Panicum miliaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PanicumMiliaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaLimiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaLimiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharoperbutylacetonicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharoperbutylacetonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharoperbutylacetonicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaSympodialisAtcc42132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Malassezia sympodialis ATCC 42132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MalasseziaSympodialisAtcc42132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusDestructans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfidibacterTakaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusSilvanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus silvanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusSilvanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCibariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCibariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisAlaskensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis alaskensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisAlaskensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCp53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cp53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCp53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofustisGlycolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusAmericanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ursus americanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UrsusAmericanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaSordidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia sordidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaSordidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacticigeniumNaphtaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacticigenium naphtae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacticigeniumNaphtaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNd2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ND2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNd2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlantibacterFlavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter flavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlantibacterFlavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasHaloplanktisTb64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TB64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTb64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMannanilyticusJcm10596(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus JCM 10596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusMannanilyticusJcm10596", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusSzentirmaiiDsm16338Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii DSM 16338 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaiiDsm16338Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaNorimbergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea norimbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaNorimbergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls350(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls350", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuminiphilusSyltensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luminiphilus syltensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuminiphilusSyltensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaAminisulfidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga aminisulfidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaAminisulfidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumCyclohexanicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium cyclohexanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumCyclohexanicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaStewartiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea stewartii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaStewartiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCarsonellaRuddiiHtIsolateThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HT isolate Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHtIsolateThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasCapnocytophagoidesDsm22835Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides DSM 22835 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoidesDsm22835Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolibacterUsitatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solibacter usitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolibacterUsitatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumPacificum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum pacificum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumPacificum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusHarenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus harenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusHarenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag433Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:433 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag433Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusVillorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus villorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusVillorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Candida] auris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaAurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CanisLupusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapioAnubisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Papio anubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PapioAnubisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4748(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4748 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4748", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KuenenbacteriaBacteriumCg2303924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium CG2303924 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumCg2303924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaBurgdorferiB31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi B31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferiB31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraWeiliiSerovarRanarumStrIcftCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira weilii serovar Ranarum str. ICFT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWeiliiSerovarRanarumStrIcftCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematobacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonosporascusSpMg133Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MG133 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg133Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoflexibacterRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoflexibacter ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoflexibacterRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexCornetziEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex cornetzi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexCornetziEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAb2028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AB2028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAb2028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumImmobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmantichitinumUrsilacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amantichitinum ursilacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmantichitinumUrsilacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusHarenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus harenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusHarenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumGa0077523Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077523 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077523Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag272(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:272 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag272", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLpu83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LPU83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpLpu83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseusSubspNoncyanogenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus subsp. noncyanogenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseusSubspNoncyanogenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProtochlamydiaNaegleriophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Protochlamydia naegleriophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusProtochlamydiaNaegleriophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerulinaMusivaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerulina musiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerulinaMusivaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TessaracoccusSpZs01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. ZS01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpZs01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifoxyd1full4714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYD1FULL4714 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyd1full4714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerotruncusSpCag528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasOceanitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas oceanitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasOceanitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpNp3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NP3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpNp3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumElephantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium elephantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumElephantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensFd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens FD1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensFd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAc2005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AC2005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAc2005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasporobacteriumPaucivoransDsm15970Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans DSM 15970 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivoransDsm15970Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZavarzinellaFormosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zavarzinella formosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZavarzinellaFormosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronumThiodismutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiodismutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiodismutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiellaGlossodoripedisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimaricolaCinnabarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola cinnabarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaCinnabarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp155Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 155 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp155Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaSideris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala sideris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaSideris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpPanfs17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PANFS17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPanfs17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHarveyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio harveyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioHarveyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasNumazuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas numazuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasNumazuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TogniniaMinimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Togninia minima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TogniniaMinimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SegniliparusRotundusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rotundus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRotundusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls340(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls340", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag182(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag182", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMucosaeLm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae LM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMucosaeLm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ToxocaraCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Toxocara canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ToxocaraCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaminicellaSporogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caminicella sporogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaminicellaSporogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMycoplasmaHaemominutumBirmingham1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemominutum Birmingham 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemominutumBirmingham1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHyovaginalisDsm12219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus hyovaginalis DSM 12219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusHyovaginalisDsm12219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSpEhc01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia sp. EhC01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSpEhc01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaricaPapayaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Carica papaya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaricaPapayaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlomeribacterGigasporarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glomeribacter gigasporarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlomeribacterGigasporarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRbg165811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_58_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaElongataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mortierella elongata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MortierellaElongataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTransvalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia transvalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaTransvalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraFabianiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera fabianii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraFabianiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungatellaHathewayiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungatella hathewayi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungatellaHathewayiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusFulvusHw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus HW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvusHw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpMd27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. MD27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpMd27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraPilosicoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira pilosicoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraPilosicoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRbg19ftcombo367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RBG19FTCOMBO367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRbg19ftcombo367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSabulinigri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sabulinigri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSabulinigri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterArupensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter arupensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterArupensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLeaf48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraFaineiSerovarHurstbridgeStrBut6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira fainei serovar Hurstbridge str. BUT 6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraFaineiSerovarHurstbridgeStrBut6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobacterSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobacterSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaKingaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kingella kingae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KingellaKingaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSpOk268Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK268 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk268Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwf13135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWF1_31_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwf13135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMelainabacteriaBacterium3541Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium 35_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacterium3541Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterOlleyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter olleyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOlleyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusFlocculiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus flocculiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichococcusFlocculiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacteriaceaeBacteriumEmtcatb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium EMTCatB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumEmtcatb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPorciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusThracensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus thracensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusThracensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMethanolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis methanolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMethanolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium6732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 67-32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSodomenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sodomense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSodomenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenibacterCertesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter certesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenibacterCertesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo2025612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_56_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo2025612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovivaxAsiaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halovivax asiaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalovivaxAsiaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumCg1024134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1024134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1024134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaFaecisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia faecis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaFaecisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolibacillusSilvestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solibacillus silvestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolibacillusSilvestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTerrigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerrigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallosphaeraCuprina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera cuprina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraCuprina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpNzg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. NZG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpNzg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacterium457255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium 457255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacterium457255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaDysenteriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShigellaDysenteriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpKrmcy2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KRMCY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKrmcy2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMaliVarPyri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Valsa mali var. pyri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ValsaMaliVarPyri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHeilongjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus heilongjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHeilongjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxDieselolei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax dieselolei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxDieselolei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata var. bicuspidata NRRL YB-4993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidataVarBicuspidataNrrlYb4993Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConidiobolusCoronatusNrrl28638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus NRRL 28638 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ConidiobolusCoronatusNrrl28638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterNectarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter nectaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterNectarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiWj10621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii WJ10621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiWj10621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 46-16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobacillusMacyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus macyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusMacyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferaxElongansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferax elongans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferaxElongansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCacaonumDsm21116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum DSM 21116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCacaonumDsm21116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LingulaAnatina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lingula anatina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LingulaAnatina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc2796Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC27/96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc2796Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaSpGbrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gbr Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGbrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TannerellaSpOralTaxonHot286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tannerella sp. oral taxon HOT-286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TannerellaSpOralTaxonHot286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpAbgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. ABG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAbgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniomycesSimplexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces simplex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesSimplexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CupriavidusTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpLf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. LF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpLf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophiliaPml168Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia PML168 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaPml168Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferDonghaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer donghaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferDonghaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsellaRubella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capsella rubella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapsellaRubella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusHopiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpDmhc10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DMHC 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDmhc10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomycesDermatitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDysgalactiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAlkalisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer alkalisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferAlkalisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumMalaysiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium malaysiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMalaysiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumPsi07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum PSI07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPsi07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThielaviaTerrestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thielavia terrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThielaviaTerrestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerochaetaPleomorphaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta pleomorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaPleomorphaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusKawachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus kawachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusKawachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisDnf00985Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccalis DNF00985 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccalisDnf00985Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag472(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag472", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf456Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf456 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf456Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSuryakundensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus suryakundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSuryakundensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSuwonensisJ42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_40_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusUliginisN3975Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis N3/975 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusUliginisN3975Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaHaliotisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaHaliotisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAmylolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amylolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmylolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrantaeDsm23927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brantae DSM 23927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrantaeDsm23927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumRubrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumRubrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraMeyeriSerovarHardjoStrWent5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira meyeri serovar Hardjo str. Went 5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraMeyeriSerovarHardjoStrWent5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraSpCag700(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag700", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenovulumMaritimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum maritimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatenovulumMaritimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NicotianaSylvestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana sylvestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NicotianaSylvestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocapsaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpAi1a2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ai1a2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAi1a2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_56_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacterialesBacterium5955(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriales bacterium 59-55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacterialesBacterium5955", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterSenuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter senuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSenuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasKyonanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimonasKyonanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumArizonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium arizonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumArizonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacollinoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracollinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacollinoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacterium13220cm27011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM27011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm27011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumS5a14aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S5A14a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS5a14aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SciscionellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sciscionella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SciscionellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CohnellaPanacarviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CohnellaPanacarviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumPleistoceniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium pleistocenium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumPleistoceniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumDtu079(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU079 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu079", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusSanaruensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sanaruensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSanaruensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumHoustonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium houstonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHoustonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_41_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FonsecaeaPedrosoi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumCg1024390Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1024390 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1024390Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraConfinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara confinis) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraConfinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisDassonvilleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis dassonvillei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisDassonvilleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlkaliphilaYim80379(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila YIM 80379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphilaYim80379", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaUrininfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella urininfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUrininfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRickettsiellaIsopodorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rickettsiella isopodorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRickettsiellaIsopodorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumHumireducensNbrc106098Dsm45392(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens NBRC 106098 DSM 45392 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducensNbrc106098Dsm45392", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronovibrioHydrogenovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio hydrogenovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioHydrogenovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlareaLozoyensisAtcc20868Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glarea lozoyensis ATCC 20868 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlareaLozoyensisAtcc20868Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegniliparusRugosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rugosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRugosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H115 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosphaeraAminiphilaDsm21120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila DSM 21120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphilaDsm21120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycosphaerellaPiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycosphaerella pini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycosphaerellaPiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlligatorMississippiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alligator mississippiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlligatorMississippiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusPiranensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus piranensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusPiranensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerrigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSp108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. 108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaSp108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kurthia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KurthiaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolaminaSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusXiphinematobacterSpIdahoGrapeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xiphinematobacter sp. Idaho Grape Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusXiphinematobacterSpIdahoGrapeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TateyamariaSpAngs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tateyamaria sp. ANGS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TateyamariaSpAngs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumVaccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium vaccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumVaccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenobacterLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenobacterLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumRadiotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium radiotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumRadiotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSeoulensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces seoulensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSeoulensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterNonchromogenicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter nonchromogenicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterNonchromogenicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxWautersiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax wautersii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxWautersiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpAap35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. AAP35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpAap35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiCiii1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CIII1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCiii1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacteralesBacteriumFibro01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacterales bacterium Fibro_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacteralesBacteriumFibro01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpAkyn10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. AKYN10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpAkyn10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpDoa9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DOA9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDoa9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp14822926(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1482292.6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14822926", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyc2full398Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL398 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full398Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumPseudograminearumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusarium pseudograminearum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusariumPseudograminearumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusViolaceofuscusCbs115571Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus CBS 115571 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscusCbs115571Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegaseliaScalarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megaselia scalaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegaseliaScalarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaCruziCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaCruziCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterSpCcs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseobacter sp. CCS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseobacterSpCcs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSp6729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 67-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSp6729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquitaleaMagnusonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquitalea magnusonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquitaleaMagnusonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCf386Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. cf386 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCf386Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaArvensicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga arvensicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaArvensicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSocranskiiVpidr56br1116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii VPIDR56BR1116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiVpidr56br1116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaSpNg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella sp. NG2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilliamellaSpNg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParachlamydiaceaeBacteriumHst3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydiaceae bacterium HST3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaceaeBacteriumHst3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiaeNem316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae NEM316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeNem316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCiat894Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CIAT894 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCiat894Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarginalisIcmp9505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis ICMP 9505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMarginalisIcmp9505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaMacacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella macacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaMacacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterOralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuhomycesTanzawaensisNrrlY17324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis NRRL Y-17324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensisNrrlY17324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpPcc7507Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7507 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7507Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpEpa45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. EPa45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpEpa45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SlackiaExigua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Slackia exigua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SlackiaExigua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusXylosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus xylosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusXylosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumCaspactino2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19035 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusNatl1aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL1A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl1aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSediminumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sediminum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSediminumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpBa92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusHiraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus hirae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusHiraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterBilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRbg134110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RBG_13_41_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRbg134110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OttowiaSpOralTaxon894(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ottowia sp. oral taxon 894 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OttowiaSpOralTaxon894", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumUkl132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium UKL13-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumUkl132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa25110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA25110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa25110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumImcc3088(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium IMCC3088 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumImcc3088", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistetesBacteriumJgi0000079d21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synergistetes bacterium JGI 0000079D21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynergistetesBacteriumJgi0000079d21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicidaNbrc103162Dsm15088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida NBRC 103162 DSM 15088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicidaNbrc103162Dsm15088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YooniaVestfoldensisSka53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis SKA53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisSka53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpRim47(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim47", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprothermobacterProteolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter proteolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterProteolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPhyllosphaeraeFa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas phyllosphaerae FA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPhyllosphaeraeFa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumGw2011gwa2407bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA2407b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa2407bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusYoungiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus youngiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusYoungiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MiscellaneousCrenarchaeota(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeota", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliopsisZonataCbs50665Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata CBS 506.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliopsisZonataCbs50665Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpLeaf131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulgatibacterIncomptus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulgatibacter incomptus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulgatibacterIncomptus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMustelaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mustelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMustelaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocellaConradiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocella conradii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocellaConradiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonnei53gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella sonnei 53G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShigellaSonnei53gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAquaticusDsm21051Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus DSM 21051 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAquaticusDsm21051Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelonoidisAbingdoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelonoidis abingdonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelonoidisAbingdoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMundtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus mundtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMundtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProvidenciaSiddallii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Providencia siddallii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusProvidenciaSiddallii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumAlpha01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Alpha_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumAlpha01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJ14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. J14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpJ14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSpLm3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus sp. LM3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSpLm3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwb1448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWB1448 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwb1448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JidaibacterAcanthamoeba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jidaibacter acanthamoeba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JidaibacterAcanthamoeba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHorneckiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horneckiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHorneckiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachionusPlicatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachionus plicatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachionusPlicatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaInconspicuaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Candida] inconspicua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaInconspicuaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BursaphelenchusXylophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bursaphelenchus xylophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BursaphelenchusXylophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpragueaLophii42110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spraguea lophii 42_110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpragueaLophii42110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat18017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabesiaEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Babesia equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BabesiaEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterJaachiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter jaachi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaachiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBohemicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBohemicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpLeaf307Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Leaf307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpLeaf307Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpKks102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. KKS102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpKks102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalicatenaContortaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena contorta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaContortaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumThermolithotrophumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium thermolithotrophum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumThermolithotrophumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PygoscelisAdeliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pygoscelis adeliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PygoscelisAdeliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaFuscipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glossina fuscipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlossinaFuscipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxOweniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apteryx owenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApteryxOweniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumSpUch001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. UCH001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpUch001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidiaBacteriumSm23282Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoidia bacterium SM23_28_2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidiaBacteriumSm23282Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAdp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ADP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAdp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumCambrienseDsm15806Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DSM15806 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDsm15806Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodothermaceaeBacteriumTcbr11b2g67Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium TcBr11B2g67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumTcbr11b2g67Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puccinia graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PucciniaGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenariaAnguillulaePl171Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Catenaria anguillulae PL171 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CatenariaAnguillulaePl171Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAlkaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alkaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlkaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaHeimbachae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia heimbachae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaHeimbachae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpRoot52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpSma27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. SMA-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpSma27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumJenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumJenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaAgalactiae14628Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae 14628 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiae14628Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPuniciscabieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces puniciscabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPuniciscabieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DictyosteliumDiscoideumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium discoideum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumDiscoideumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNageliiDsm13675Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii DSM 13675 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNageliiDsm13675Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpH103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaOleracea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brassica oleracea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrassicaOleracea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaBombiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaBombiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSanguinisSk49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumTaa166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium TAA166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumTaa166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaDefragransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella defragrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaDefragransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSciuriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sciuri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSciuriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsphigho201full4330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO201FULL4330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho201full4330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RicinusCommunisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ricinus communis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RicinusCommunisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full5028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL5028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full5028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsphigho202full4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPHIGHO202FULL4520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsphigho202full4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaDagmatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaDagmatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlenkiaTaihuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klenkia taihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlenkiaTaihuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusIniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus iniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaBombiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella bombi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaBombiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiveispirillumIrakenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niveispirillum irakense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiveispirillumIrakenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoribacteriaBacteriumWga3g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poribacteria bacterium WGA3G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoribacteriaBacteriumWga3g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot662Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root662 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot662Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt318Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCnt318Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumCanarienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium canariense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumCanarienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusPleuropneumoniae5bL20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 5b L20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae5bL20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpZor0019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. ZOR0019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpZor0019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def QuadrisphaeraSpDsm44207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Quadrisphaera sp. DSM 44207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "QuadrisphaeraSpDsm44207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinopsisMarcescibilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprinopsis marcescibilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprinopsisMarcescibilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaFiliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga filiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaFiliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterPsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter psychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterPsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiSe8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii SE8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiSe8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmataSpShpl17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmata sp. SHPL17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmataSpShpl17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasAustralica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas australica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasAustralica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumAaa252a02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium AAA252A02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumAaa252a02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumWds1c4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium WDS1C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumWds1c4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonsdaleaBritannicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea britannica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaBritannicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuciliaCuprinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lucilia cuprina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuciliaCuprinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarithrixSpCanyon246Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marithrix sp. Canyon 246 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarithrixSpCanyon246Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9302Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9302Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiccationiduransArizonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Siccationidurans arizonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SiccationiduransArizonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremaOrientale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trema orientale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TremaOrientale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLausannensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lausannensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLausannensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaAurantifolia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma aurantifolia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaAurantifolia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCanoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas canoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCanoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkenseKam1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Kam1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkenseKam1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpEjy3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. EJY3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEjy3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesParvulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces parvulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesParvulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KoribacterVersatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Koribacter versatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KoribacterVersatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelosinusFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelosinusFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpBsc265(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. BSC265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpBsc265", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFOXYB1_FULL_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifoxyb1Full4711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumCg1023112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_31_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1023112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSp113p3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. 113P3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSp113p3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeopsychrobacterElectrodiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geopsychrobacter electrodiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeopsychrobacterElectrodiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNageliiDsm13675Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii DSM 13675 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNageliiDsm13675Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNovofumigatusIbt16806Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus IBT 16806 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusNovofumigatusIbt16806Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassomonasActiniarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas actiniarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasActiniarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpAed(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. AED graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpAed", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag798(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:798 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag798", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1999Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1999Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpB1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpB1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpWmmb322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg164923Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_49_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164923Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexithrixDorotheae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flexithrix dorotheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlexithrixDorotheae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaLanguidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Facklamia languida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FacklamiaLanguidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuromusaKysingii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromusa kysingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromusaKysingii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusThailandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus thailandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusThailandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiriformosporaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Piriformospora indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PiriformosporaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusTenaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus tenax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusTenaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeophyllumTrabeumAtcc11539Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum ATCC 11539 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GloeophyllumTrabeumAtcc11539Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumGw2011gwa24413b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA24413b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa24413b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaPalleroniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaPalleroniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0040Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0040Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PararhodobacterSpCcbmm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pararhodobacter sp. CCBMM2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PararhodobacterSpCcbmm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeomicrobiumSpJcm19055Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geomicrobium sp. JCM 19055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeomicrobiumSpJcm19055Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SandarakinorhabdusLimnophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus limnophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusLimnophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MangrovimonasSpSt2l15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaEumusaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora eumusae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaEumusaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonSm150(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SM1-50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSm150", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCimexLectulariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex lectularius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimexLectulariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpFjat14222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. FJAT-14222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpFjat14222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumRubrisubalbicansM1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans M1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicansM1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteimonasAbyssi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteimonasAbyssi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumCamemberti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium camemberti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumCamemberti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaBarthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza barthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaBarthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpSoil748Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil748 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil748Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaEndosymbiontOfAmblyommaAmericanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont of Amblyomma americanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiontOfAmblyommaAmericanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetosporaChiangmaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetospora chiangmaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycetosporaChiangmaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwa24110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWA24110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwa24110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_01_FULL_51_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo201Full5118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo202full5016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO202FULL5016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo202full5016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSpEs052Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sp. ES.052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSpEs052Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaOvisStrMichiganEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovis str. Michigan Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaOvisStrMichiganEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaProfundaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia profunda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaProfundaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaTriticina11BbbdRace1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia triticina 1-1 BBBD Race 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PucciniaTriticina11BbbdRace1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyc2full4228Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL4228 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full4228Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacaseiAtcc334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei ATCC 334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParacaseiAtcc334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaGranuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaistia granuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaistiaGranuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicisCip107643(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis CIP 107643 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicisCip107643", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCl6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CL6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCl6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobiumRoseumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermomicrobium roseum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermomicrobiumRoseumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronovibrioMagnus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio magnus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioMagnus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf469(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf469 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf469", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterPiechaudiiAtcc43553Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii ATCC43553 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiAtcc43553Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TraorellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Traorella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TraorellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasHongkongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas hongkongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasHongkongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumAustralicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium australicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAustralicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusSpTaa43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus sp. TAA 43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSpTaa43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusibacterSp3d3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusibacter sp. 3D3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusibacterSp3d3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeucaenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leucaenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeucaenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus glaucus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusGlaucusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterovibrioNorvegicusDsm15893Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus DSM 15893 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusDsm15893Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho202full4916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL4916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full4916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfBathymodiolus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusReticulitermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus reticulitermitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusReticulitermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisSubspCoryniformisCect5711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis subsp. coryniformis CECT 5711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisSubspCoryniformisCect5711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterKyonggiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kyonggiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKyonggiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPseudintermediusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermediusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallibacteriumScheffleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metallibacterium scheffleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetallibacteriumScheffleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcromyrmexEchinatiorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acromyrmex echinatior Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcromyrmexEchinatiorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo202full4337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO202FULL4337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo202full4337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichormusVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichormus variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichormusVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumCaspalpha2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas mali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaVacuolataZ761(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Z-761 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolataZ761", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaAstilbisJcm15831Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia astilbis JCM 15831 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaiaAstilbisJcm15831Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CulexQuinquefasciatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Culex quinquefasciatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CulexQuinquefasciatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaPanaciterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma panaciterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaPanaciterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucosporidiumCreatinivorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucosporidium creatinivorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucosporidiumCreatinivorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterActinosclerusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter actinosclerus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterActinosclerusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacterium6920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium 69-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacterium6920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesSp992aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes sp. 992a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesSp992aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpCcge1002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasChitiniclasticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas chitiniclastica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasChitiniclasticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SungbacteriaBacteriumRifcsplowo201full6025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL6025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full6025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAobensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia aobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAobensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiaceaeBacteriumKb18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridiaceae bacterium KB18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiaceaeBacteriumKb18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerpetosiphonGeysericolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon geysericola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonGeysericolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacinutrixJangbogonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix jangbogonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixJangbogonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriFusaroEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri Fusaro Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriFusaroEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GulbenkianiaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gulbenkiania indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GulbenkianiaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCoccineaBrfm310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trametes coccinea BRFM310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrametesCoccineaBrfm310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesDaqus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces daqus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesDaqus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifoxyd1full3611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFOXYD1FULL3611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifoxyd1full3611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterFarmeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter farmeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFarmeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumLlx17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium LLX17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumLlx17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlivibacterSitiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olivibacter sitiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlivibacterSitiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiMethylbutyraticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei methylbutyratica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiMethylbutyraticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusPseudintermediusHku1003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius HKU10-03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermediusHku1003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpBv3p1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BV3P1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBv3p1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTriplexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium triplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTriplexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaAmbifariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ambifaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAmbifariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Struthio camelus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StruthioCamelusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusVariansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus varians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusVariansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulciaMuelleriGwss(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri GWSS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriGwss", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedOscillibacterSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Oscillibacter sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedOscillibacterSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaPealeanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella pealeana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPealeanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPLOWO2_01_FULL_48_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLeaf127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinimicrobiumTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProtegensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAngstadtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium angstadtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAngstadtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13817 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumJgi0000039d08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium JGI 0000039D08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumJgi0000039d08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkaliphilusOremlandiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus oremlandii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusOremlandiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKururiensisM130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis M130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensisM130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAbscessus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAbscessus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDelicatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter delicatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDelicatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFonticolaRb25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola RB25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaRb25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1468(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1468", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria mucosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMucosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusClavatusNrrl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus NRRL 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusClavatusNrrl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMicansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella micans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMicansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpSfdEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFD Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfdEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioMagneticusRs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus RS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusRs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSubsaxonicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium subsaxonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSubsaxonicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxBorkumensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax borkumensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxBorkumensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButtiauxellaAgrestis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella agrestis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaAgrestis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatisLmg20103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis LMG20103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisLmg20103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumSpTh20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium sp. TH-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumSpTh20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcticibacterSvalbardensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter svalbardensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterSvalbardensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanizomenonFlosAquaeUkl13Pb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aphanizomenon flos-aquae UKL13-PB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AphanizomenonFlosAquaeUkl13Pb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemobosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemobos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemobosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24387Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24387 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24387Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag776(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:776 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag776", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Henriciella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HenriciellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronovibrioMagnusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio magnus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioMagnusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesOctosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces octosporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesOctosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtelocyanobacteriumThalassaSio64986Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa SIO64986 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaSio64986Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidophilus30scEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus 30SC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilus30scEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidisEr3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis ER-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlastomycesDermatitidisEr3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpisthorchisFelineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis felineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisFelineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraCrunogena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira crunogena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraCrunogena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCaribbeanicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio caribbeanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioCaribbeanicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSaguiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter saguini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSaguiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAgglomeransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea agglomerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaAgglomeransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioNeptunius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio neptunius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioNeptunius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegilopsTauschiiSubspStrangulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii subsp. strangulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AegilopsTauschiiSubspStrangulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSp9096(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. 9096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSp9096", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterAnophelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter anophelis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterAnophelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpAp50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisUzonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis uzonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisUzonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmaAcidophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma acidophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaAcidophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBouvetiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bouvetii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBouvetiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarinimicrobiaBacteriumCg1024814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marinimicrobia bacterium CG1_02_48_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarinimicrobiaBacteriumCg1024814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibularhizoctoniaSpCbs109695Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibularhizoctonia sp. CBS 109695 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibularhizoctoniaSpCbs109695Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumUrocaniciphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium urocaniciphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUrocaniciphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSka58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SKA58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSka58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParapedobacterKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpDfci1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DFCI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDfci1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaSiddalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia siddallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaSiddalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRbg134613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG134613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg134613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollichthysLucidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collichthys lucidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollichthysLucidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonSmtz145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon SMTZ1-45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonSmtz145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_12_FULL_44_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo212Full4413bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumRifoxya2full4310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFOXYA2FULL4310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifoxya2full4310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloglycomycesAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloglycomyces albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloglycomycesAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumGa0077528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium Ga0077528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumGa0077528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwd23259Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23259Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpL74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. L74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpL74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtheneCuniculariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Athene cunicularia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtheneCuniculariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumHtcc2143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumArsenaticumDsm13514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum DSM 13514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticumDsm13514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannospalaxGalili(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nannospalax galili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NannospalaxGalili", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHamsteriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hamsteri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHamsteriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalanaerobiumPraevalensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium praevalens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumPraevalensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSpCamponotileonardiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotileonardi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotileonardiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptothrixCholodnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptothrix cholodnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptothrixCholodnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscoideaRubescensDsm1968Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ascoidea rubescens DSM 1968 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AscoideaRubescensDsm1968Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanohaloarchaeaArchaeonB1br10u2g1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumTimonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VaribaculumTimonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterEnzymogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter enzymogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterEnzymogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorselliaAnophelisDsm18579Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thorsellia anophelis DSM 18579 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThorselliaAnophelisDsm18579Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumOculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium oculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfTevniaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Tevnia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfTevniaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpCf8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. CF8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpCf8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosarchaeumLimniumSfb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosarchaeum limnium SFB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosarchaeumLimniumSfb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterGlacialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter glacialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterGlacialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterFarmeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter farmeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFarmeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE2733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusFermentansJbw45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans JBW45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PelosinusFermentansJbw45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifoxyc2Full479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYC2_FULL_47_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyc2Full479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGwa1418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GWA1_41_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGwa1418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioHalophilusDsm15072Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus DSM 15072 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilusDsm15072Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumAsp1005aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium ASP10-05a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumAsp1005aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpLm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. LM2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpLm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolosigranulumPigrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dolosigranulum pigrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DolosigranulumPigrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7Edl933(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 EDL933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Edl933", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterSpDg15cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG15C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg15cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumArthrosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arthrosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArthrosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusMorrhuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus morrhuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusMorrhuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenatarsenatisSf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis SF-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatisSf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRbg164224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG164224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg164224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full3615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3615 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3808Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3808 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3808Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4152bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4152b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4152bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaBirminghamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella birminghamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaBirminghamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpEs010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. ES.010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpEs010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmillariaOstoyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armillaria ostoyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmillariaOstoyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusHippeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusHippeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFOXYA1_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusChliarophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus chliarophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusChliarophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpPnj185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. PNJ185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpPnj185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMucilaginosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiAtcc11842(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii ATCC11842 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiAtcc11842", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium2146faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 2146FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium2146faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpElb17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ELB17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpElb17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpHgf2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. HGF2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpHgf2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAndreraoultiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus andreraoultii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAndreraoultiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpLeaf51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. Leaf51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpLeaf51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsphigho201full5728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPHIGHO201FULL5728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsphigho201full5728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimazuellaKribbensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimazuella kribbensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimazuellaKribbensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOdinarchaeotaArchaeonLcb4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Odinarchaeota archaeon LCB_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOdinarchaeotaArchaeonLcb4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesCiferriiNrrlY1031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii NRRL Y-1031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesCiferriiNrrlY1031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRoot180(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root180 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot180", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpCl154(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. CL154 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpCl154", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpNio1057(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. NIO-1057 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpNio1057", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfurimonasDismutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfurimonas dismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosulfurimonasDismutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpA2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpA2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg164411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_44_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus elongatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusElongatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquifexAeolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquifex aeolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquifexAeolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusDucreyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus ducreyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusDucreyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaScoriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola scoriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaScoriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanobisporaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planobispora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanobisporaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacillusSpCag826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus sp. CAG:826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusSpCag826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilis7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera versatilis 7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraVersatilis7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGsub(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Gsub graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGsub", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRubidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rubida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRubidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoniliophthoraPerniciosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamazzottiusVarieornatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ramazzottius varieornatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RamazzottiusVarieornatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasStagniDsm19981Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Roseomonas stagni DSM 19981 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RoseomonasStagniDsm19981Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaSimulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaSimulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimimaricolaPyoseonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola pyoseonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaPyoseonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasGudaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas gudaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasGudaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumInterjectum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium interjectum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumInterjectum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAgarilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaBlandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella blandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaBlandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasPantelleriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas pantelleriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasPantelleriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaBovineCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica BOVINE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaBovineCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PowellomycesHirtusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Powellomyces hirtus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PowellomycesHirtusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaOxidasicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina oxidasica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaOxidasicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WenxiniaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WenxiniaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSpJdfr02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. JdFR-02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpJdfr02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusMahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusMahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpWcd2001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd2001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacterSpAm169(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccharibacter sp. AM169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccharibacterSpAm169", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeauveriaBassiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BeauveriaBassiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaSpJchs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta sp. JCHS_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaSpJchs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilibacterAurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter aurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabilibacterAurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp172e8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 172E8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp172e8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOrs278Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ORS278 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOrs278Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTaa204Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA204 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa204Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPasteuri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pasteuri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPasteuri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacteriumRaap1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium RAAP-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumRaap1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpMb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. MB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusThailandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halococcus thailandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalococcusThailandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FranconibacterPulverisDsm19144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter pulveris DSM 19144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FranconibacterPulverisDsm19144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerpetosiphonGeysericolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon geysericola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonGeysericolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasFlueggeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas flueggei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasFlueggeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSp2b12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. 2B12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DickeyaSp2b12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinivibrioAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinivibrio alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinivibrioAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSp9135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermaerobacterSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacteriumCg2305140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium CG2_30_51_40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumCg2305140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasJinjuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas jinjuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJinjuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia speluncae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpeluncaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMelliventris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus melliventris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMelliventris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovoraNrrlY12698Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Babjeviella inositovora NRRL Y-12698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BabjeviellaInositovoraNrrlY12698Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpYr096Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. yr096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpYr096Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonB1br10e2g2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon B1Br10E2g2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonB1br10e2g2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteigerwaltiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella steigerwaltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteigerwaltiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaSpUrhb0036(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. URHB0036 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpUrhb0036", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251971sch5477799aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251971SCH5477799a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251971sch5477799aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OerskoviaTurbataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia turbata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OerskoviaTurbataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_37_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesSpJdfr54Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr54Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsphigho202full4916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL4916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full4916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerracidiphilusGabretensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terracidiphilus gabretensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerracidiphilusGabretensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70357Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70357 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70357Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus septemdierum str. Myojin knoll Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpAkyn10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. AKYN10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpAkyn10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpCcbus3uf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. CCBUS3UF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusSpCcbus3uf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterChlorophenolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter chlorophenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterChlorophenolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSpizizenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis spizizenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisSpizizenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudocatenulatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudocatenulatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudocatenulatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsoniaIntracellularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lawsonia intracellularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LawsoniaIntracellularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSp119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. 1.19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSp119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloranaerobacterAzorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscobolusImmersusRn42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ascobolus immersus RN42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AscobolusImmersusRn42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CenarchaeumSymbiosumAEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosumAEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB12_FULL_58_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfiporiaCocos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfiporia cocos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfiporiaCocos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylella taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylellaTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PestalotiopsisFiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PestalotiopsisFiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesDavaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces davaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDavaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpMb263Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. MB263 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpMb263Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArhodomonasAquaeoleiDsm8974Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei DSM 8974 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArhodomonasAquaeoleiDsm8974Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DethiosulfatibacterAminovoransDsm17477Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans DSM 17477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovoransDsm17477Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumGondwanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium gondwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumGondwanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnithobacteriumRhinotrachealeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithobacterium rhinotracheale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithobacteriumRhinotrachealeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LaodelphaxStriatellus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Laodelphax striatellus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LaodelphaxStriatellus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropithecusCoquereli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propithecus coquereli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropithecusCoquereli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GonapodyaProliferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gonapodya prolifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GonapodyaProliferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPerorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus peroris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPerorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumFreudenreichiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium freudenreichii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumFreudenreichiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpLw3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSiccaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sicca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSiccaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSoliNbrc100801Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas soli NBRC 100801 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSoliNbrc100801Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermaniaPiniformisNbrc15059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Skermania piniformis NBRC 15059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SkermaniaPiniformisNbrc15059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeromyscusManiculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasEutrophaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas eutropha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEutrophaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OerskoviaEnterophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia enterophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OerskoviaEnterophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusViniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusViniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Streptomyces albus albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "StreptomycesAlbusAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRectaleAtcc33656Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Eubacterium] rectale ATCC 33656 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumRectaleAtcc33656Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWA2_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwa24310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm47Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpIcm47Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronincolaFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronincola ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronincolaFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioSpJcm19048Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio sp. JCM 19048 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioSpJcm19048Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_39_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAkagiiDsm12554Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium akagii DSM 12554 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAkagiiDsm12554Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpUrha0019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. URHA0019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpUrha0019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpBgarf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BGARF1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBgarf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNodosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces nodosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNodosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomosp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_42_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaGrimesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia grimesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaGrimesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFluviicolaRiflensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fluviicola riflensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFluviicolaRiflensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopogonVesiculosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopogon vesiculosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopogonVesiculosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SideroxydansSpGwf25914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans sp. GWF2_59_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SideroxydansSpGwf25914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutusTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opitutus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpitutusTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraButanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera butanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraButanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsplowo212full5310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LingulaAnatinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lingula anatina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LingulaAnatinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BipolarisOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortnoybacteriaBacteriumRbg13408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_13_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg13408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumSchaaliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum schaalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumSchaaliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasMacacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas macacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasMacacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_44_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc24417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYeochonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yeochonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYeochonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaJaponicaA8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyella japonica A8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyellaJaponicaA8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HylemonellaGracilisAtcc19624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis ATCC19624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisAtcc19624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaBronchisepticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bordetella bronchiseptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BordetellaBronchisepticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumArgentinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium argentinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArgentinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasAsaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas asaccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasAsaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaXylanovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesMelasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles melas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesMelasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesBacteriumScgcAaa011l6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011L6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011l6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterAcanthamoebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaedibacterAcanthamoebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesJaponicusYfs275Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus yFS275 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicusYfs275Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodosinusMongolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodosinus mongolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodosinusMongolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full4317bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL4317b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full4317bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumAo1c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium AO1C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumAo1c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMiluonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium miluonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMiluonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisCinereaBcdw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea BcDW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaBcdw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusSb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus SB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusSb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasGudaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas gudaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasGudaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RozellaAllomycisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rozella allomycis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RozellaAllomycisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacterium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaVirensGv298Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma virens Gv29-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaVirensGv298Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusManliponensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus manliponensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusManliponensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusSp6rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus sp. 6R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSp6rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSputiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sputi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GordoniaSputiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcremoniumChrysogenumAtcc11550Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum ATCC 11550 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcremoniumChrysogenumAtcc11550Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFurukawaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas furukawaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFurukawaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaSpKh3b4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. KH3B4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpKh3b4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraWolffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialocephalaSubalpinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala subalpina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaSubalpinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobrachiumCelereEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermobrachium celere Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermobrachiumCelereEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioHalioticoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio halioticoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioHalioticoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusThermoamylovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus thermoamylovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusThermoamylovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumKuznetsovii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum kuznetsovii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumKuznetsovii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeminorellaGrimontii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leminorella grimontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeminorellaGrimontii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WirthbacteriaBacteriumCg2305411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wirthbacteria bacterium CG2305411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WirthbacteriaBacteriumCg2305411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_12_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYB1_FULL_43_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyb1Full4319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonsdaleaQuercinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea quercina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaQuercinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacinutrixSpPamc27137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lacinutrix sp. PAMC27137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LacinutrixSpPamc27137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EctothiorhodosinusMongolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodosinus mongolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodosinusMongolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriDmel1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Dmel1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDmel1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlleyaSpVcsm12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Olleya sp. VCSM12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OlleyaSpVcsm12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumAcidaminophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium acidaminophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumAcidaminophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSpSa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. SA_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpSa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureococcusAnophagefferens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aureococcus anophagefferens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AureococcusAnophagefferens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaryophanonTenue(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caryophanon tenue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaryophanonTenue", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaConspicuaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea conspicua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaConspicuaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisAtcc14393Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ATCC14393 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAtcc14393Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumAe2021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AE2021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAe2021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSilageiJcm19001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus silagei JCM 19001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSilageiJcm19001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumCg10244142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG1_02_44_142 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg10244142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaArabinofermentansNrrlYb2248Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] arabinofermentans NRRL YB-2248 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaArabinofermentansNrrlYb2248Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HeliocybeSulcataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heliocybe sulcata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeliocybeSulcataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeuconostocCitreum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc citreum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCitreum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraCyclica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira cyclica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraCyclica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumisMeloVarMakuwa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo var. makuwa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CucumisMeloVarMakuwa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumZagget2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TypeBSymbiontOfPlautiaStaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Type-B symbiont of Plautia stali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TypeBSymbiontOfPlautiaStaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpPp1y(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. PP1Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpPp1y", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusAmylolentusCbs6039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus CBS 6039 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptococcusAmylolentusCbs6039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusStrTiberius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus str. Tiberius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusStrTiberius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortieraAleyrodidarumBtbhrsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum BTBHRs Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumBtbhrsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpRoot930Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root930 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot930Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpEpsl25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. EpSL25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEpsl25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalothermothrixSpDtu029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix sp. DTU029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixSpDtu029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElectrophorusElectricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Electrophorus electricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElectrophorusElectricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwc25713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWC2_57_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwc25713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaKunkeliiCr23xEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii CR2-3x Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaKunkeliiCr23xEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaQuateirensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella quateirensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaQuateirensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHeli29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. HelI29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GillisiaSpHeli29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpAw25m09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. AW25M09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpAw25m09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassilibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpTne862(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. TNe-862 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpTne862", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumJaponicumUsda124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCurvus52592Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter curvus 525.92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterCurvus52592Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFermentumIfo3956(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum IFO3956 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFermentumIfo3956", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFuscovaginaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fuscovaginae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFuscovaginaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterHartoniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter hartonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterHartoniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusHorikoshiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horikoshii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHorikoshiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium6411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 64-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium6411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanidioschyzonMerolaeStrain10dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae strain 10D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolaeStrain10dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CharaBrauniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chara braunii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CharaBrauniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaSoliDsm19436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kaistia soli DSM 19436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KaistiaSoliDsm19436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:161 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaeTomato(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tomato graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTomato", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExserohilumTurcicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exserohilum turcica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExserohilumTurcicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlwc3742Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3742 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3742Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmoSalarEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmo salar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmoSalarEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumOtsza272Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium OTSzA272 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumOtsza272Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCimexLectulariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex lectularius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimexLectulariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipheNecatorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysiphe necator Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipheNecatorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasXanthomarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xanthomarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXanthomarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusMarinaDsm22363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina DSM 22363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingorhabdusMarinaDsm22363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubinisphaeraBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubinisphaera brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubinisphaeraBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeobacteroidesBs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides BS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesBs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusStomatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus stomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusStomatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPHIGHO2_01_FULL_48_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaAlbicansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida albicans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaAlbicansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSp2319x1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 2319x1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp2319x1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpErg5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. ERG5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpErg5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuriculariaDelicata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Auricularia delicata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AuriculariaDelicata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyronemaOmphalodesCbs100304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyronema omphalodes CBS 100304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyronemaOmphalodesCbs100304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaPneumoniaeM129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae M129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeM129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4152bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4152b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4152bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumGw2011gwb24517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB24517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb24517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSomeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas somerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSomeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma marginale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaUniformisNbrc13702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia uniformis NBRC 13702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaUniformisNbrc13702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOlivochromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olivochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlivochromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpMa067296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. MA067296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpMa067296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaviibacterAbscessus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caviibacter abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaviibacterAbscessus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumAap99Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap99Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerBermudensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipiger bermudensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipigerBermudensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiCft073Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli CFT073 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiCft073Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraYellowstonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera yellowstonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraYellowstonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoniaPhycicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesonia phycicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoniaPhycicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisGlossinidius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sodalis glossinidius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SodalisGlossinidius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumMedicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium medicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMedicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_60_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpCcgela001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCGELA001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCcgela001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesCryophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosilyticumSpI15g10i2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum sp. I15G10I2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumSpI15g10i2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonInterdigitaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichophytonInterdigitaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronobacteriumTexcoconenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium texcoconense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumTexcoconenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitromicrobiumSpJlt1363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JLT1363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJlt1363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaCoronata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capronia coronata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaproniaCoronata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOv322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OV322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOv322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaVarigenaUsmarc1261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena USMARC1261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsmarc1261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBorgpeterseniiSerovarPomonaStr200901868Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Pomona str. 200901868 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarPomonaStr200901868Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_51_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumCg1024331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG1_02_43_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg1024331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaBrachyanthaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza brachyantha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaBrachyanthaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumNorvegicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium norvegicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumNorvegicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacteriumSm2381Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm2381Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusBourgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusBourgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpC04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. C04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpC04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixInsectorumRcef264Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix insectorum RCEF 264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporothrixInsectorumRcef264Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormivibrioCitricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formivibrio citricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormivibrioCitricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomicrococcusAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neomicrococcus aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeomicrococcusAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnchocercaVolvulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca volvulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OnchocercaVolvulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTerrigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerrigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasUenonisDsm23387Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinidiaChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinidia chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinidiaChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterAminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminobacterAminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpOv641Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OV641 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOv641Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumNodosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium nodosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumNodosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpHysEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. HYS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpHysEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodococcusDrewsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodococcus drewsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiorhodococcusDrewsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumSpAccc05744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ACCC05744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpAccc05744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricicoccusPullicaecorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyricicoccus pullicaecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyricicoccusPullicaecorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpNbimcp2c3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. NBIMCP2C3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpNbimcp2c3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpHgh0039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HGH0039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHgh0039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonB261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesRadicidentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces radicidentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesRadicidentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LodderomycesElongisporusNrrlYb4239Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus NRRL YB-4239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LodderomycesElongisporusNrrlYb4239Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterRhaeticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter rhaeticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterRhaeticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4520Fw2644Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4520 (FW-2644) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4520Fw2644Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpRifrc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. RIFRC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpRifrc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSydowiiCbs59365Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sydowii CBS 593.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusSydowiiCbs59365Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp651059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexZeteki(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex zeteki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexZeteki", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinophytocolaXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg135723Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_13_57_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg135723Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraChibensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura chibensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraChibensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinocyclocheilusAnshuiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus anshuiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusAnshuiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCrispatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crispatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrispatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusWentiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus wentii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusWentiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAmylolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp7136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 71-36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRoot140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHemicellulosilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus hemicellulosilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHemicellulosilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:115 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermofilumSp1910bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum sp. 1910b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermofilumSp1910bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpMccc1a02491Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A02491 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a02491Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuisEa183292Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis EA183292 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuisEa183292Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumAerophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum aerophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumAerophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwe23937Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE23937 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe23937Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGsubEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Gsub Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGsubEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsphigho201full4522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGinsengihumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ginsengihumi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGinsengihumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusSpCo6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus sp. CO-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusSpCo6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpHm582Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. HM58-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpHm582Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YooniaVestfoldensisDsm16212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis DSM 16212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisDsm16212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaDumasiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dumasiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDumasiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg164411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_44_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterHormaecheiSubspXiangfangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. xiangfangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspXiangfangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynergistalesBacterium5424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synergistales bacterium 54_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynergistalesBacterium5424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FictibacillusArsenicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus arsenicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FictibacillusArsenicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedTermiteGroup1BacteriumPhylotypeRsD17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Rs-D17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeRsD17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumGwa1448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium GWA1_44_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumGwa1448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAurimucosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium aurimucosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAurimucosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RathayibacterToxicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter toxicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RathayibacterToxicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDecumbens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium decumbens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDecumbens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium6313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 63-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PisolithusTinctorius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pisolithus tinctorius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PisolithusTinctorius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasKyonanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerrimonasKyonanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrivivaxSpScn71131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax sp. SCN 71-131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxSpScn71131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocapsaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusBadius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus badius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusBadius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemolamaeStrPurdueEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemolamae str. Purdue Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemolamaeStrPurdueEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSp99Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. 99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSp99Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumCb782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum CB782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumCb782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalneatrixAlpicaDsm16621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Balneatrix alpica DSM 16621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BalneatrixAlpicaDsm16621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpLeaf26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Leaf26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpLeaf26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EchinococcusGranulosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus granulosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EchinococcusGranulosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterVibrioidesOr37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides OR37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesOr37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseicitreumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseicitreum antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseicitreumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumDecipiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium decipiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumDecipiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifoxyb2full327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYB2FULL327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxyb2full327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCaseiBl23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei BL23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiBl23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumRifoxyb1full3315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium RIFOXYB1FULL3315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumRifoxyb1full3315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplorickettsiaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf151Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf151 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf151Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterRhizovicinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferAdhaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferAdhaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharimonasAalborgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharimonas aalborgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharimonasAalborgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRbg13469Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RBG_13_46_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRbg13469Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeocapsaSpPcc7428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC7428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc7428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusGordoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus gordonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusGordoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspHoutenaeStrAtccBaa1581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. houtenae str. ATCC BAA-1581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspHoutenaeStrAtccBaa1581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasCryotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas cryotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCryotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorangiumCellulosumSo01572Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So01572 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSo01572Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonauticusSpA7aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. A7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSpA7aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUmwwy(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWWY graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwwy", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSph1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSpL2l1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. L2L1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpL2l1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwa14311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA14311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa14311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoalloteichusHymeniacidonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus hymeniacidonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusHymeniacidonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSlackiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces slackii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSlackiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumGw2011gwa14429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA14429 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa14429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho201full3637Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO201FULL3637 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho201full3637Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CentipedaPeriodontiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Centipeda periodontii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CentipedaPeriodontiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaMeridionalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza meridionalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaMeridionalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HumibacillusSpDsm29435Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Humibacillus sp. DSM 29435 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HumibacillusSpDsm29435Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCynos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma cynos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCynos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaCaroliniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia caroliniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaCaroliniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DichloromethanomonasElyunquensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dichloromethanomonas elyunquensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DichloromethanomonasElyunquensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCincinnatiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioCincinnatiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumSubglacialeExf2481(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale EXF-2481 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AureobasidiumSubglacialeExf2481", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumUlceransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium ulcerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumUlceransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpYr247Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. yr247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpYr247Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg166432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLactaridi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lactaridi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLactaridi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumCuenotiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium cuenoti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumCuenotiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DinoroseobacterShibaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dinoroseobacter shibae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DinoroseobacterShibaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusGilardii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusGilardii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeHs11286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae HS11286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeHs11286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuribaculumIntestinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muribaculum intestinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuribaculumIntestinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasOryzaePxo99aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae PXO99A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePxo99aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpYr412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. YR412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpYr412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNageliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nagelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNageliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCamelliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCamelliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisSk564(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK564 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk564", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumOxidotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium oxidotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumOxidotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaEnoecaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella enoeca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaEnoecaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumPsychroaquaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium psychroaquaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPsychroaquaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiritimatiellaGlycovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kiritimatiella glycovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KiritimatiellaGlycovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHdn1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HdN1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHdn1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCorcagiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter corcagiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCorcagiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegilopsTauschiiSubspStrangulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aegilops tauschii subsp. strangulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AegilopsTauschiiSubspStrangulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh3588(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH3588 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh3588", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaAtcc43541Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia ATCC43541 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaAtcc43541Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacebacteriaBacteriumCg1024331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG1_02_43_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg1024331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpJs42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JS42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJs42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanis209318(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis 209318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanis209318", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLitorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium litorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumLitorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelativoransSpBnc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. BNC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpBnc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHimb55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpKmsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KMS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKmsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThelaziaCallipaedaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thelazia callipaeda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThelaziaCallipaedaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumRifcsphigho212full4012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO212FULL4012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho212full4012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesPombe972h(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe 972h- graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombe972h", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumRadiotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumRadiotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRoseburiaSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Roseburia sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedRoseburiaSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls646Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS646 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls646Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisH5384Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis H538.4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisH5384Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMacedonicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macedonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMacedonicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaOdoriferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia odorifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaOdoriferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltibacterLentus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altibacter lentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltibacterLentus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSp1501(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. 1501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSp1501", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacrostomumLignanoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macrostomum lignano Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacrostomumLignanoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaProteobacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return zeta proteobacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaProteobacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSpMgh106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sp. MGH106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSpMgh106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwd23614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWD23614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwd23614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriovoraxSpBsw11ivCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BSW11IV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBsw11ivCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumOrchidophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orchidophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrchidophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecatorAmericanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Necator americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NecatorAmericanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermaniaPiniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Skermania piniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SkermaniaPiniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumTanacetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tanaceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTanacetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasTaeanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas taeanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasTaeanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAd3010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AD3010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAd3010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaMoutnovskia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta moutnovskia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaMoutnovskia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalotaleaAlkalilentaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halotalea alkalilenta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalotaleaAlkalilentaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaGamsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma gamsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaGamsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaDoshiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella doshiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaDoshiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansDsm12475(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans DSM12475 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansDsm12475", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcetothermiaBacteriumJdfr52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialocephalaScopiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala scopiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaScopiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesFlavidovirensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavidovirens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavidovirensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusCarbonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus carbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusCarbonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcobacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helcobacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelcobacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27245(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27245", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7425(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7425 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7425", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 36_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TumebacillusFlagellatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tumebacillus flagellatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TumebacillusFlagellatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumOlb10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobialesBacteriumClorobi01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobiales bacterium Clorobi_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobialesBacteriumClorobi01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeodactylibacterXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylibacter xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylibacterXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaQuasipneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella quasipneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaQuasipneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaElarraichensisGillSymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Solemya elarraichensis gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SolemyaElarraichensisGillSymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminobacterAmylophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminobacter amylophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminobacterAmylophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpC9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. C9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpC9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodonellumIkkaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodonellum ikkaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodonellumIkkaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TakifuguRubripesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Takifugu rubripes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TakifuguRubripesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaVirensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma virens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaVirensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedimonasVaricaedens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caedimonas varicaedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaedimonasVaricaedens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerofustisStercorihominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerofustis stercorihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerofustisStercorihominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperaRadiovictrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Truepera radiovictrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrueperaRadiovictrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag462Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:462 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag462Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioVulgarisHildenboroughCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Hildenborough Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisHildenboroughCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpPamc26642(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. PAMC 26642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpPamc26642", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusMetallicusDsm6482Jcm9184Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus DSM 6482 JCM 9184 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfolobusMetallicusDsm6482Jcm9184Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumMagneticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNku1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. NkU-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNku1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpOralTaxon920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas sp. oral taxon 920 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasSpOralTaxon920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpS6spd3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S6Spd3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS6spd3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KtedonobacterSp13120cm45311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ktedonobacter sp. 13_1_20CM_4_53_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KtedonobacterSp13120cm45311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetitomaculumRuminisDsm5522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetitomaculum ruminis DSM 5522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetitomaculumRuminisDsm5522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpA39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. A39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpA39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaMurrelliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella murrelli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaMurrelliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraPerniciosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpB13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. b13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpB13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixFlexilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix flexilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiothrixFlexilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemobosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemobos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemobosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusPastorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus pastoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusPastorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumPseudograminearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium pseudograminearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumPseudograminearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NumidumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Numidum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NumidumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraCarrionii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora carrionii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraCarrionii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckii2038Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii 2038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckii2038Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumKbs96(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs96", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NoviherbaspirillumAutotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Noviherbaspirillum autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NoviherbaspirillumAutotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGw2011gwb1499Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB1499 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb1499Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumChkci002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium CHKCI002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumChkci002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpUw4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. UW4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUw4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterSpLeaf3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter sp. Leaf3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SanguibacterSpLeaf3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensSk114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens SK114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensSk114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminispirochaetaSmaragdinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminispirochaeta smaragdinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminispirochaetaSmaragdinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeF0167(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae F0167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeF0167", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifcsplowo201Full4925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibaculumBaratangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutibaculum baratangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutibaculumBaratangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZunongwangiaMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloquadratumWalsbyiDsm16790Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi DSM16790 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiDsm16790Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrotaleaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrotalea flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrotaleaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumRbg19ftcombo3514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium RBG19FTCOMBO3514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumRbg19ftcombo3514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSpA28l(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. A28L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpA28l", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenococcusSpPcc7305Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenococcus sp. PCC7305 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenococcusSpPcc7305Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrybacteriaBacteriumRifcsplowo201full4424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO201FULL4424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo201full4424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSakeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sakei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSakeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarthrobacterSulfonivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter sulfonivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSulfonivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusVillorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus villorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusVillorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusAcidocaldariusDsm446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius DSM446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusDsm446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchleiferiaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schleiferia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchleiferiaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgassiziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agassizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgassiziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNasuiaDeltocephalinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nasuia deltocephalinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNasuiaDeltocephalinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit055293(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 05-5293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit055293", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_56_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb241528n17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_528N17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241528n17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCatenulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces catenulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCatenulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusRhodnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpCnt312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. CNT312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpCnt312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylomonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHoaglandellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hoaglandella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusHoaglandellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHyointestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusPushchinoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus pushchinoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusPushchinoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpPg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. PG-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpPg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaBrachyantha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza brachyantha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaBrachyantha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassomonasViridansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas viridans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasViridansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistesSp31syn1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synergistes sp. 31syn1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynergistesSp31syn1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa2407bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA2_40_7b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa2407bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelghirimycesThermohalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melghirimyces thermohalophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelghirimycesThermohalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpRoot65Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot65Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf24266(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_42_66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24266", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioliNbrc102428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fumarioli NBRC 102428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusFumarioliNbrc102428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVaccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vaccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVaccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilalesBacteriumLsucc0135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium LSUCC0135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumLsucc0135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DebaryomycesHanseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DebaryomycesHanseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumHimb114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionivibrioDicarboxylicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionivibrio dicarboxylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionivibrioDicarboxylicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuraishiaCapsulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kuraishia capsulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KuraishiaCapsulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumThermoalcaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] thermoalcaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumThermoalcaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumBv3ac1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium BV3Ac1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumBv3ac1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisVancoresmycina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis vancoresmycina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisVancoresmycina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumChinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capsicum chinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapsicumChinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110056(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110056", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiCsThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CS Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCsThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaAurea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa aurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAurea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCaccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiptonbacteriaBacteriumGwb1496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium GWB1496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumGwb1496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiromycesFinnisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piromyces finnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiromycesFinnisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesOlivochromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olivochromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlivochromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioPanuliriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio panuliri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioPanuliriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJlsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JLS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJlsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterSpRoot672Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. Root672 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpRoot672Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMultisaccharivorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella multisaccharivorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMultisaccharivorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRbg133615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_36_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg133615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesSpSoil535Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. Soil535 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpSoil535Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusRifietoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus rifietoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusRifietoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiorhodospiraSibiricaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodospira sibirica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiorhodospiraSibiricaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumSpAb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGwa15412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GWA1_54_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGwa15412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasBadia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas badia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasBadia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kingella denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KingellaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobonumTyrrellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobonum tyrrellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobonumTyrrellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaVincentii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema vincentii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaVincentii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulieris281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris 281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulieris281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSanticrucisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella santicrucis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSanticrucisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DanionellaTranslucidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Danionella translucida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DanionellaTranslucidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmaragdicoccusNiigatensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smaragdicoccus niigatensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmaragdicoccusNiigatensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaOleariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga olearia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KosmotogaOleariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Baumannia cicadellinicola str. Hc (Homalodisca coagulata) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BaumanniaCicadellinicolaStrHcHomalodiscaCoagulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpRoot1497Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. Root1497 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRoot1497Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarsonellaRuddiiHtThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HT Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHtThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRattaustraliani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattaustraliani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattaustraliani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOv608Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. OV608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOv608Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDisiensJcm6334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens JCM6334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensJcm6334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaFairfieldensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella fairfieldensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaFairfieldensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioPonticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ponticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioPonticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSp329mfsha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 329MFSha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp329mfsha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomicrobiumPiriformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomicrobium piriforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomicrobiumPiriformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaPulmonicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pulmonicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPulmonicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAkibai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus akibai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAkibai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMojavensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mojavensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusMojavensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterPiechaudiiAtcc43553(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii ATCC43553 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiAtcc43553", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrinickiaSymbioticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trinickia symbiotica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrinickiaSymbioticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Facklamia hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FacklamiaHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyotisDavidiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Myotis davidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MyotisDavidiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerfeziaBoudieriAtccMya4762(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Terfezia boudieri ATCC MYA-4762 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TerfeziaBoudieriAtccMya4762", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumIndologenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indologenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndologenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumPapyrosolvensC7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens C7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensC7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpCnj954(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. CNJ-954 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpCnj954", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_45_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusVersicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus versicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusVersicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisCinereaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Botrytis cinerea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BotrytisCinereaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinicolaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Echinicola pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EchinicolaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladusLaminosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MastigocladusLaminosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HodgkiniaCicadicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hodgkinia cicadicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HodgkiniaCicadicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaGoodfellowiiDsm19756Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii DSM 19756 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowiiDsm19756Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumKh1t2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KH1T2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKh1t2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidaceaeBacteriumBroad1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioidaceae bacterium Broad1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardioidaceaeBacteriumBroad1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OidiodendronMaiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oidiodendron maius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OidiodendronMaiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSouthafrica7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SouthAfrica7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSouthafrica7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbawacabacteriaBacteriumRbg164210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Abawacabacteria bacterium RBG164210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbawacabacteriaBacteriumRbg164210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPelagibacterSpHimb1321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. HIMB1321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpHimb1321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumAponinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium aponinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumAponinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBirtlesiiIbs325Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella birtlesii IBS 325 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaBirtlesiiIbs325Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumL18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium L18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumL18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:389 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulieris281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris 281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulieris281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBovisDsm19482Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis DSM 19482 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumBovisDsm19482Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpGhviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ghvi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGhviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDentasiniJcm15908(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella dentasini JCM 15908 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDentasiniJcm15908", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusTimidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus timidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiothermusTimidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumEnclenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium enclense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumEnclenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumSpJ15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. J15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJ15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeniophoraSpContEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peniophora sp. CONT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeniophoraSpContEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterBeijingensisDsm21582Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis DSM 21582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DyadobacterBeijingensisDsm21582Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimimaricolaPyoseonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola pyoseonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaPyoseonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudodesulfovibrioPiezophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio piezophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioPiezophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumNitrativoransNl23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans NL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativoransNl23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaEiseniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaEiseniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaBestiolaeCbs10118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae CBS 10118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KwoniellaBestiolaeCbs10118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronobacteriumGregoryiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium gregoryi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumGregoryiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaGoodfellowiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia goodfellowii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaGoodfellowiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasIlicicolaDsm19980(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas ilicicola DSM 19980 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasIlicicolaDsm19980", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeophocaenaAsiaeorientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterHenriciiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter henricii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterHenriciiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisRmscc3703(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 3703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc3703", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodarcisMuralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Podarcis muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PodarcisMuralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAzotifigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAzotifigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaGrimmiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia grimmiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGrimmiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusFuriosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus furiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrococcusFuriosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpStflb209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. StFLB209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpStflb209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumReuteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium reuteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumReuteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixSpP13c2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. P13C2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpP13c2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthamoebaCastellaniiStrNeff(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii str. Neff graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcanthamoebaCastellaniiStrNeff", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusElongatusDsm2908Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus DSM 2908 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusElongatusDsm2908Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMargulisbacteriaBacteriumGwd239127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWD2_39_127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwd239127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusPalustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus palustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPalustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg134510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_13_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg134510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumLeiognathiMandapamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi mandapamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiMandapamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHarenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia harenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaHarenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpC6a8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. C6A8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpC6a8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MooreaProducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moorea producens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MooreaProducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaHeveanensisBcc8398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis BCC8398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KwoniellaHeveanensisBcc8398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnncaliiaAlgeraePra339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anncaliia algerae PRA339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnncaliiaAlgeraePra339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaFacilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidocella facilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidocellaFacilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus viridans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AerococcusViridansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpJm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. JM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpJm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSinduriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sinduriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSinduriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaTanneraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella tannerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTanneraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterAlpinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter alpinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterAlpinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DubosiellaNewyorkensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dubosiella newyorkensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DubosiellaNewyorkensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumTolulyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum tolulyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AromatoleumTolulyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full5410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL5410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full5410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumAbikonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium abikonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumAbikonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusWynniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wynnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWynniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacterium4787(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4787 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4787", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus oralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaArizonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaArizonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporomusaSubterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporomusa subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerosporomusaSubterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifoxya2full4528Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFOXYA2FULL4528 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifoxya2full4528Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelissococcusPlutonius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melissococcus plutonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelissococcusPlutonius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusJ1074Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus J1074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAlbusJ1074Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpD16q13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. D16Q13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpD16q13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpF0314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. F0314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpF0314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaSpEjp617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. Ejp617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSpEjp617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiulongibacterSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jiulongibacter sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JiulongibacterSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusInfernusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus infernus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusInfernusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201452450sch5900713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201452450SCH5900713 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201452450sch5900713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumInterjectumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium interjectum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumInterjectumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatusAuricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomatus auricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatusAuricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaFiliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga filiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaFiliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBgiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bgi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBgiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaGranulosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola granulosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicolaGranulosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot342Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root342 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot342Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hortaea werneckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HortaeaWerneckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterSpDg31dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG31D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg31dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisBalhimycinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis balhimycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisBalhimycinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobellusClavatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobellus clavatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobellusClavatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwb1437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWB1437 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwb1437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClostridioformeAgr2157Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] clostridioforme AGR2157 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioformeAgr2157Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpTth04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. TTH0-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpTth04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaBangkokensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora bangkokensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaBangkokensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsphigho212full4417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPHIGHO212FULL4417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsphigho212full4417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusTeuberi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus teuberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VagococcusTeuberi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_12_FULL_45_19b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho212Full4519b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KutzneriaAlbidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KutzneriaAlbidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpCf444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. CF444 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpCf444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TurneriellaParvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Turneriella parva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TurneriellaParvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumSpLk11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliobacteriumModesticaldumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Heliobacterium modesticaldum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HeliobacteriumModesticaldumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaYl17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila YL17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasHydrophilaYl17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurellaAmilsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella amilsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAmilsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSeleniigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelobacterSeleniigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpSoil772Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Soil772 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpSoil772Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcidophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CutaneotrichosporonOleaginosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cutaneotrichosporon oleaginosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CutaneotrichosporonOleaginosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxya1full4011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYA1FULL4011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxya1full4011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwb1558(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWB1_55_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwb1558", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpOralTaxon299StrF0039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. oral taxon 299 str. F0039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpOralTaxon299StrF0039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumHalophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumHalophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSp117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. 117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSp117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocurvusVexinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvus vexinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvusVexinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSalmonicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSalmonicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiEuryarchaeoteRedseaS11B3n4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote REDSEA-S11_B3N4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeoteRedseaS11B3n4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnncaliiaAlgeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anncaliia algerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnncaliiaAlgeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusDentisani7746Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7746 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7746Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegetibacterKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Segetibacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SegetibacterKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_53_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistocephalusSolidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistocephalus solidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistocephalusSolidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSepticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium septicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSepticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TsukamurellaPulmonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pulmonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPulmonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierellaPraeacutaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tissierella praeacuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TissierellaPraeacutaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg136114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_61_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatellicoccusMarimammaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catellicoccus marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatellicoccusMarimammaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaBongoriN26808Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori N26808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriN26808Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VignaAngularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vigna angularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VignaAngularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpBs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPhocaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPhocaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprinopsisCinereaOkayama7130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea okayama7#130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoprinopsisCinereaOkayama7130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUrha0033(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. URHA0033 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUrha0033", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaSpHeli12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. HelI12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpHeli12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCuniculorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter cuniculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCuniculorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBryantii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bryantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBryantii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGillisiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gillisiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGillisiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophusFodinaeScgcAaa011A17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophus fodinae SCGC AAA011-A17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophusFodinaeScgcAaa011A17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_01_FULL_39_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo201Full3912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpMCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. M Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpMCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumGloeosporioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaSpielmaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella spielmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaSpielmaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterSpDsm44400Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. DSM 44400 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpDsm44400Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetothermiaBacterium6432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium 64_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacterium6432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercosporaZeinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cercospora zeina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CercosporaZeinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSp103dpr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 103DPR2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp103dpr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumRifoxya2full4620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFOXYA2FULL4620 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifoxya2full4620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumGallicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium gallicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGallicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpZbg7aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. ZBG7A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpZbg7aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaJiangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea jiangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaJiangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriAtcc11577Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri ATCC11577 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBuchneriAtcc11577Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeiaOryzaeDsm17879Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leeia oryzae DSM 17879 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeeiaOryzaeDsm17879Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSalivariusUcc118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius UCC118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSalivariusUcc118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrocadiaSpUtamx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaOblonga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella oblonga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOblonga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacteriumRifoxya1full6910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium RIFOXYA1FULL6910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacteriumRifoxya1full6910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpRoot342Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot342Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlexibacterLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlexibacterLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpZbg7aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. ZBG7A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpZbg7aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeomarinobacterEctocarpiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeomarinobacter ectocarpi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeomarinobacterEctocarpiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsplowo212full3822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO212FULL3822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo212full3822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPactumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pactum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPactumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumGilvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGilvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CommensalibacterIntestini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterIntestini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg134510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG134510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg134510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxElongansAtccBaa1513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haloferax elongans ATCC BAA-1513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaloferaxElongansAtccBaa1513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenirhodobacterEnshiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenirhodobacter enshiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenirhodobacterEnshiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_02_FULL_40_12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LutibacterOricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter oricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LutibacterOricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaJinanensisNbrc108249Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jinanensis NBRC 108249 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaJinanensisNbrc108249Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottschalkiaAciduriciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottschalkia acidurici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottschalkiaAciduriciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusWakoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus wakoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusWakoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg135819(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_58_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135819", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesYokosukanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces yokosukanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesYokosukanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumSpHh01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. HH01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpHh01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifoxyd12full4821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYD12FULL4821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyd12full4821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeminicoccusRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geminicoccus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeminicoccusRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialosimplexSpHf37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialosimplex sp. HF37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialosimplexSpHf37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAidingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aidingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAidingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobiumAcetethylicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobium acetethylicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobiumAcetethylicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaTrematumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella trematum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaTrematumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPlantarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus plantarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusPlantarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerstersiaGyiorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kerstersia gyiorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KerstersiaGyiorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumSpPcc7001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. PCC7001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpPcc7001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumSpF0372Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium sp. F0372 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumSpF0372Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BombellaIntestini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bombella intestini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BombellaIntestini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwc23922(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWC2_39_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwc23922", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumFacileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium facile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumFacileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattellaGermanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattella germanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattellaGermanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaH8234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida H8234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaH8234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RattusNorvegicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rattus norvegicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RattusNorvegicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaAffPulcherrimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metschnikowia aff. pulcherrima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetschnikowiaAffPulcherrimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporothrixSchenckiiAtcc58251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii ATCC 58251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporothrixSchenckiiAtcc58251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkiellaAquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkiella aquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkiellaAquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusPoinariiG6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii G6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusPoinariiG6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaMuridarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia muridarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaMuridarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterBaekdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter baekdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterBaekdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSwuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSwuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPasteurianus3p3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus 3P3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianus3p3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosmotogaArenicorallinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KosmotogaArenicorallinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElioraeaTepidiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elioraea tepidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElioraeaTepidiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shigella sonnei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShigellaSonneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuisEa183292Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis EA183292 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuisEa183292Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoselliniaNecatrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rosellinia necatrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoselliniaNecatrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospirillumFerriphilumMl04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum ML-04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilumMl04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077532(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077532 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077532", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200240037sch5390672(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200240037SCH5390672 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200240037sch5390672", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevisNbrc100599Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis NBRC100599 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisNbrc100599Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumCg2303639Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium CG2_30_36_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumCg2303639Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwf1525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF1525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf1525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusItalicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus italicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusItalicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpBnl1100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. BNL1100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBnl1100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaeiDsm21440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei DSM 21440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaeiDsm21440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrothermaeBacteriumJdfr72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermae bacterium JdFR72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrothermaeBacteriumJdfr72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntestinimonasButyriciproducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas butyriciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasButyriciproducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD2_FULL_41_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PatulibacterMinatonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter minatonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PatulibacterMinatonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgaricusBisporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agaricus bisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgaricusBisporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritaleaMyrionectaeDsm19524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Maritalea myrionectae DSM 19524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MaritaleaMyrionectaeDsm19524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PusillimonasSpT77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pusillimonas sp. T77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PusillimonasSpT77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumAcmicro1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium acMicro-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumAcmicro1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaViscosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita viscosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AequorivitaViscosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LelliottiaAmnigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lelliottia amnigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LelliottiaAmnigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraChibensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura chibensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraChibensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinibacterRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinibacterRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HirundoRustica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hirundo rustica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HirundoRustica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedAcidilobusSpMg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. MG graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpMg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacteriumGd5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium GD5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumGd5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilaceaeBacterium11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilaceae bacterium 11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilaceaeBacterium11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasSpMarseillep2440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas sp. MarseilleP2440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSpMarseillep2440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerobacterThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaerobacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphaerobacterThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaucibacterSpKctc42545Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paucibacter sp. KCTC 42545 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaucibacterSpKctc42545Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaDiscariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia discariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaDiscariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBohemicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBohemicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRoot1290Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root1290 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot1290Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpOk091(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OK091 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOk091", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFOXYB1_FULL_46_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifoxyb1Full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinatimonasHippeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas hippei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasHippeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WaddliaChondrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Waddlia chondrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WaddliaChondrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesCinnabarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trametes cinnabarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrametesCinnabarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermaerobacterSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpYs1rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YS1r Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYs1rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisDaomEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaomEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSobria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sobria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSobria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumUltimumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium ultimum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PythiumUltimumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelatoporiaSubvermisporaB(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GelatoporiaSubvermisporaB", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesClarus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides clarus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesClarus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDoosanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium doosanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDoosanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMmlr14006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpRr217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Rr 217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpRr217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlercreutziaEquolifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlercreutzia equolifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlercreutziaEquolifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariprofundusFerrooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus ferrooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MariprofundusFerrooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyotisLucifugus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myotis lucifugus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyotisLucifugus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCcmmd2014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CCMMD2014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCcmmd2014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixInsectorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix insectorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporothrixInsectorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ManihotEsculentaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Manihot esculenta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ManihotEsculentaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPaucisporeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces paucisporeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPaucisporeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpWd121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD12.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMacedonicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus macedonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMacedonicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopostipesSuicloacalisDsm15692(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis DSM 15692 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalisDsm15692", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeggiatoaLeptomitoformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa leptomitoformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaLeptomitoformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterMathraniiSubspMathraniiStrA3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii subsp. mathranii str. A3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathraniiSubspMathraniiStrA3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumScgcAaa252m02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium SCGC AAA252M02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumScgcAaa252m02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumTcs42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium tcs-42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumTcs42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonadaceaeBacteriumBrhc29Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium BRHc29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumBrhc29Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacterium4484702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_70.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumOraleDsm12838Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale DSM 12838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumOraleDsm12838Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFOXYB1_FULL_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumDiphtheriaeNctc13129Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae NCTC 13129 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriaeNctc13129Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpJ39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalilimnicolaEhrlichii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalilimnicola ehrlichii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalilimnicolaEhrlichii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheropithecusGeladaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theropithecus gelada Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheropithecusGeladaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrogenomatusAuricolaScgcAaa011E14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Microgenomatus auricola SCGC AAA011-E14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrogenomatusAuricolaScgcAaa011E14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasSpAst10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. AST10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfurimonasSpAst10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumIndolisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium indolis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIndolisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiribacterSpUahsp71Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter sp. UAHSP71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpiribacterSpUahsp71Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaBestiolae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella bestiolae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KwoniellaBestiolae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusFulgidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus fulgidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusFulgidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CystobacterFerrugineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cystobacter ferrugineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CystobacterFerrugineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusSpUfo1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus sp. UFO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelosinusSpUfo1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBombiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bombi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBombiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpCf079Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. CF079 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpCf079Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsplowo201full4327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPLOWO201FULL4327 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsplowo201full4327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinimicrobiumAgarilyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium agarilyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumAgarilyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0472Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0472 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0472Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesPubescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trametes pubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrametesPubescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaColwellianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella colwelliana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaColwellianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpLeaf126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Leaf126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpLeaf126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesItalicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesItalicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkiellaCookevillensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella cookevillensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaCookevillensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GallibacteriumGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThielaviaTerrestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thielavia terrestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThielaviaTerrestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZhongshaniaAliphaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zhongshania aliphaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZhongshaniaAliphaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFOXYC1_FULL_48_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrococcusRivularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrococcusRivularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutaceaeBacteriumTav4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalieaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haliea rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalieaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovis914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bovis 914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaBovis914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraHibiscaNbrc15177Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura hibisca NBRC 15177 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraHibiscaNbrc15177Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmatalesArchaeonAplasma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Aplasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonAplasma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DinoroseobacterShibae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dinoroseobacter shibae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DinoroseobacterShibae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMarseillensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marseillensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarseillensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorSaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor saccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorSaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAtratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces atratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAtratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PannonibacterPhragmitetusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pannonibacter phragmitetus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PannonibacterPhragmitetusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFCSPLOWO2_02_FULL_48_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifcsplowo202Full4814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WinogradskyellaPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PirellulaStaleyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pirellula staleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PirellulaStaleyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusSk52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus SK52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusSk52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumCamembertiFm013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium camemberti FM 013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliumCamembertiFm013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusDora7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus DORA7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusDora7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAquilunaSpUbMaderosw2red(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aquiluna sp. UB-MaderosW2red graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAquilunaSpUbMaderosw2red", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalonatronumSaccharophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halonatronum saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalonatronumSaccharophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwb25519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWB2_55_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwb25519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaPortivictoriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella portivictoriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaPortivictoriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_12_FULL_40_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho212Full4012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho2024316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO2024316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho2024316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJoosteiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium joostei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJoosteiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesSpLutziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides sp. lutzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesSpLutziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpCc9605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterGracilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter gracilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterGracilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpPcc6303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC6303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc6303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusViolaceofuscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMarthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria marthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaMarthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DentipellisFragilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dentipellis fragilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DentipellisFragilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolobusProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaLitoreaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yoonia litorea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YooniaLitoreaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraLucentensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira lucentensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraLucentensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SteccherinumOchraceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Steccherinum ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SteccherinumOchraceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliiroseovariusSediminilitorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius sediminilitoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusSediminilitorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMacauensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus macauensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusMacauensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumNitrogenifigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium nitrogenifigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumNitrogenifigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumGalatiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium galatii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumGalatiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TranquillimonasAlkanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tranquillimonas alkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TranquillimonasAlkanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyphomyrmexCostatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyphomyrmex costatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyphomyrmexCostatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeijerinckiaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumCg2306627Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_66_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2306627Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanofastidiosumMethylthiophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanofastidiosum methylthiophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanofastidiosumMethylthiophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumBohemicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumBohemicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0039 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaAltunense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrinema altunense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrinemaAltunense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusBarophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus barophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusBarophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpThb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. thb2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpThb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasOligotrophaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas oligotropha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasOligotrophaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesCryophilusOy26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces cryophilus OY26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesCryophilusOy26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterIndolifexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter indolifex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterIndolifexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumHainanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium hainanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumHainanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SenegalimassiliaAnaerobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Senegalimassilia anaerobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SenegalimassiliaAnaerobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAculeatusAtcc16872(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus ATCC 16872 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusAculeatusAtcc16872", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaCriceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia criceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaCriceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSolaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSolaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusActinosclerus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus actinosclerus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusActinosclerus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyllobacteriumSpUnc302mfcol52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. UNC302MFCol52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhyllobacteriumSpUnc302mfcol52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpBls98(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BLS98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBls98", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium13140cm6619Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_66_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6619Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaCoronataCbs61796Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata CBS 617.96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaproniaCoronataCbs61796Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeclerciaAdecarboxylataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leclercia adecarboxylata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeclerciaAdecarboxylataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticumDsm21995Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum DSM 21995 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLipolyticumDsm21995Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumDaeguenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium daeguense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumDaeguenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGorillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGorillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumMesophilumDsm19309(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum DSM 19309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilumDsm19309", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaVirilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila virilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaVirilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckiiCbs1146(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii CBS 1146 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckiiCbs1146", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsplowo201full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPLOWO201FULL3913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsplowo201full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf264Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf264 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf264Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFinegoldiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides finegoldii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFinegoldiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1416 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpCcge1002Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1002 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1002Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCommuneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCommuneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaConceptionensis9403948Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis 9403948 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaConceptionensis9403948Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAlgidicarnisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium algidicarnis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAlgidicarnisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusSpCag390(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:390 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag390", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnisphaeraAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnisphaeraAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAmylolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus amylolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAmylolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpNcppb925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. NCPPB 925 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpNcppb925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCremoricolorata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cremoricolorata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCremoricolorata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSyntrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter syntrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSyntrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAustralienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma australiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAustralienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobacteriovoraxAntillogorgiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteriovorax antillogorgiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobacteriovoraxAntillogorgiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu37dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU37D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu37dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApibacterMensalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apibacter mensalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApibacterMensalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumLentum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium lentum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumLentum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AestuariibacterSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aestuariibacter salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AestuariibacterSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrnatilineaApprimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornatilinea apprima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnatilineaApprimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizophagusIrregularisDaom181602Daom197198(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 181602=DAOM 197198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602Daom197198", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSaccharolyticusJop10301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus JOP 1030-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticusJop10301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalescamantesBacteriumScgcAaa471m6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calescamantes bacterium SCGC AAA471M6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalescamantesBacteriumScgcAaa471m6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def QuasibacillusThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Quasibacillus thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "QuasibacillusThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasMediaWsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas media WS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AeromonasMediaWsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ModestobacterSpLeaf380(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. Leaf380 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpLeaf380", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApiotrichumPorosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apiotrichum porosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApiotrichumPorosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1025115Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_51_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025115Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumJosuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium josui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumJosuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterInsulaenigraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRubens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium rubens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRubens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumEscambienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKefiriDsm20587Jcm5818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri DSM 20587 JCM 5818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKefiriDsm20587Jcm5818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpImh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. IMH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpImh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaCaribensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caribensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaribensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MollicutesBacteriumHr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSubterraneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium subterraneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSubterraneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSpIstkbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. ISTKB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpIstkbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobiArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParageobacillusThermoglucosidasiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermoglucosidasius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermoglucosidasiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpDnf00663(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. DNF00663 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpDnf00663", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaNeapolitanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga neapolitana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaNeapolitanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaCelerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Grimontia celer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GrimontiaCelerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseobacterDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpCal575Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. CAL575 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpCal575Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumPrausnitziiL26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii L26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiL26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAmel2xe9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. Amel2xE9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAmel2xe9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwb14311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWB14311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwb14311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxSp19m6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 19m6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp19m6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiumSpLsa18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobium sp. LSA18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiumSpLsa18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacterium4920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 49-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacaseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacaseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlcaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRadiobacterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium radiobacter Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRadiobacterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumJlt2015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium JLT2015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumJlt2015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpAg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. Ag1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpAg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlimentariusDsm20249(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius DSM 20249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAlimentariusDsm20249", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp68310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 68-3-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp68310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumShimoideiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shimoidei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShimoideiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaAsiatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaAsiatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasSp22ii1619i(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. 22II-16-19i graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSp22ii1619i", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full3816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL3816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full3816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntrasporangiumFlavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumFlavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAcidominimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus acidominimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAcidominimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRiegeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium riegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRiegeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraMultiparaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira multipara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraMultiparaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMarmotaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marmotae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarmotaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEui1cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EuI1c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpEui1cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaHackeliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella hackeliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaHackeliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitomaculumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Robiginitomaculum antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RobiginitomaculumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AedesAlbopictus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aedes albopictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AedesAlbopictus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSporosphaeroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sporosphaeroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSporosphaeroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LunatimonasLonarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lunatimonas lonarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LunatimonasLonarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpPp1yCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. PP1Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpPp1yCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptotermesSecundusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptotermes secundus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptotermesSecundusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomorphaceaeBacteriumBacl21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumFrediiUsda257Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii USDA257 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiUsda257Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AvibacteriumParagallinarum72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaArcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria arctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaArcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMsp13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MSP13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMsp13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTanneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tanneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusTanneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSojaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSojaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LautropiaMirabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lautropia mirabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LautropiaMirabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusMontanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus montanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMontanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallbacteriaBacteriumGwc24935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wallbacteria bacterium GWC24935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WallbacteriaBacteriumGwc24935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpAc3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. AC-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusSpAc3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisSubspTessellariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. tessellarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspTessellariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_37_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu089(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU089 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu089", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DechloromonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumCaspactino5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeTagetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae tagetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeTagetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorciDsm25326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella porci DSM 25326 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoraxellaPorciDsm25326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPamc26617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLuteoviolaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusThioparusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus thioparus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusThioparusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp6910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 69-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumChkci006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium CHKCI006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumChkci006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpAs2mbin001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. AS2MBin001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpAs2mbin001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLavenduligriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lavenduligriseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLavenduligriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophaceaeBacteriumCg2305814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_58_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2305814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterArilaitensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter arilaitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterArilaitensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasHydrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas hydrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasHydrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumMobileF1926Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium mobile F1926 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EpibacteriumMobileF1926Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaBronchialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia bronchialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaBronchialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataellaPhaffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataella phaffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataellaPhaffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctopirusHydrillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus hydrillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusHydrillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifoxyc2full3412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYC2FULL3412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyc2full3412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumCg2306627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_66_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2306627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaHaemolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL3910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterSpDh1f(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. DH1f graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpDh1f", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesMissouriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes missouriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesMissouriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusElongatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusElongatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumVexansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pythium vexans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PythiumVexansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoplasmaTermitumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoplasma termitum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoplasmaTermitumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaTuricatae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia turicatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaTuricatae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipomycesStarkeyiNrrlY11557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi NRRL Y-11557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LipomycesStarkeyiNrrlY11557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchwartziaSuccinivoransDsm10502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans DSM 10502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchwartziaSuccinivoransDsm10502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4016bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4016b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4016bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasSpHmsc077f02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC077F02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc077f02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusEutactus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus eutactus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprococcusEutactus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiangellaPhaseoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xiangella phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XiangellaPhaseoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalodenitrificansDsm735Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans DSM 735 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificansDsm735Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaplasmaMarginaleFlorida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale Florida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleFlorida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensisKr140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis KR-140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DeinococcusHopiensisKr140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriticumUrartuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Triticum urartu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TriticumUrartuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthromitusSpSfbturkeyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBturkey Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbturkeyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf89Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf89Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag631Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:631 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag631Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumFreudenreichiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium freudenreichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumFreudenreichiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusJacksonbacteriaBacteriumRifoxya2Full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jacksonbacteria bacterium RIFOXYA2_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJacksonbacteriaBacteriumRifoxya2Full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldilineaAerophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldilinea aerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldilineaAerophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraAraneosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaera araneosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraAraneosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110056Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110056 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110056Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyangiaceaeBacteriumUtpro1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polyangiaceae bacterium UTPRO1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolyangiaceaeBacteriumUtpro1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaS028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia S028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaS028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_40_16b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4016b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioCosticolaSubspAlcaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinivibrio costicola subsp. alcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinivibrioCosticolaSubspAlcaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGoldsteiniiDsm19448Wal12034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii DSM 19448 WAL 12034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteiniiDsm19448Wal12034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSeniorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senioris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSeniorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaSpF366Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. F36-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpF366Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaPhthalaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia phthalatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaPhthalaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpLw4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumInfernumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum infernum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumInfernumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp11649663Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164966.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649663Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUreicelerivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ureicelerivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUreicelerivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpLm4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. LM4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLm4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_01_FULL_55_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho201Full5513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsphigho212full429(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL429 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full429", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HepatoplasmaCrinochetorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hepatoplasma crinochetorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HepatoplasmaCrinochetorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg16439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_37_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full3725Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldalkalibacillusThermarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldalkalibacillus thermarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldalkalibacillusThermarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaTimorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dietzia timorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DietziaTimorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusThailandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus thailandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusThailandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpSk140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpSk140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaTaeniospiralisNbrc102512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga taeniospiralis NBRC 102512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaTaeniospiralisNbrc102512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRifcsphigho201full6617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPHIGHO201FULL6617 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsphigho201full6617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaParisiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella parisiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaParisiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivirgaSpongicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga spongicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSpongicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat18017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaSordida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Valsa sordida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ValsaSordida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumLimnosediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium limnosediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumLimnosediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaHypogea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga hypogea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermotogaHypogea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaFucicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga fucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaFucicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOeniDsm19972(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oeni DSM 19972 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOeniDsm19972", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumRuminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ruminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumRuminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPorcinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium porcinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPorcinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSp73145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp73145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensUlvanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens ulvanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensUlvanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaFeriruminatorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma feriruminatoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaFeriruminatorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacterium4920Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 49-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4920Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumVerruco04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Verruco_04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumVerruco04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloprofundusMarisrubri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloprofundus marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloprofundusMarisrubri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0472(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0472 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0472", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSpEbm38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter sp. EBM-38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSpEbm38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerobacterThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerobacter thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerobacterThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_44_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbispora rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFrankenforstenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium frankenforstense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFrankenforstenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidiaBacteriumGa0077558Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium Ga0077558 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacteriumGa0077558Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleFloridaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale Florida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleFloridaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GastranaerophilalesBacteriumZag111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium Zag111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumZag111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AliagarivoransMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArsenicicoccusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa044d11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA044D11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa044d11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBrantaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus brantae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBrantaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaSp6041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moorella sp. 60_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoorellaSp6041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GolovinomycesCichoracearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces cichoracearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesCichoracearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpRoot70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalariasFasciatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salarias fasciatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalariasFasciatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSp1315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 13-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp1315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumMoriokaenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium moriokaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMoriokaenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonTcbr11e2g28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterZhejiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter zhejiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterZhejiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CriibacteriumBergeroniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Criibacterium bergeronii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CriibacteriumBergeroniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FontibacillusPanacisegetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fontibacillus panacisegetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FontibacillusPanacisegetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaEpidermidihirudinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia epidermidihirudinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaEpidermidihirudinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumAtcc25586Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum ATCC25586 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAtcc25586Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumWolinskyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium wolinskyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumWolinskyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNiastensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia niastensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaNiastensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaPhiladelphia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila Philadelphia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPhiladelphia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpCacia14h2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. CACIA14H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpCacia14h2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCaccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccomyxaSubellipsoidea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoidea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisRmscc2394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RMSCC 2394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRmscc2394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaPickettii12dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYD1_FULL_37_29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAculeatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusAculeatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumKuroshiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium kuroshium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumKuroshiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterHarbinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHarbinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumNigrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum nigrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumNigrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpRoot655Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root655 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot655Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoraliomargaritaAkajimensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita akajimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaAkajimensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasPruni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pruni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPruni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParabuchneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabuchneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabuchneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasTranslucensPvUndulosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens pv. undulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasTranslucensPvUndulosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RozellaAllomycis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rozella allomycis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RozellaAllomycis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMachipongonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus machipongonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMachipongonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpLig30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. lig30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpLig30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatiyooniaSediminum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia sediminum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaSediminum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpPbn3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PBN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpPbn3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaLincolnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lincolnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLincolnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarisediminitaleaAggregataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marisediminitalea aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarisediminitaleaAggregataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DolichospermumCircinaleAwqc131cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dolichospermum circinale AWQC131C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DolichospermumCircinaleAwqc131cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAmylolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amylolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmylolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPanuliriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio panuliri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioPanuliriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalothiobacillusSpLs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. LS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpLs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRbg133914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RBG_13_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRbg133914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasNoxia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas noxia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasNoxia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyc2full3521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3521 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaSpHfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia sp. HF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaSpHfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpB7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpB7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonRbg16369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon RBG_16_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonRbg16369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaArenicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinispora arenicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisporaArenicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp142mfcol31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 142MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp142mfcol31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_37_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraLatinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura latina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraLatinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf336(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf336", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu089Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU089 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu089Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMucilaginosus3016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus 3016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosus3016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumNeonatale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium neonatale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNeonatale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaParamesenteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella paramesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaParamesenteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaLimiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia limi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaLimiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporobacterMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporobacter mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerosporobacterMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuillusLuteusUhSluLm8N1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Suillus luteus UH-Slu-Lm8-n1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SuillusLuteusUhSluLm8N1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzobacteroidesPseudotrichonymphaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azobacteroides pseudotrichonymphae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzobacteroidesPseudotrichonymphaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CricetulusGriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cricetulus griseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CricetulusGriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinosporangiumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinosporangium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinosporangiumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumAcidipropioniciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidipropionici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcidipropioniciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAcidiproducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidiproducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifoxyc1full3814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYC1FULL3814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyc1full3814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumPropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium propionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumPropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOk048(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OK048 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOk048", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GuillardiaThetaCcmp2712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta CCMP2712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GuillardiaThetaCcmp2712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAeruginosaPao1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa PAO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAeruginosaPao1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeefgeaRivuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deefgea rivuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeefgeaRivuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesUncialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces uncialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesUncialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPituitosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPituitosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasGibsoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas gibsoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGibsoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpathasporaPassalidarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spathaspora passalidarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpathasporaPassalidarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlcaliphilaJab1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaliphila JAB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaliphilaJab1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaCostaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga costaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaCostaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaLinguale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma linguale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLinguale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full4219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSpMit1003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MIT1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMit1003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonsdaleaQuercinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea quercina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaQuercinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphopichiaBurtoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphopichiaBurtoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraInadaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira inadai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInadaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpNies2104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-2104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies2104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwd23333Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWD2_33_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwd23333Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusHeteromorphusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusHeteromorphusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterSpRta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. RTa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AchromobacterSpRta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMeningitidisMc58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria meningitidis MC58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMeningitidisMc58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaDoshiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella doshiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaDoshiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHeidelbergense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heidelbergense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeidelbergense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr80(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR80 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr80", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraEvergladensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera evergladensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraEvergladensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeCc1557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaUbonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia ubonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaUbonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumResistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium resistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumResistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumMercantei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium mercantei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumMercantei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaEndophyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma endophyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaEndophyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaNs342Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea NS342 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaNs342Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumGw2011gwf23720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWF23720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwf23720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrrellaDioscoreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orrella dioscoreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrrellaDioscoreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFLusitanicusCbs27749(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus CBS 277.49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicusCbs27749", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumHimb59Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB59 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb59Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaPealeana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella pealeana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPealeana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiKle1255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii KLE1255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiKle1255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusThermomutatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus thermomutatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusThermomutatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPacaenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pacaense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPacaenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaOleraceaVarOleraceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea var. oleracea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrassicaOleraceaVarOleraceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSaprophyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus saprophyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSaprophyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNovocastrense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium novocastrense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNovocastrense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaculusJaculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jaculus jaculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JaculusJaculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronobacteriumGregoryiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium gregoryi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumGregoryiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosalsumZhilinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosalsumZhilinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPneumoniaeTigr4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae TIGR4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeTigr4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolycyclovoransAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polycyclovorans algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolycyclovoransAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumLlx17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium LLX17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumLlx17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerruconisGallopava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verruconis gallopava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerruconisGallopava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Canis lupus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CanisLupus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_50_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full5012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaHippikonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma hippikon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaHippikonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxParadoxus110bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Variovorax paradoxus 110B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VariovoraxParadoxus110bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpN54mgs139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. N54MGS139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpN54mgs139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSaliphilaYim90502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila YIM 90502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphilaYim90502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSteyniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus steynii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSteyniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudochrobactrumSpB5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudochrobactrum sp. B5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudochrobactrumSpB5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRectaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium rectale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRectaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpNzgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. NZG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpNzgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterSpJ41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. J41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpJ41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpPml113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PML113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPml113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensUlvanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens ulvanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensUlvanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus salinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_34_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa13413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumHirsutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gossypium hirsutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GossypiumHirsutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpBsw20308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. Bsw20308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpBsw20308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaBalticaOs155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shewanella baltica OS155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBalticaOs155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPullorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pullorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPullorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaPolyisoprenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia polyisoprenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaPolyisoprenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterNamhaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter namhaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterNamhaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacaceaeArchaeonB1Br10E2g22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon B1-Br10_E2g22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeonB1Br10E2g22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLc300Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LC300 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLc300Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpAl04100510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. AL041005-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpAl04100510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85201450255sch5639931Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201450255SCH5639931 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201450255sch5639931Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_43_32b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpS7Ms2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S7 MS 2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS7Ms2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag1944415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG_194_44_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1944415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TersicoccusPhoenicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus phoenicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TersicoccusPhoenicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidisNbrc100137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arthritidis NBRC 100137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaArthritidisNbrc100137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladopsisRepens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladopsis repens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MastigocladopsisRepens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis2159bfaaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 2159BFAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis2159bfaaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMicrarchaeotaArchaeonCg1024740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_47_40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1024740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucco07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParasponiaAndersoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parasponia andersonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParasponiaAndersoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetofabaAustralisIt1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnetofaba australis IT-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnetofabaAustralisIt1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMuelleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina muelleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMuelleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FermentibacterDaniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fermentibacter daniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FermentibacterDaniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cucumibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CucumibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpBgarf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BGARF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBgarf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_47_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaFortuitaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia fortuita Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaFortuitaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaLongicatenaDsm13814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena DSM13814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaDsm13814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhyscomitrellaPatensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Physcomitrella patens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhyscomitrellaPatensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24716 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSp11andimar09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. 11ANDIMAR09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSp11andimar09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTrypoxylicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus trypoxylicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusTrypoxylicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OerskoviaTurbataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia turbata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OerskoviaTurbataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] cellulosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa028a23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA028A23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa028a23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucothrixMucorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucothrix mucor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucothrixMucorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusKribbensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kribbensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusKribbensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumHumicireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum humicireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHumicireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGerencseriaeDsm6844Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae DSM 6844 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGerencseriaeDsm6844Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full4934(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL4934 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full4934", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaAurantiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kushneria aurantia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KushneriaAurantiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24817 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaErythraeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora erythraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinopolysporaErythraeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NasuiaDeltocephalinicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nasuia deltocephalinicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NasuiaDeltocephalinicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumScrofulaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium scrofulaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumScrofulaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Glassbacteria bacterium RIFCSPLOWO2_12_FULL_58_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGlassbacteriaBacteriumRifcsplowo212Full5811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CobetiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cobetia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CobetiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus oralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaCentraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma centrale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaCentraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaInsidiosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia insidiosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RalstoniaInsidiosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaaliaTuricensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia turicensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaTuricensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerrigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arthritidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaArthritidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRotai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus rotai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRotai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasGlacialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasGlacialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNavarrensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio navarrensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioNavarrensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusTokodaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus tokodaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfolobusTokodaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprothermobacterProteolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter proteolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterProteolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaHinziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella hinzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaHinziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpAtcc39149Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. ATCC39149 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpAtcc39149Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesSpShpl62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpDs20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. DS20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpDs20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanistesCaeruleusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanistes caeruleus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanistesCaeruleusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusPenneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Proteus penneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProteusPenneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaSeeligeri12bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria seeligeri 12b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaSeeligeri12bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf265Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf265 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf265Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacteriumBbd199112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium BBD 1991-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacteriumBbd199112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumBetavasculorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium betavasculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBetavasculorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteribacillusPersepolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteribacillus persepolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteribacillusPersepolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLwoffii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaFusca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida fusca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaFusca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesOdontolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces odontolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesOdontolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TimonellaSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Timonella senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TimonellaSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasVeronii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas veronii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasVeronii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusStoloniferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus stolonifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizopusStoloniferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpMit055293Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT 05-5293 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit055293Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaMazei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina mazei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaMazei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterFlavusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter flavus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterFlavusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaVirens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma virens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaVirens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpGj21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. GJ21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpGj21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPHIGHO2_01_FULL_48_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsphigho201Full4822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpulaLacrymansVarLacrymansS73Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans var. lacrymans S7.3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerpulaLacrymansVarLacrymansS73Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAgariciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas agarici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAgariciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSalivarius57iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus salivarius 57I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSalivarius57iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumXylanophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium xylanophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumXylanophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa25510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_55_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa25510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiliocolobusTephroscelesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piliocolobus tephrosceles Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiliocolobusTephroscelesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirulinaSubsalsaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirulina subsalsa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirulinaSubsalsaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillaGorillaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gorilla gorilla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GorillaGorillaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterBeijingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter beijingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterBeijingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsasporaOwczarzakiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capsaspora owczarzaki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapsasporaOwczarzakiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosilyticumRuminicolaJcm14822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cellulosilyticum ruminicola JCM 14822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CellulosilyticumRuminicolaJcm14822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpLrs4154Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. LRS4.154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpLrs4154Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSpTsri0078Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. TSRI0078 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpTsri0078Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpGcs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. GCS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpGcs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full4813b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_48_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full4813b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg136020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_60_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg136020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DechloromonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumFacile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium facile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumFacile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacterium3153(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 3153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium3153", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaVespertilionis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malassezia vespertilionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalasseziaVespertilionis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumUmmariense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium ummariense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUmmariense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OvisAriesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ovis aries Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OvisAriesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicellaActignisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicella actignis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicellaActignisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm47Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpIcm47Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar324ClusterBacteriumSar324ctd7b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium SAR324CTD7B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumSar324ctd7b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionSr1BacteriumRaac1sr11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium RAAC1SR11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumRaac1sr11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasChangbaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas changbaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasChangbaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SericytochromatiaBacteriumS15bmn24raac196(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24RAAC_196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24raac196", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho201full4110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO201FULL4110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho201full4110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermatophilusCongolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DermatophilusCongolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxyb1Full4319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYB1_FULL_43_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyb1Full4319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGullanellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gullanella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGullanellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisChungbukensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis chungbukensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisChungbukensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesKanasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kanasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKanasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpH5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma palmae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaPalmaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumCymbalariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EremotheciumCymbalariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMsp13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MSP13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMsp13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAnisopliaeBrip53293(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium anisopliae BRIP 53293 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAnisopliaeBrip53293", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYk2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YK2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYk2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WigglesworthiaGlossinidiaSpGmo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia sp. Gmo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaSpGmo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HugenholtziaRoseola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HugenholtziaRoseola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPristinaespiralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pristinaespiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPristinaespiralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisB6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisB6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyseterCatodon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Physeter catodon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhyseterCatodon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrinickiaCaryophylliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trinickia caryophylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrinickiaCaryophylliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloferulaStellataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloferula stellata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloferulaStellataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrenneriaGoodwinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brenneria goodwinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrenneriaGoodwinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCapillatusDsm19910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus DSM 19910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCapillatusDsm19910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalneolaSpEhc07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Balneola sp. EhC07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BalneolaSpEhc07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrinisAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMetschnikoviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio metschnikovii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMetschnikoviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr70337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70337 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSakeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sakei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSakeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedClostridiaBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridia bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiaBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosumFd172Ss1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum FD-172 SS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosumFd172Ss1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumTenueNies30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phormidium tenue NIES-30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhormidiumTenueNies30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_36_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCsiv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CSIV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCsiv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccaeAtcc33574Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccae ATCC33574 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccaeAtcc33574Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisF0319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis F0319 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisF0319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpDsm11652(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. DSM 11652 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpDsm11652", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosIndicusXBosTaurusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bos indicus x Bos taurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BosIndicusXBosTaurusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwb26316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSubspInaquosorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. inaquosorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspInaquosorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumNodatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium nodatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumNodatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiostomaPiceaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiostoma piceae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiostomaPiceaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusLacustrisStrTousEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus lacustris str. Tous Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SynechococcusLacustrisStrTousEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumFlavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumFlavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTunicataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas tunicata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTunicataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalonomonasRubraDsm5091Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Malonomonas rubra DSM 5091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MalonomonasRubraDsm5091Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaInsecticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia insecticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaInsecticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpSoil797Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil797 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil797Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureocirculatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureocirculatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureocirculatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSpSponge(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. sponge graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpSponge", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumMola814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium MOLA814 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumMola814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3715 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpPf153(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Pf153 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPf153", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterMraziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter mrazii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMraziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporichthyaPolymorphaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporichthya polymorpha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporichthyaPolymorphaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusChitonophagusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus chitonophagus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusChitonophagusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSquillarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium squillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSquillarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterColiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter coli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterColiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanohaloarchaeaArchaeonSg9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon SG9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonSg9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiPvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumCauenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium cauense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCauenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaTasmaniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tasmaniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTasmaniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlsr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALSr1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlsr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFloricolaDsm23037Jcm16512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus floricola DSM 23037 JCM 16512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFloricolaDsm23037Jcm16512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRbg16437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumRubrisubalbicansM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicansM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc7217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirulinaMajorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirulina major Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirulinaMajorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_38_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusCecorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus cecorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCecorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidophilusNcfmEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus NCFM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilusNcfmEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandarakinorhabdusLimnophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus limnophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusLimnophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosospiraSp5618(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. 56-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSp5618", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumWolinskyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium wolinskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumWolinskyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg10255237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_55_237 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg10255237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YaniellaHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yaniella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YaniellaHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumCrithidiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium crithidii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumCrithidiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaceaeSpMortierellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae sp. Mortierella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeSpMortierellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KallipygaGabonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga gabonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KallipygaGabonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumAromaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum aromaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AromatoleumAromaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaGb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida GB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaGb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwb1448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWB1448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwb1448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceicoccusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoschusMoschiferus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moschus moschiferus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoschusMoschiferus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpFc2001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FC2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFc2001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumCg1025453(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG1_02_54_53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg1025453", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD2_FULL_41_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd2Full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudosphingobacteriumDomesticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudosphingobacterium domesticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudosphingobacteriumDomesticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalislikeEndosymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sodalislike endosymbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SodalislikeEndosymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaecibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caecibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaecibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrackiellaOedipodisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brackiella oedipodis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrackiellaOedipodisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticoccusMarisrubri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ponticoccus marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PonticoccusMarisrubri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopelagicolaGijangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudopelagicola gijangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudopelagicolaGijangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkiellaCookevillensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkiella cookevillensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkiellaCookevillensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacteriovoraxMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacteriovorax marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacteriovoraxMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudaminobacterSalicylatoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudaminobacter salicylatoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudaminobacterSalicylatoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_02_FULL_40_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeoehrlichiaLotoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neoehrlichia lotoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeoehrlichiaLotoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasEustigmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas eustigma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasEustigmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full3826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsplowo201full4418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPLOWO201FULL4418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsplowo201full4418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumInsulare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum insulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumInsulare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterHolothuriorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter holothuriorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterHolothuriorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlareaLozoyensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glarea lozoyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlareaLozoyensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusAmyloliquefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus amyloliquefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusAmyloliquefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Giardia intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GiardiaIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPrunellaeJcm25354(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaia prunellae JCM 25354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaiaPrunellaeJcm25354", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpIcm39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TropicibacterNaphthalenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tropicibacter naphthalenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TropicibacterNaphthalenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScheffersomycesStipitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScheffersomycesStipitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfRidgeiaPiscesaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia piscesae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeiaPiscesaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobacterThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobacter thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenobacterThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMikamiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mikamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaMikamiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpHjm029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HJM029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHjm029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumGw2011Gwa14610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium GW2011_GWA1_46_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumGw2011Gwa14610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronohydrobacterThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronohydrobacter thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronohydrobacterThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusThermantarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermantarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermantarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusAmyloliquefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus amyloliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusAmyloliquefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumCpb6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium CPB6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCpb6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PimelobacterSimplex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pimelobacter simplex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PimelobacterSimplex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBrevicatena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brevicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrevicatena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium5039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 50-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium5039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsidiaRepensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Absidia repens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AbsidiaRepensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubeoparvulumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubeoparvulum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubeoparvulumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpOv279(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv279", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumGwf23715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWF2_37_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwf23715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumHalopraeferens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum halopraeferens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHalopraeferens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTeresEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora teres Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTeresEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCf386(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. cf386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCf386", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpVcb2006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCB2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcb2006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharobutylicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharobutylicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharobutylicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphriteaJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphritea japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphriteaJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAmazonitimonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amazonitimonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmazonitimonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc2459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC2459 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc2459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpMusc93Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc93Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaPelophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina pelophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaPelophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidiaBacterium4341(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidia bacterium 43-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidiaBacterium4341", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethyloteneraVersatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm1743Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1743 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1743Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusChungangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus chungangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusChungangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaPhenaziniumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenazinium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenaziniumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMucilaginosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus mucilaginosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMucilaginosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrospiraPlatensisYz(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis YZ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisYz", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGullanellaEndobiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gullanella endobia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGullanellaEndobiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisVesicatoriaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris vesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisVesicatoriaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpWchac010034Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. WCHAc010034 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpWchac010034Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YonathbacteriaBacteriumRifcsphigho201full4441(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL4441 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full4441", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSocompensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio socompensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSocompensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusHospitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidianus hospitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidianusHospitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChristensenellaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenella timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumSalmoneumNbrc103935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum NBRC 103935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneumNbrc103935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacasei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacasei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarithrixSpCanyonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marithrix sp. Canyon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarithrixSpCanyonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPseudoobscuraPseudoobscuraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura pseudoobscura Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscuraPseudoobscuraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRbg134613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_13_46_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg134613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumGwb25626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium GWB2_56_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumGwb25626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerBermudensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipiger bermudensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipigerBermudensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacillusAlbusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacillus albus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacillusAlbusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrioBacteriovorusWEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusWEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticoccusMarisrubriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ponticoccus marisrubri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PonticoccusMarisrubriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaSpCag878Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma sp. CAG:878 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaSpCag878Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumResistensNbrc103078Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium resistens NBRC 103078 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumResistensNbrc103078Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg165211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_52_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg165211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSeleniipraecipitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas seleniipraecipitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSeleniipraecipitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFischeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioFischeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpC01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaMediocidica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora mediocidica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaMediocidica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonodelphisDomesticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monodelphis domestica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonodelphisDomesticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_44_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaTucsonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella tucsonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaTucsonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaKunkelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaKunkelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CetobacteriumSomeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cetobacterium somerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CetobacteriumSomeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSp7392Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp7392Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydatigeraTaeniaeformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydatigera taeniaeformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydatigeraTaeniaeformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThorarchaeotaArchaeonSmtz145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thorarchaeota archaeon SMTZ1-45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThorarchaeotaArchaeonSmtz145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusSpBf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sp. BF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSpBf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPHIGHO2_12_FULL_36_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsphigho212Full369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBay1663(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BAY1663 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBay1663", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL4113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasArcisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas arcis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasArcisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LamprocystisPurpureaDsm4197Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea DSM 4197 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LamprocystisPurpureaDsm4197Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpPrm31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. PRM31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpPrm31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFragilisNctc9343(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis NCTC 9343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisNctc9343", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassilionigeriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilionigeriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilionigeriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lindowbacteria bacterium RIFCSPLOWO2_12_FULL_62_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurococcusFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe2015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE2015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe2015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfovibrioThiophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio thiophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioThiophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusIhuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusCrassostreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus crassostreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusCrassostreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAsiaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium asiaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAsiaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesDentalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces dentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDentalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaBronchialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella bronchialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaBronchialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiploscapterPachysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diploscapter pachys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiploscapterPachysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasGranuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas granuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasGranuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifoxyb12full507Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFOXYB12FULL507 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifoxyb12full507Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBeijingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus beijingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBeijingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseochromogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseochromogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseochromogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseatelesSpYr242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseateles sp. YR242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseatelesSpYr242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPneumoniaeFh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae FH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeFh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Valsa mali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ValsaMali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFlevenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium flevense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFlevenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAcidiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAcidiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumAe2021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AE2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAe2021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhodospiraHalochlorisStrAEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris str. A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorhodospiraHalochlorisStrAEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterExcellensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter excellens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterExcellensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaWexleraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blautia wexlerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlautiaWexleraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSeohaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter seohaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSeohaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansDsm642(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans DSM642 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansDsm642", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFischerbacteriaBacteriumRbg13378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fischerbacteria bacterium RBG_13_37_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFischerbacteriaBacteriumRbg13378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpFs083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. FS08-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpFs083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCcge510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CCGE510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCcge510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomicrostromaGlucosiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomicrostroma glucosiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomicrostromaGlucosiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinifilumFragileJcm15579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinifilum fragile JCM 15579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinifilumFragileJcm15579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpKle1728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. KLE1728 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpKle1728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpStm4661(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. STM4661 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpStm4661", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaArizonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica arizonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaArizonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinivibrioSharmensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio sharmensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSharmensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gillisia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GillisiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpKk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. KK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpKk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumSulfidifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum sulfidifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumSulfidifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemobos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemobos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemobos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudophaeobacterLeonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter leonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterLeonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root241 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AfifellaMarinaDsm2698Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Afifella marina DSM 2698 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AfifellaMarinaDsm2698Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthocheilonemaViteaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acanthocheilonema viteae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcanthocheilonemaViteaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmanitaMuscaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amanita muscaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmanitaMuscaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterAsymbioticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter asymbioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterAsymbioticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSolincolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium solincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSolincolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkiellaAquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkiella aquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkiellaAquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaPacificaDsm45543Cns863Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45543 CNS-863 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45543Cns863Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterXylinusE25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus E25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusE25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccibacterColletisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Siccibacter colletis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SiccibacterColletisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipiger marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipigerMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IshikawaellaCapsulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ishikawaella capsulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IshikawaellaCapsulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusChromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus chromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusChromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerinicoccusProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaPtereochthonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia ptereochthonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPtereochthonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumCg2303812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium CG2_30_38_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumCg2303812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077540(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077540 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077540", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPseudoalcaligenesCect5344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes CECT5344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesCect5344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4645Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4645 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4645Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpApr13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. APR13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpApr13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisus13826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus 13826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisus13826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumBeibuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium beibuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumBeibuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumOceanicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium oceanicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOceanicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_40_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterInhibens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter inhibens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterInhibens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovibrioSalinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovibrio salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovibrioSalinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil763Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil763 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil763Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusVillosusKin24T80Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanocaldococcus villosus KIN24-T80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanocaldococcusVillosusKin24T80Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumArcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanobacterium arcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriumArcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGlaucescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces glaucescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlaucescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasSpFcs9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas sp. FCS-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteimonasSpFcs9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiK12SubstrW3110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. W3110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrW3110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaphorinaCitriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diaphorina citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiaphorinaCitriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapillibacterCinnamivoransDsm12816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans DSM 12816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PapillibacterCinnamivoransDsm12816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200240037sch5390672Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200240037SCH5390672 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200240037sch5390672Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PonticoccusMarisrubriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ponticoccus marisrubri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PonticoccusMarisrubriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_44_12b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full4412bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea longicatena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaLongicatenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisPierantonius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sodalis pierantonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SodalisPierantonius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaMelaleucaeAtcc49191(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae ATCC 49191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucaeAtcc49191", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPalustre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPalustre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesIncarnatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces incarnatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIncarnatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraViscosaTufc12733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Calocera viscosa TUFC12733 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaloceraViscosaTufc12733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theileria equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheileriaEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspDublinensisLmg23823Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. dublinensis LMG 23823 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspDublinensisLmg23823Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVacciniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia vaccinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaVacciniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusChagannorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus chagannorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusChagannorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OligellaUreolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oligella ureolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OligellaUreolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp3j1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 3J1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp3j1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC1_37_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatoriaAcuminata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria acuminata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaAcuminata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo202Full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_02_FULL_40_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo202Full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9902(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9902 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9902", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IlumatobacterCoccineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ilumatobacter coccineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IlumatobacterCoccineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full379(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full379", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaYeongjuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niastella yeongjuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiastellaYeongjuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudosphingobacteriumDomesticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudosphingobacterium domesticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudosphingobacteriumDomesticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioSpMilost1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MilosT1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMilost1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumUtcfx2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumMinutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium minutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumMinutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpRoot70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag786(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:786 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag786", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusInulinusCasd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus CASD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusInulinusCasd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSpYr573Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. YR573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpYr573Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosotenuisCloacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis cloacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisCloacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IdiomarinaSediminumDsm21906Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina sediminum DSM 21906 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaSediminumDsm21906Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMucosaeLm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae LM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMucosaeLm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaSprentiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaPtereochthonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia ptereochthonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPtereochthonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHochsteniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumHochsteniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterKookiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kookii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKookiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaSpPcc7108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. PCC7108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpPcc7108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifoxyd12full3339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYD12FULL3339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyd12full3339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaGallinacea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia gallinacea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaGallinacea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGlobisporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces globisporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlobisporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpEhn03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. EhN03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpEhn03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSpCag357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister sp. CAG:357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterSpCag357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConexibacterWoeseiIso977n(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei Iso977N graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiIso977n", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsphigho212full6614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO212FULL6614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho212full6614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpHgb5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. HGB5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesSpHgb5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseobacterDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaPatagoniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella patagoniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPatagoniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasIngrahamiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ingrahamii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromonasIngrahamiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaSaccharevitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena saccharevitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaSaccharevitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPectinophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pectinophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPectinophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpKo116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. KO116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpKo116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. indica serovar 6,14,25:z10:1,(2),7 str. 1121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspIndicaSerovar61425Z10127Str1121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmigerFormicilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmiger formicilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmigerFormicilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusVillorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus villorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusVillorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpR4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. R4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaSpR4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacterium13220cm2628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium 13_2_20CM_2_62_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacterium13220cm2628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwa2359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA2359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa2359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LamprocystisPurpureaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LamprocystisPurpureaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenophilusAzovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenophilus azovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenophilusAzovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetivibrioCellulolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetivibrio cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetivibrioCellulolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27986(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27986", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaccharosporaIrregularisDsm2635Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis DSM 2635 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularisDsm2635Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmmonsiaCrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia crescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaCrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium637Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium637Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumMetallireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumMetallireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumRifoxyc2full3612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC2FULL3612 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc2full3612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSuwonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter suwonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSuwonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeOzaenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae ozaenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeOzaenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaSpT9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella sp. T9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpT9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsonellaClevelandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lawsonella clevelandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LawsonellaClevelandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpTne862Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. TNe-862 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpTne862Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNidulansFgscA4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans FGSC A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusNidulansFgscA4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpErmr104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. ERMR1:04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpErmr104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavicepsPurpurea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Claviceps purpurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClavicepsPurpurea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRoquefortiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium roqueforti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRoquefortiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesOdontolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces odontolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesOdontolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpBmg51109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG51109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg51109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpSt2l15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacteriaceaeBacteriumGd5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium GD5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumGd5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosakoniaRadicincitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia radicincitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KosakoniaRadicincitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag884Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:884 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag884Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCristatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCristatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifoxya2full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL4118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaesserellaParasuisSh0165Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glaesserella parasuis SH0165 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlaesserellaParasuisSh0165Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp54146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 54_146 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp54146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUreolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUreolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibacaCalidilacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseibaca calidilacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseibacaCalidilacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureocirculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureocirculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureocirculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanopusillusAcidilobiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanopusillus acidilobi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanopusillusAcidilobiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpX1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. X1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpX1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UreaplasmaDiversumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma diversum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaDiversumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSelenatarsenatisSf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis SF-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatisSf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuhomycesTanzawaensisNrrlY17324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis NRRL Y-17324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensisNrrlY17324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTyrobutyricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tyrobutyricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTyrobutyricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5420 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensQ287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Q287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensQ287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CamelusDromedariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Camelus dromedarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CamelusDromedariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasWolfeiSubspMethylbutyraticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei subsp. methylbutyratica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiSubspMethylbutyraticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinarchaeumSpHarchtbsk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinarchaeum sp. HarchtBsk1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinarchaeumSpHarchtbsk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumGwa25015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium GWA2_50_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumGwa25015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMarisflaviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marisflavi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMarisflaviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumAurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium aurum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RattusNorvegicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rattus norvegicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RattusNorvegicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheionarchaeaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasitellaParasitica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parasitella parasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParasitellaParasitica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGigeriorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGigeriorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:921 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumJeaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium jeanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumJeaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremaOrientaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trema orientale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TremaOrientaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterNoctilucaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter noctilucae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterNoctilucaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RosenbergiellaNectareaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rosenbergiella nectarea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RosenbergiellaNectareaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RathayibacterToxicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter toxicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RathayibacterToxicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraStrobi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara strobi) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraStrobi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag180Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:180 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag180Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumGwa2509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium GWA2_50_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumGwa2509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransAk01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans AK01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransAk01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaParapsilosisCdc317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida parapsilosis CDC317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaParapsilosisCdc317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaKashmirensisWt001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis WT001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisWt001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RugamonasRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rugamonas rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RugamonasRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumRaac4od11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium RAAC4OD11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumRaac4od11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalotheceSpPcc7418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothece sp. PCC7418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalotheceSpPcc7418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaNiveoalba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora niveoalba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaNiveoalba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCfn42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CFN42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCfn42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterUraniireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterUraniireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHydrogeniformansDsm21757(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium hydrogeniformans DSM 21757 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumHydrogeniformansDsm21757", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesParvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastomycesParvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAurantiacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CobetiaSpUcd24c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cobetia sp. UCD-24C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CobetiaSpUcd24c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaPneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaShimofusensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaShimofusensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4648Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4648 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4648Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcusStipitatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus stipitatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyxococcusStipitatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeBacteriumPba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium PBA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacteriumPba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCoatesbacteriaBacteriumRbg136614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Coatesbacteria bacterium RBG_13_66_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCoatesbacteriaBacteriumRbg136614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumKluyveriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium kluyveri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumKluyveriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumInfirmumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium infirmum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumInfirmumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUberis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus uberis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusUberis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusSpXh2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus sp. XH2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusSpXh2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeadbetterellaByssophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leadbetterella byssophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeadbetterellaByssophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfTrichogrammaPretiosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma pretiosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaPretiosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaistia adipata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaistiaAdipata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxRadicisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax radicis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxRadicisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumSoil82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium SOIL82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumSoil82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesMissouriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes missouriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesMissouriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecochlorisSpCib2401(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prosthecochloris sp. CIB 2401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProsthecochlorisSpCib2401", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaRobiniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea robiniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaRobiniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonisDsm23387Jcm13868(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 JCM 13868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387Jcm13868", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TectomicrobiaBacteriumRifcsplowo202full7019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tectomicrobia bacterium RIFCSPLOWO202FULL7019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TectomicrobiaBacteriumRifcsplowo202full7019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpBr816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. BR816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpBr816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumArcisJcm13916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum arcis JCM 13916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumArcisJcm13916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaJiangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea jiangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaJiangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb01580(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB01580 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb01580", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201350091sch5140682(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201350091SCH5140682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201350091sch5140682", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusAmylolentusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptococcusAmylolentusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OperophteraBrumataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Operophtera brumata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OperophteraBrumataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobacteralesBacteriumDelta02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacterales bacterium Delta_02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacteralesBacteriumDelta02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisDsm19559Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis DSM19559 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisDsm19559Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDigitatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium digitatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDigitatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiranofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiranofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiranofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumSpMes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. MES graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumSpMes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaCaldariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Treponema caldaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TreponemaCaldariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolirubrumPuertoriconensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solirubrum puertoriconensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolirubrumPuertoriconensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiohalocapsaSpMl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiohalocapsa sp. ML1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiohalocapsaSpMl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterInvisus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister invisus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterInvisus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpCmf222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf 22.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpCmf222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_38_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumCg1023721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAdhaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter adhaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAdhaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpKle1280Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. KLE1280 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpKle1280Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumKht7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KHT7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKht7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BesnoitiaBesnoitiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Besnoitia besnoiti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BesnoitiaBesnoitiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumParadoxumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium paradoxum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumParadoxumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UreibacillusThermosphaericusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ureibacillus thermosphaericus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UreibacillusThermosphaericusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpJ54Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. J54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJ54Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasPalmitaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlobisporangiumUltimumDaomBr144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Globisporangium ultimum DAOM BR144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlobisporangiumUltimumDaomBr144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraSpB5022Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira sp. B5-022 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSpB5022Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterAerophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter aerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterAerophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynchytriumEndobioticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium endobioticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynchytriumEndobioticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaSpOralTaxon928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella sp. oral taxon 928 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemellaSpOralTaxon928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpAap35(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. AAP35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpAap35", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumHerbicidovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium herbicidovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumHerbicidovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc6312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC6312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc6312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIhumiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ihumii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIhumiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquaspirillumSerpens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum serpens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSerpens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf13410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF1_34_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf13410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesnuesiellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desnuesiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesnuesiellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium659(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium659", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6247Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-47 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6247Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CribrihabitansMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cribrihabitans marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CribrihabitansMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaSpAtcc55076Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea sp. ATCC 55076 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaSpAtcc55076Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasAustralicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas australica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasAustralicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGasseriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gasseri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGasseriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacteriaBacteriumGut307Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacteria bacterium GUT307 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacteriaBacteriumGut307Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermokryptusMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermokryptus mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermokryptusMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelphinapterusLeucasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Delphinapterus leucas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DelphinapterusLeucasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensisKctc13613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus siamensis KCTC 13613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSiamensisKctc13613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesMccartyi195(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi 195 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyi195", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusXylosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus xylosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusXylosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporidiumMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisSpSc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminobacterSpRm87(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminobacter sp. RM87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminobacterSpRm87", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArsenophilumNbrc109478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum NBRC 109478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilumNbrc109478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucosporidiumCreatinivorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucosporidium creatinivorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucosporidiumCreatinivorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa278o22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA278O22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa278o22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesMerus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles merus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesMerus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpPsbb023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. PSBB023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPsbb023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaViswanathii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Candida viswanathii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaViswanathii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemocanisStrIllinois(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis str. Illinois graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanisStrIllinois", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaceaeBacteriumRedseas32b1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxellaceae bacterium REDSEAS32B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaceaeBacteriumRedseas32b1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaSpAf7305cm02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenella sp. AF73-05CM02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaSpAf7305cm02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpAt9bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. At9b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpAt9bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpQxt31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. QXT-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpQxt31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAntriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus antri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAntriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusGaemokensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gaemokensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGaemokensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag762Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:762 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag762Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PucciniaCoronataVarAvenaeFSpAvenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Puccinia coronata var. avenae f. sp. avenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PucciniaCoronataVarAvenaeFSpAvenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalovivaxAsiaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halovivax asiaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalovivaxAsiaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumS7086c20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium S7086C20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumS7086c20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc511d10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusStomatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus stomatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusStomatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRickettsiellaIsopodorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rickettsiella isopodorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRickettsiellaIsopodorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusPentosaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus pentosaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusPentosaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaGlabrataCbs138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Candida] glabrata CBS 138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaGlabrataCbs138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusViniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusViniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCiat894(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CIAT894 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCiat894", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMindensisDsm14500Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis DSM 14500 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMindensisDsm14500Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifoxyb1full4712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeiaOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leeia oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeeiaOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpYim77409Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermus sp. YIM77409 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermusSpYim77409Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCorcagiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter corcagiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCorcagiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpLeaf336Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf336 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf336Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpGw2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GW2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGw2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusChungwhensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus chungwhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacillusChungwhensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraSpNm10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. NM10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpNm10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag245Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:245 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag245Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis3145bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 3145B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis3145bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRectaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium rectale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRectaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumDg741(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg741", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_39_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MadurellaMycetomatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Madurella mycetomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MadurellaMycetomatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiocapsaRoseopersicina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa roseopersicina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaRoseopersicina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumXinjiangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xinjiangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXinjiangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterorhabdusCaecimurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterorhabdus caecimuris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterorhabdusCaecimurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKnackmussiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas knackmussii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKnackmussiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterParvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter parvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterParvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusSphaericusOt4b31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus sphaericus OT4b31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusSphaericusOt4b31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmatimonadetesBacteriumOlb18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium OLB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumOlb18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterArboriphilusAnor1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus ANOR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilusAnor1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaAttenuataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana attenuata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NicotianaAttenuataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUnc280mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC280MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc280mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaMelophagi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella melophagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaMelophagi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusSpEb02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus sp. EB02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusSpEb02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisSpSb2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SB2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSb2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeBvOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAgalactiaeLmg14747(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae LMG14747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeLmg14747", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHordeiDsm19519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hordei DSM 19519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHordeiDsm19519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaTimorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dietzia timorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DietziaTimorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrdosporaColligataOc4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ordospora colligata OC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OrdosporaColligataOc4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasBromiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas bromi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasBromiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldanaerobiusFijiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterActinomycetemcomitansRhaa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter actinomycetemcomitans RhAA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterActinomycetemcomitansRhaa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JacksonbacteriaBacteriumRifoxya2full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jacksonbacteria bacterium RIFOXYA2FULL4312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JacksonbacteriaBacteriumRifoxya2full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3924 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumRifoxya2Full4620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFOXYA2_FULL_46_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifoxya2Full4620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobacteriovoraxAntillogorgiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteriovorax antillogorgiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobacteriovoraxAntillogorgiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsicumAnnuum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capsicum annuum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapsicumAnnuum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosediminibacterOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosediminibacter oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosediminibacterOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_48_13b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaGuizhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea guizhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaGuizhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumWoodiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium woodii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWoodiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesBailiiClib213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii CLIB 213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailiiClib213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaJordanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella jordanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaJordanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSharpeaeJcm1186Dsm20505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae JCM 1186 DSM 20505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSharpeaeJcm1186Dsm20505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasMesophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinomonasMesophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFurnissiiNctc11218(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio furnissii NCTC 11218 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioFurnissiiNctc11218", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Morganella psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MorganellaPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpHeronEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. Heron Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHeronEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusHd100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus HD100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusHd100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoclostridiumSpYl32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium sp. YL32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumSpYl32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillaceaeBacteriumBrhc57Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillaceae bacterium BRHc57 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillaceaeBacteriumBrhc57Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasSpBgc7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. BGC7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpBgc7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0426(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0426 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0426", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumBeijerinckiiDsm7166Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii DSM 7166 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckiiDsm7166Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusFulvusHw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus fulvus HW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcusFulvusHw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaBalbisiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Musa balbisiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusaBalbisiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasEuropaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas europaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEuropaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechlorosomaSuillum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dechlorosoma suillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DechlorosomaSuillum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpCci3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CcI3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCci3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAcrylicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio acrylicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAcrylicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioHalioticoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio halioticoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioHalioticoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpCf284Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF284 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf284Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpAntEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAntEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaFuscipesFuscipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Glossina fuscipes fuscipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GlossinaFuscipesFuscipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCastoreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus castoreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCastoreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSwezeyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus swezeyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSwezeyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaSpPf2b19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. PF2B19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpPf2b19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterSpMm124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. MM124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpMm124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpeibonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces speibonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpeibonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia suis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina brevipalpis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaBrevipalpisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioOstreicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ostreicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioOstreicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TieghemosteliumLacteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tieghemostelium lacteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TieghemosteliumLacteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumDifficileCd160(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile CD160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficileCd160", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MillerozymaFarinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Millerozyma farinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MillerozymaFarinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaFloridanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia floridanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaFloridanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSp9096Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. 9096 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSp9096Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumPhaseoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium phaseoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumPhaseoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrisomaLimiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrisoma limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrisomaLimiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysemysPictaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chrysemys picta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChrysemysPictaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastopirellulaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastopirellula marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastopirellulaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusFasciansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusFasciansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromatialesBacteriumUscgtaylorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromatiales bacterium USCgTaylor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromatialesBacteriumUscgtaylorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmazonaAestiva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amazona aestiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmazonaAestiva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaphidiopsisBrookii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Raphidiopsis brookii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RaphidiopsisBrookii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamlibacterTataouinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter tataouinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RamlibacterTataouinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira kmetyi serovar Malaysia str. Bejo-Iso9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraKmetyiSerovarMalaysiaStrBejoIso9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterUraniireducensRf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Rf4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacterUraniireducensRf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuhomycesTanzawaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaSpF0422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella sp. F0422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaSpF0422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodalisPierantoniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sodalis pierantonius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SodalisPierantoniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrophominaPhaseolinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacrophominaPhaseolinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpC448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. C448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpC448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilisYch46(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis YCH46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisYch46", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSpMai1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. MAI-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpMai1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureobasidiumNamibiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium namibiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumNamibiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifoxyd2full5815(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYD2FULL5815 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyd2full5815", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonAplasmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Aplasma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonAplasmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpA16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. A16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpA16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumM3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium M3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumM3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaSiderisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala sideris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaSiderisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterYeojuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter yeojuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteibacterYeojuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumUmmarienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium ummariense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUmmarienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaLecithinolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema lecithinolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaLecithinolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDecumbensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium decumbens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDecumbensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumSalpingitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium salpingitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumSalpingitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HanseniasporaUvarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora uvarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaUvarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalimicrobiumHalophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium halophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumHalophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaCaviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCaviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TremaOrientaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trema orientale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TremaOrientaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypocladiumParadoxum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium paradoxum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumParadoxum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaSpAngrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaJordanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella jordanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaJordanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwa15235Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA1_52_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa15235Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionNc10BacteriumRifcsplowo202full6622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium RIFCSPLOWO202FULL6622 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumRifcsplowo202full6622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckiiCbs1146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii CBS 1146 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckiiCbs1146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaAtrinaeC38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria atrinae C3-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KocuriaAtrinaeC38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronumLacustreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumLacustreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospirillumFerriphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferriphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerriphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JohnsonellaIgnava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Johnsonella ignava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JohnsonellaIgnava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSpJc8eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. JC8E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KurthiaSpJc8eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0386(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0386 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0386", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaMultipartitaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella multipartita Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NakamurellaMultipartitaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumSpS3pf19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium sp. S3PF19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumSpS3pf19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudopelagicolaGijangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudopelagicola gijangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudopelagicolaGijangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusPropionicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelosinus propionicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelosinusPropionicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaMontaniterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma montaniterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaMontaniterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaludibacteriumYongneupenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpTg39a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. TG39a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpTg39a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesFLusitanicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. lusitanicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFLusitanicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23810 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacteriumWieringaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium wieringae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWieringaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumHydrogeniphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hydrogeniphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHydrogeniphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalodenitrificansDsm735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans DSM 735 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificansDsm735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspArizonaeSerovar62Z4Z23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. arizonae serovar 62:z4,z23:- graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspArizonaeSerovar62Z4Z23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkiellaAquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella aquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaAquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24260Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24260 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24260Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraSpAngm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeauveriaBassianaD15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana D1-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaD15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRennini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rennini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRennini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNiveusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niveus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNiveusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophilusSpLeaf414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. Leaf414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpLeaf414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraSpMccc1a01148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag582Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:582 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag582Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpNk3a76Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. NK3A76 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpNk3a76Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumHaemolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium haemolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumHaemolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusSp2gbenrichCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus sp. 2GBenrich Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusSp2gbenrichCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpR4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella sp. R4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaSpR4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSoldanellicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soldanellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoldanellicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusCarnicancriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus carnicancri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusCarnicancriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpAp49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. AP49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAp49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiariaAnomalaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tilletiaria anomala Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TilletiariaAnomalaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaDiarizonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica diarizonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaDiarizonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotioniger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotioniger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonariusCbs121057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius CBS 121057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonariusCbs121057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPseudotuberculosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacteriumJdfr52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSynoviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma synoviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSynoviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndolissoclinumFaulkneriL2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiveispirillumIrakenseDsm11586Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Niveispirillum irakense DSM 11586 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NiveispirillumIrakenseDsm11586Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpSk140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpSk140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumHiltneriN3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri N3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneriN3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_45_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumIndoltheticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indoltheticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndoltheticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLaterculaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina latercula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLaterculaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpNkbg15041cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. NKBG15041c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpNkbg15041cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg164921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg164921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMarmorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus marmoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMarmorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasThermotoleransDsm14292(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans DSM 14292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasThermotoleransDsm14292", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisAtcc49296Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC49296 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc49296Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMarseillensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marseillensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarseillensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTestisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus testis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusTestisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCyriacigeorgicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia cyriacigeorgica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaCyriacigeorgicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallionellalesBacteriumRifcsplowo202full5747Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallionellales bacterium RIFCSPLOWO202FULL5747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallionellalesBacteriumRifcsplowo202full5747Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxya2Full4315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA2_FULL_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya2Full4315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterJaponicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter japonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaponicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho201full37110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL37110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full37110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumExtorquensAm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium extorquens AM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumExtorquensAm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusSpEb02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus sp. EB02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusSpEb02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothielavioidesTerrestrisNrrl8126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermothielavioides terrestris NRRL 8126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermothielavioidesTerrestrisNrrl8126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusCurtisiiAtcc43063Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC43063 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc43063Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusOdoriferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus odorifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOdoriferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LasiusNiger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lasius niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LasiusNiger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCuniculorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter cuniculorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCuniculorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriaceaeBacteriumP6a17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionibacteriaceae bacterium P6A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriaceaeBacteriumP6a17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMinutissimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium minutissimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMinutissimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaThermarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga thermarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaThermarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumBrhc20aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium BRHc20a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumBrhc20aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DolichospermumCircinaleAwqc131cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dolichospermum circinale AWQC131C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DolichospermumCircinaleAwqc131cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpR43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. R43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpR43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRhodniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxya12full3519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA12FULL3519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya12full3519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoschusMoschiferusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moschus moschiferus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoschusMoschiferusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusPrevotiiDsm20548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii DSM20548 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiDsm20548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaVagansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea vagans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaVagansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckii2038(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii 2038 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckii2038", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024416 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirestonebacteriaBacteriumRifoxya2full408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYA2FULL408 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxya2full408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaVelum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solemya velum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp01251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 0-1251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp01251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiraMiltonrushiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Meira miltonrushii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MeiraMiltonrushiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesWuyuanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wuyuanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWuyuanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaBaltica18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cellulophaga baltica 18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CellulophagaBaltica18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusSpCag542Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus sp. CAG:542 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusSpCag542Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoalkalibacterSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumJkg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium JKG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumJkg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeophocaenaAsiaeorientalisAsiaeorientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis asiaeorientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalisAsiaeorientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RachicladosporiumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rachicladosporium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RachicladosporiumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpYr558Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. YR558 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpYr558Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaSpSwk7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula sp. SWK7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaSpSwk7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpNbs1129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. NBS 11-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpNbs1129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusKuroshimensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus kuroshimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusKuroshimensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomicrobiumOkeanokoitesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium okeanokoites Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumOkeanokoitesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAmphilectiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina amphilecti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAmphilectiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalitaleaSaponilacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalitalea saponilacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalitaleaSaponilacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumLabreanumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum labreanum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumLabreanumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LindowbacteriaBacteriumRifcsplowo212full6227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lindowbacteria bacterium RIFCSPLOWO212FULL6227 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LindowbacteriaBacteriumRifcsplowo212full6227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbus7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzhakiellaAustraliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaAustraliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BauldiaLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bauldia litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BauldiaLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrospiraInopinata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrospira inopinata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrospiraInopinata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumKluyveriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium kluyveri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumKluyveriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlligatorSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alligator sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlligatorSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumOlb22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium OLB22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumOlb22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaFSpontaneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa f. spontanea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaFSpontaneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaAerolatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma aerolatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaAerolatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacterium41269Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium 41_269 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacterium41269Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHydrophobicaNbrc16057Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica NBRC 16057 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GordoniaHydrophobicaNbrc16057Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaThermolimosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermolimosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermolimosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSulfidiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sulfidiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSulfidiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PunicaGranatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Punica granatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PunicaGranatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusElongatusPcc7942Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Synechococcus elongatus PCC7942 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SynechococcusElongatusPcc7942Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillalesBacteriumScgcAaa298n10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillales bacterium SCGC AAA298N10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanospirillalesBacteriumScgcAaa298n10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchotonaPrinceps(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochotona princeps graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchotonaPrinceps", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabidopsisThalianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis thaliana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisThalianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumL21thd2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium L21THD2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumL21thd2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StereumHirsutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stereum hirsutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StereumHirsutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoselliniaNecatrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rosellinia necatrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoselliniaNecatrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasElysicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas elysicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasElysicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArh4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_54_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesBurtonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanococcoidesBurtonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaSediminilitoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kangiella sediminilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KangiellaSediminilitoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB262(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB262", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatagioenasFasciataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Patagioenas fasciata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PatagioenasFasciataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFOXYD1_FULL_48_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full3984(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL3984 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full3984", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGilvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGilvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus infantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusInfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:217 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFjat26967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-26967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat26967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYD1_FULL_52_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyd1Full5236Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDubiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter dubius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDubiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoclostridiumLitoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumLitoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaParvirubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sutterella parvirubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SutterellaParvirubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSeosinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia seosinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSeosinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpNfr04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActibacteriumMucosumKctc23349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actibacterium mucosum KCTC 23349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActibacteriumMucosumKctc23349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCloacaeJd6301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae JD6301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeJd6301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo202full4811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO202FULL4811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo202full4811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCannabisPvPhaseoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas cannabis pv. phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCannabisPvPhaseoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenihalanaerobacterShriftii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenihalanaerobacter shriftii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenihalanaerobacterShriftii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumJosuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium josui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumJosuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KalmanozymaBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaSpinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora spinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaSpinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusOxalaticusNbrc13593Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus NBRC 13593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CupriavidusOxalaticusNbrc13593Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaSeiffertiiAtcc49495Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma seiffertii ATCC 49495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaSeiffertiiAtcc49495Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_39_39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaryophanonTenueEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caryophanon tenue Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaryophanonTenueEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RothiaMucilaginosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rothia mucilaginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RothiaMucilaginosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaLansingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella lansingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaLansingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataellaPastorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Komagataella pastoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KomagataellaPastorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucosporidiumCreatinivorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucosporidium creatinivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucosporidiumCreatinivorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpEpsl25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. EpSL25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEpsl25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FelisCatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Felis catus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FelisCatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiMaff303099(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti MAFF303099 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiMaff303099", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalitaleaCylindroidesT287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Faecalitalea cylindroides T2-87 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FaecalitaleaCylindroidesT287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaOleraceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brassica oleracea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrassicaOleraceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesStercorirosorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides stercorirosoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesStercorirosorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliihoefleaSp2ww(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliihoeflea sp. 2WW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliihoefleaSp2ww", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaErythraea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora erythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaErythraea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusChoshinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus choshinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusChoshinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolobacteriumMooreiF0204Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei F0204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiF0204Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterHeilmanniiAsb14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii ASB1.4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterHeilmanniiAsb14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuisYs72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis YS72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisYs72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrancourtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella drancourtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrancourtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterBemidjiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter bemidjiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterBemidjiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKrulwichiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus krulwichiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusKrulwichiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusParahaemolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus parahaemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParahaemolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaCuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosarchaeumKoreenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpZagget8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. Zagget8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZagget8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusUreasiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureasiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreasiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MidichloriaMitochondriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Midichloria mitochondrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MidichloriaMitochondriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaChutoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orientia chuto Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrientiaChutoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaHelminthoecaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoecaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls474Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls474Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_01_FULL_46_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo201Full4610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevinemaAndersonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevinema andersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevinemaAndersonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaNewyorkensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina newyorkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaNewyorkensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBorstelensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoalloteichusHymeniacidonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoalloteichus hymeniacidonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoalloteichusHymeniacidonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwc14710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWC14710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwc14710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpTf25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. tf2-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpTf25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAuratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces auratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAuratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuodenibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duodenibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuodenibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeophyllumTrabeumAtcc11539Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum ATCC 11539 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GloeophyllumTrabeumAtcc11539Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronincolaFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronincola ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronincolaFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosarchaeumKoreenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseobacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseobacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraRoreriMca2997Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri MCA 2997 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraRoreriMca2997Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumVaginaeDsm15829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium vaginae DSM15829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopobiumVaginaeDsm15829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaMultimorphosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea multimorphosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaMultimorphosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonEplasma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Eplasma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonEplasma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaSelenatireducensDsm17993(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sedimenticola selenatireducens DSM 17993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SedimenticolaSelenatireducensDsm17993", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0381(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0381", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwc23423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC23423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc23423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TindalliaMagadiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tindallia magadiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TindalliaMagadiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpMit0604(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. MIT0604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpMit0604", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPiperiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piperi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiperiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaproniaCoronataCbs61796(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capronia coronata CBS 617.96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaproniaCoronataCbs61796", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSulci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sulci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSulci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArachidicoccusSpBs20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus sp. BS20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusSpBs20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifoxyc2full4719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYC2FULL4719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyc2full4719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKazanBacteriumGw2011gwa15015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium GW2011GWA15015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumGw2011gwa15015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpNbimcp2c3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. NBIMCP2C3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpNbimcp2c3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermobacterWolfeiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter wolfeii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterWolfeiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwf24317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF24317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf24317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumGw2011gwf23720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWF23720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwf23720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSp6158faact1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. 6158FAACT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TannerellaSp6158faact1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarcicellaHirudinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudarcicella hirudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudarcicellaHirudinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumVitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium vitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumVitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerochaetaGlobosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta globosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaGlobosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusRambellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus rambellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusRambellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumJenseniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium jensenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumJenseniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpRoot1471Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root1471 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot1471Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9431(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9431 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9431", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Morganella psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MorganellaPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterGlobiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter globiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterGlobiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquaspirillumSpLm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum sp. LM1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSpLm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BryobacterAggregatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bryobacter aggregatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BryobacterAggregatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichobilharziaRegentiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichobilharzia regenti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichobilharziaRegentiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumSpUch001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. UCH001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpUch001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpOv329(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV329 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv329", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaNanhaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola nanhaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanicolaNanhaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanopyrusKandleriAv19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri AV19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanopyrusKandleriAv19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumSoleaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum soleae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSoleaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterGossypii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter gossypii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterGossypii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC1_37_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc13712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatirhabdiumButyrativoransDsm18734(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfatirhabdium butyrativorans DSM 18734 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfatirhabdiumButyrativoransDsm18734", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasPhaseoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasPhaseoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifoxyd2Full5815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFOXYD2_FULL_58_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifoxyd2Full5815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpTarazonaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Tarazona Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpTarazonaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom197198w(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 197198w graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom197198w", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlexibacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TissierelliaBacteriumKa00581(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tissierellia bacterium KA00581 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TissierelliaBacteriumKa00581", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwf236839(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWF2_36_839 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwf236839", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium66474(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 66-474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium66474", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaMalayiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brugia malayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrugiaMalayiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaPickettii12dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaApicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella apicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilliamellaApicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpP4b1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. P4B1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpP4b1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_53_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesMangenotii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusHopiensisKr140Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus hopiensis KR-140 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DeinococcusHopiensisKr140Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterOkinawensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter okinawensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOkinawensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumVrystaatense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium vrystaatense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumVrystaatense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpAb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Bacterium2013arg42iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium 2013Arg42i Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Bacterium2013arg42iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL509 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4204Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4204 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4204Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc14615Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC14615 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc14615Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioNigripulchritudoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nigripulchritudo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioNigripulchritudoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgromycesAureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesAureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DermacoccusSpEllin185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. Ellin185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DermacoccusSpEllin185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumHch1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium HCH-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumHch1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSpRim28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot1304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumSpGbchlbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium sp. GBChlB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumSpGbchlbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocPunctiforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc punctiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocPunctiforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioMixtus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio mixtus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioMixtus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CupriavidusTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusUliginisN3975Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis N3/975 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusUliginisN3975Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaAnisa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella anisa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaAnisa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpStflb209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. StFLB209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpStflb209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterConcisus13826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter concisus 13826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterConcisus13826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoruegeriaMarinistellaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria marinistellae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaMarinistellaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDentalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyberlindneraJadiniiNrrlY1542Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyberlindnera jadinii NRRL Y-1542 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyberlindneraJadiniiNrrlY1542Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferSpQ7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. Q7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpQ7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumNigrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum nigrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumNigrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAlbaNbrc108234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia alba NBRC 108234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAlbaNbrc108234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriKos6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri KOS6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriKos6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpAb3007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. AB3007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpAb3007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusHaemolyticusM21639(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21639 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21639", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasUreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas ureae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasUreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocodylusPorosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crocodylus porosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrocodylusPorosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErinaceusEuropaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erinaceus europaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErinaceusEuropaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesShahiiWal8301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes shahii WAL 8301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesShahiiWal8301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesPosadasii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides posadasii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesPosadasii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAld1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAld1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpRc2dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc2d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc2dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumGeorgienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaxillusRubicundulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaxillusRubicundulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaMirobrigensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora mirobrigensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMirobrigensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpScn7327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. SCN 73-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpScn7327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcticibacterEurypsychrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter eurypsychrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterEurypsychrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsplowo201full5020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO201FULL5020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo201full5020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacacaNemestrinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macaca nemestrina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacacaNemestrinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusCleftensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus cleftensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusCleftensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaHypoxylonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylaria hypoxylon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylariaHypoxylonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorogloeopsisFritschiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorogloeopsis fritschii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorogloeopsisFritschiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag552Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:552 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag552Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbusJ1074(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus J1074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAlbusJ1074", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiodiazotrophaEndoloripesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endoloripes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndoloripesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopostipesSuicloacalisDsm15692Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopostipes suicloacalis DSM 15692 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopostipesSuicloacalisDsm15692Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs3022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-3022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs3022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMacacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter macacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMacacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg165418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinococcusLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinococcusLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaReesei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma reesei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaReesei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumB14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium B14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumB14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinococcusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaUbonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia ubonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaUbonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLeaf58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharoperbutylacetonicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharoperbutylacetonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharoperbutylacetonicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYr528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR528 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliCfn42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli CFN42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliCfn42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusVersutus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus versutus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccusVersutus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoplanusLimicolaDsm2279Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus limicola DSM 2279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusLimicolaDsm2279Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaritaleaMyrionectaeDsm19524Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Maritalea myrionectae DSM 19524 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MaritaleaMyrionectaeDsm19524Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SuhomycesTanzawaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Suhomyces tanzawaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SuhomycesTanzawaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumFaecium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium faecium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumFaecium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa024d14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA024D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa024d14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesOvatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ovatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOvatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixFlexilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix flexilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiothrixFlexilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraRoreriMca2997(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri MCA 2997 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraRoreriMca2997", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumKnowlesiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinusE25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus E25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusE25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloactinosynnemaIranicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaIranicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisRemanei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis remanei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisRemanei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumDtu059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCfSaccharolyticumK10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cf. saccharolyticum K10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCfSaccharolyticumK10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusBrumalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polyporus brumalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolyporusBrumalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobellusRufus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobellus rufus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobellusRufus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubrimonasCliftonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubrimonas cliftonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubrimonasCliftonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheobromaCacao(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theobroma cacao graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheobromaCacao", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraTigrisAltaicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris altaica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantheraTigrisAltaicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCohniiNbrc15565(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cohnii NBRC 15565 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCohniiNbrc15565", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_41_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24117", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoaurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoaurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoaurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSpSa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. SA_1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpSa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVitaminophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces vitaminophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVitaminophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumBergheiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium berghei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumBergheiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLeaf48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladusLaminosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MastigocladusLaminosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpRoot65Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot65Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesotogaPrima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesotoga prima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesotogaPrima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Niyogibacteria bacterium RIFCSPLOWO2_12_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNiyogibacteriaBacteriumRifcsplowo212Full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermarchaeotaArchaeonJdfr18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermarchaeota archaeon JdFR-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermarchaeotaArchaeonJdfr18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg135021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_50_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo201full4826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO201FULL4826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo201full4826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPseudofirmusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudofirmus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudofirmusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumKh2t8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium KH2T8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumKh2t8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumLf3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return bacterium LF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriumLf3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVirginiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces virginiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesVirginiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRbg133914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RBG133914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRbg133914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLappah108(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH108 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpLappah108", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_12_FULL_41_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUrha0014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. URHA0014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUrha0014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacterSp126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter sp. 126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthobacterSp126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendroctonusPonderosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dendroctonus ponderosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DendroctonusPonderosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusPacaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus pacaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusPacaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngm7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B261 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonasPhototrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas phototrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasPhototrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaDasiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachancea dasiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachanceaDasiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrobasidiumTorrendii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermosubterraneusDsm16057Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfofundulus thermosubterraneus DSM 16057 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfofundulusThermosubterraneusDsm16057Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExidiaGlandulosaHhb12029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exidia glandulosa HHB12029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExidiaGlandulosaHhb12029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpNcppb925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. NCPPB 925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpNcppb925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolffiiSerovarKhoratStrKhoratH2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolffii serovar Khorat str. Khorat-H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolffiiSerovarKhoratStrKhoratH2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho201full4111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO201FULL4111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho201full4111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrettanomycesNaardenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces naardenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesNaardenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterMarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter marensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterMarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterUraniireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter uraniireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterUraniireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumHtcc2207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpWg5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. WG5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpWg5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoflavonifractorSpMarseillep3106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor sp. MarseilleP3106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorSpMarseillep3106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatiyooniaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteraceaeBacteriumPmmr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacteraceae bacterium PMMR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacteraceaeBacteriumPmmr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasPopuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas populi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasPopuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGilichinskyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gilichinskyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGilichinskyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusSp13mg44airCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus sp. 13MG44air Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JeotgalicoccusSp13mg44airCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodniusProlixus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodnius prolixus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodniusProlixus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasOligotrophaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas oligotropha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasOligotrophaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusSaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumSepticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium septicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSepticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumContaminansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumContaminansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpartinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas spartinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpartinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCinaediCcug18818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi CCUG18818 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediCcug18818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaAzurea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora azurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaAzurea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR221 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpTpbh4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. TPBH4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpTpbh4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacaseiAtcc334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei ATCC 334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParacaseiAtcc334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSpPro95Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. PRO95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpPro95Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumRbg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoanaerobaculumSaburreumDsm3986Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum saburreum DSM3986 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSaburreumDsm3986Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnicellularCyanobacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnicellularCyanobacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpMarseillep328(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. MarseilleP328 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpMarseillep328", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulusDsm18846Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus DSM 18846 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulusDsm18846Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetranychusUrticaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetranychus urticae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetranychusUrticaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp4212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSp13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumLongipes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium longipes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumLongipes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaGansuensisDsm44835Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Jiangella gansuensis DSM 44835 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JiangellaGansuensisDsm44835Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesJensenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides jensenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesJensenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCalviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCalviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAa4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumDifficile630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile 630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficile630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRubidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rubida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRubidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerotiniaBorealisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia borealis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaBorealisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4027(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4027 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4027", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXbb2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSpTu14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sp. TU-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSpTu14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCaseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCaseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumVivaxSal1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Sal-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVivaxSal1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraKernoviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora kernoviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraKernoviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSp4081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 40-81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp4081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterPectenicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter pectenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterPectenicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpGa2829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-2829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa2829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumIndicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumIndicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_50_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaFerrariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ferrariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFerrariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaRubripromontoriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula rubripromontorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaRubripromontoriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrodochiumBolleyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microdochium bolleyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrodochiumBolleyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCaseiDsm20011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei DSM20011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiDsm20011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumUniforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium uniforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumUniforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusParcubacteriaBacterium4484255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Parcubacteria bacterium 4484_255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusParcubacteriaBacterium4484255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcidifarinaeDsm19394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidifarinae DSM 19394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidifarinaeDsm19394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoflavibacterZeaxanthinifaciensDsm18436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens DSM 18436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensDsm18436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSparsogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sparsogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSparsogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusVerrucosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus verrucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusVerrucosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterLuteusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter luteus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLuteusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusYunnanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusYunnanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrodictiumOccultumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium occultum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumOccultumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TissierellaPraeacutaDsm18095(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tissierella praeacuta DSM 18095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TissierellaPraeacutaDsm18095", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusMacroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus macroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusMacroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterSpPpn85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter sp. Ppn85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterSpPpn85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumRifoxyb1full5412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYB1FULL5412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyb1full5412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpOv174Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. OV174 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpOv174Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAminophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaVersiformeJcm10478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema versiforme JCM 10478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatrinemaVersiformeJcm10478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusSpNa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus sp. NA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusSpNa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraSp63(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thauera sp. 63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThaueraSp63", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSantoriniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter santoriniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSantoriniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromohalobacterJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKapabacteriaThiocyanatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kapabacteria thiocyanatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKapabacteriaThiocyanatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSoldanellicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium soldanellicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSoldanellicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonInterdigitaleMr816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton interdigitale MR816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichophytonInterdigitaleMr816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RutstroemiaSpNjr2017aBbwEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rutstroemia sp. NJR-2017a BBW Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RutstroemiaSpNjr2017aBbwEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasRupellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Megamonas rupellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MegamonasRupellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumActinocoloniiformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium actinocoloniiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumActinocoloniiformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacibacillusPorcorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacillus porcorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacibacillusPorcorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyocaulusViviparusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dictyocaulus viviparus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DictyocaulusViviparusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaVespertilionisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Malassezia vespertilionis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MalasseziaVespertilionisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumHydatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hydatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHydatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAphoticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aphoticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAphoticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParastagonosporaNodorumSn15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum SN15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParastagonosporaNodorumSn15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_37_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumStercorariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium stercorarium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumStercorariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwa24110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWA24110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwa24110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpDsm18164Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. DSM 18164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpDsm18164Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusAcidocaldariusDsm446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius DSM446 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusDsm446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077526 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpGwc16184Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. GWC1_61_84 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpGwc16184Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSp519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. 51_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSp519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumGa0077531Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077531 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077531Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSaprophyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia saprophytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSaprophyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMt2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. MT2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpMt2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwb16080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWB1_60_80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwb16080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterJohnsoniiXbb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter johnsonii XBB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterJohnsoniiXbb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzovibrioRestrictus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azovibrio restrictus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzovibrioRestrictus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaSpCba1127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula sp. CBA1127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaSpCba1127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMisasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus misasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMisasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwellbacteriaBacteriumRifcsplowo212full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO212FULL4311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo212full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf23917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaOculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma oculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaOculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaShimofusensisNbrc100134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia shimofusensis NBRC 100134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaShimofusensisNbrc100134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumMs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumMs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml96a049Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML96A049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml96a049Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KytococcusSedentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kytococcus sedentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KytococcusSedentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf274(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf274", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesQaidamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces qaidamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesQaidamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtelocyanobacteriumThalassaAlohaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa ALOHA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaAlohaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombellaIntestiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bombella intestini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BombellaIntestiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusPeptidifermentansDsm18978Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans DSM 18978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentansDsm18978Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDenticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella denticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDenticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_48_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full4817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaMellicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wallemia mellicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WallemiaMellicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoniliophthoraPerniciosaFa553Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora perniciosa FA553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraPerniciosaFa553Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordonibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordonibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanospirillumHungateiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanospirillum hungatei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanospirillumHungateiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag877Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:877 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag877Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCristatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cristatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCristatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypsizygusMarmoreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hypsizygus marmoreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HypsizygusMarmoreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeDcc43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae DCC43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeDcc43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolimonasFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solimonas flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolimonasFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRattaustralianiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattaustraliani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattaustralianiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesParvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces parvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomycesParvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferrisomaCamini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deferrisoma camini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeferrisomaCamini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumAb4001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium AB4001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumAb4001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeromyxobacterSpRbg166914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. RBG_16_69_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpRbg166914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusSpPamc21323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus sp. PAMC21323 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusSpPamc21323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRifcsphigho212full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPHIGHO212FULL4510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsphigho212full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaSpPe36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moritella sp. PE36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoritellaSpPe36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusColeohominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coleohominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusColeohominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo202full4337Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO202FULL4337 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo202full4337Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpWy10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. WY10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpWy10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreneyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freneyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFreneyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaMallotivoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia mallotivora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaMallotivoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwa23526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWA2_35_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwa23526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2304851(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_48_51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304851", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota group-6 archaeon AD8-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeotaGroup6ArchaeonAd81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTypographi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia typographi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTypographi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatranaerobiusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natranaerobius thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatranaerobiusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JiangellaMuralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jiangella muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JiangellaMuralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParauberisNcfd2020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis NCFD2020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisNcfd2020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DasaniaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dasania marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DasaniaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBreveEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium breve Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBreveEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiGoettingen(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Goettingen graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiGoettingen", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionisporaSp2237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionispora sp. 2/2-37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionisporaSp2237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiOharaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei oharae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiOharaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Beta vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BetaVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpSgbin1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag632(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:632 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag632", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungatellaHathewayiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungatella hathewayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungatellaHathewayiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpragueaLophii42110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spraguea lophii 42_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpragueaLophii42110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoritellaViscosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moritella viscosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoritellaViscosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfOnchocerca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Onchocerca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfOnchocerca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXbb1006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB1006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb1006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusSpCag782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus sp. CAG:782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprococcusSpCag782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwa24915Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA2_49_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa24915Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillibacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpMlsb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. MLSB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpMlsb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipataDsm17808Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kaistia adipata DSM 17808 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KaistiaAdipataDsm17808Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHBB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConfluentimicrobiumSpEmb200ns6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Confluentimicrobium sp. EMB200NS6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConfluentimicrobiumSpEmb200ns6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpCf468(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF468 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf468", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusComesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus comes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprococcusComesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacterAlgarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacter algarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacterAlgarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumFrediiNgr234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii NGR234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiNgr234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumVrystaatenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium vrystaatense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumVrystaatenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYD2_FULL_39_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaMiricolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Elizabethkingia miricola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ElizabethkingiaMiricolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCystitidisDsm20524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis DSM 20524 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidisDsm20524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumBdw918(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BDW918 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBdw918", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusPeraridilitorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus peraridilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPeraridilitorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaTobetsuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella tobetsuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaTobetsuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusChampanellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusChampanellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSd21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SD21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSd21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaWorsleiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella worsleiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaWorsleiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMoscovienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum moscoviense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMoscovienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProvidenciaSiddalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Providencia siddallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusProvidenciaSiddalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CloacibacteriumNormanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacibacterium normanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacibacteriumNormanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCommune(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCommune", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb14314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb14314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumGubbeenenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gubbeenense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGubbeenenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAstaxanthinifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas astaxanthinifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAstaxanthinifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxDieseloleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax dieselolei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxDieseloleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumAo1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium AO1B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumAo1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusMicrosporusAtcc52813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizopus microsporus ATCC 52813 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizopusMicrosporusAtcc52813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1397Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_39_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1397Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonisporaThiosulfatigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaSaanichensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tatumella saanichensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TatumellaSaanichensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaCasuarinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia casuarinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaCasuarinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BarnesiellaViscericola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella viscericola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaViscericola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumAngustumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium angustum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumAngustumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpRoot336d2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root336D2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot336d2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraSpNd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. ND1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpNd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrientalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter orientalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOrientalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAlcoholivoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum alcoholivorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAlcoholivoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRubrobruneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rubrobrunea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRubrobruneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EptatretusBurgeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eptatretus burgeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EptatretusBurgeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntestinimonasMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonCsp11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon CSP1-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCsp11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg166719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_67_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg166719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsphigho202full4912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPHIGHO202FULL4912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsphigho202full4912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSpPpcgb2223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PPCGB 2223 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPpcgb2223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HathewayaProteolyticaDsm3090Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica DSM 3090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HathewayaProteolyticaDsm3090Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSyringaeCc1557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas syringae CC1557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSyringaeCc1557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinellusMicaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprinellus micaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprinellusMicaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumHiltneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisBrandtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Myotis brandtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MyotisBrandtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHordei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hordei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHordei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpP5119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P5-119 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP5119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesBrasiliensisPb18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Pb18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensisPb18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusMeridieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus meridiei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusMeridieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaMacacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaMacacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTuricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces turicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesTuricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumRaimondiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gossypium raimondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GossypiumRaimondiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorAmbiguus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucor ambiguus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucorAmbiguus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechenseLl01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium czechense LL01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumCzechenseLl01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumRifcsphigho212full3622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium RIFCSPHIGHO212FULL3622 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumRifcsphigho212full3622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpYbl2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YBL2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYbl2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaVulneris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia vulneris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaVulneris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilicibacterLacuscaerulensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter lacuscaerulensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SilicibacterLacuscaerulensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YangiaSpCcbmm3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yangia sp. CCBMM3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YangiaSpCcbmm3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaPalmaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma palmae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaPalmaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaProductaAtcc27340Dsm2950Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta ATCC 27340 DSM 2950 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlautiaProductaAtcc27340Dsm2950Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymomonasMobilisPomaceae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis pomaceae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisPomaceae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumDenitrificansAtcc51888(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans ATCC51888 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificansAtcc51888", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LobosporangiumTransversaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lobosporangium transversale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LobosporangiumTransversaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasDonghaensisDsm18148Ho3R19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis DSM 18148 HO3-R19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArenimonasDonghaensisDsm18148Ho3R19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BisonBisonBison(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bison bison bison graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BisonBisonBison", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAethiopicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aethiopicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAethiopicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumLimnosediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium limnosediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumLimnosediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobacterSpRoot404Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root404 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot404Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFCircinelloidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerriphaselusSpR1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus sp. R1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusSpR1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaLupini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora lupini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaLupini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InquilinusLimosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Inquilinus limosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "InquilinusLimosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiccibacterTuricensisLmg23730Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter turicensis LMG 23730 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SiccibacterTuricensisLmg23730Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRhodobacterLobularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodobacter lobularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodobacterLobularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaRapaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brassica rapa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrassicaRapaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaTheileri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma theileri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaTheileri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpKt25bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. KT25b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpKt25bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiibiusSpNy1634622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Branchiibius sp. NY16-3462-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BranchiibiusSpNy1634622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAerogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio aerogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioAerogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterMelonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter melonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterMelonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoahuilensisP1143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis p1.1.43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCoahuilensisP1143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAntibioticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces antibioticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAntibioticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpP6b1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P6B1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP6b1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalimicrobiumJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolanumTuberosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solanum tuberosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolanumTuberosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpLor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. LOR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpLor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasEustigmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas eustigma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasEustigmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDendritiformisC454Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis C454 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformisC454Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHygroscopicusJinggangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus jinggangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusJinggangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollimonasSpOk242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaMinor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella minor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaMinor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrospiraPlatensisNies39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis NIES39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisNies39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelissococcusPlutoniusAtcc35311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Melissococcus plutonius ATCC 35311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MelissococcusPlutoniusAtcc35311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaMaltosaXu316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Xu316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaMaltosaXu316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGracilibacteriaBacteriumCg10238174(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gracilibacteria bacterium CG1_02_38_174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGracilibacteriaBacteriumCg10238174", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptobacterTengchongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kryptobacter tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KryptobacterTengchongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwb11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhytofirmansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phytofirmans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhytofirmansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArtemisiaAnnuaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Artemisia annua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArtemisiaAnnuaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodiomycesAlkalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SodiomycesAlkalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpTfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. TF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpTfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc2458(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC2458 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc2458", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpF0436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBingchenggensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bingchenggensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBingchenggensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylumTricornutumCcap10551Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum CCAP 1055/1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutumCcap10551Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteitaleaPratensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteitalea pratensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteitaleaPratensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag488(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:488 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag488", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrettanomycesNaardenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces naardenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesNaardenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusCaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusCaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumGoodii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium goodii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumGoodii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumRedseas09b7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium REDSEAS09B7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumRedseas09b7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusSpKp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus sp. Kp2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusSpKp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumOpportunistum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium opportunistum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOpportunistum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSeleniigenesDsm18267Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes DSM 18267 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PelobacterSeleniigenesDsm18267Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonchuraStriataDomesticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lonchura striata domestica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LonchuraStriataDomesticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpBa92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaHispanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula hispanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaHispanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpNTMorphotypeBEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. N.t. morphotype B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EpulopisciumSpNTMorphotypeBEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc14312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC14312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc14312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag884(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:884 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag884", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfiporiaCocosMd104Ss10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolfiporia cocos MD-104 SS10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolfiporiaCocosMd104Ss10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAkl19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllomycesMacrogynus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allomyces macrogynus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllomycesMacrogynus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGambrini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gambrini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGambrini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfurarchaeumFormicicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfurarchaeum formicicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalodesulfurarchaeumFormicicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCurvatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus curvatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCurvatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacaAbyssiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibaca abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacaAbyssiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaRadiotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma radiotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRadiotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerribacillusAidingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus aidingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerribacillusAidingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXbd2001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBD2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbd2001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_50_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2699(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2699 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2699", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosartoryaFischeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neosartorya fischeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeosartoryaFischeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeO1BiovarEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 biovar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO1BiovarEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusAzorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius azorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAzorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomicrobialesSpKi4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Thermomicrobiales sp. KI4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "ThermomicrobialesSpKi4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatonellaMorbiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catonella morbi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatonellaMorbiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterTibetensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter tibetensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterTibetensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaZeaeDsm19591Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Runella zeae DSM 19591 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RunellaZeaeDsm19591Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpKw12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. KW12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpKw12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf405(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf405 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf405", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStriatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium striatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStriatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesCiferriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesCiferriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumAustralicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium australicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAustralicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UreaplasmaUrealyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma urealyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaUrealyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpEr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. ER2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpEr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPsychrophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella psychrophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPsychrophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpRs9917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. RS9917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpRs9917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum3841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 3841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum3841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusUreilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus ureilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusUreilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusTerranovensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus terranovensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusTerranovensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusAcididurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acididurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcididurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermatophilusCongolensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DermatophilusCongolensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMendocinaNk01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mendocina NK01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMendocinaNk01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaLimosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Runella limosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RunellaLimosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldithrixSpRbg13449(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix sp. RBG_13_44_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldithrixSpRbg13449", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisIgneusKol5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris igneus Kol 5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisIgneusKol5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumDtu027Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium DTU027 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumDtu027Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichormusSpNmc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichormus sp. NMC-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichormusSpNmc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUrhb0009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. URHB0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUrhb0009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat27231Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27231 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27231Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusLocisalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus locisalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusLocisalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpBal6xEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BAL6X Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBal6xEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGingeriNcppb3146Lmg5327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri NCPPB 3146 LMG 5327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasGingeriNcppb3146Lmg5327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PercaFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Perca flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PercaFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusMahiiDsm5219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus mahii DSM 5219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusMahiiDsm5219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpYr710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. YR710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpYr710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSalsus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus salsus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSalsus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaEnoecaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella enoeca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaEnoecaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSp3131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 3_1_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionNc10BacteriumCsp15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium CSP1-5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumCsp15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichoplaxSpH2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax sp. H2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxSpH2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogladiusCellulolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermogladius cellulolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermogladiusCellulolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpTw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. TW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpTw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetireducensDsm10703Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetireducens DSM 10703 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcetireducensDsm10703Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSpAsf360(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. ASF360 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpAsf360", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSubbeticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agromyces subbeticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgromycesSubbeticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaPsychrerythraeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovivaxAsiaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halovivax asiaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalovivaxAsiaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisSorokinianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris sorokiniana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BipolarisSorokinianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumSalsuginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium salsuginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSalsuginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LepisosteusOculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lepisosteus oculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LepisosteusOculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SagittulaStellataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sagittula stellata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SagittulaStellataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPropionicifaciensDsm19291Jcm14649Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens DSM 19291 JCM 14649 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciensDsm19291Jcm14649Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiofilumFlexileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiofilum flexile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiofilumFlexileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGlobisporusC1027Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces globisporus C-1027 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGlobisporusC1027Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumAethiopicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium aethiopicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAethiopicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenariaAnguillulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenaria anguillulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenariaAnguillulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCereusRock344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus Rock3-44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusRock344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAzotoformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus azotoformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAzotoformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpLeaf384Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf384 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf384Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumBrasilenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum brasilense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumBrasilenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaPhytofirmans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phytofirmans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhytofirmans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumLymphophilumAcs093VSch5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum ACS-093-V-SCH5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilumAcs093VSch5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumIndicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumIndicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc7502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VanderwaltozymaPolysporaDsm70294Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora DSM 70294 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VanderwaltozymaPolysporaDsm70294Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzisolibacterPropanilivoraxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryzisolibacter propanilivorax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzisolibacterPropanilivoraxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DermatophilusCongolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DermatophilusCongolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPsychraerophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium psychraerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPsychraerophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrackiellaOedipodisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brackiella oedipodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrackiellaOedipodisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumGlaciei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium glaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGlaciei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumSpScc3193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium sp. SCC3193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumSpScc3193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf89Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf89Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotaleaPsychrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotalea psychrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotaleaPsychrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSuebicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus suebicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSuebicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMcba15008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaHollisaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Grimontia hollisae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GrimontiaHollisaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacterium41269Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium 41_269 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacterium41269Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniellaLuteolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella luteola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaLuteolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho201full4349Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO201FULL4349 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho201full4349Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsPolyrhachisfurcataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachisfurcata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisfurcataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumRifcsplowo202full6214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPLOWO202FULL6214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsplowo202full6214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4710b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4710b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4710b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho202full5216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL5216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full5216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusXiphinematobacterSpIdahoGrape(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xiphinematobacter sp. Idaho Grape graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusXiphinematobacterSpIdahoGrape", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PunctulariaStrigosozonataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Punctularia strigosozonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PunctulariaStrigosozonataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full509bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL509b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full509bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg19ftcombo5621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO5621 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo5621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParambassisRangaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parambassis ranga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParambassisRangaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerpetosiphonAurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herpetosiphon aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerpetosiphonAurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParvimonasSpF0440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. F0440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpF0440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBacteremicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium bacteremicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBacteremicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_12_FULL_46_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo212Full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgreiaBicolorata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agreia bicolorata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgreiaBicolorata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaSpY9602Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella sp. Y9602 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RahnellaSpY9602Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHyorhinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSubterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter subterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSubterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaBogorensisNbrc16594(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Asaia bogorensis NBRC 16594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AsaiaBogorensisNbrc16594", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriL37603(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri L37603 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriL37603", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg134915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioHalophilusDsm15072(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus DSM 15072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilusDsm15072", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusGlaucusCbs51665(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus glaucus CBS 516.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusGlaucusCbs51665", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusProomii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus proomii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusProomii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaDc2201(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila DC2201 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaDc2201", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0429 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuribacillusStibiiarsenatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuribacillus stibiiarsenatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuribacillusStibiiarsenatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_12_FULL_43_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo212Full4312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinus1366Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus 1366 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinus1366Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAegiribacteriaBacteriumMlsCCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aegiribacteria bacterium MLS_C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAegiribacteriaBacteriumMlsCCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NasoniaVitripennisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nasonia vitripennis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NasoniaVitripennisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacearchaeotaArchaeonRbg133326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacearchaeota archaeon RBG_13_33_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacearchaeotaArchaeonRbg133326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusSpretusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mus spretus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusSpretusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorangiumCellulosumSoCe56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So ce56 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSoCe56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiaceaeBacteriumKb18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridiaceae bacterium KB18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiaceaeBacteriumKb18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpCag52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospirillumFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiversisporaEpigaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Diversispora epigaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DiversisporaEpigaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporomusaSphaeroidesDsm2875(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporomusa sphaeroides DSM 2875 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporomusaSphaeroidesDsm2875", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusNishinomiyaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus nishinomiyaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DermacoccusNishinomiyaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WaddliaChondrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Waddlia chondrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WaddliaChondrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeolentinusLepideusHhb14362Ss1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neolentinus lepideus HHB14362 ss-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeolentinusLepideusHhb14362Ss1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMojavensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mojavensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusMojavensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_42_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaUli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella uli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasEchinoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas echinoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasEchinoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosmotogaArenicorallinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KosmotogaArenicorallinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlesiomonasShigelloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plesiomonas shigelloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlesiomonasShigelloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomicrobiumPiriforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomicrobium piriforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomicrobiumPiriforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPrimitiaZas2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSp7321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. 73-21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSp7321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg134510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_13_45_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg134510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreicellaSpSe45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. SE45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitreicellaSpSe45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGordonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGordonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCfSaccharolyticumK10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Clostridium] cf. saccharolyticum K10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCfSaccharolyticumK10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliiroseovariusCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaVirensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma virens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaVirensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumBouchesdurhonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium bouchesdurhonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumBouchesdurhonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasRuminantiumLactilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium lactilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumLactilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatoriaNigroviridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria nigroviridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaNigroviridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSetaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora setae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSetaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusBoraciitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus boraciitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusBoraciitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarthrobacterSiccitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter siccitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSiccitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_42_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full4222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronovibrioHydrogenovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio hydrogenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioHydrogenovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HarrisonbacteriaBacteriumRifcsphigho212full4816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harrisonbacteria bacterium RIFCSPHIGHO212FULL4816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarrisonbacteriaBacteriumRifcsphigho212full4816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumBal199Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium BAL199 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumBal199Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSp2742308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia sp. 2742-308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSp2742308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaistia adipata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaistiaAdipataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExserohilumTurcicaEt28aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exserohilum turcica Et28A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExserohilumTurcicaEt28aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaAsperellumCbs43397Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma asperellum CBS 433.97 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAsperellumCbs43397Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag485Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:485 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag485Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasGwangyangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas gwangyangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiimonasGwangyangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassiosiraPseudonana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassiosira pseudonana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassiosiraPseudonana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinispora pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinisporaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full5423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL5423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full5423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpNbimcp2c3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. NBIMCP2C3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumSpNbimcp2c3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpW121067(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. W121067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpW121067", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CytophagaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusChampanellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusChampanellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonHepatopenaeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon hepatopenaei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonHepatopenaeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaKroppenstedtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaKroppenstedtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PundamiliaNyerereiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pundamilia nyererei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PundamiliaNyerereiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasAcidaminiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas acidaminiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasAcidaminiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonsdaleaPopuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaPopuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaZeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Runella zeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RunellaZeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratiruptorTergarcusDsm16512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus DSM 16512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitratiruptorTergarcusDsm16512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPLOWO2_01_FULL_38_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsplowo201Full3812b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminibacterMediatlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumSaponariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum saponariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSaponariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpBa92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasCangingivalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas cangingivalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCangingivalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaSpHk05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scytonema sp. HK-05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScytonemaSpHk05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaMurisAs145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia muris AS145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EhrlichiaMurisAs145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SkermanellaAerolataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Skermanella aerolata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SkermanellaAerolataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumBarkeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium barkeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumBarkeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosphaeraAggregansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosphaera aggregans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosphaeraAggregansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumJb7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum JB7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumJb7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc3007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC3007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc3007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumHalorespirans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespirans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisB84634Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis B84634 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisB84634Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSpMctg156(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola sp. MCTG156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanicolaSpMctg156", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaFraseri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila fraseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaFraseri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusP6b7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus P6B7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusP6b7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSlackiiAtcc49928(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces slackii ATCC 49928 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSlackiiAtcc49928", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot708(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot708", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YokenellaRegensburgeiAtcc43003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yokenella regensburgei ATCC 43003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YokenellaRegensburgeiAtcc43003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTermitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium termitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTermitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusSubspTestudinumSp3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. testudinum Sp3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspTestudinumSp3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusGrossensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus grossensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusGrossensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_49_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full4219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL4219 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full4219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterCelticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter celticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCelticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGeothermarchaeotaArchaeonJdfr13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Geothermarchaeota archaeon JdFR-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGeothermarchaeotaArchaeonJdfr13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomosp3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls474(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls474", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp2kl3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0874(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0874 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0874", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobacillusMacyaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus macyae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusMacyaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSimiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium simiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSimiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumAcapulense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium acapulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAcapulense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusObeumAtcc29174Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus obeum ATCC29174 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusObeumAtcc29174Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypocladiumCapitatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium capitatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumCapitatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumPygmaeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium pygmaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPygmaeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCb03234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusRadiodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus radiodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusRadiodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzimaplasmaSpHr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Izimaplasma sp. HR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IzimaplasmaSpHr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0077540Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0077540 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0077540Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBorealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBorealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterTroitsensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter troitsensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterTroitsensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisTerraeSubspTerraeNbrc15098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae subsp. terrae NBRC 15098 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisTerraeSubspTerraeNbrc15098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo2OfFrankliniellaOccidentalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 of Frankliniella occidentalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2OfFrankliniellaOccidentalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaFaecimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia faecimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaFaecimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUliginosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium uliginosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumUliginosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanohalarchaeumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanohalarchaeum thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanohalarchaeumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSp5720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 57_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp5720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaJaponicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaJaponicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpRoot83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. Root83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpRoot83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 39-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus constellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusConstellatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuberDsm16370Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ruber DSM 16370 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioRuberDsm16370Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPestisCo92Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pestis CO92 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "YersiniaPestisCo92Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusAcidiphilusNbrc100859Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus NBRC 100859 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilusNbrc100859Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpG5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. G5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpG5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusSolitariusNbrc100494Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius NBRC 100494 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetragenococcusSolitariusNbrc100494Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumPullorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pullorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPullorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutremaSalsugineumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eutrema salsugineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EutremaSalsugineumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrocarboniphagaEffusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CharadriusVociferusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Charadrius vociferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CharadriusVociferusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaUdeisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia udeis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaUdeisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpYr477Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR477 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr477Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg19ftCombo6530(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_19FT_COMBO_65_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg19ftCombo6530", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_56_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosalsumZhilinaeDsm4017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae DSM 4017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosalsumZhilinaeDsm4017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpLeaf78Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf78Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRbg166534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPhytoplasmaPruniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma pruni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaPruniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngustibacterSpRoot456Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Angustibacter sp. Root456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AngustibacterSpRoot456Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCoccinea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trametes coccinea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrametesCoccinea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobilicoccusPelagiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mobilicoccus pelagius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MobilicoccusPelagiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaMacrocephaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina macrocephali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMacrocephaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagnetotacticumMs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum MS-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticumMs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoHordeiUh48574(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ustilago hordei Uh4857-4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UstilagoHordeiUh48574", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomosp3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThecamonasTrahensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thecamonas trahens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThecamonasTrahensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombellaIntestiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bombella intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BombellaIntestiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumSpP610x1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. P610X1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpP610x1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusCarbonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptacidiphilus carbonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptacidiphilusCarbonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaGarinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia garinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaGarinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IxodesScapularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ixodes scapularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IxodesScapularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13140cm6927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13140CM6927 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13140cm6927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremellaMesenterica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tremella mesenterica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TremellaMesenterica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaRocourtiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria rocourtiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaRocourtiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaKroppenstedtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia kroppenstedtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaKroppenstedtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDextrinicusDsm20335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus DSM 20335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDextrinicusDsm20335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasSpNm51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaPseudoobscuraPseudoobscura(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura pseudoobscura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscuraPseudoobscura", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActibacteriumMucosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actibacterium mucosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActibacteriumMucosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacillusSpOk032(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk032", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAcaciaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia acaciae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAcaciaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe23640Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE2_36_40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe23640Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifoxyc1full4826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFOXYC1FULL4826 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifoxyc1full4826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatoriaNigroviridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria nigroviridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaNigroviridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VogesellaSpEbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogesella sp. EB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogesellaSpEbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemominutumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemominutum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemominutumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterFerrugineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter ferrugineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterFerrugineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterMyodis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter myodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMyodis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArlettae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaOvisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveraIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KluyveraIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaAfzelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella afzelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaAfzelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LipomycesStarkeyiNrrlY11557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi NRRL Y-11557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LipomycesStarkeyiNrrlY11557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixTepida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix tepida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixTepida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesXylanisolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides xylanisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesXylanisolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoyosellaSubflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoyosella subflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoyosellaSubflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaGrahamiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella grahamii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaGrahamiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumCambrienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum cambriense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VaribaculumCambrienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaSpAngrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. ANGR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpAngrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_49_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaEnzanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora enzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaEnzanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeocapsaSpPcc7428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC7428 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc7428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaBenhamiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma benhamiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaBenhamiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumGilvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium gilvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumGilvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCrassostreae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia crassostreae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaCrassostreae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorNaganoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconacetobacterSpSxcc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter sp. SXCC-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterSpSxcc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa278o22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA278O22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa278o22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNigerAtcc1015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus niger ATCC 1015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusNigerAtcc1015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaThiooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella thiooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaThiooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSeoulense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium seoulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSeoulense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAnatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma anatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAnatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorvusBrachyrhynchosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corvus brachyrhynchos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorvusBrachyrhynchosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaNiveoalbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora niveoalba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaNiveoalbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiolapillusBrandeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiolapillus brandeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiolapillusBrandeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaTimonensisCris5cb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella timonensis CRIS5CB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaTimonensisCris5cb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAmmonioxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia ammonioxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAmmonioxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RathayibacterSpLeaf296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSalinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina salinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSalinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumTardaugens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium tardaugens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumTardaugens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSchubertii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas schubertii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasSchubertii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpMst1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MSt1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMst1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaEchinicomitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga echinicomitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEchinicomitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMacquariensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macquariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMacquariensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaSpAl04100510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. AL041005-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpAl04100510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaAsymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia asymbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaAsymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxHaloduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHaloduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumRifcsplowo212full4010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO212FULL4010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo212full4010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixRoseaIamM220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix rosea IAM M-220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LimnothrixRoseaIamM220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13220cm5827(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_2_20CM_58_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13220cm5827", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrusXBretschneideri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyrus x bretschneideri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyrusXBretschneideri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsplowo212full4211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPLOWO212FULL4211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsplowo212full4211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlantibacterSpLeaf314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Plantibacter sp. Leaf314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlantibacterSpLeaf314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaBogorensisNbrc16594Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Asaia bogorensis NBRC 16594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AsaiaBogorensisNbrc16594Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusGattiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus gattii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptococcusGattiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumSpSma27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. SMA-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpSma27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiaceaeBacteriumGa0074131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium Ga0074131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumGa0074131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemolyticusM19501(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M19501 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM19501", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMustelae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mustelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMustelae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmataMassilianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmata massiliana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmataMassilianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColobusAngolensisPalliatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colobus angolensis palliatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColobusAngolensisPalliatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSp7sr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. 7SR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSp7sr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetschnikowiaBicuspidataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia bicuspidata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaBicuspidataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterOleivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter oleivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterOleivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumNeopropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum neopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumNeopropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforegulaConservatrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulforegula conservatrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulforegulaConservatrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanTroglodytesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pan troglodytes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PanTroglodytesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiphophorusCouchianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus couchianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XiphophorusCouchianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeoasaiaChiangmaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neoasaia chiangmaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeoasaiaChiangmaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilvimarinusAgarilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus agarilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusAgarilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesResistomycificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces resistomycificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesResistomycificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaMattheeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma mattheei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMattheeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythruraGouldiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrura gouldiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythruraGouldiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapitellaTeleta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capitella teleta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapitellaTeleta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumRhizophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraYegresiiCbs114405Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii CBS 114405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraYegresiiCbs114405Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusJohnsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJohnsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumPusillumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium pusillum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumPusillumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusHalotoleransDsm16375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans DSM 16375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinococcusHalotoleransDsm16375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinum202f(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum 202F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinum202f", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSp90Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. 90 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSp90Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonadalesBacterium66474Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 66-474 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium66474Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumDiphtheriaeNctc13129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae NCTC 13129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriaeNctc13129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpLeaf183(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf183", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCorrugataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas corrugata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCorrugataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH053Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H053 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH053Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCaseiDsm20011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei DSM20011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiDsm20011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumScgcAaa252p10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252P10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252p10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobaculumHydrogeniformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum hydrogeniformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumHydrogeniformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyb1full4015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYB1FULL4015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyb1full4015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCollagenovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium collagenovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCollagenovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSpNcppb925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium sp. NCPPB 925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSpNcppb925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerticilliumDahliaeVdls17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Verticillium dahliae VdLs.17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VerticilliumDahliaeVdls17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucorCircinelloidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mucor circinelloides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MucorCircinelloidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumLacusprofundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lacusprofundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLacusprofundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvularculaOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNk4a136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A136 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho2024118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO2024118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho2024118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsplowo201full4818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO201FULL4818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo201full4818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChristensenellaceaeBacteriumPhil1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaAsaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella asaccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemellaAsaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRbg165624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_56_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloceraViscosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calocera viscosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloceraViscosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasNitrosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas nitrosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasNitrosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaSordidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Valsa sordida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ValsaSordidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GalbibacterMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Galbibacter marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GalbibacterMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaElongataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaElongataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusZhangzhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus zhangzhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusZhangzhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus mitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMandelii36mfcvi11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii 36MFCvi11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandelii36mfcvi11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaZhejiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia zhejiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaZhejiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaHispanicaCriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia hispanica CRI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaHispanicaCriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaLacunaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaLacunaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYD1_FULL_51_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyd1Full5118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumGraminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum graminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGraminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpB1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. B1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpB1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpB7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpB7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesOleiciplenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides oleiciplenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOleiciplenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterNanhaiticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nanhaiticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNanhaiticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSediminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSediminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypothrixBouteillei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolypothrixBouteillei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSulciaMuelleriCariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri CARI Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriCariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig2b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaIntermedia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia intermedia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaIntermedia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSpSg02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. SG02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSpSg02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasCapnocytophagoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSp5039(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. 50-39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSp5039", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificansPd1222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans PD1222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccusDenitrificansPd1222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumScgcAaa011l6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium SCGC AAA011L6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumScgcAaa011l6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaedlerellaArabinosiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaedlerella arabinosiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaedlerellaArabinosiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaPiezophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga piezophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinitogaPiezophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaEutrophaH16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha H16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaH16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusProteolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusProteolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAlbusJ1074Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces albus J1074 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAlbusJ1074Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaFormicigeneransAtcc27755Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dorea formicigenerans ATCC27755 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DoreaFormicigeneransAtcc27755Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaSiciliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAnguillarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio anguillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioAnguillarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpJcm19056Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19056 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19056Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisSpNies3709(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis sp. NIES-3709 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeminocystisSpNies3709", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkenseKam1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Kam1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkenseKam1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnasPlatyrhynchosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anas platyrhynchos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnasPlatyrhynchosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanotheceSpCcy0110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. CCY0110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpCcy0110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EchinococcusMultilocularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus multilocularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EchinococcusMultilocularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyosynoviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyosynoviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyosynoviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylohalobiusCrimeensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylohalobius crimeensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylohalobiusCrimeensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumOxalicum1142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium oxalicum 114-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliumOxalicum1142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymomonasMobilisZm4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ZM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisZm4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumIndoltheticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indoltheticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndoltheticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5424 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PirellulaSpShsr6aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pirellula sp. SHSr6A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PirellulaSpShsr6aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorothrixHollandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorothrix hollandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorothrixHollandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaVignaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga vignae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaVignaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesLutiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides luti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesLutiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLpu83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. LPU83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSpLpu83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusCristatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusCristatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudolongumPv82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudolongum PV8-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumPseudolongumPv82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumLarrymooreiAf310Atcc51759Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei AF3.10 ATCC 51759 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymooreiAf310Atcc51759Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSeleniigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelobacterSeleniigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesAtroparvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles atroparvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesAtroparvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusPhenolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus phenolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusPhenolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpMaepy2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MAEPY2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMaepy2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MixiaOsmundaeIam14324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mixia osmundae IAM 14324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MixiaOsmundaeIam14324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwf23720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWF2_37_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwf23720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_37_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopococcusTabaciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopococcus tabaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopococcusTabaciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilliamellaIntestiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella intestini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilliamellaIntestiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudolabrysSpRoot1462(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudolabrys sp. Root1462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudolabrysSpRoot1462", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSinaloensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sinaloensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSinaloensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZosteraMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zostera marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZosteraMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesAureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces aureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesAureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelghirimycesThermohalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melghirimyces thermohalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelghirimycesThermohalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetobutylicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetobutylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetobutylicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasporobacteriumPaucivoransDsm15970Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parasporobacterium paucivorans DSM 15970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParasporobacteriumPaucivoransDsm15970Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpKbs0703(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. KBS0703 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpKbs0703", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpRoot186(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root186 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot186", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaElizabethae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella elizabethae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaElizabethae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifcsphigho201full4029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFCSPHIGHO201FULL4029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifcsphigho201full4029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpXbb1001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XBB1001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXbb1001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaMexicana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poecilia mexicana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoeciliaMexicana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpMed152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. MED152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpMed152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusSpTolsrEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus sp. TolSR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusSpTolsrEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VecturithrixGranuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vecturithrix granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VecturithrixGranuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBay1663Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BAY1663 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBay1663Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaBusckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila busckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaBusckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPertussisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella pertussis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaPertussisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaGraminisFSpTriticiCrl75367003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Puccinia graminis f. sp. tritici CRL 75-36-700-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PucciniaGraminisFSpTriticiCrl75367003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CinnamomumMicranthumFKanehiraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum f. kanehirae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CinnamomumMicranthumFKanehiraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSimilisDsm23365Jcm2765Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus similis DSM 23365 JCM 2765 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSimilisDsm23365Jcm2765Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpAe3006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPLOWO2_01_FULL_43_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AciduliprofundumSpMar08339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum sp. MAR08339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumSpMar08339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_49_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaHarzianumCbs22695(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma harzianum CBS 226.95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaHarzianumCbs22695", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNd2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ND2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNd2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliagarivoransMarinusDsm23064Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus DSM 23064 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransMarinusDsm23064Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpAtexabd23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. ATexABD23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAtexabd23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb215Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB215 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb215Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortieraAleyrodidarumTvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portiera aleyrodidarum TV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortieraAleyrodidarumTvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloquadratumWalsbyiDsm16790Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi DSM16790 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiDsm16790Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctobacteriumSpCag266Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG266 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag266Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumAbikonenseNbrc16140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium abikonense NBRC 16140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumAbikonenseNbrc16140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb01580Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB01580 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb01580Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumUmmarienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium ummariense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumUmmarienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaSpRifcsphigho212full4215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coxiella sp. RIFCSPHIGHO212FULL4215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoxiellaSpRifcsphigho212full4215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumDeleyianum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum deleyianum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumDeleyianum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpF52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. F52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpF52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumDiazoefficiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium diazoefficiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumDiazoefficiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BasidiobolusMeristosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodomicrobiumUdaipurenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpJl475Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. JL475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpJl475Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrueperellaPyogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trueperella pyogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrueperellaPyogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacterium4484213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterLongobardusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter longobardus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterLongobardusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaArabinofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida arabinofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaArabinofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeckwithbacteriaBacteriumGw2011gwa24310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beckwithbacteria bacterium GW2011GWA24310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeckwithbacteriaBacteriumGw2011gwa24310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaOtitidiscaviarumIfm11049(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum IFM 11049 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarumIfm11049", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAtcc12561Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium ATCC12561 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAtcc12561Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumSm23732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_73_2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm23732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia puris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaPurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesPapillosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides papillosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesPapillosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlpinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alpinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlpinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaYangpuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora yangpuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaYangpuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaJiangningensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella jiangningensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaJiangningensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocystisAeruginosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microcystis aeruginosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrocystisAeruginosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitisJcm10512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis JCM 10512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitisJcm10512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpOk665Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. OK665 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpOk665Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrocitellusParryiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Urocitellus parryii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrocitellusParryiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasAbyssiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteimonas abyssi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteimonasAbyssiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BombusImpatiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bombus impatiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BombusImpatiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymomonasMobilisPomaceaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis pomaceae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisPomaceaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_02_FULL_39_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho202Full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrinomonasMethylaliphatogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrinomonas methylaliphatogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrinomonasMethylaliphatogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumNodulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium nodulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumNodulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenococcusSpPcc7305Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenococcus sp. PCC7305 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenococcusSpPcc7305Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BaudoiniaPanamericana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Baudoinia panamericana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BaudoiniaPanamericana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_12_FULL_41_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho212Full4113b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpOv641(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. OV641 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpOv641", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaDaqingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena daqingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaDaqingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifoxyd2full369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFOXYD2FULL369 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifoxyd2full369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TropicibacterNaphthalenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tropicibacter naphthalenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TropicibacterNaphthalenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalostagnicolaLarseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola larsenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaLarseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterGuttiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter guttiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterGuttiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeobacterItalicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterItalicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RattusNorvegicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rattus norvegicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RattusNorvegicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusCoxiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus coxii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusCoxiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterCitreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter citreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterCitreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaAtcc43768Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea ATCC 43768 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaAtcc43768Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. ozaenae NBRC 105683 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspOzaenaeNbrc105683Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpEi5c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. EI5c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpEi5c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCatarrhalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CytophagaFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscovopsisWeberiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escovopsis weberi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscovopsisWeberiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPellirubrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrinema pellirubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrinemaPellirubrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiae2603vREnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae 2603V/R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiae2603vREnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4924 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifoxyd2full4310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD2FULL4310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd2full4310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMargulisbacteriaBacteriumGwf2359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWF2_35_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwf2359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSpDg1229Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. DG1229 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpDg1229Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpOv700(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV700 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv700", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag780Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:780 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag780Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GasterosteusAculeatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gasterosteus aculeatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GasterosteusAculeatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSp9402080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. 9402080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSp9402080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaSpiniferaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala spinifera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaSpiniferaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumGwf24413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWF2_44_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwf24413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiribacterSalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiribacterSalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpH5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GilvimarinusPolysaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus polysaccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusPolysaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusUrinimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus urinimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusUrinimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumAsp1004aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium ASP10-04a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumAsp1004aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHalperniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium halperniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHalperniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InediibacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Inediibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "InediibacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumResistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium resistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumResistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYB2_FULL_32_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full4028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL4028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full4028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpSt904(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. ST904 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpSt904", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3808(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3808", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusRobiginosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus robiginosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusRobiginosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho201full4010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL4010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full4010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaffinicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraffinicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaffinicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyosynoviaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyosynoviae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyosynoviaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothiobacillusNeapolitanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus neapolitanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusNeapolitanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyaloscyphaBicolorE(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaBicolorE", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpNsp222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. NSP222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpNsp222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDactylopiusCoccus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius coccus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCoccus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterLanienaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lanienae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLanienaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxHalodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHalodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LasiusNigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lasius niger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LasiusNigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogeometricumRufumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum rufum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumRufumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpBjgmmb45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. BJGMMB45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpBjgmmb45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSpKtr9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. KTR9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpKtr9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacillusKuerlensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacillus kuerlensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacillusKuerlensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusAuricularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus auricularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAuricularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PodarcisMuralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Podarcis muralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PodarcisMuralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp35wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 35W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp35wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaAerogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella aerogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaAerogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PodosporaAnserinaSMat(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Podospora anserina S mat+ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PodosporaAnserinaSMat", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpRoot133Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root133 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot133Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpYr096(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. yr096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpYr096", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasOryziterrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas oryziterrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasOryziterrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaLaminariaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella laminariae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KiloniellaLaminariaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OleibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oleibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OleibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasGardneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas gardneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasGardneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutaceaeBacteriumTav4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_42_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusMaceransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMaceransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinihabitansFlavidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinihabitans flavidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinihabitansFlavidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaChahannaoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba chahannaoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaChahannaoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpCastelsardoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. Castelsardo Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpCastelsardoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpPh10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. PH10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpPh10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumRifoxya2full4315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA2FULL4315 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya2full4315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesTriticiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GaeumannomycesTriticiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhenaziniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenazinium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenaziniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannizziaGypseaCbs118893Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nannizzia gypsea CBS 118893 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NannizziaGypseaCbs118893Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpinosisporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia spinosispora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpinosisporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoritellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moritella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoritellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistetesBacteriumJgi0000079d21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synergistetes bacterium JGI 0000079D21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynergistetesBacteriumJgi0000079d21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumVincentii3136a2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 3136A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii3136a2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPolytrichastri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium polytrichastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPolytrichastri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondromycesApiculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces apiculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChondromycesApiculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSp109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeifsoniaSp109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumParaense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpYr583Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. YR583 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpYr583Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaMesophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala mesophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaMesophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSenegalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium senegalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSenegalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa264110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_64_110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa264110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaitoellaComplicataNrrlY17804(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saitoella complicata NRRL Y-17804 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaitoellaComplicataNrrlY17804", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudozymaBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaMuscicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fischerella muscicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FischerellaMuscicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu072Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU072 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu072Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilvimarinusAgarilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusAgarilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwa25611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA25611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa25611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasOligotropha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas oligotropha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasOligotropha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaJiangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaJiangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasGraminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas graminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGraminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaKandleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella kandleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaKandleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusIbericus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus ibericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusIbericus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarvinbryantiaFormatexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marvinbryantia formatexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarvinbryantiaFormatexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAquidurenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquidurense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquidurenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaCorporis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella corporis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCorporis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCorienseDsm10284Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum coriense DSM 10284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumCorienseDsm10284Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGa0077554Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium Ga0077554 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGa0077554Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusVineaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus vineae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusVineaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CnuellaTakakiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cnuella takakiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CnuellaTakakiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricibacterSpH121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sp. H121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSpH121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumGw2011gwf23915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium GW2011GWF23915 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumGw2011gwf23915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg10243210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_43_210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg10243210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSedlakii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter sedlakii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterSedlakii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisF0423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris F0423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisF0423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg166719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_67_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg166719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UncinocarpusReesii1704Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii 1704 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UncinocarpusReesii1704Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpLeaf288Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf288Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButtiauxellaAgrestisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buttiauxella agrestis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButtiauxellaAgrestisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminibacterMediatlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caminibacter mediatlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaminibacterMediatlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPyogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pyogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPyogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaMollaretiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia mollaretii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaMollaretiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolumonasSpBrl61(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tolumonas sp. BRL61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TolumonasSpBrl61", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAureusSubspAureusNctc8325(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus subsp. aureus NCTC 8325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusAureusSubspAureusNctc8325", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisLikeEndosymbiontOfProechinophthirusFluctusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sodalis-like endosymbiont of Proechinophthirus fluctus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SodalisLikeEndosymbiontOfProechinophthirusFluctusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpM240(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. M240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpM240", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterLanthieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter lanthieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterLanthieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacterSpHeli10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacter sp. HelI10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacterSpHeli10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineActinobacteriumMedacidiG2bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizophyllumCommuneH48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Schizophyllum commune H4-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SchizophyllumCommuneH48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwb1385(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWB1385 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwb1385", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccidioidesSpLutzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccidioides sp. lutzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccidioidesSpLutzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCetorumMit007128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter cetorum MIT007128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCetorumMit007128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg166418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_64_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusDakarensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dakarensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusDakarensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesSpAs95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. AS95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpAs95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusCaldoxylosilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus caldoxylosilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusCaldoxylosilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSaccharolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSaccharolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedSup05ClusterBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "UnculturedSup05ClusterBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium czechense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumCzechense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSp2ht1a6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. 2HT1A6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSp2ht1a6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumSchaaliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobaculum schaalii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobaculumSchaaliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAlligatoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alligatoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlligatoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBalearica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas balearica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBalearica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumBrasilenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum brasilense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumBrasilenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMcba15012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFlavescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flavescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlavescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiansivirgaZeaxanthinifaciensCcSamt1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens CC-SAMT-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCcSamt1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacillusOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccalesArchaeonRumenM2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon RumEn M2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeonRumenM2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LonchuraStriataDomestica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lonchura striata domestica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LonchuraStriataDomestica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpUnc402clcolEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. UNC402CLCol Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpUnc402clcolEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSp13d2w2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. 13D2W2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSp13d2w2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeLg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Lg2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeLg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full4414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumScgcAaa252a02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium SCGC AAA252A02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumScgcAaa252a02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteimonasMephitisDsm12574Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Luteimonas mephitis DSM 12574 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LuteimonasMephitisDsm12574Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpNb41yEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. NB4-1Y Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpNb41yEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesOrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces oris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesOrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOralisAtcc35037Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC35037 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc35037Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDechloracetivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio dechloracetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDechloracetivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumHigginsianumImi349063Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum higginsianum IMI 349063 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumHigginsianumImi349063Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaRhizoxinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia rhizoxinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaRhizoxinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusHnlc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterDaqiaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daqiaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaqiaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpTcm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TCM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTcm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlareaLozoyensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glarea lozoyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlareaLozoyensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaMonticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia monticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaMonticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFischeriNrrl181Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus fischeri NRRL 181 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusFischeriNrrl181Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrenophoraTeresFTeres01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora teres f. teres 0-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTeresFTeres01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaAzotonutricium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema azotonutricium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaAzotonutricium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AestuariivitaBoseongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aestuariivita boseongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AestuariivitaBoseongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeosporobacterFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geosporobacter ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeosporobacterFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusUrinaehominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus urinaehominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AerococcusUrinaehominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudothermotogaThermarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga thermarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaThermarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_01_FULL_48_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpKu2611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU2-6(11) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu2611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpOv322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. OV322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpOv322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0074141(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0074141 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0074141", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiCsIsolateThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CS isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCsIsolateThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_FULL_40_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo202Full4011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaCylindrica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabaena cylindrica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabaenaCylindrica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAcetiAtcc23746Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti ATCC23746 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAcetiAtcc23746Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumLubricantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lubricantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLubricantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesFriuliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes friuliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesFriuliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc29g08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC29G08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc29g08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalisDsm15212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis DSM 15212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalisDsm15212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumP7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium P7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumP7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HoyosellaSubflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoyosella subflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoyosellaSubflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoflavibacterZeaxanthinifaciensS86(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens S86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensS86", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaArabinofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida arabinofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaArabinofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanofastidiosumMethylthiophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanofastidiosum methylthiophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanofastidiosumMethylthiophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasAquimarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychromonasAquimarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhenoliruptrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phenoliruptrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhenoliruptrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg136414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_64_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumD1873Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum D 1873 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumD1873Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpNdb4y10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. NDB4Y10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpNdb4y10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0442Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0442 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0442Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumNygamai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium nygamai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumNygamai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergenciaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emergencia timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmergenciaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasPusillaCcmp1545Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonas pusilla CCMP1545 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicromonasPusillaCcmp1545Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorellaSorokinianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorella sorokiniana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorellaSorokinianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchicusJcm15530Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus JCM 15530 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKimchicusJcm15530Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumMor1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Mor1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumMor1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeeiaOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leeia oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeeiaOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscoideaRubescensDsm1968(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ascoidea rubescens DSM 1968 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AscoideaRubescensDsm1968", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMantenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium mantenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMantenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaCibariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella cibaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaCibariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixNivea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix nivea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiothrixNivea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTegetincolaDsm22377Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola DSM 22377 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincolaDsm22377Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanPaniscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pan paniscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PanPaniscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaMorbillorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella morbillorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaMorbillorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumOlb16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium OLB16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumOlb16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidaceaeBacteriumBroad1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardioidaceae bacterium Broad1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardioidaceaeBacteriumBroad1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasEutrophaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas eutropha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEutrophaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaElegans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella elegans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaElegans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpRac04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. RAC04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpRac04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot268Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root268 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot268Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPeloridisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter peloridis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPeloridisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioKueneniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio kuenenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioKueneniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BavariicoccusSeileri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bavariicoccus seileri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BavariicoccusSeileri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCavendishiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cavendishii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCavendishiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpUw4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. UW4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUw4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusErythropolis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus erythropolis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusErythropolis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiocapsaRoseopersicinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiocapsa roseopersicina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiocapsaRoseopersicinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterPittiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter pittii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterPittiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconacetobacterDiazotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter diazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterDiazotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpVcd2006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCD2006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcd2006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUreicelerivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ureicelerivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUreicelerivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariprofundusFerrooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mariprofundus ferrooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MariprofundusFerrooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FodinicurvataFenggangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata fenggangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataFenggangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Danaus plexippus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DanausPlexippusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifoxyd1full4023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD1FULL4023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd1full4023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavovariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavovariabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavovariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AustwickiaChelonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Austwickia chelonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AustwickiaChelonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumParaffinicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraffinicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaffinicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDaejeonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter daejeonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterDaejeonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPectinovorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium pectinovorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPectinovorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaZimbabwensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichinella zimbabwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichinellaZimbabwensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedFlavonifractorSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Flavonifractor sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedFlavonifractorSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12451111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245111.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12451111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UstilagoMaydis521Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ustilago maydis 521 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "UstilagoMaydis521Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumKyorinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium kyorinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumKyorinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TurneriellaParvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Turneriella parva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TurneriellaParvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrypanosomaTheileriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trypanosoma theileri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrypanosomaTheileriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteinernemaCarpocapsae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Steinernema carpocapsae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SteinernemaCarpocapsae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsplowo202full388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO202FULL388 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo202full388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc512e3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-2E3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc512e3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryhalocaulisCaribicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryhalocaulis caribicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryhalocaulisCaribicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaSpIbvhs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSaprophyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia saprophytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaSaprophyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumImcc3088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumImcc3088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioOrientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio orientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioOrientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrechmeriaConiospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Drechmeria coniospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DrechmeriaConiospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaGrandensisFslF60971(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria grandensis FSL F6-0971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaGrandensisFslF60971", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiumMinutumPei191Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Pei191 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutumPei191Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusLutimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius lutimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusLutimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaMinutaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Christensenella minuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMinutaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterWuianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter wuianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterWuianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaCellulosilyticaTb100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica TB100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilyticaTb100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaProducta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blautia producta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlautiaProducta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTamurae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia tamurae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTamurae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArtemisiaAnnuaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Artemisia annua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArtemisiaAnnuaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionimicrobiumLymphophilumAcs093VSch5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum ACS-093-V-SCH5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilumAcs093VSch5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RudanellaLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rudanella lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RudanellaLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusSpA2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. A-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpA2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMycoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mycoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMycoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpL77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. L77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpL77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RicheliaIntracellularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Richelia intracellularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RicheliaIntracellularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaFerrariae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia ferrariae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaFerrariae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGubbeenense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gubbeenense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGubbeenense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wigglesworthia glossinidia endosymbiont of Glossina morsitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WigglesworthiaGlossinidiaEndosymbiontOfGlossinaMorsitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSphenisciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sphenisci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSphenisciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobacterPhocae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobacter phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobacterPhocae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterPulverisDsm19144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter pulveris DSM 19144 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FranconibacterPulverisDsm19144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumTropicaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum tropicale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumTropicaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExidiaGlandulosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exidia glandulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExidiaGlandulosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacificimonasFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacificimonas flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacificimonasFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaludibacterSp4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter sp. 47-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaludibacterSp4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioBizertensisDsm18034(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis DSM 18034 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensisDsm18034", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptosporangiumAmethystogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium amethystogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumAmethystogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymoseptoriaTriticiIpo323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici IPO323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaTriticiIpo323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpSyk6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. SYK6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpSyk6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RokubacteriaBacteriumGwa27335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusHalodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus halodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusHalodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCapitovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium capitovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCapitovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusGarvieaeI113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae I113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeI113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpMh3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. MH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumSpMh3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusVulcani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus vulcani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusVulcani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetoanaerobiumSticklandiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetoanaerobium sticklandii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetoanaerobiumSticklandiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaomCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaomCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusZeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLehensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lehensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLehensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSubantarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumNk3d112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NK3D112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNk3d112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaArenicorallinaS304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina S304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KosmotogaArenicorallinaS304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpPcc6312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC6312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc6312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusBathoardescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus bathoardescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusBathoardescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavicepsPurpureaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Claviceps purpurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClavicepsPurpureaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifcsplowo202full4011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO202FULL4011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo202full4011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasSpAe3005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. AE3005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpAe3005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumMedpeswsndg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAgglomeratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces agglomeratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAgglomeratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSp4636Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter sp. 46_36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSp4636Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpHl46(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. HL46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpHl46", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumH143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum H143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumH143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYD12_FULL_33_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyd12Full3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaPtereochthonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia ptereochthonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPtereochthonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaprospiraGrandisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saprospira grandis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaprospiraGrandisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAmyloliquefaciensDsm7Atcc23350Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus amyloliquefaciens DSM 7 ATCC 23350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAmyloliquefaciensDsm7Atcc23350Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatusAuricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomatus auricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatusAuricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCapillatusDsm19910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus DSM 19910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCapillatusDsm19910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDakarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus dakarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusDakarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumSpMesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. MES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumSpMesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpJs666(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. JS666 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpJs666", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaRighensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora righensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaRighensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CronobacterDublinensisSubspLausannensisLmg23824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lausannensis LMG 23824 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLausannensisLmg23824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCrustorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus crustorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCrustorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaParaffinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia paraffinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaParaffinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraSpUpii135e(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. UPII135E graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpUpii135e", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusPeptonophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus peptonophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPeptonophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloceanibacterSteviniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter stevinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterSteviniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumHerbicidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium herbicidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumHerbicidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliagarivoransMarinusDsm23064Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aliagarivorans marinus DSM 23064 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AliagarivoransMarinusDsm23064Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcusNigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcus niger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcusNigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SarcinaSpDsm11001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sarcina sp. DSM 11001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SarcinaSpDsm11001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus infantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusInfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSalinitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSyngnathidarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium syngnathidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSyngnathidarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTamuraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia tamurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTamuraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSpJdfr02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. JdFR-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpJdfr02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpLeaf394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. Leaf394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpLeaf394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaTuberolachnusSalignusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Tuberolachnus salignus) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaTuberolachnusSalignusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraMultipara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira multipara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraMultipara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia rettgeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaculusJaculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jaculus jaculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JaculusJaculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlumeriaGraminisFSpHordeiDh14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blumeria graminis f. sp. hordei DH14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlumeriaGraminisFSpHordeiDh14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenericutesBacteriumGwf25713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_57_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf25713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedCoprococcusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Coprococcus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedCoprococcusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp14822926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1482292.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14822926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaWeaveri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria weaveri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWeaveri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrametesCinnabarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trametes cinnabarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrametesCinnabarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocorpusculumBavaricumDsm4179Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum DSM 4179 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricumDsm4179Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSaxobsidensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus saxobsidens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSaxobsidensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpPcc7376(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7376 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7376", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaAcidipaludis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia acidipaludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaAcidipaludis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium637Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium637Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBadiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus badius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusBadiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAltamirensisNbrc108246Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia altamirensis NBRC 108246 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAltamirensisNbrc108246Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaclostridiumBifermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraclostridium bifermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaclostridiumBifermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpSoil538(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Soil538 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpSoil538", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisNatto(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis natto graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisNatto", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasNaphthalenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas naphthalenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasNaphthalenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDendritiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus dendritiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDendritiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaceaeSpMortierellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae sp. Mortierella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeSpMortierellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesXanthophaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xanthophaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXanthophaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_46_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MongoliimonasTerrestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mongoliimonas terrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MongoliimonasTerrestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg165711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_57_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf2890(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2890 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2890", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_46_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermonemaRossianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermonema rossianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermonemaRossianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BesnoitiaBesnoiti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Besnoitia besnoiti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BesnoitiaBesnoiti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusAwamori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus awamori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusAwamori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaCincinnatiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella cincinnatiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaCincinnatiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterWuhouensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter wuhouensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterWuhouensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCoagulans26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsplowo201full4424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPLOWO201FULL4424 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsplowo201full4424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InquilinusLimosusDsm16000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Inquilinus limosus DSM 16000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "InquilinusLimosusDsm16000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_49_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full4914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusAminovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_12_FULL_41_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo212Full4116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpUnc41mfs5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC41MFS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc41mfs5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmmonsiaSpCac2015a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Emmonsia sp. CAC-2015a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmmonsiaSpCac2015a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag345(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:345 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag345", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarssoninaBrunneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marssonina brunnea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarssoninaBrunneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HippeaAlviniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hippea alviniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HippeaAlviniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioXylanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio xylanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioXylanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhabdusUtahensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusUtahensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpH1nCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia sp. H1n Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaSpH1nCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinalesArchaeonMethan01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Methan_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeonMethan01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudocercosporaFijiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora fijiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaFijiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlbidovulumXiamenenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Albidovulum xiamenense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlbidovulumXiamenenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpIec1808Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IEC1808 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIec1808Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaDiuraphisNoxiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Diuraphis noxia) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaDiuraphisNoxiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpWb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. WB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpWb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsPolyrhachisfurcataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachisfurcata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisfurcataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwellbacteriaBacteriumRifcsphigho212full4417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPHIGHO212FULL4417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsphigho212full4417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo201full5024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL5024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full5024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaIvanoviiLondoniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria ivanovii londoniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaIvanoviiLondoniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSp13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterSpHtcc2170(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter sp. HTCC2170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterSpHtcc2170", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusRambelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus rambellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusRambelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaDiclinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia diclina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaDiclinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumZor0006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ZOR0006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumZor0006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiesiaPthiripubisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riesia pthiripubis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiesiaPthiripubisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp37zxx(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 37zxx graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp37zxx", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioPanuliri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio panuliri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioPanuliri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusChungangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus chungangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusChungangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChytriomycesConfervae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chytriomyces confervae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChytriomycesConfervae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CulexQuinquefasciatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Culex quinquefasciatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CulexQuinquefasciatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaChauliocolaAtcc49578Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola ATCC 49578 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaChauliocolaAtcc49578Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSputorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sputorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSputorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonasAcidaminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonas acidaminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacimonasAcidaminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCb03234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB03234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb03234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil761Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil761 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil761Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaPaurometabolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeHs11286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae HS11286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeHs11286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiBacteriumOlb4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovirgaLieniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermovirga lienii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermovirgaLieniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiferrobacterThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidiferrobacter thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidiferrobacterThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumGraminearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium graminearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumGraminearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSeminalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella seminalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSeminalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonisDsm23387Jcm13868Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis DSM 23387 JCM 13868 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasUenonisDsm23387Jcm13868Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpWmma185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. WMMA185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpWmma185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GloeobacterViolaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter violaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeobacterViolaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteusVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteus vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteusVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldithrixAbyssiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix abyssi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldithrixAbyssiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteococcusJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteococcus japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteococcusJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CriibacteriumBergeroniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Criibacterium bergeronii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CriibacteriumBergeroniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium4632Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 46-32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4632Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSynechococcusSpongiarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Synechococcus spongiarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSynechococcusSpongiarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaZoogloeoidesAtcc25935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides ATCC 25935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DuganellaZoogloeoidesAtcc25935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaAcuminataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Musa acuminata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusaAcuminataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl21Mag121220Bin10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 MAG-121220-bin10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Mag121220Bin10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasSpHgc4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. HGC4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpHgc4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminimonasQiaohouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sediminimonas qiaohouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SediminimonasQiaohouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasUshuaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas ushuaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasUshuaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSp31syn3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 31syn3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp31syn3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_42_49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusUliginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusUliginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCellulolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCellulolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSpAbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. aB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpAbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag956(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:956 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag956", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LupinusAngustifoliusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lupinus angustifolius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LupinusAngustifoliusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusHunanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus hunanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHunanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodisVasculorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis vasculorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisVasculorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumCsp12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium CSP12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumCsp12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonBa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon BA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonBa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_12_FULL_48_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwa24319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_43_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StachybotrysChlorohalonataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stachybotrys chlorohalonata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StachybotrysChlorohalonataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapillibacterCinnamivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PapillibacterCinnamivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls237Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS237 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls237Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumGa0074139Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074139 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074139Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFragilis3112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis 3112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilis3112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumOranimenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium oranimense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumOranimenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumSpCag314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. CAG:314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumSpCag314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRbg13509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RBG_13_50_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRbg13509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLuteoviolaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogranumRubrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halogranum rubrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalogranumRubrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenibacillusSchlegeliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenibacillus schlegelii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenibacillusSchlegeliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinimicrobiumSubtropicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium subtropicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSubtropicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0295(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0295", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpDabal43bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. DABAL43B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpDabal43bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusEquuliSubspEquuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus equuli subsp. equuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusEquuliSubspEquuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciens007cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens 007c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciens007cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpL250Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. L250 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpL250Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprinellusMicaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprinellus micaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprinellusMicaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterAphrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter aphrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterAphrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLongusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio longus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLongusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrotaleaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrotalea flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrotaleaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusEpiphyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus epiphyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEpiphyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaGenomosp8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaladaptatusCibariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus cibarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusCibariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpMcba15012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_012 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpCnj954Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. CNJ-954 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpCnj954Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AciduliprofundumBoonei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aciduliprofundum boonei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AciduliprofundumBoonei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaceaeBacteriumMarseillep2826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium MarseilleP2826 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumMarseillep2826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioDiazotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio diazotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioDiazotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytalidiumLignicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scytalidium lignicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScytalidiumLignicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterChinhatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter chinhatensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterChinhatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23272Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23272 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23272Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpAap82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusContaminansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus contaminans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusContaminansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PavoCristatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pavo cristatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PavoCristatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDentisani7746(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7746 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7746", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar92BacteriumBacl16Mag120619Bin48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 MAG-120619-bin48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16Mag120619Bin48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKribbensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kribbensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusKribbensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OstreococcusLucimarinusCce9901Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus CCE9901 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OstreococcusLucimarinusCce9901Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusBourgensisMs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis MS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanoculleusBourgensisMs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaGottschalkiiDsm13577(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii DSM 13577 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkiiDsm13577", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerophagaThermohalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerophaga thermohalophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerophagaThermohalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaJejuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella jejuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaJejuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasBadiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas badia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasBadiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full5338Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL5338 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full5338Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusSpA20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. A20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpA20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_61_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusNeoformansVarNeoformansJec21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans var. neoformans JEC21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptococcusNeoformansVarNeoformansJec21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolamina rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolaminaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumUlceransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium ulcerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumUlceransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumCamembertiFm013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicillium camemberti FM 013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliumCamembertiFm013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GorillibacteriumTimonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gorillibacterium timonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GorillibacteriumTimonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiaFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConchiformibiusKuhniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius kuhniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusKuhniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesStipitatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TalaromycesStipitatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpPealriverEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. pealriver Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPealriverEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChiloSuppressalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chilo suppressalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChiloSuppressalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonScgcAaa282k18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA282K18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa282k18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaNautarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella nautarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaNautarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumCellulolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium cellulolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumCellulolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaWeaveriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria weaveri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaWeaveriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCinaediCcug18818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi CCUG18818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediCcug18818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumEnshienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium enshiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumEnshienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromatiaceaeBacterium2141tstbd0c01aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromatiaceae bacterium 2141TSTBD0c01a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromatiaceaeBacterium2141tstbd0c01aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoribacteriaBacteriumWga3gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poribacteria bacterium WGA3G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoribacteriaBacteriumWga3gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DothistromaSeptosporumNze10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dothistroma septosporum NZE10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DothistromaSeptosporumNze10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraFlavalba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura flavalba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraFlavalba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusAlimentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusAlimentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm46838Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 46838 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm46838Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusBvHnlc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterRoseosalivariusDsm11622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hymenobacter roseosalivarius DSM 11622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HymenobacterRoseosalivariusDsm11622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorciDsm25326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moraxella porci DSM 25326 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoraxellaPorciDsm25326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumCellobioparum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellobioparum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellobioparum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAljtEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJT Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAljtEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FontibacillusPanacisegetis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fontibacillus panacisegetis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FontibacillusPanacisegetis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSediminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSediminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaGlycaniphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia glycaniphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaGlycaniphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasFlueggeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas flueggei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasFlueggeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpHot20860m813o14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813O14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813o14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusFerrooxidansAtcc53993(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC53993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc53993", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumBrhc0(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BRHc0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBrhc0", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarithrixSpCanyon246(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marithrix sp. Canyon 246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarithrixSpCanyon246", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaObeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia obeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaObeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorexAraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sorex araneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SorexAraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPutealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPutealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthorchisViverrini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis viverrini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisViverrini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusAcididuransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acididurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcididuransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UzinuraDiaspidicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uzinura diaspidicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UzinuraDiaspidicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpScn6822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. SCN 68-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpScn6822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAcridum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium acridum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumAcridum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansDsm642Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans DSM642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansDsm642Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraPhenolivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thauera phenolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaueraPhenolivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpHmsc071c03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC071C03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc071c03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpH053(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H053 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH053", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus infantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusInfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNidulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nidulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusNidulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteriDsm20016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri DSM20016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteriDsm20016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimangrovimonasIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidimangrovimonas indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidimangrovimonasIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EzakiellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ezakiella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EzakiellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumSpB510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. B510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpB510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumPeregrinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium peregrinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPeregrinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc25546(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_55_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc25546", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacterAlgarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentibacter algarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentibacterAlgarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifoxyb12full359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYB12FULL359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyb12full359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAgarilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSpNdb4y10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces sp. NDB4Y10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSpNdb4y10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldithrixSpRbg13449Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix sp. RBG_13_44_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldithrixSpRbg13449Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarpegnathosSaltatorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Harpegnathos saltator Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HarpegnathosSaltatorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPhyllostachyosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium phyllostachyos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPhyllostachyosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloceraViscosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calocera viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloceraViscosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisChungbukensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis chungbukensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisChungbukensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp150fbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 150FB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp150fbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraSantarosai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira santarosai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraSantarosai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterMarburgensisStrMarburg(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis str. Marburg graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensisStrMarburg", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAmarae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amarae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmarae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLutea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lutea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasLutea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLc145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LC145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLc145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPaucivoransNbrc100373(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia paucivorans NBRC 100373 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaPaucivoransNbrc100373", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxValerianellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax valerianellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxValerianellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumCg2303520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium CG2_30_35_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumCg2303520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TupaiaBelangeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tupaia belangeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TupaiaBelangeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusSpY3961Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. Y3961 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpY3961Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpAtcc51142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. ATCC51142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpAtcc51142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaesserellaParasuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaesserella parasuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaesserellaParasuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseolineaSerpensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseolinea serpens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseolineaSerpensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNeuiiDsm8576Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii DSM8576 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiDsm8576Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho202full4420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO202FULL4420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho202full4420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaLongibrachiatumAtcc18648Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum ATCC 18648 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatumAtcc18648Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumCongolenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium congolense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumCongolenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_FULL_43_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho202Full4332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CanisLupusDingo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Canis lupus dingo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CanisLupusDingo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisKc583(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis KC583 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaBacilliformisKc583", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag631Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:631 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag631Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterGottschalkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter gottschalkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterGottschalkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKsb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division KSB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchlyaHypogynaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achlya hypogyna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchlyaHypogynaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliicoccusPersicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliicoccus persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliicoccusPersicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongyloidesStercoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides stercoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesStercoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat29937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29937 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusIlyis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus ilyis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichococcusIlyis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfTrabutinaMannipara(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina mannipara graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaMannipara", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpUrhb0015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URHB0015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpUrhb0015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMerdae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium merdae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMerdae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumFalciparumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium falciparum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumFalciparumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAnimalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus animalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAnimalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLionensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lionensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasLionensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumDifficile630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoclostridium difficile 630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoclostridiumDifficile630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaplasmaMarginaleFloridaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale Florida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleFloridaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumRifcsplowo202full5816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium RIFCSPLOWO202FULL5816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumRifcsplowo202full5816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizoporaParadoxaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schizopora paradoxa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchizoporaParadoxaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_48_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMediterranei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioMediterranei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpSgbin1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaChrysanthemi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya chrysanthemi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaChrysanthemi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaucusCarota(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daucus carota graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaucusCarota", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SneathiellaGlossodoripedisJcm23214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sneathiella glossodoripedis JCM 23214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SneathiellaGlossodoripedisJcm23214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasMuralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas muralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasMuralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculischaeffi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculischaeffi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculischaeffi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PuniceibacteriumSpImcc21224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puniceibacterium sp. IMCC21224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PuniceibacteriumSpImcc21224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSuwonensis111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis 111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensis111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumParascrofulaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parascrofulaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumParascrofulaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacacaMulatta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macaca mulatta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacacaMulatta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_12_FULL_48_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho212Full4817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrooxidansAtcc53993Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC53993 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc53993Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusDesertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus deserti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusDesertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp1nla3eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 1NLA3E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSp1nla3eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusXiphinematobacterSpIdahoGrapeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Xiphinematobacter sp. Idaho Grape Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusXiphinematobacterSpIdahoGrapeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpRu33cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. RU33C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpRu33cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobaculumParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpHmsc075b08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. HMSC075B08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpHmsc075b08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumTf0111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TF01-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTf0111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusPhenolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus phenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusPhenolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho202full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO202FULL3613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho202full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensisVarSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Camellia sinensis var. sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CamelliaSinensisVarSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full4934Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL4934 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full4934Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwf24415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWF24415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwf24415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTakakiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium takakiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTakakiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_41_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxya2full4753Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL4753 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full4753Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusAneurinilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus aneurinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusAneurinilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DerxiaGummosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Derxia gummosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DerxiaGummosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS920 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpLq44Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. LQ44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpLq44Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaEuropaeaSh398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea SH398 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaeaSh398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaSpHtcc2999(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. HTCC2999 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSpHtcc2999", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa168p09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA168P09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa168p09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisAd2017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis AD2017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisAd2017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_44_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177nandCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177Nand Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177nandCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpUrhb0020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. URHB0020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpUrhb0020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil522Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil522 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil522Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonnei53g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shigella sonnei 53G graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShigellaSonnei53g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumParafortuitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium parafortuitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumParafortuitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpRoot136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. Root136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpRoot136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumAquatileDsm21506(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum aquatile DSM 21506 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumAquatileDsm21506", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusWk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus WK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusWk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DebaryomycesHanseniiCbs767Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii CBS767 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DebaryomycesHanseniiCbs767Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SlackiaHeliotrinireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Slackia heliotrinireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SlackiaHeliotrinireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpCg3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IlyobacterPolytropusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ilyobacter polytropus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IlyobacterPolytropusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TistrellaMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tistrella mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TistrellaMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCinaediPagu611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi PAGU611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediPagu611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumGbs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium GBS-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumGbs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusBromiiL263(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bromii L2-63 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusBromiiL263", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusMume(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prunus mume graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrunusMume", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaCaribensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia caribensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaCaribensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls474Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS474 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls474Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterJeongneungensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter jeongneungensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterJeongneungensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisRifamycinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis rifamycinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisRifamycinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwa2378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA2378 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa2378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParusMajorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parus major Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParusMajorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrososphaeraViennensisEn76(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis EN76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitrososphaeraViennensisEn76", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSpHot286Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. HOT286 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TannerellaSpHot286Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC03Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C03 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC03Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAcidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus acidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAcidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo202full4511cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4511c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4511cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusAcidocaldariusSusazEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius SUSAZ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusSusazEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMfb021Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MFB021 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMfb021Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPorcinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus porcinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPorcinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallusGallus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallus gallus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallusGallus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobacteroidesCellulosolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteroides cellulosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobacteroidesCellulosolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumGw2011gwf24332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium GW2011GWF24332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumGw2011gwf24332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135152Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135152Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylophilusSpLeaf220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylophilus sp. Leaf220 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylophilusSpLeaf220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonajaTextilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonaja textilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonajaTextilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterRoseusDsm17521(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pontibacter roseus DSM 17521 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PontibacterRoseusDsm17521", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSherrisiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sherrisii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSherrisiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwe23928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_39_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe23928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYB1_FULL_38_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyb1Full3816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenoanaerobacteriumSaccharovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenoanaerobacterium saccharovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenoanaerobacteriumSaccharovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYC2_FULL_45_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyc2Full4512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaPertussisTohama(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis Tohama graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussisTohama", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterSpOralTaxon458StrW10330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. oral taxon 458 str. W10330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AggregatibacterSpOralTaxon458StrW10330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotryobasidiumBotryosumFd172Ss1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Botryobasidium botryosum FD-172 SS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BotryobasidiumBotryosumFd172Ss1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMetschnikoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio metschnikovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioMetschnikoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSp24yea8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. 24YEA8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSp24yea8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalisS6c4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis S6C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisS6c4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpLeaf344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Leaf344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLeaf344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho212full4519bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO212FULL4519b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho212full4519bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumParatuberculosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium paratuberculosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAviumParatuberculosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPseudospumaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella pseudospumae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPseudospumaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermorudisPeleae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermorudis peleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermorudisPeleae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobotrysOligosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobotrysOligosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGoldsteiniiDsm19448Wal12034Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii DSM 19448 WAL 12034 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteiniiDsm19448Wal12034Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospirillumFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAmnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella amnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAmnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHalodenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatellicoccusMarimammalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catellicoccus marimammalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatellicoccusMarimammalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodomicrobiumVannieliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodomicrobium vannielii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodomicrobiumVannieliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidipropionibacteriumAcidipropionici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium acidipropionici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumAcidipropionici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicosporidiumSpAtcc50920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicosporidium sp. ATCC 50920 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicosporidiumSpAtcc50920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalvatorMerianaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salvator merianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalvatorMerianaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusOshimaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus oshimai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusOshimaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaHeimbachaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Providencia heimbachae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaHeimbachaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaOralTaxonTm7x(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria oral taxon TM7x graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaOralTaxonTm7x", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumJdfr77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium JdFR-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumJdfr77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterDaqiaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daqiaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaqiaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomassariellaVexataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomassariella vexata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomassariellaVexataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot190Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root190 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot190Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumTusciaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium tusciae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumTusciaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusThermantarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus thermantarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusThermantarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaTimonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia timonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaTimonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcticibacterSvalbardensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcticibacter svalbardensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcticibacterSvalbardensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterSp6612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. 66-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSp6612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusIainarchaeumAndersoniiScgcAaa011E11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Iainarchaeum andersonii SCGC AAA011-E11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusIainarchaeumAndersoniiScgcAaa011E11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarisediminitaleaAggregata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marisediminitalea aggregata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarisediminitaleaAggregata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasBennonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas bennonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasBennonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonadaceaeBacteriumGwc25813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonadaceae bacterium GWC2_58_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonadaceaeBacteriumGwc25813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpRifcsphigho201full6931Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. RIFCSPHIGHO201FULL6931 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRifcsphigho201full6931Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasLuteola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas luteola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasLuteola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaTularensisHolarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis holarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrancisellaTularensisHolarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusDpc4571Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus DPC4571 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusDpc4571Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSecaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus secaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSecaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisVasculorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis vasculorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisVasculorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseofilumReptotaeniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseofilum reptotaenium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseofilumReptotaeniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLentiflavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lentiflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLentiflavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag30730263Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:307_30_263 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag30730263Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricurvumSpPc0866(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum sp. PC08-66 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumSpPc0866", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa028a23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA028A23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa028a23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpE14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. e14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpE14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaSimulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila simulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaSimulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAeruginosaPao1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas aeruginosa PAO1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAeruginosaPao1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonquetellaAnthropi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jonquetella anthropi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JonquetellaAnthropi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpOk602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ok602 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpOk602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3713bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3713b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3713bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetalesBacterium7110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 71-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium7110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaSpLeaf446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. Leaf446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpLeaf446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFurnissiiNctc11218Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio furnissii NCTC 11218 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioFurnissiiNctc11218Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusPsychrodurans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus psychrodurans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusPsychrodurans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterPectinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algibacter pectinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgibacterPectinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlomusCerebriformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glomus cerebriforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlomusCerebriformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpUnc279mftsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC279MFTsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc279mftsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpHk10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. HK10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpHk10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenothrixSpD3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenothrix sp. D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenothrixSpD3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaLacunata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lacunata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLacunata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNereisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nereis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioNereisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusNeoformansVarNeoformansJec21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans var. neoformans JEC21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptococcusNeoformansVarNeoformansJec21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasPhaseoliPvDieffenbachiaeLmg695(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas phaseoli pv. dieffenbachiae LMG 695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasPhaseoliPvDieffenbachiaeLmg695", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpPhil15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Phil15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpPhil15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaBoonei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula boonei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaBoonei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifoxyd2full369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFOXYD2FULL369 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifoxyd2full369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesNourseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces noursei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNourseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp161mfsha21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 161MFSha21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp161mfsha21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Snodgrassella alvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SnodgrassellaAlviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumPuteiDsm12395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum putei DSM 12395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumPuteiDsm12395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpLeaf307(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Leaf307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpLeaf307", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpAf1440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter sp. AF1440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArcobacterSpAf1440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumPrunaredense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium prunaredense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPrunaredense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpCibCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. CIB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpCibCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CronobacterDublinensisSubspLausannensisLmg23824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lausannensis LMG 23824 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLausannensisLmg23824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraStrobiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara strobi) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraStrobiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaConcavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia concava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaConcavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusMetallicusDsm6482Jcm9184(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus DSM 6482 JCM 9184 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfolobusMetallicusDsm6482Jcm9184", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsphigho202full4916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPHIGHO202FULL4916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsphigho202full4916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_47_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full4732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusTokodaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus tokodaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfolobusTokodaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum californiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusGriffiniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus griffiniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusGriffiniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterPectinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algibacter pectinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgibacterPectinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumHaoraniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium haoranii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHaoraniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSp6626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. 66-26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSp6626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomycesKudriavzevii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzevii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusDestructans2063121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans 20631-21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructans2063121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocinitomixAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolaminaSpCba1230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolamina sp. CBA1230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolaminaSpCba1230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium6417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 64-17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NafulsellaTurpanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nafulsella turpanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NafulsellaTurpanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsphigho201full63240(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO201FULL63240 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho201full63240", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHepaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter hepaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHepaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixSchenckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporothrix schenckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporothrixSchenckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAespoeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio aespoeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAespoeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxyd2full4310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD2FULL4310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd2full4310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiromycesFinnisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piromyces finnis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiromycesFinnisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomicrobiumBuryatense5gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylomicrobium buryatense 5G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylomicrobiumBuryatense5gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpBiwako01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. BIWAKO-01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpBiwako01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpPamc21821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 21821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc21821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpGa2829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-2829 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa2829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMirumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma mirum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaMirumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumS714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpRifcsphigho212full6519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. RIFCSPHIGHO212FULL6519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpRifcsphigho212full6519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NakamurellaLactea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella lactea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NakamurellaLactea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusSpOk042Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus sp. OK042 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusSpOk042Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosTaurusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bos taurus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BosTaurusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidoterrestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidoterrestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidoterrestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumDcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium DC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumDcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoelleriellaLiberaRcef2490Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moelleriella libera RCEF 2490 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoelleriellaLiberaRcef2490Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ObscuribacterPhosphatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Obscuribacter phosphatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ObscuribacterPhosphatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesFunestus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles funestus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesFunestus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHirsutaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hirsuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaHirsutaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraAustralicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira australica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAustralicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGilvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gilvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumGilvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolymorphaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterMarinusA45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter marinus A45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacterMarinusA45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaMaltophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema maltophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaMaltophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsMilitaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps militaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CordycepsMilitaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMuralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus muralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMuralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumSpRoot472d3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium sp. Root472D3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumSpRoot472d3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusRubiinfantis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus rubiinfantis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusRubiinfantis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBroomiiSerovarHurstbridgeStr5399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira broomii serovar Hurstbridge str. 5399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBroomiiSerovarHurstbridgeStr5399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 39-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifcsphigho201full4029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFCSPHIGHO201FULL4029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifcsphigho201full4029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusYunnanensisNbrc103083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis NBRC 103083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusYunnanensisNbrc103083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwc13712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC13712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc13712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSwingsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium swingsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSwingsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpongiibacterTropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter tropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterTropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumSpKb01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium sp. KB01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumSpKb01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFastidiosusNbrc101226(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus NBRC 101226 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusFastidiosusNbrc101226", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOkhensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus okhensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusOkhensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf371(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf371", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698rsb12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta MAD698RSB12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698rsb12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4118 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpFl(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Fl graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpFl", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScheffersomycesStipitisCbs6054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis CBS 6054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ScheffersomycesStipitisCbs6054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwa14423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWA14423 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwa14423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeishmaniaInfantumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leishmania infantum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaInfantumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactucaSativa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactuca sativa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactucaSativa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJidaibacterAcanthamoebaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jidaibacter acanthamoeba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJidaibacterAcanthamoebaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumCuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6754(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 67-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6754", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_FULL_42_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho202Full4219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalapricumSalinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halapricum salinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalapricumSalinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumSpLf3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. LF3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpLf3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusUreasiticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureasiticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreasiticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSp10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. 10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSp10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterExcellensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter excellens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterExcellensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOulorumF0390Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oulorum F0390 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOulorumF0390Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasSpAap120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas sp. AAP120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasSpAap120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumLaevaniformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium laevaniformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLaevaniformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterOleivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter oleivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterOleivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaTabacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana tabacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NicotianaTabacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSpAk22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. AK22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSpAk22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCaseiBl23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus casei BL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCaseiBl23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLionensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasLionensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlexibacterFlexilisDsm6793Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter flexilis DSM 6793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlexibacterFlexilisDsm6793Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolanumTuberosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solanum tuberosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolanumTuberosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedArchaeonA07hr60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HR60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hr60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNTMorphotypeBCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Epulopiscium sp. N.t. morphotype B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EpulopisciumSpNTMorphotypeBCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterVadiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter vadi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterVadiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAkl11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaNavojoaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila navojoa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaNavojoaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc8051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC8051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc8051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24266Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_42_66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24266Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcanthochromisPolyacanthus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acanthochromis polyacanthus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcanthochromisPolyacanthus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfHeteropsyllaCubana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla cubana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaCubana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPallens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus pallens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPallens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp3andimar09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 3ANDIMAR09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp3andimar09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag38Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag38Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinococcusHalotoleransDsm16375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinococcus halotolerans DSM 16375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinococcusHalotoleransDsm16375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumJeonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jeonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJeonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHdn1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HdN1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHdn1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOligofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oligofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOligofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusAcidiphilusNbrc100859Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus NBRC 100859 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilusNbrc100859Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpSk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava sp. SK-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaSpSk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumMultivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMultivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaShandongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia shandongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaShandongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSp7321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. 73-21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSp7321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis05zyh33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis 05ZYH33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuis05zyh33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3862Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3862 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3862Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSpKl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. KL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpKl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusKribbensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus kribbensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusKribbensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospirillumFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospirillum ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospirillumFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAng1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAng1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhenylobacteriumSpRoot1290(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. Root1290 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpRoot1290", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenxiniaSaemankumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia saemankumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WenxiniaSaemankumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpHmsc062g07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. HMSC062G07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpHmsc062g07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaSpYqh10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. YQH10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShewanellaSpYqh10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothermarchaeotaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geothermarchaeota archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeothermarchaeotaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SoonwooaBuanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Soonwooa buanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SoonwooaBuanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSpSw150(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. SW150 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSpSw150", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHdn1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HdN1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHdn1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterSpM18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraCorneaHhb12733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Calocera cornea HHB12733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaloceraCorneaHhb12733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobonumTyrrellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobonum tyrrellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobonumTyrrellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdiutrixIntracellularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adiutrix intracellularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdiutrixIntracellularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumHochsteniumAtcc700873Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium ATCC 700873 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumHochsteniumAtcc700873Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHomopropionicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium homopropionicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHomopropionicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSonorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sonorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSonorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeotheceVerrucosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece verrucosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeotheceVerrucosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot240Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot240Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpLb2011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. LB2011 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpLb2011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJaponicaT1X7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica T1-X7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJaponicaT1X7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSlbn35Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. SLBN-35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSlbn35Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24535(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_45_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24535", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaPediculicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riesia pediculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiesiaPediculicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicellaMetallireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidicellaMetallireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumItalicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium italicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumItalicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgassiziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agassizii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgassiziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconacetobacterSpSxcc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter sp. SXCC-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterSpSxcc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaMarinoflavaDsm3653Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava DSM 3653 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaDsm3653Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMontpellierensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella montpellierensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMontpellierensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusVersutusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planococcus versutus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanococcusVersutusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimicrobiiaBacteriumBacl6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArsenophonusTriatominarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus triatominarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusTriatominarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho201full3725Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3725 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3725Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylophilusSpLeaf220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylophilus sp. Leaf220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylophilusSpLeaf220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumIranicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumIranicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KurthiaSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kurthia senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KurthiaSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinosporangiumSpNrrlb3428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinosporangium sp. NRRLB3428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinosporangiumSpNrrlb3428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalinemaSpCaciam(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalinema sp. CACIAM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalinemaSpCaciam", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPolysaccharolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] polysaccharolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolysaccharolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpFuku2iso50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Fuku2ISO50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpFuku2iso50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumSpAt1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AT1b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAt1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0040(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0040 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0040", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndobugulaSertulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endobugula sertula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndobugulaSertulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFradiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fradiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFradiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCc53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CC53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCc53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhymatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phymatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhymatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusAureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaPm70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida Pm70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaPm70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg163611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG163611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg163611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesotogaPrimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesotoga prima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesotogaPrimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobisporaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbispora rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumGw2011gwf236131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF236131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf236131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsphigho212full6320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPHIGHO212FULL6320 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsphigho212full6320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiabellaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niabella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiabellaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KribbellaSpAli6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kribbella sp. ALI6A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KribbellaSpAli6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaMtcc5279Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida MTCC5279 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaMtcc5279Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcaligenaceaeBacteriumDtu041Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenaceae bacterium DTU041 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcaligenaceaeBacteriumDtu041Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoellerellaWisconsensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moellerella wisconsensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoellerellaWisconsensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalalkalibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halalkalibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalalkalibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaceaeBacteriumDtu054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusGordoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus gordonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusGordoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMarmorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus marmoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMarmorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolituusThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolituusThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobiformaLacisalsi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma lacisalsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobiformaLacisalsi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacterRiflensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peribacter riflensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeribacterRiflensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpEur3222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. EUR3222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpEur3222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSimulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium simulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSimulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNebraskenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium nebraskense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNebraskenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusBoraciitolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus boraciitolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusBoraciitolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpMaepy2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. MAEPY2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpMaepy2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusSubspTestudinumSp3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. testudinum Sp3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspTestudinumSp3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MageeibacillusIndolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mageeibacillus indolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MageeibacillusIndolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpHv1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Hv1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpHv1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctobacteriumSpCag266(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG266 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag266", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaDefragransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella defragrans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaDefragransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathycoccusPrasinos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathycoccus prasinos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathycoccusPrasinos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspSpizizeniiTuB10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. spizizenii TU-B-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspSpizizeniiTuB10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterTropicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter tropicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterTropicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCylindrosporumDsm605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cylindrosporum DSM 605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCylindrosporumDsm605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacterium6551Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium 65-51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacterium6551Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinidiaChinensisVarChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinidia chinensis var. chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinidiaChinensisVarChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaledivibacterHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maledivibacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaledivibacterHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineosporiaAurantiaca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kineosporia aurantiaca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KineosporiaAurantiaca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraMesophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira mesophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraMesophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobicatellaSulfidifaciensDsm15739Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens DSM 15739 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciensDsm15739Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSp6754Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. 67-54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSp6754Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasUenonis603Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas uenonis 603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasUenonis603Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicellulosiruptorMorganiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor morganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorMorganiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquamicrobiumAerolatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermusProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodothermusProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamormyropsKingsleyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paramormyrops kingsleyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParamormyropsKingsleyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterHimalayensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter himalayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHimalayensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLautusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lautus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLautusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumGossypiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium gossypii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EremotheciumGossypiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacterium448493(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448493", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpsilonproteobacteriaBacteriumTcs49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epsilonproteobacteria bacterium tcs-49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpsilonproteobacteriaBacteriumTcs49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpJm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaSericeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marivirga sericea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarivirgaSericeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycetaceaeBacteriumMp11305(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomycetaceae bacterium MP113-05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycetaceaeBacteriumMp11305", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusLaa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius LAA1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusLaa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterNonchromogenicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter nonchromogenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterNonchromogenicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansAtcc10379(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans ATCC10379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansAtcc10379", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaCopriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella copri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCopriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZygosaccharomycesBailiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zygosaccharomyces bailii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZygosaccharomycesBailiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpMor2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. Mor2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpMor2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag1004157Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:10041_57 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag1004157Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviimonasAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Defluviimonas alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DefluviimonasAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAurantiacumDsm6208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium aurantiacum DSM 6208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAurantiacumDsm6208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaMallotivoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia mallotivora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaMallotivoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpS718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella sp. S718 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSpS718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpBa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. ba1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumSpBa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPaludisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter paludis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPaludisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDri13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DRI13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDri13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPopuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumPopuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusGilardiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusGilardiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaprolegniaDiclina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia diclina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaDiclina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumHimb59Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB59 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb59Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisPrasina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis prasina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPrasina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiribacterSpUahsp71Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spiribacter sp. UAHSP71 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpiribacterSpUahsp71Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl21Mag121220Bin10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL21 MAG-121220-bin10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl21Mag121220Bin10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterWoluwensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter woluwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterWoluwensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumFaniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium faniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumFaniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolysporaRighensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora righensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaRighensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm2793Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM2793 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm2793Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaMtcc5279(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida MTCC5279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaMtcc5279", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNdiopicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ndiopicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusNdiopicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JetteniaCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jettenia caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JetteniaCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaBryantii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema bryantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaBryantii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag3212622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:321_26_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag3212622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuricellaSpT08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella sp. T08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaSpT08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShuttleworthiaSatelles(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shuttleworthia satelles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShuttleworthiaSatelles", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterSpA7a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter sp. A7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterSpA7a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraSantarosaiSerovarShermaniStrLt821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira santarosai serovar Shermani str. LT 821 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraSantarosaiSerovarShermaniStrLt821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlautiaWexleraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blautia wexlerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlautiaWexleraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalisS6c4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis S6C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalisS6c4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionKazanBacteriumRifcsphigho201full4414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RIFCSPHIGHO201FULL4414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRifcsphigho201full4414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaLotononidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lotononidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLotononidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpCra2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. CRA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpCra2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaOleariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga olearia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KosmotogaOleariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaOrthopsilosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida orthopsilosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaOrthopsilosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumFumariolicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum fumariolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumFumariolicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaHofmanniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmanni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmanniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumUasb270(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacterium UASB270 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriumUasb270", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterHiberniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter hiberniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHiberniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariniphagaAnaerophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mariniphaga anaerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MariniphagaAnaerophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricellaSpT08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricella sp. T08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfuricellaSpT08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaSpGmku363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. GMKU363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpGmku363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusManzaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidianus manzaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidianusManzaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSuncheonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium suncheonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSuncheonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMf105b01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium Mf 105b01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMf105b01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGwa15235Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium GWA1_52_35 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGwa15235Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesProvencensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesProvencensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTerricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia terricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTerricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediculusHumanusCorporisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus corporis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PediculusHumanusCorporisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobialesBacteriumClorobi01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorobiales bacterium Clorobi_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorobialesBacteriumClorobi01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumPhleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium phlei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumPhleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaSpHtcc2999Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. HTCC2999 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSpHtcc2999Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpC100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. C100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpC100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusChondroitinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus chondroitinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusChondroitinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBalearicaDsm6083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas balearica DSM 6083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBalearicaDsm6083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusVitulinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus vitulinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusVitulinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EvansiaMuelleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Evansia muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EvansiaMuelleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudescherichiaVulnerisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudescherichia vulneris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudescherichiaVulnerisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaForsythiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tannerella forsythia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TannerellaForsythiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterCrusticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterCrusticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteralesBacteriumCg2306027(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium CG2_30_60_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumCg2306027", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterGummosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter gummosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterGummosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopodocesHumilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudopodoces humilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudopodocesHumilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaOklahomensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia oklahomensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaOklahomensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubeoparvulumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubeoparvulum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubeoparvulumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHyicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus hyicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHyicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPseudobrasiliensisNbrc108224Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis NBRC 108224 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensisNbrc108224Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo201full3334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO201FULL3334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo201full3334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasIlicicolaDsm19980Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas ilicicola DSM 19980 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasIlicicolaDsm19980Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumCg23070394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG2_30_70_394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg23070394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobusAcidocaldariusDsm639Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius DSM 639 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusDsm639Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusSpAm4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. AM4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSpAm4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenedentesBacteriumCg1024214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium CG1024214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumCg1024214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioOstreicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ostreicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioOstreicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifoxyd2full5815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFOXYD2FULL5815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifoxyd2full5815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnobacterSpCaciam66h1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. CACIAM 66H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpCaciam66h1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioGalatheae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio galatheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioGalatheae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusSp29Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. 2.9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusSp29Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusP6b7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus P6B7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusP6b7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpOt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. OT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpOt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenalcaligenesHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenalcaligenes hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenalcaligenesHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocCarnosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc carnosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCarnosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumLaevaniformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium laevaniformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLaevaniformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot180Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root180 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot180Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfobacillusThermosulfidooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus thermosulfidooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusThermosulfidooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CobetiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cobetia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CobetiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraAustralicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira australica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraAustralicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85201450255sch5639931(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201450255SCH5639931 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201450255sch5639931", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsialesBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiangellaPhaseoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xiangella phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XiangellaPhaseoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaeBacteriumRifcsplowo2123915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospinae bacterium RIFCSPLOWO2_12_39_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospinaeBacteriumRifcsplowo2123915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_49_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterConcretionis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter concretionis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterConcretionis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumParatuberculosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium avium paratuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAviumParatuberculosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineBacteriumAo1C(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return marine bacterium AO1-C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineBacteriumAo1C", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSharpeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSharpeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe23121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE23121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe23121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenimonasSpSl110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenimonas sp. SL110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenimonasSpSl110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasNitritireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas nitritireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasNitritireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodonghicolaXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudodonghicola xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudodonghicolaXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCalifornicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces californicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCalifornicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSpizizeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis spizizenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisSpizizeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWC1_49_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonRbg166727(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_16_67_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg166727", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassilionigeriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilionigeriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilionigeriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwb14719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWB1_47_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwb14719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAbscessusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAbscessusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldibacillusDebilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldibacillus debilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldibacillusDebilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpWd162(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD16.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd162", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TarsiusSyrichta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tarsius syrichta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TarsiusSyrichta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporisoriumScitamineumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporisorium scitamineum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporisoriumScitamineumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocPiscinale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc piscinale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocPiscinale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptoniumThompsoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kryptonium thompsoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KryptoniumThompsoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusInfantariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus infantarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusInfantariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinovumAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinovum algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinovumAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StylophoraPistillataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stylophora pistillata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StylophoraPistillataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpM1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpM1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosococcusWatsoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus watsonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusWatsoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaYangpuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora yangpuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaYangpuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumYoeliiYoelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium yoelii yoelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumYoeliiYoelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GadusMorhuaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gadus morhua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GadusMorhuaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterSpS108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter sp. S10-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterSpS108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DielmaFastidiosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dielma fastidiosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DielmaFastidiosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp2kl27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PalleroniaRufaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Palleronia rufa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PalleroniaRufaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumSit11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium SIT11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumSit11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpSma27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. SMA-27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpSma27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kurthia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KurthiaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp1315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 13-15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp1315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaTyphimurium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhimurium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphimurium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcoidesBurtoniiDsm6242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides burtonii DSM 6242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesBurtoniiDsm6242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo202Full519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_02_FULL_51_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo202Full519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterDaepoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter daepoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterDaepoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermovibrioAmmonificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermovibrio ammonificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermovibrioAmmonificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPseudalcaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus pseudalcaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPseudalcaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium6322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpNrrlb16309(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. NRRLB16309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpNrrlb16309", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumNamnetense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Propionibacterium] namnetense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumNamnetense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoraliomargaritaAkajimensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita akajimensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaAkajimensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfococcusMultivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus multivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusMultivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRapiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rapi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRapiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpNbrc111131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NBRC 111131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNbrc111131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrigoribacteriumSpLeaf415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlomeribacterGigasporarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glomeribacter gigasporarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlomeribacterGigasporarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasCellaseaDsm20118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cellulomonas cellasea DSM 20118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CellulomonasCellaseaDsm20118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe3006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPuniciscabiei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces puniciscabiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPuniciscabiei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaginellaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vaginella massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VaginellaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiphiliumSpCag727Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium sp. CAG:727 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumSpCag727Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandarakinorhabdusSpAap62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sandarakinorhabdus sp. AAP62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SandarakinorhabdusSpAap62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmoebophilusAsiaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus asiaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusAsiaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpRw2a1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. RW2A1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpRw2a1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusClausseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus claussenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusClausseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPiriflorinigransCfbp5888Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans CFBP 5888 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigransCfbp5888Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaVulgarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Beta vulgaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BetaVulgarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptobacillusNotomytisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus notomytis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusNotomytisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumRifcsplowo212full3712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RIFCSPLOWO212FULL3712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRifcsplowo212full3712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacterialesBacteriumBrhc54Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium BRHc54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumBrhc54Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PalleroniaRufa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Palleronia rufa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PalleroniaRufa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaBlandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella blandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaBlandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_43_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesiotobacterExalbescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesiotobacter exalbescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesiotobacterExalbescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp32146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3214.6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpHmsc075b08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. HMSC075B08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpHmsc075b08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifoxyc2full4719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYC2FULL4719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyc2full4719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHelveticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter helveticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHelveticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosovibrioSpNv6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio sp. Nv6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioSpNv6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHel13378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel1_33_78 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel13378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAntibioticophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus antibioticophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAntibioticophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumLipoferum4bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum 4B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AzospirillumLipoferum4bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonDl31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon DL31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonDl31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YokenellaRegensburgeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yokenella regensburgei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YokenellaRegensburgeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachisHedomyrmaTurneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterOboediensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter oboediens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterOboediensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PicoidesPubescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Picoides pubescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PicoidesPubescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibularhizoctoniaSpCbs109695(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibularhizoctonia sp. CBS 109695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibularhizoctoniaSpCbs109695", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonsdaleaQuercina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea quercina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaQuercina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovoraxOdorimutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerovorax odorimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerovoraxOdorimutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag288Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag288Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicractiniumConductrix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micractinium conductrix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicractiniumConductrix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospiraTrueperiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospira trueperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospiraTrueperiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterHepaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter hepaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHepaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSuwonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter suwonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSuwonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaGlaucaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora glauca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaGlaucaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosIndicusXBosTaurusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bos indicus x Bos taurus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BosIndicusXBosTaurusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalpingoecaRosetta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salpingoeca rosetta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalpingoecaRosetta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_12_FULL_48_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho212Full4816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPratensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pratensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPratensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumUrha0028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium URHA0028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumUrha0028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaAtypicaKonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica KON Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaKonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCincinnatiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cincinnatiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioCincinnatiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrabacterSpRoot85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Root85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpRoot85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRadioresistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter radioresistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRadioresistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterPectinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algibacter pectinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgibacterPectinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DolosigranulumPigrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dolosigranulum pigrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DolosigranulumPigrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinopithecusBietiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus bieti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusBietiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DromaiusNovaehollandiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dromaius novaehollandiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DromaiusNovaehollandiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulforegulaConservatrixCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulforegula conservatrix Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulforegulaConservatrixCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycomycesBlakesleeanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusTengchongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusTengchongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydansH24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans H24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydansH24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_01_FULL_40_98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSp5720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. 57_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSp5720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriDmel1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Providencia rettgeri Dmel1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriDmel1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtelocyanobacteriumThalassaSio64986Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa SIO64986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaSio64986Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpHel13349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel13349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolaribacterSpHel13349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisTropicalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisTropicalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioSpRm50Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. RM50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpRm50Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusB316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus B316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusB316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YamadazymaTenuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YamadazymaTenuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpRoot1480d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root1480D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot1480d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavicepsPurpurea201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Claviceps purpurea 20.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClavicepsPurpurea201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSp217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. 217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSp217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlenkiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klenkia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlenkiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerofustisStercorihominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerofustis stercorihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerofustisStercorihominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPHIGHO2_01_FULL_44_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsphigho201Full4441", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGraminisolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides graminisolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGraminisolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpMccc1a01428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01428 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DuganellaSpRoot1480d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Root1480D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpRoot1480d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChoiromycesVenosus1206131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Choiromyces venosus 120613-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChoiromycesVenosus1206131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsplowo201full4534bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO201FULL4534b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo201full4534bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioTasmaniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio tasmaniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioTasmaniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterPulverisDsm19144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Franconibacter pulveris DSM 19144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FranconibacterPulverisDsm19144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm6137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM6137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm6137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyronemaOmphalodesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyronema omphalodes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyronemaOmphalodesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusPeptonophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus peptonophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPeptonophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferSpZgt114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. ZGT114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpZgt114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiferrobacterThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidiferrobacter thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidiferrobacterThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRossiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rossiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRossiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpLeaf72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Leaf72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpLeaf72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RasamsoniaEmersonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RasamsoniaEmersonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumSpMj126nf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium sp. MJ126NF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumSpMj126nf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6258(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6258", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp15544247(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1554424.7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp15544247", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuglansRegia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Juglans regia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JuglansRegia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterWolfeiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter wolfeii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterWolfeiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumLuteumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium luteum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumLuteumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCriceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus criceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCriceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantholopsHodgsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantholops hodgsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantholopsHodgsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscibacillusSalipiscariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpWg21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. WG21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpWg21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelampsoraLariciPopulina98ag31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Melampsora larici-populina 98AG31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MelampsoraLariciPopulina98ag31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasTurrisvirgatae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas turrisvirgatae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTurrisvirgatae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tectomicrobia bacterium RIFCSPLOWO2_02_FULL_70_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho202full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO202FULL3913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho202full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusFleurettiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus fleurettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusFleurettiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeonGw2011ar20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBoissieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter boissieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBoissieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEbm40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium EBM-40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumEbm40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpIs2118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. IS2118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpIs2118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytosporaLeucostoma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cytospora leucostoma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CytosporaLeucostoma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimicrobiumAcidiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrimicrobium acidiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrimicrobiumAcidiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumNalgiovenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium nalgiovense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumNalgiovenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusVitulinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus vitulinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusVitulinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenolissoclinumPacificiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenolissoclinum pacificiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenolissoclinumPacificiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BizioniaArgentinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bizionia argentinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BizioniaArgentinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCaecimuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides caecimuris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCaecimuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSimilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter similis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSimilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpCl6col(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. cl6col graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpCl6col", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucibacterSpKctc42545(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paucibacter sp. KCTC 42545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaucibacterSpKctc42545", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AncylostomaCaninumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma caninum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCaninumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumGw2011gwa14610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium GW2011GWA14610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumGw2011gwa14610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusParaburkholderiaKirkiiUzhbot1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Paraburkholderia kirkii UZHbot1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusParaburkholderiaKirkiiUzhbot1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4422bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4422b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4422bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaEndosymbiontOfOrnithodorosMoubata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Francisella endosymbiont of Ornithodoros moubata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiontOfOrnithodorosMoubata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilisF(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilisF", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166443(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166443", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumReichenbachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium reichenbachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumReichenbachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAcrylicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio acrylicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAcrylicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumCg23041165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_41_165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg23041165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosmotogaArenicorallinaS304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina S304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KosmotogaArenicorallinaS304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntrasporangiaceaeBacteriumUrhb0013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangiaceae bacterium URHB0013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiaceaeBacteriumUrhb0013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciibacterSuperstesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciibacter superstes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciibacterSuperstesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpMn802workerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Mn802worker Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpMn802workerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StappiaSpEs058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. ES.058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StappiaSpEs058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpF0473Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. F0473 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpF0473Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20218Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20218 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20218Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GleimiaColeocanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gleimia coleocanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GleimiaColeocanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumOlb17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium OLB17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumOlb17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IchthyophthiriusMultifiliisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBenthicaKt99Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shewanella benthica KT99 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBenthicaKt99Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaSoliDsm19436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kaistia soli DSM 19436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KaistiaSoliDsm19436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpX1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. X1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpX1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusFrigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus frigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFrigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrientiaChutoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Orientia chuto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrientiaChutoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidiprofundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwc13712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC13712 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc13712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1859(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1859 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1859", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopelagiusInordinatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halopelagius inordinatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalopelagiusInordinatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterJejuni414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuni414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidesmisPriestleyiUlc007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi ULC007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiUlc007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpCf136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. CF136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpCf136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprothermobacterProteolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coprothermobacter proteolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoprothermobacterProteolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntrasporangiumCalvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium calvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumCalvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterCuticularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter cuticularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCuticularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPluripotensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pluripotens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPluripotensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrarchaeotaArchaeonRbg16369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon RBG16369 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonRbg16369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumProteolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium proteolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProteolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryziasLatipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryzias latipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryziasLatipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCirculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus circulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCirculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4717 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpSoap(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpSoap", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckiiCbs1146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii CBS 1146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckiiCbs1146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSp5139bfaa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus sp. 5139BFAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusSp5139bfaa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasPalmitatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaGansuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jiangella gansuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JiangellaGansuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithorhynchusAnatinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ornithorhynchus anatinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OrnithorhynchusAnatinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterGangjinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter gangjinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterGangjinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenolissoclinumPacificiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenolissoclinum pacificiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenolissoclinumPacificiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaTaiwanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma taiwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTaiwanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisKunsanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis kunsanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisKunsanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsphigho201full4422bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO201FULL4422b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho201full4422bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudopedobacterSaltans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudopedobacter saltans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudopedobacterSaltans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumRifcsplowo202full5816Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium RIFCSPLOWO202FULL5816 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumRifcsplowo202full5816Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaRhizoxinicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia rhizoxinica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaRhizoxinicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumSm2361(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SM23_61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSm2361", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsphigho202full3936Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPHIGHO202FULL3936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsphigho202full3936Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrigamiaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strigamia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrigamiaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpBh72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. BH72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpBh72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBingchenggensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bingchenggensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBingchenggensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumGallinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gallinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGallinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterMishustinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter mishustinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterMishustinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSalmonicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia salmonicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSalmonicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HungateiclostridiumCellulolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium cellulolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumCellulolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrionaceaeBacteriumBs12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrionaceae bacterium Bs12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrionaceaeBacteriumBs12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropithecusCoquereliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propithecus coquereli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropithecusCoquereliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasHistidinilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas histidinilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasHistidinilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf141Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf141 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf141Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEisenbacteriaBacteriumRbg167146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Eisenbacteria bacterium RBG_16_71_46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusEisenbacteriaBacteriumRbg167146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicroterricolaViridariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microterricola viridarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicroterricolaViridariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasMelonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas melonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMelonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeratocystisFimbriata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeratocystisFimbriata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusPaucihalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus paucihalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusPaucihalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf469Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf469 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf469Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusRuberCbs135680(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ruber CBS 135680 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusRuberCbs135680", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHyicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus hyicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHyicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCarnosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus carnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCarnosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsphigho201full4817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL4817 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full4817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrapisisporaBlattaeCbs6284(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae CBS 6284 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaBlattaeCbs6284", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaForsetiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella forsetii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaForsetiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumGw2011Gwa1409(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium GW2011_GWA1_40_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumGw2011Gwa1409", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpBhbn044Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BHBN044 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSpBhbn044Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCystitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium cystitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCystitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAlkalicaDsm8900(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica DSM 8900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalicaDsm8900", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaAestuariiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimia aestuarii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimiaAestuariiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetascardoviaCriceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Metascardovia criceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MetascardoviaCriceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPHIGHO2_12_FULL_45_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsphigho212Full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrucibulumLaeveCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crucibulum laeve Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrucibulumLaeveCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumBranderi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium branderi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumBranderi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTunicataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas tunicata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTunicataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllomycesMacrogynusAtcc38327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Allomyces macrogynus ATCC 38327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AllomycesMacrogynusAtcc38327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp01251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 0-1251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp01251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpBhbn044Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BHBN044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HyphomonasSpBhbn044Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesGambiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles gambiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesGambiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwf23829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23829 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronobacteriumGregoryi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronobacterium gregoryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronobacteriumGregoryi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimonasFerruginea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrimonasFerruginea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCoralii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio coralii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioCoralii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StoquefichusSpSb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. SB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpSb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpNciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Nci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpNciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitriliruptorAlkaliphilusDsm45188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus DSM 45188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilusDsm45188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchizosaccharomycesPombeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schizosaccharomyces pombe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchizosaccharomycesPombeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasLuteolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasLuteolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaMediumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema medium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaMediumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminobacteriumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusSpJcm16833Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. JCM 16833 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpJcm16833Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterYoungaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter youngae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterYoungaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg164923Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_49_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg164923Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45544Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45544 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45544Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeomargaritaLithophoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeomargarita lithophora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeomargaritaLithophoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesNigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces niger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpNyagatareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Nyagatare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasSpNyagatareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSpSfb93Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter sp. SFB93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelobacterSpSfb93Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParacuniculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paracuniculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParacuniculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_34_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp8g7msg3316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 8G7MSG3316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp8g7msg3316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSubflavaDsm22618Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava DSM 22618 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflavaDsm22618Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterMorbiferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter morbifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconobacterMorbiferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatimeriaChalumnaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Latimeria chalumnae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LatimeriaChalumnaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpRoot135Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root135 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot135Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumisMelo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cucumis melo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CucumisMelo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shimia aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShimiaAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23813bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23813b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23813bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccomyxaSubellipsoideaC169Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea C-169 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoideaC169Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassilibacteriumSenegalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassilibacteriumSenegalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndolissoclinumFaulkneriL5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endolissoclinum faulkneri L5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndolissoclinumFaulkneriL5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpY412mc10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Y412MC10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpY412mc10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterEchinorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter echinorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterEchinorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa288g21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288G21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288g21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrodochiumBolleyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microdochium bolleyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrodochiumBolleyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiardiaLambliaP15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia P15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaP15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosimicrobiumCellulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSp651059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraPsammophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraPsammophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrauserellaRugosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prauserella rugosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrauserellaRugosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasMontiporaeCl33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae CL-33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporaeCl33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaSympodialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malassezia sympodialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalasseziaSympodialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSpM21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. M21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpM21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaprolegniaParasiticaCbs22365Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica CBS 223.65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaprolegniaParasiticaCbs22365Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_42_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteroidobacterDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Steroidobacter denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SteroidobacterDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavisolibacterGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquidulcibacterPaucihalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquidulcibacter paucihalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquidulcibacterPaucihalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaMalleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mallei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMalleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaElaeagniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia elaeagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaElaeagniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusUreilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesOris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesOris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusWk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus WK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusWk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaSpCag878Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma sp. CAG:878 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaSpCag878Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumNeoaurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium neoaurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumNeoaurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinalesArchaeonMethan01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcinales archaeon Methan_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinalesArchaeonMethan01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PirellulaSpShsr6aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pirellula sp. SHSr6A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PirellulaSpShsr6aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidaceaeBacteriumMs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidaceae bacterium MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidaceaeBacteriumMs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpeibonaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces speibonae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpeibonaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobalesArchaeonAcd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Acd1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfolobalesArchaeonAcd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicoccusPhenolivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicoccus phenolivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicoccusPhenolivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFluvialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fluvialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioFluvialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSpSd62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. SD62 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpSd62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGilvosporeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvosporeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvosporeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumDehalogenans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dehalogenans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDehalogenans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSoudanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas soudanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSoudanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBoevrei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella boevrei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBoevrei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloglobulusMorosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloglobulus morosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloglobulusMorosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodolunaLacicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoluna lacicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodolunaLacicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaForsythiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tannerella forsythia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TannerellaForsythiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpMi1205(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. MI1205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpMi1205", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslr70331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumJannaschiiDsm6295(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii DSM 6295 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschiiDsm6295", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaRodhainiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma rodhaini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaRodhainiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaLambliaP15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia P15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaP15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagnetotacticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Haemophilus] felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NothoproctaPerdicariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nothoprocta perdicaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NothoproctaPerdicariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpF0091Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0091 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0091Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiPvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumDtu014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpHmsc072f04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC072F04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc072f04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumCg104938Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_49_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104938Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaMarismortuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula marismortui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaMarismortuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesOnderdonkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes onderdonkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesOnderdonkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolentinusLepideusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neolentinus lepideus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeolentinusLepideusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusSilvanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus silvanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusSilvanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumIners(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium iners graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumIners", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevirhabdusPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevirhabdus pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevirhabdusPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusGrossensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus grossensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusGrossensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApostichopusJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apostichopus japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApostichopusJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRaac3tm71Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RAAC3TM71 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRaac3tm71Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfatibacterAminovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfatibacter aminovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DethiosulfatibacterAminovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOtitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOtitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterVibrioformisDsm8776(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis DSM 8776 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformisDsm8776", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPeriocalifornicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides periocalifornicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPeriocalifornicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGigeriorumDsm23908Crbip2485Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus gigeriorum DSM 23908 CRBIP 24.85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGigeriorumDsm23908Crbip2485Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpVlb120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. VLB120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpVlb120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaricomesPhytoseiuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acaricomes phytoseiuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcaricomesPhytoseiuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumChinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capsicum chinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapsicumChinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpLeaf420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Leaf420 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLeaf420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPyrifoliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erwinia pyrifoliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPyrifoliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEdens01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Edens01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEdens01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania africana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaAfricanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmazonaCollariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amazona collaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmazonaCollariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocPseudomesenteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc pseudomesenteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocPseudomesenteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCellulosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellulosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellulosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SucciniclasticumRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SucciniclasticumRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRufum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rufum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRufum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaHelminthoecaStrOregon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca str. Oregon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoecaStrOregon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaRattimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterOlleyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter olleyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterOlleyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpU41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. U41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpU41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf4489Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF4489 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf4489Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium13140cm6517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_65_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls350Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS350 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls350Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPeoriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus peoriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPeoriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNk4a136Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A136 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a136Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoSp1063(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosipho sp. 1063 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosiphoSp1063", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpAl212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. AL212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpAl212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpBg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Bg2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpBg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonadaceaeBacteriumH1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumH1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiyogibacteriaBacteriumRifcsplowo212full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO212FULL4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo212full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamiellaSorbophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamiella sorbophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WickerhamiellaSorbophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSalinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157H7StrSakaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli O157:H7 str. Sakai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiO157H7StrSakaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrivivaxBenzoatilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax benzoatilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxBenzoatilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27916 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPiraticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas piratica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPiraticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSulciaMuelleriGwss(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sulcia muelleri GWSS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSulciaMuelleriGwss", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_47_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpGas231(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. GAS231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpGas231", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumPhotometricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodospirillum photometricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodospirillumPhotometricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfatatorAutotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator autotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAutotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillalesBacterium7018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 70-18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium7018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpCp53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Cp53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCp53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumIranicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium iranicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIranicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HugenholtziaRoseolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HugenholtziaRoseolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuraishiaCapsulataCbs1993(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kuraishia capsulata CBS 1993 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KuraishiaCapsulataCbs1993", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CinnamomumMicranthumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CinnamomumMicranthumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2303621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_36_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2303621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriumSpPmmr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidobacterium sp. PMMR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidobacteriumSpPmmr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusYeei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus yeei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusYeei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosarcinaPallidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halosarcina pallida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalosarcinaPallidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaSpEcsmb14101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ECSMB14101 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpEcsmb14101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocPiscinaleCena21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nostoc piscinale CENA21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NostocPiscinaleCena21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaXinjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora xinjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaXinjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolaciniaPetrolearia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia petrolearia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPetrolearia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalisaetaLongaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salisaeta longa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalisaetaLongaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg13389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG13389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg13389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpMb200Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. MB200 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpMb200Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlobicatellaSulfidifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Globicatella sulfidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlobicatellaSulfidifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSubtropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes subtropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSubtropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full4619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL4619 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full4619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaAcuminata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Musa acuminata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusaAcuminata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPutidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema putidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPutidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusJl18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus JL-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusJl18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RegiellaInsecticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Regiella insecticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RegiellaInsecticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaSpVcsa23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olleya sp. VCSA23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlleyaSpVcsa23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReinekeaBlandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Reinekea blandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ReinekeaBlandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisKctc3167(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis KCTC3167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisKctc3167", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexibacterFlexilisDsm6793(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flexibacter flexilis DSM 6793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlexibacterFlexilisDsm6793", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerochaetaPleomorpha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta pleomorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaPleomorpha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaOvisStrMichiganCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma ovis str. Michigan Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaOvisStrMichiganCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaMeleagridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma meleagridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaMeleagridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumYanniciiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium yannicii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumYanniciiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSp233421i1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. 233421I1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSp233421i1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfTrabutina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_42_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full4228Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpW9775Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. W9775 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpW9775Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumL21thd2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium L21THD2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumL21thd2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpRuh2624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. RUH2624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpRuh2624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxRowiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apteryx rowi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApteryxRowiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsphigho212full439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO212FULL439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho212full439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HolophagaFoetida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Holophaga foetida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HolophagaFoetida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumGastri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium gastri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumGastri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisXylanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis xylanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisXylanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpMc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. MC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpMc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA1_44_29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa14429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevinemaAndersoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevinema andersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevinemaAndersoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumCaspactino2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium caspactino2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCaspactino2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0262(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpF0262", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VesicomyosociusOkutaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vesicomyosocius okutanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VesicomyosociusOkutaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InediibacteriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Inediibacterium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "InediibacteriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloscardoviaMacacaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia macacae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaMacacaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsphigho202full5118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL5118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full5118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulieris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MobiluncusMulieris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenochaetaSpDs3say3a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrenochaeta sp. DS3sAY3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrenochaetaSpDs3say3a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGlumaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia glumae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaGlumaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifoxyc2full4719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYC2FULL4719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyc2full4719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag841(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:841 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag841", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusZancles(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus zancles graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusZancles", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEe36Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EE36 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpEe36Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaCephalotesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atta cephalotes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AttaCephalotesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumNepotumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium nepotum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumNepotumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumisSativus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cucumis sativus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CucumisSativus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumArenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumArenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisMediterraneiS699Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei S699 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisMediterraneiS699Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpChkci003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CHKCI003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpChkci003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwa24110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWA2_41_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwa24110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumGwa1448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium GWA1_44_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumGwa1448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPneumoniaeD39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae D39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeD39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1058 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophoarchaeumButanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum butanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumButanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwb14311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWB14311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwb14311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumLinensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium linens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumLinensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSp6021061333(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. 6021061333 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSp6021061333", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumPhytohabitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium phytohabitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumPhytohabitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpScgcAaa160p02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. SCGC AAA160P02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpScgcAaa160p02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PerlucidibacaAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Perlucidibaca aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PerlucidibacaAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpOmz838Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. OMZ838 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpOmz838Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumStriatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium striatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumStriatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusPolysaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius polysaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusPolysaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumGossipiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium gossipiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumGossipiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpQa3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. QA3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpQa3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumUlcerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulcerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlcerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpUnc363mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC363MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc363mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRbg134110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium RBG_13_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRbg134110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpIbvss2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnchocercaFlexuosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca flexuosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OnchocercaFlexuosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_01_FULL_40_98 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf3557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF3557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf3557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSpDw0440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dickeya sp. DW 0440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DickeyaSpDw0440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaBurnetiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coxiella burnetii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoxiellaBurnetiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterAmalonaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter amalonaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterAmalonaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1026051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1026051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1026051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag156Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:156 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag156Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFlexibilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas flexibilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFlexibilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraInadaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira inadai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraInadaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRbg163611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG163611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg163611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeptunicoccusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptunicoccus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptunicoccusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterNataicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter nataicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterNataicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMarmotae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marmotae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarmotae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaDrozanskii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella drozanskii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaDrozanskii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaTaiwanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma taiwanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTaiwanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brevibacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrevibacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuis22083Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis 22083 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuis22083Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpF0557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. F0557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpF0557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFallax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium fallax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFallax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaPleuritidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pleuritidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPleuritidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHokkaidonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp7016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 70-16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesShahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes shahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesShahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasSpRifcsplowo2123612Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFCSPLOWO2_12_36_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifcsplowo2123612Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterPasteurianusIfo328301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter pasteurianus IFO328301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPasteurianusIfo328301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusParcubacteriaBacterium4484255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Parcubacteria bacterium 4484_255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusParcubacteriaBacterium4484255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1024989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_49_89 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1024989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpLmtr3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LMTR 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLmtr3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSalsusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus salsus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSalsusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_40_27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4027", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumRifcsphigho202full4613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO202FULL4613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho202full4613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusVersicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus versicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusVersicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrucellaMelitensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brucella melitensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrucellaMelitensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumSoil82Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium SOIL82 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumSoil82Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumVariabileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium variabile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVariabileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovorusGlucosetrophusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylovorus glucosetrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylovorusGlucosetrophusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapitellaTeletaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capitella teleta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapitellaTeletaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemocanisStrIllinoisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis str. Illinois Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanisStrIllinoisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpJdr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JDR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJdr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterButzleriRm4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri RM4018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriRm4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonJ07hb67Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HB67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hb67Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp14657030(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1465703.0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14657030", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusSendaiensisNbrc100866Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis NBRC 100866 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensisNbrc100866Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf24317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF24317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf24317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifoxyd2full3415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYD2FULL3415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyd2full3415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTsri0281Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TSRI0281 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTsri0281Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeotogaPetraeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geotoga petraea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeotogaPetraeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmillariaSolidipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armillaria solidipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmillariaSolidipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaEutrophaH16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha H16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaH16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibiumSpTrichskd4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseibium sp. TrichSKD4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseibiumSpTrichskd4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacterium13120cm5428Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium 13_1_20CM_54_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacterium13120cm5428Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIThaumarchaeote(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeote", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwf24242(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWF24242 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwf24242", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviramulusBasaltisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus basaltis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusBasaltisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSp651402(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-1402 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp651402", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasArcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas arcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfallasArcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusActinosclerusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus actinosclerus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusActinosclerusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKorlensisNbrc107688(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus korlensis NBRC 107688 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusKorlensisNbrc107688", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusVietnamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusVietnamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfofustisGlycolicusDsm9705(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfofustis glycolicus DSM 9705 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfofustisGlycolicusDsm9705", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6803Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6803 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6803Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallaecimonasXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallaecimonas xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallaecimonasXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RozellaAllomycisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rozella allomycis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RozellaAllomycisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetesBacteriumGwe132154Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWE1_32_154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwe132154Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumMfb021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MFB021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMfb021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenirhodobacterEnshiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenirhodobacter enshiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenirhodobacterEnshiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaTyrosinosolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella tyrosinosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaTyrosinosolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaMultilocaleAtcc49900Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale ATCC 49900 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocaleAtcc49900Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLactisRw25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium lactis RW2-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumLactisRw25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratiruptorTergarcusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor tergarcus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorTergarcusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphothecaResinaeAtcc22711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amorphotheca resinae ATCC 22711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmorphothecaResinaeAtcc22711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_49_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaOleraceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brassica oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrassicaOleraceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophilia5bai2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia 5BAI2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophilia5bai2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPerolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus perolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPerolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterNitrophenolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter nitrophenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterNitrophenolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocinitomixCatalasiticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix catalasitica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixCatalasiticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvencibacteriumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Provencibacterium massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProvencibacteriumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFOXYC2_FULL_39_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifoxyc2Full398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTyphiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia typhi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiaTyphiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliopsisZonataCbs50665Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata CBS 506.65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PenicilliopsisZonataCbs50665Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterFreundiiCfnih1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter freundii CFNIH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterFreundiiCfnih1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiberibacterAfricanusPtsapsyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liberibacter africanus PTSAPSY Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiberibacterAfricanusPtsapsyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpYab3001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. YAB3001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpYab3001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAsiaticusPsy62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus psy62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusPsy62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterToleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter tolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterToleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonMixedEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixedEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TokpelaiaHoelldobleriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tokpelaia hoelldoblerii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TokpelaiaHoelldobleriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusChilensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusQuebecensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus quebecensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusQuebecensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpFc2001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FC2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFc2001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSalinaYim90010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardiopsis salina YIM 90010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiopsisSalinaYim90010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermococcusOkinawensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus okinawensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusOkinawensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculusVarScolymusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cynara cardunculus var. scolymus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CynaraCardunculusVarScolymusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasDonghaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenimonasDonghaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfovibrioPeptidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio peptidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioPeptidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolimangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solimangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSolimangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconacetobacterSpSxcc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gluconacetobacter sp. SXCC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GluconacetobacterSpSxcc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchwartziaSuccinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchwartziaSuccinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSpCp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. CP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpCp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidibacterThalassicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidibacterThalassicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAc4496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AC44/96 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAc4496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpOk909Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ok909 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOk909Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusArachidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus arachidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusArachidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PersicobacterSpJzb09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Persicobacter sp. JZB09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PersicobacterSpJzb09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RobiginitaleaBiformata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea biformata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaBiformata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumRubrisubalbicans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBizertensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia rettgeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRettgeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JonquetellaAnthropiE333e1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi E333E1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiE333e1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptotermesSecundusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptotermes secundus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptotermesSecundusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesOlindensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces olindensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesOlindensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpNe3005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. ne3005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpNe3005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBryantiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella bryantii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBryantiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumMurisUcdAy4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brachybacterium muris UCD-AY4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrachybacteriumMurisUcdAy4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaNegevensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kingella negevensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KingellaNegevensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPolaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas polaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPolaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AustrofundulusLimnaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Austrofundulus limnaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AustrofundulusLimnaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAceticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aceticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAceticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp2kl3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterLimosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janibacter limosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanibacterLimosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho212full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO212FULL4422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho212full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMannanilyticusJcm10596Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus JCM 10596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusMannanilyticusJcm10596Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnavibacteriaBacteriumGwc23612Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWC2_36_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwc23612Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesHl037pa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes HL037PA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesHl037pa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNeoaurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium neoaurum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumNeoaurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrolobusFumarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrolobus fumarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrolobusFumarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCadaverisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cadaveris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCadaverisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEnterocolitica8081(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yersinia enterocolitica 8081 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YersiniaEnterocolitica8081", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColobusAngolensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colobus angolensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColobusAngolensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumChilense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chilense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChilense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm8964Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM8964 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm8964Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumEtliMimosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli mimosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliMimosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaProvencensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella provencensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProvencensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotiiLm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii LM2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridioidesMangenotiiLm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNiameyenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium niameyense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNiameyenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavonifractorPlautii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavonifractor plautii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavonifractorPlautii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpJahCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JAH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJahCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobiArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpiroformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium spiroforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpiroformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaHofmanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scytonema hofmannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScytonemaHofmanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasChironomiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas chironomi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachymonasChironomiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionTm6BacteriumUasb340Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium UASB340 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumUasb340Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaSkyensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella skyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaSkyensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpCf385Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. CF385 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpCf385Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaVerecundum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma verecundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaVerecundum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiOharae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei oharae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiOharae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusFiliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus filiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusFiliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalalkalicoccusJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halalkalicoccus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalalkalicoccusJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaOmnicolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia omnicolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaOmnicolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaWenchangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea wenchangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaWenchangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full4414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpBisph1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. Bisph1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpBisph1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSubterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Knoellia subterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSubterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TanticharoeniaSakaeratensisNbrc103193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tanticharoenia sakaeratensis NBRC 103193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TanticharoeniaSakaeratensisNbrc103193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumSpAf8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaMultocidaPm70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella multocida Pm70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaMultocidaPm70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrososphaeraViennensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraViennensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesOdoratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucoagaricusSpSymccos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucoagaricus sp. SymCcos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucoagaricusSpSymccos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoesziomycesAntarcticusT34Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moesziomyces antarcticus T-34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoesziomycesAntarcticusT34Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraMobilis13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis 13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilis13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacteriumJgi0000077k19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium JGI 0000077K19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacteriumJgi0000077k19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4222 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumMobileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium mobile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMobileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KiloniellaMajaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kiloniella majae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KiloniellaMajaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusHeteromorphusCbs11755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus CBS 117.55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusHeteromorphusCbs11755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleomorphomonasOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pleomorphomonas oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PleomorphomonasOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraAustraliensisBen110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera australiensis Ben110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraAustraliensisBen110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaMajor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leishmania major graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaMajor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumViolaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium violaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumViolaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaPseudobrasiliensisNbrc108224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis NBRC 108224 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensisNbrc108224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShigellaDysenteriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShigellaDysenteriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisTaihuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis taihuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisTaihuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusJurassicusNbrc107829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus NBRC 107829 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusJurassicusNbrc107829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineBacteriumAo1CEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return marine bacterium AO1-C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineBacteriumAo1CEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSpSd626rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. SD626R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpSd626rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterHepaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter hepaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHepaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhytofirmansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phytofirmans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhytofirmansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCaprae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCaprae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpApr13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. APR13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpApr13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesDerwentensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes derwentensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesDerwentensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxya2full4315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYA2FULL4315 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxya2full4315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumVariabileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium variabile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVariabileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusSpMarseillep2731(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus sp. MarseilleP2731 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrococcusSpMarseillep2731", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltiarchaealesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altiarchaeales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltiarchaealesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BombusImpatiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bombus impatiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BombusImpatiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWeilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira weilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWeilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpRoot52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Root52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpRoot52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrusBergyltaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrus bergylta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrusBergyltaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydophilaFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCampestris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraKmetyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira kmetyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraKmetyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNc2004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaBermudensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula bermudensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvularculaBermudensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCibarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cibarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCibarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoflavonifractorSpMarseillep3106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoflavonifractor sp. MarseilleP3106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoflavonifractorSpMarseillep3106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 71-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasIngrahamii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ingrahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromonasIngrahamii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandicaDsm15978Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica DSM 15978 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandicaDsm15978Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaTularensisSchus4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis SCHUS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisSchus4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzorhizobiumCaulinodansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium caulinodans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumCaulinodansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusCopahuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidianus copahuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidianusCopahuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterKobei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter kobei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterKobei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwc14518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWC14518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwc14518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StegastesPartitus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stegastes partitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StegastesPartitus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansPlanktonicusIiD5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Limnohabitans planktonicus II-D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LimnohabitansPlanktonicusIiD5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSteynii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter steynii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSteynii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gramella flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GramellaFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumSpScadc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum sp. SCADC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumSpScadc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusDepauperatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus depauperatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptococcusDepauperatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterValericigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter valericigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterValericigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharothrixSpNrrlb16348Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16348Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpicoccumNigrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epicoccum nigrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpicoccumNigrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EwingellaAmericanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ewingella americana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EwingellaAmericanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AscobolusImmersus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ascobolus immersus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AscobolusImmersus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricanaCbs2517Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania africana CBS 2517 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaAfricanaCbs2517Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusSalariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus salarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusSalariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAlginolyticusNbrc15630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus NBRC15630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioAlginolyticusNbrc15630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRifcsphigho201full6617Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RIFCSPHIGHO201FULL6617 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRifcsphigho201full6617Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaCynodegmi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga cynodegmi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCynodegmi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumJeddahenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium jeddahense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumJeddahenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermatophilusCongolensisDsm44180Nbrc105199(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dermatophilus congolensis DSM 44180 NBRC 105199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DermatophilusCongolensisDsm44180Nbrc105199", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpAap60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. AAP60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpAap60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerovibrioVeloxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio velox Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioVeloxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_02_FULL_47_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumSalicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum salicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSalicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGracilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGracilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucca08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterFiliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter filiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterFiliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FournierellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fournierella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FournierellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriA1501Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri A1501 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriA1501Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaceyellaSacchariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Laceyella sacchari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LaceyellaSacchariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuaniaAlbidiflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruania albidiflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuaniaAlbidiflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGhanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGhanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKuenenbacteriaBacteriumCg2303924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium CG2_30_39_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumCg2303924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpRoot4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella veroralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaVeroralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaLucivoraxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaLucivoraxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwc23941(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC23941 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc23941", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpBa93Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa93Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasRhizophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas rhizophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasRhizophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSuryakundensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus suryakundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSuryakundensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumOrbiculare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusAsinusAsinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Equus asinus asinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EquusAsinusAsinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaVacuolataZ761Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata Z-761 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolataZ761Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterNecessariusStir1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius STIR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusStir1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpVpap30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. VPAP30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioSpVpap30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpIs79a3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Is79A3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpIs79a3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSp2136faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 2136FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp2136faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumReichenbachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium reichenbachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumReichenbachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGhanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGhanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaSpGbbuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia sp. GBBU Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaSpGbbuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumResistensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium resistens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumResistensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiBl21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli BL21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiBl21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinosporaRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinospora rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoactinosporaRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFCSPLOWO2_02_FULL_48_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifcsplowo202Full4811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseochromogenusSubspOscitansDs12976(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces roseochromogenus subsp. oscitans DS 12.976 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesRoseochromogenusSubspOscitansDs12976", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CosenzaeaMyxofaciensAtcc19692(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens ATCC 19692 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciensAtcc19692", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaeiDsm21440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei DSM 21440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaeiDsm21440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumF0540(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium F0540 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumF0540", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumNiveocremeumHhb9708Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum HHB9708 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeumHhb9708Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterBemidjiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter bemidjiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterBemidjiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaGuancheCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Drosophila guanche Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGuancheCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrateuriaAurantia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frateuria aurantia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrateuriaAurantia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaEntomophagaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia entomophaga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaEntomophagaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCastoreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus castoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCastoreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SoonwooaBuanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Soonwooa buanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SoonwooaBuanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnobacteriumBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnobacterium bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnobacteriumBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaSpW5cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga sp. W5C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaSpW5cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesExalbidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides exalbidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesExalbidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisVariantCapraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantCapraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelatoporiaSubvermispora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gelatoporia subvermispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GelatoporiaSubvermispora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanofollisEthanolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanofollis ethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanofollisEthanolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfatatorAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfatator atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfatatorAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterKobeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter kobei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterKobeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KryptolebiasMarmoratusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kryptolebias marmoratus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KryptolebiasMarmoratusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaStagnalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia stagnalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaStagnalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriaceaeBacteriumChkci004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterPostgatei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter postgatei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterPostgatei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FabibacterSp4d4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter sp. 4D4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FabibacterSp4d4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasCitrea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas citrea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasCitrea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag452Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:452 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag452Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil763Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil763 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil763Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterSpOr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter sp. OR-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterSpOr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferSpQ7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. Q7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpQ7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumLipolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRbg133615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_36_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg133615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full379Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL379 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full379Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAviarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAviarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaapiaArgillaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jaapia argillacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JaapiaArgillaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus septemdierum str. Myojin knoll Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolusSeptemdierumStrMyojinKnollCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DebaryomycesHanseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DebaryomycesHanseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat18017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanifilumFulgidumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planifilum fulgidum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanifilumFulgidumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumSpRac02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. RAC02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpRac02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcidisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acidisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcidisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpinosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium spinosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpinosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPrimitiaZas1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMurrayiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus murrayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMurrayiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroogloeocystisSiderophila52SC1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila 5.2 s.c.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophila52SC1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaInagensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaInagensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesocricetusAuratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesocricetus auratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesocricetusAuratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusSubspFetusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus subsp. fetus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetusSubspFetusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevyellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levyella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevyellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusAsymbiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus asymbiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusAsymbiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_01_FULL_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho201Full4110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterActinosclerusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter actinosclerus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterActinosclerusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumLubricantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lubricantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLubricantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasArgentinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas argentinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasArgentinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumVa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium VA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumVa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpOv174(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. OV174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpOv174", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGwa15412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GWA15412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGwa15412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaMellicolaCbs63366Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wallemia mellicola CBS 633.66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WallemiaMellicolaCbs63366Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrauserellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prauserella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrauserellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusAquatilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus aquatilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusAquatilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho202full5012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO202FULL5012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho202full5012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesnuesiellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desnuesiella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesnuesiellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusTropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronolimnobiusInnermongolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronolimnobius innermongolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronolimnobiusInnermongolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesPhilippinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes philippinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesPhilippinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeiaOryzaeDsm17879Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leeia oryzae DSM 17879 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeeiaOryzaeDsm17879Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpL21syrabEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. L21SyrAB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpL21syrabEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MikellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mikella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MikellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumDeleyianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum deleyianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumDeleyianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippusPlexippusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus plexippus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DanausPlexippusPlexippusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinotignumSchaaliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum schaalii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinotignumSchaaliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium13140cm6619Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 13_1_40CM_66_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium13140cm6619Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisVancoresmycinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis vancoresmycina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisVancoresmycinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaBongoriNctc12419Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella bongori NCTC12419 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaBongoriNctc12419Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAnthracisAmes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Ames graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisAmes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpDsi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dsi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDsi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpCf614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. CF614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpCf614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IctidomysTridecemlineatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ictidomys tridecemlineatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IctidomysTridecemlineatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumVerticillioides7600(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium verticillioides 7600 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumVerticillioides7600", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticiRepentisPt1cBfpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora tritici-repentis Pt-1C-BFP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTriticiRepentisPt1cBfpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraMultiparaAtcc19207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara ATCC19207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaAtcc19207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArsenophilumNbrc109478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum NBRC 109478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilumNbrc109478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpAr710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. AR7-10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpAr710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimonasFerrugineaDsm30193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea DSM 30193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TerrimonasFerrugineaDsm30193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLablabiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium lablabi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLablabiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisPretoriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis pretoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisPretoriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat27251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpCcbus3uf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. CCBUS3UF1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusSpCcbus3uf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumOxidoreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium oxidoreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumOxidoreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterCelerSubspAstrifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter celer subsp. astrifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeucobacterCelerSubspAstrifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24063Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24063Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrochothrixCampestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix campestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrochothrixCampestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe3004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiae2603vR(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae 2603V/R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiae2603vR", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpMaddingley(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. Maddingley graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMaddingley", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSiamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus siamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSiamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg13389(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_38_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg13389", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenolepisDiminutaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenolepis diminuta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenolepisDiminutaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusPiezophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus piezophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusPiezophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaDisparCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaDisparCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermofilumAdornatus1505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermofilum adornatus 1505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermofilumAdornatus1505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpG2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. G2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpG2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpK24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. K24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpK24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpApr13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. APR13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpApr13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NumidaMeleagris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Numida meleagris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NumidaMeleagris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasMoolapensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas moolapensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronomonasMoolapensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusRadioduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus radiodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusRadioduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosarchaeumKoreenseMy1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense MY1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreenseMy1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWC2_34_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwc23423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBiflexaSerovarPatocStrainPatoc1Paris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira biflexa serovar Patoc strain Patoc 1 (Paris) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBiflexaSerovarPatocStrainPatoc1Paris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixSpHeli90Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix sp. HelI90 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixSpHeli90Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaXinjiangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora xinjiangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaXinjiangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumCulicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium culicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCulicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumHydrothermaleDsm13146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfacinum hydrothermale DSM 13146 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfacinumHydrothermaleDsm13146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaBryophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bryophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBryophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColumbaLivia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Columba livia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColumbaLivia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD2_FULL_43_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CytophagaceaeBacteriumScn5212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cytophagaceae bacterium SCN 52-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CytophagaceaeBacteriumScn5212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwd24019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWD24019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwd24019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaRectivirgulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora rectivirgula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaRectivirgulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumLubricantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lubricantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLubricantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusRobiginosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus robiginosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusRobiginosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaSpCag471Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:471 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag471Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFOXYC1_FULL_48_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CystobacterFuscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter fuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CystobacterFuscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCitronellolis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas citronellolis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCitronellolis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpDnf00869Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. DNF00869 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpDnf00869Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumCaspalpha6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium caspalpha6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCaspalpha6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OdoribacterSplanchnicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Odoribacter splanchnicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OdoribacterSplanchnicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPolytrichastriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium polytrichastri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPolytrichastriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasaccharibacterApiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parasaccharibacter apium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParasaccharibacterApiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaNodosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia nodosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaNodosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium659Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 65-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium659Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpD14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. D14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpD14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilunaSpUbmaderosw2redCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. UBMaderosW2red Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpUbmaderosw2redCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevundimonasSpRoot1279Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root1279 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot1279Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGhanensisDsm18630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis DSM 18630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGhanensisDsm18630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TilletiopsisWashingtonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tilletiopsis washingtonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TilletiopsisWashingtonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisAlaskensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis alaskensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisAlaskensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAnt303(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ant303 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAnt303", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HarpegnathosSaltator(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Harpegnathos saltator graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HarpegnathosSaltator", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpA12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpA12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaThermotoleransCbs6340(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachancea thermotolerans CBS 6340 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachanceaThermotoleransCbs6340", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprosuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprosuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprosuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrorhabdusArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraNanhaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNiastensisDsm21313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Massilia niastensis DSM 21313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MassiliaNiastensisDsm21313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobiusVermicularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobius vermicularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobiusVermicularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimkaniaNegevensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Simkania negevensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SimkaniaNegevensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPhilomiragia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella philomiragia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPhilomiragia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumRifoxya2full3321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL3321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full3321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLoti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium loti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumLoti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNt26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NT-26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNt26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiansivirgaZeaxanthinifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorallococcusSpCag1435Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corallococcus sp. CAG:1435 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorallococcusSpCag1435Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYB2_FULL_32_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxyb2Full327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhenoliruptrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phenoliruptrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhenoliruptrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusWulumuqiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus wulumuqiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusWulumuqiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpCb0205Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0205Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirestonebacteriaBacteriumRifoxya2full408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYA2FULL408 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxya2full408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SodiomycesAlkalinusF11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sodiomyces alkalinus F11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SodiomycesAlkalinusF11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixBouteilleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolypothrixBouteilleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaChutoStrDubai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Orientia chuto str. Dubai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OrientiaChutoStrDubai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConfluentimicrobiumSpEmb200ns6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Confluentimicrobium sp. EMB200NS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConfluentimicrobiumSpEmb200ns6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusCapsulatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus capsulatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusCapsulatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFryxellicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fryxellicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFryxellicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpLtsp885(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP885 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp885", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptosphaeriaMaculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptosphaeria maculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptosphaeriaMaculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumCg2304320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium CG2_30_43_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumCg2304320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_42_49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4249Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo212full4116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO212FULL4116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo212full4116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSimulansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus simulans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSimulansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaCypripediiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea cypripedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaCypripediiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusAmylolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusAmylolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixAgardhii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktothrix agardhii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktothrixAgardhii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloprevotellaTannerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella tannerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaTannerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaAlgaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa algae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaAlgaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpYt30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. YT30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpYt30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_52b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAviumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus avium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAviumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumLimosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium limosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumLimosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VagococcusLutraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus lutrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VagococcusLutraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollierbacteriaBacteriumRifoxya2full4620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium RIFOXYA2FULL4620 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumRifoxya2full4620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrolunatusPhosphovorusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus phosphovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusPhosphovorusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSaccharolyticusDsm5350(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus DSM 5350 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticusDsm5350", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaBongoriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella bongori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaBongoriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpM26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. M26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpM26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag460Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:460 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag460Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiIai39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli IAI39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiIai39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCyriacigeorgicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia cyriacigeorgica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaCyriacigeorgicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilithrixLuteolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labilithrix luteola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabilithrixLuteolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacterium13120cm3538Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_20CM_3_53_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13120cm3538Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvens6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvens6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumGa0074139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetovibrioBlakemoreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetovibrio blakemorei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetovibrioBlakemoreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumImmobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium immobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumImmobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaIhumiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ihumii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIhumiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaTropica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia tropica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaTropica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnaporthiopsisPoae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnaporthiopsis poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnaporthiopsisPoae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylella taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylellaTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumRenaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium renale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumRenaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPertussis18323Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bordetella pertussis 18323 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BordetellaPertussis18323Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraEvergladensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera evergladensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraEvergladensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaeniglutamicibacterGangotriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter gangotriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterGangotriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusRhinitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus rhinitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusRhinitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterCastelliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter castelli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCastelliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavibacterMichiganensisCapsiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis capsici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisCapsiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsaiaPrunellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asaia prunellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsaiaPrunellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaeruleatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caeruleatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaeruleatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KingellaOralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kingella oralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KingellaOralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_50_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CutibacteriumAcnes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium acnes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAcnes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho201full6320Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL6320 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full6320Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktomarinaTemperata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktomarina temperata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktomarinaTemperata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full3984Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL3984 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full3984Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaSabulilitoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sabulilitoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSabulilitoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFf9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FF9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFf9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsialesBacteriumAc37bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiales bacterium Ac37b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsialesBacteriumAc37bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumGje10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GJE10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGje10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobacterSpDg60Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacter sp. DG_60 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacterSpDg60Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Haemophilus] felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymobacterPalmaeDsm10491(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zymobacter palmae DSM 10491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZymobacterPalmaeDsm10491", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeBacterium4572322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium 4572_32.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacterium4572322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwc23313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWC23313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwc23313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBuccalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella buccalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBuccalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MixiaOsmundaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mixia osmundae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MixiaOsmundaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlatysternonMegacephalumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Platysternon megacephalum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlatysternonMegacephalumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyc2full3825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3825 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaPhiladelphiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila Philadelphia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPhiladelphiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp21mfcrub11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 21MFCrub1.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp21mfcrub11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaTuricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia turicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaTuricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpTb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. TB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpTb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoclostridiumSpYl32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium sp. YL32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumSpYl32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAgarici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas agarici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAgarici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PuniceicoccalesBacteriumVerruco02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBiviaJcvihmp010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia JCVIHMP010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaJcvihmp010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioCuneatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiUmn026Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli UMN026 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiUmn026Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSaliphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHlucco18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumEnshiense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium enshiense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumEnshiense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSynechococcusSpongiarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Synechococcus spongiarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSynechococcusSpongiarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_02_FULL_43_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo202Full4337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumStanieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium stanieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumStanieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13410(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13410 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13410", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr88(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr88", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpSm9913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. SM9913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpSm9913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmataSpIil30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemmata sp. IIL30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemmataSpIil30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilvensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silvensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilvensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasTranslucensPvUndulosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens pv. undulosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasTranslucensPvUndulosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BariatricusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bariatricus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BariatricusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwa23217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_32_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa23217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusB316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus B316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusB316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg2304851Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_48_51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304851Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpTkpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TKP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpTkpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSuwonensisJ42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWadsworthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella wadsworthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaWadsworthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaHalocynthiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria halocynthiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaHalocynthiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOzensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOzensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeophyllumTrabeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeophyllumTrabeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaXylanovoransDsm12503(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans DSM 12503 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovoransDsm12503", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesTogonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides togonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesTogonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AncylostomaCaninumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma caninum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCaninumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacteriumWieringaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacterium wieringae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacteriumWieringaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPlatycodiSf21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi SF21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiSf21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaTritici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zymoseptoria tritici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZymoseptoriaTritici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrovirgaPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochrovirga pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchrovirgaPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WuchereriaBancroftiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wuchereria bancrofti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WuchereriaBancroftiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanoxidansArh2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium RIFCSPLOWO2_02_FULL_73_56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumRifcsplowo202Full7356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumTepidiprofundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNodensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nodensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNodensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterAcetatoxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter acetatoxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterAcetatoxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpSoil538Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Soil538 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpSoil538Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifcsplowo201full4811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPLOWO201FULL4811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsplowo201full4811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MannheimiaSucciniciproducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia succiniciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSucciniciproducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodiscusSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelodiscus sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelodiscusSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusClausiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus clausii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusClausiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PogonaVitticeps(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pogona vitticeps graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PogonaVitticeps", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidisNbrc100137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia arthritidis NBRC 100137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaArthritidisNbrc100137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKimbladii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimbladii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimbladii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaCellobiosiphilaDsm17781Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila DSM 17781 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphilaDsm17781Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTeresCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrenophora teres Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrenophoraTeresCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CallorhinchusMiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Callorhinchus milii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CallorhinchusMiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSeleniipraecipitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas seleniipraecipitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSeleniipraecipitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumGenomosp1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaHaliotis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShewanellaHaliotis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaMayonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia mayonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaMayonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpJdm601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium sp. JDM601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSpJdm601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUvarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUvarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaAnnulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theileria annulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheileriaAnnulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Loktanella hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LoktanellaHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusTengchongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusTengchongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterKorlensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter korlensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacterKorlensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumCellulolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hungateiclostridium cellulolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HungateiclostridiumCellulolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronohydrobacterThiooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronohydrobacter thiooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronohydrobacterThiooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaBuccaeAtcc33574Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella buccae ATCC33574 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBuccaeAtcc33574Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedSup05ClusterBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return uncultured SUP05 cluster bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UnculturedSup05ClusterBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasPhycophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas phycophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasPhycophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSaccharophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSaccharophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesAtroparvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles atroparvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesAtroparvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumObuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium obuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumObuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceispirillumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puniceispirillum marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PuniceispirillumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_37_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusElongatusDsm2908Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus elongatus DSM 2908 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusElongatusDsm2908Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMarshii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella marshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMarshii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpYr266Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR266 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr266Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSenioris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus senioris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSenioris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo212full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO212FULL4614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo212full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterPseudethanolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacter pseudethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacterPseudethanolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiensJcm6334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella disiens JCM6334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaDisiensJcm6334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrioBacteriovorusW(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus W graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusW", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenoxybacterAcetivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenoxybacter acetivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenoxybacterAcetivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithrixFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidithrix ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidithrixFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaOnionYellows(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma onion yellows graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaOnionYellows", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaParvumStrIndiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma parvum str. Indiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaParvumStrIndiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NumidaMeleagrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Numida meleagris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NumidaMeleagrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSyrphidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma syrphidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSyrphidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharobutylicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharobutylicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharobutylicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusHd100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus HD100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusHd100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterThiooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter thiooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterThiooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpRc586Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. RC586 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioSpRc586Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwa2447Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA2447 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa2447Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FinegoldiaMagnaAtcc53516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Finegoldia magna ATCC53516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FinegoldiaMagnaAtcc53516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpMwhadlerw8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. MWHAdlerW8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpMwhadlerw8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BisonBisonBisonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bison bison bison Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BisonBisonBisonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasCryotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas cryotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasCryotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumUj101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium UJ101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumUj101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumBc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum BC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumBc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OtolemurGarnettii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Otolemur garnettii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OtolemurGarnettii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_43_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatoriaSpPcc10802(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria sp. PCC10802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaSpPcc10802", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyosteliumDiscoideum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dictyostelium discoideum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DictyosteliumDiscoideum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuritaleaHydrogenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZobelliaGalactanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zobellia galactanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZobelliaGalactanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanicumHalliiVarHalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Panicum hallii var. hallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PanicumHalliiVarHalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterUpsaliensisJv21(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis JV21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensisJv21", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraGargensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera gargensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraGargensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobiumLuteolumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium luteolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumLuteolumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterEthanolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter ethanolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterEthanolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGilvigriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvigriseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvigriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria fleischmannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaFleischmanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXbd2001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBD2001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbd2001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensisHga0223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis HGA0223 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensisHga0223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpMwb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MWB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpMwb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Facklamia hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FacklamiaHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbsidiaGlauca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Absidia glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbsidiaGlauca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat29814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-29814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat29814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwf23876(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWF23876 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwf23876", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpAnt303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Ant303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpAnt303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaZobellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina zobellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaZobellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMethanolicusPb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus PB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusPb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmaragdicoccusNiigatensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Smaragdicoccus niigatensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SmaragdicoccusNiigatensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaTrevisaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia trevisanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaTrevisaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GambusiaAffinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gambusia affinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GambusiaAffinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospiraOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospira oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospiraOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAnthracisSterneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Sterne Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisSterneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LindowbacteriaBacteriumRifcsplowo212full6227(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lindowbacteria bacterium RIFCSPLOWO212FULL6227 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LindowbacteriaBacteriumRifcsplowo212full6227", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterobasidionIrregulareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeterobasidionIrregulareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolfebacteriaBacteriumRifoxyb1full5412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYB1FULL5412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyb1full5412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumTibeticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tibeticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTibeticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumStanieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumStanieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesCellulosilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides cellulosilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCellulosilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovoraxOdorimutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerovorax odorimutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerovoraxOdorimutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_43_32b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParacaseiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paracasei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParacaseiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusHippeiDsm8344Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei DSM 8344 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusHippeiDsm8344Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAlginolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alginolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlginolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRbg19ftcombo5311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RBG19FTCOMBO5311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRbg19ftcombo5311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusaAcuminataSubspMalaccensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Musa acuminata subsp. malaccensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MusaAcuminataSubspMalaccensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpOv279Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. OV279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpOv279Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpHl48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSpNml063099Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella sp. NML063099 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TatumellaSpNml063099Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferGlycinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer glycinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferGlycinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpHel13355(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. Hel1_33_55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpHel13355", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlemurSimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prolemur simus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProlemurSimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPseudopneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pseudopneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPseudopneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalibacillusSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibacillus soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacillusSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfHeteropsyllaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsyllaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasKoyamaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas koyamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasKoyamaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinimonasKoreensisDsm17726Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis DSM 17726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasKoreensisDsm17726Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliothisVirescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Heliothis virescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HeliothisVirescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumGwe25113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium GWE2_51_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumGwe25113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusIbericus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ibericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusIbericus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusKekensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus kekensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusKekensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpHgb5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. HGB5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlistipesSpHgb5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaSp179522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia sp. 179522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaSp179522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoHordeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ustilago hordei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UstilagoHordeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusObesiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusObesiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSpWkb8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpWkb8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurivibrioAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurivibrio alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurivibrioAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOrisC735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oris C735 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOrisC735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPluranimalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella pluranimalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPluranimalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidaceaeBacteriumMs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidaceae bacterium MS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidaceaeBacteriumMs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumAqs3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium AqS3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumAqs3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAlgidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus algidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlgidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSclerotialus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sclerotialus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSclerotialus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium2w06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 2W06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium2w06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinosynnemaSpAli144Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema sp. ALI-1.44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaSpAli144Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsSpCamponotisaundersi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps sp. camponotisaundersi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsSpCamponotisaundersi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OenococcusKitaharae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus kitaharae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OenococcusKitaharae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPinnipediorumSubspPinnipediorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum subsp. pinnipediorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorumSubspPinnipediorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumI46Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium I46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumI46Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasEndodontalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas endodontalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasEndodontalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SimkaniaNegevensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Simkania negevensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SimkaniaNegevensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_02_FULL_42_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho202Full4215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumC7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonauticusSp384375Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. 38_4375 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSp384375Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpK90mix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. K90mix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpK90mix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterPhosphatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter phosphatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterPhosphatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonadaceaeBacteriumT822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonadaceae bacterium T82-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonadaceaeBacteriumT822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSelangorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus selangorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSelangorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumGlucuronolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glucuronolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlucuronolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumScgcAaa168p09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA168P09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa168p09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpNfr16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NFR16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNfr16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelianthusAnnuusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helianthus annuus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelianthusAnnuusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf2580Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2580 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2580Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot685Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root685 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot685Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesMisionensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces misionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMisionensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusHaemolyticusM21621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho212full6025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO212FULL6025 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho212full6025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaTropicalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida tropicalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaTropicalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GulosibacterMolinativorax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gulosibacter molinativorax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GulosibacterMolinativorax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhlebiopsisGiganteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhlebiopsisGiganteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisParvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis parvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocystisParvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSchinkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia schinkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaSchinkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLipolyticusBf04cf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus BF04CF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusBf04cf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TropherymaWhippleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tropheryma whipplei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TropherymaWhippleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumClostridioforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumClostridioforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNk4a179(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a179", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaUreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina ureae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaUreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusNeutrinimicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus neutrinimicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusNeutrinimicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaTyphiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia typhi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaTyphiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxKonjaciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax konjaci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxKonjaciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisericumExileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum exile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldisericumExileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumGrantiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium grantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGrantiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BalaenopteraAcutorostrataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Balaenoptera acutorostrata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BalaenopteraAcutorostrataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaKt2440Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida KT2440 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaKt2440Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlutamicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glutamicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlutamicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaAnimalorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria animaloris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaAnimalorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFlevense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium flevense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFlevense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaKt2440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida KT2440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaKt2440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovermiculusHalophilusDsm18834Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus DSM 18834 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilusDsm18834Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaKroppenstedtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia kroppenstedtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaKroppenstedtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSp329mfshaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 329MFSha Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp329mfshaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialosimplexSpHf37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialosimplex sp. HF37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialosimplexSpHf37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJaponicaNbrc103040Dsm22348Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas japonica NBRC 103040 DSM 22348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasJaponicaNbrc103040Dsm22348Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaTeleogrylliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Erwinia] teleogrylli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTeleogrylliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa2499(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA2499 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa2499", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosimplexCarlsbadense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halosimplex carlsbadense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalosimplexCarlsbadense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe13724Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE13724 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe13724Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraAerophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira aerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraAerophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusFaeciumNrrlb2354(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium NRRLB2354 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumNrrlb2354", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_01_FULL_39_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho201Full3925", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWallbacteriaBacteriumGwc24935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wallbacteria bacterium GWC2_49_35 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWallbacteriaBacteriumGwc24935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumCch3a5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH3A5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch3a5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpS9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. S9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpS9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusSpCag390Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. CAG:390 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpCag390Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg136414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_13_64_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg136414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpYt30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. YT30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpYt30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpTksCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TKS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTksCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe13724(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_37_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe13724", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillalesBacteriumScgcAaa298n10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillales bacterium SCGC AAA298N10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillalesBacteriumScgcAaa298n10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSpPcc7507Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7507 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7507Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaHominisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia hominis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaHominisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpSoil772Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Soil772 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpSoil772Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasXianhensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xianhensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasXianhensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusSk52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus SK52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusSk52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDextrinicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus dextrinicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDextrinicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharimonasAalborgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharimonas aalborgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharimonasAalborgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSpPro95Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. PRO95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpPro95Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSihwensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sihwensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GordoniaSihwensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumScn6820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium SCN 68-20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumScn6820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaLupiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora lupini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaLupiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelodictyonLuteolumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon luteolum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelodictyonLuteolumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterSpHimb1321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HIMB1321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHimb1321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_39_39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full3939Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasArenaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas arenae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasArenaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuraticoccusMonumentiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Auraticoccus monumenti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AuraticoccusMonumentiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumImcc14465Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium IMCC14465 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumImcc14465Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidilobusSaccharovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidilobus saccharovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidilobusSaccharovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalimicrobiumAerophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalimicrobium aerophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalimicrobiumAerophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrybacteriaBacteriumRifcsphigho201full4817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrybacteria bacterium RIFCSPHIGHO201FULL4817 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrybacteriaBacteriumRifcsphigho201full4817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot604Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root604 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot604Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrotetrasporaNiveoalbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora niveoalba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaNiveoalbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumNoviomagenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium noviomagense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNoviomagenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothermothrixOreniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix orenii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixOreniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterBilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNatriegensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio natriegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioNatriegensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrospiraSpKp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. Kp2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraSpKp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusVulcanalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus vulcanalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusVulcanalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeromassilibacillusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumPolytrichastriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium polytrichastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPolytrichastriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumT5br10b2g0Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium T5Br10B2g0 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumT5br10b2g0Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpZ31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. Z-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpZ31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPaucisporeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces paucisporeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPaucisporeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriticumUrartuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Triticum urartu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TriticumUrartuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfHeteropsylla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Heteropsylla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfHeteropsylla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpEnrichmentEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichmentEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdeonellaSakaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ideonella sakaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdeonellaSakaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobalesArchaeonAcd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Acd1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfolobalesArchaeonAcd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAkl19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. AKL19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAkl19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSimilisDsm23365Jcm2765Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus similis DSM 23365 JCM 2765 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSimilisDsm23365Jcm2765Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu069Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU069 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu069Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleomorphomonasOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pleomorphomonas oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PleomorphomonasOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniborusEthanoligenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus ethanoligenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusEthanoligenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusTundrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus tundrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusTundrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeadbetterellaByssophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leadbetterella byssophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeadbetterellaByssophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratiruptorSpSb1552Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitratiruptor sp. SB1552 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitratiruptorSpSb1552Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetakosakoniaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTa06BacteriumDg24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TA06 bacterium DG_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTa06BacteriumDg24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladusLaminosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladus laminosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MastigocladusLaminosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasSpMex14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. Mex14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpMex14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaOrthopsilosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida orthopsilosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaOrthopsilosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobacteralesBacteriumDelta02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobacterales bacterium Delta_02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophobacteralesBacteriumDelta02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloterrigenaHispanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena hispanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaHispanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUrhd0025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHD0025 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhd0025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaHispanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hispanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaHispanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZootermopsisNevadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zootermopsis nevadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZootermopsisNevadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaemateliaEncephala(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Naematelia encephala graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NaemateliaEncephala", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TigriopusCalifornicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tigriopus californicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TigriopusCalifornicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrocarboniphagaEffusaAp103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrocarboniphaga effusa AP103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrocarboniphagaEffusaAp103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRifoxyb1full4015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFOXYB1FULL4015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifoxyb1full4015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCiat894Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CIAT894 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCiat894Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesIncarnatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces incarnatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesIncarnatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesEggerthiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides eggerthii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesEggerthiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpBrhc9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BRHc9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBrhc9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilegiaCoeruleaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquilegia coerulea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquilegiaCoeruleaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulforhabdusNorvegicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulforhabdus norvegica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulforhabdusNorvegicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiWsm1741Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii WSM1741 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiWsm1741Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPantherisDsm15945Jcm12539Nbrc106106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris DSM 15945 JCM 12539 NBRC 106106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPantherisDsm15945Jcm12539Nbrc106106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumVacuolatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumGuttoideumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum guttoideum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumGuttoideumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesGerencseriaeDsm6844(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces gerencseriae DSM 6844 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGerencseriaeDsm6844", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaOvipneumoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma ovipneumoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaOvipneumoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24711bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_47_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24711bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag43(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:43 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag43", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSp291Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 291 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoprobacillusSp291Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHodgkiniaCicadicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hodgkinia cicadicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHodgkiniaCicadicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumYsd2013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSD2013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsd2013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae MGH 78578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeMgh78578Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumGwf25820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium GWF2_58_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGwf25820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwf23885(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWF2_38_85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwf23885", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHarbinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus harbinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHarbinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimonasChungwhensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinimonas chungwhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinimonasChungwhensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesNoursei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces noursei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesNoursei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PetromyzonMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Petromyzon marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PetromyzonMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomycesKudriavzeviiIfo1802Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccharomyces kudriavzevii IFO 1802 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccharomycesKudriavzeviiIfo1802Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOrs278Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ORS278 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOrs278Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYC2_FULL_43_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyc2Full4316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaBannensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia bannensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaBannensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCg2303430Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_34_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303430Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1025541(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1025541 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1025541", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGelatini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gelatini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusGelatini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensFgi94(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens FGI94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensFgi94", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucinivoransHirudinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucinivorans hirudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucinivoransHirudinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterOxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconobacterOxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrunusPersica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prunus persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrunusPersica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioHalophilusDsm15072Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenovibrio halophilus DSM 15072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrogenovibrioHalophilusDsm15072Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaJamestowniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella jamestowniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaJamestowniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumTsurumienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium tsurumiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumTsurumienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAurantiacusDsm18675Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus DSM 18675 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusAurantiacusDsm18675Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumItalicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium italicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumItalicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRbg134510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG134510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg134510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucco18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCO18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucco18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho202full4212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumGrahamii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium grahamii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGrahamii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaHulunbeirensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba hulunbeirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaHulunbeirensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpJs211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. JS21-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpJs211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot240Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root240 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot240Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwd23259(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_59 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23259", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacillusLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceibacteriumMercurialeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceibacterium mercuriale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceibacteriumMercurialeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPseudotuberculosisC231(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis C231 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosisC231", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAnaemiaeNbrc100462(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia anaemiae NBRC 100462 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAnaemiaeNbrc100462", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterThiogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geobacter thiogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeobacterThiogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCibi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cibi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusCibi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovirgulaThermocuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovirgula thermocuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovirgulaThermocuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPurisNbrc108233(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia puris NBRC 108233 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaPurisNbrc108233", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyroidesPhaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myroides phaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyroidesPhaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHiranonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hiranonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHiranonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusAneurinilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus aneurinilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusAneurinilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDentasiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentasini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentasiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermaceaeBacteriumTcbr11b2g67Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium TcBr11B2g67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumTcbr11b2g67Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinophytocolaXanthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xanthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXanthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterColi76339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter coli 76339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterColi76339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcaligenaceaeBacteriumDtu041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcaligenaceae bacterium DTU041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcaligenaceaeBacteriumDtu041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CronobacterDublinensisSubspDublinensisLmg23823(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. dublinensis LMG 23823 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspDublinensisLmg23823", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_48_13b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full4813bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlyciniphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium glyciniphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumGlyciniphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterPseudonitzschiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter pseudonitzschiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterPseudonitzschiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumSpHmsc063g07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium sp. HMSC063G07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSpHmsc063g07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsdaarsusmarc1261Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1261 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1261Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumIslandicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum islandicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumIslandicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaLoescheiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella loescheii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaLoescheiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaCapsosiphonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita capsosiphonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AequorivitaCapsosiphonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpOrs3324(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3324 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3324", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsplowo202full4019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPLOWO202FULL4019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsplowo202full4019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSp73145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. 73-145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSp73145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidocaldariusLaa1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidocaldarius LAA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidocaldariusLaa1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPametensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pametensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPametensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumMarinumDsm44953(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium marinum DSM 44953 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumMarinumDsm44953", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiRu7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii RU7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiRu7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCapillatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCapillatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaFlocculosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma flocculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudozymaFlocculosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusWentiiDto134e9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus wentii DTO 134E9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusWentiiDto134e9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPohangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pohangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPohangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpA39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. A39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpA39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpKimCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. KIM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpKimCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChroogloeocystisSiderophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomicronemaHongdechlorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomicronema hongdechloris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomicronemaHongdechlorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpGws1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. GWS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpGws1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavihumibacterSolisilvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter solisilvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSolisilvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaCenocepacia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cenocepacia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCenocepacia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHoaglandellaEndobia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hoaglandella endobia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHoaglandellaEndobia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaF1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida F1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaF1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VittaformaCorneaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vittaforma corneae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VittaformaCorneaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumSm2339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium SM23_39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumSm2339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremblayaPrincepsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya princeps Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TremblayaPrincepsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyriculariaOryzae7015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyricularia oryzae 70-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyriculariaOryzae7015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusJostiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus jostii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusJostiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BabelaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Babela massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BabelaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYC2_FULL_39_67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxyc2Full3967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumAngstadtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium angstadtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAngstadtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisStrAmesAncestor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis str. Ames Ancestor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisStrAmesAncestor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumMesophilicumSr166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum SR1.6/6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicumSr166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9211 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomethylophilusAlvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylophilus alvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomethylophilusAlvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumOlb8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusLacrimalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaLanguidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Facklamia languida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FacklamiaLanguidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpNfr04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasSpMarseillep2440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyricimonas sp. MarseilleP2440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyricimonasSpMarseillep2440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumDaeguense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium daeguense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumDaeguense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BremiaLactucaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bremia lactucae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BremiaLactucaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1237 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusAbyssiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus abyssi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusAbyssiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumJannaschiiDsm6295Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii DSM 6295 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschiiDsm6295Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg135518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_13_55_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg135518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EudoraeaAdriaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eudoraea adriatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EudoraeaAdriaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerotiniaSclerotiorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusSendaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus sendaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusSendaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedBacteroidesSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Bacteroides sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedBacteroidesSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesGriseorubensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseorubensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNavarrensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio navarrensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioNavarrensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusAquimarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus aquimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAquimarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPuniceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus puniceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPuniceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70737Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70737 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70737Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpX12014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. X1(2014) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpX12014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaMiyamotoi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia miyamotoi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaMiyamotoi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5411b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5411b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5411b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SymbiobacterMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Symbiobacter mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SymbiobacterMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsplowo201full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCaseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus casei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCaseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpPhil15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. Phil15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpPhil15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusHomiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus homiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHomiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumAo1bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium AO1B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumAo1bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratireductorIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumLacustreDsm10312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre DSM 10312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronumLacustreDsm10312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylopumilusPlanktonicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus planktonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusPlanktonicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldimonasManganoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas manganoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldimonasManganoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Schekmanbacteria bacterium RIFCSPLOWO2_12_FULL_38_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSchekmanbacteriaBacteriumRifcsplowo212Full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg165624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_56_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMb2021(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MB2021 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMb2021", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp162mfsha11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 162MFSha11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp162mfsha11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWalczuchellaMonophlebidarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Walczuchella monophlebidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWalczuchellaMonophlebidarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumBavaricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasAscidiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas ascidiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasAscidiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterSp6612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. 66-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSp6612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumMedpeswsndg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium MedPESWsndG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumMedpeswsndg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleiagrimonasSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oleiagrimonas soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OleiagrimonasSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp11649663(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1164966.3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp11649663", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfCamponotusColobopsisObliquusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLydicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lydicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLydicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpSat1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SAT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSat1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSp2mfcol31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium sp. 2MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumSp2mfcol31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypocladiumOphioglossoidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenarthrobacterAurescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter aurescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterAurescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusFerrooxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus ferrooxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusFerrooxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BatrachochytriumDendrobatidisJam81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JAM81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJam81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FomitopsisPinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fomitopsis pinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FomitopsisPinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucosisporaMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucosispora maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucosisporaMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4315b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4315b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4315b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpBrhc22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BRHc22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpBrhc22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpArEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurovum sp. AR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurovumSpArEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_49_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full4934Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioVulgarisMiyazakiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio vulgaris Miyazaki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioVulgarisMiyazakiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaWadeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia wadei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaWadeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusCerbereus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus cerbereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusCerbereus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumYuanmingenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium yuanmingense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumYuanmingenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaNovaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia nova Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaNovaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumMunicipaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum municipale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumMunicipaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasJeddahensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jeddahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJeddahensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalimonasAmylolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalimonas amylolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalimonasAmylolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistosomaBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolamprologusBrichardi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neolamprologus brichardi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeolamprologusBrichardi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasHortorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas hortorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasHortorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllosalinactinosporaLopnorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allosalinactinospora lopnorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllosalinactinosporaLopnorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumGwa15412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GWA15412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGwa15412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiHtIsolateThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HT isolate Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHtIsolateThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaErythraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella erythra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaErythraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EffusibacillusPohliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Effusibacillus pohliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EffusibacillusPohliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumOgunienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum oguniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumOgunienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumMalaysienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium malaysiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumMalaysienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaHaemulonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Candida] haemulonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaHaemulonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusStearothermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus stearothermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusStearothermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorSaccharolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor saccharolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorSaccharolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MixiaOsmundaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mixia osmundae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MixiaOsmundaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf23338(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23338", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobacillusCompostiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobacillus composti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobacillusCompostiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusYunnanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus yunnanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusYunnanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DasypusNovemcinctus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dasypus novemcinctus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DasypusNovemcinctus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasEuvesicatoriaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas euvesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasEuvesicatoriaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaSativaJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusCaldoxylosilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus caldoxylosilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusCaldoxylosilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_02_FULL_37_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo202Full3719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechlorosomaSuillumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dechlorosoma suillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DechlorosomaSuillumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumLitoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium litorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLitoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUlceribovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ulceribovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUlceribovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_40_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaSpDd3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. DD3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpDd3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpRoot135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMageritense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium mageritense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumMageritense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelampsoraLariciPopulina98ag31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Melampsora larici-populina 98AG31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MelampsoraLariciPopulina98ag31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBornimense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium bornimense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBornimense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterOrnithocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ornithocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterOrnithocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraHibisca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura hibisca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraHibisca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeRhinoscleromatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae rhinoscleromatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeRhinoscleromatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferribacterDesulfuricansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deferribacter desulfuricans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeferribacterDesulfuricansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpongiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter spongiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpongiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusNishinomiyaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus nishinomiyaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DermacoccusNishinomiyaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelleaBalneolensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hellea balneolensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelleaBalneolensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaTerraeKimAndJung2007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Kim and Jung 2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitinophagaTerraeKimAndJung2007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumLentumNbrc107847(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lentum NBRC 107847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLentumNbrc107847", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolineaTardaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolinea tarda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolineaTardaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpRoot335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosakoniaRadicincitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia radicincitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KosakoniaRadicincitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanibacillusModesticaldus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulcanibacillus modesticaldus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulcanibacillusModesticaldus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicycliphilusDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalophilicArchaeonJ07hx64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HX64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hx64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumScn6937(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium SCN 69-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumScn6937", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusLactisCremoris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis cremoris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisCremoris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraTerpstraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira terpstrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraTerpstraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumGw2011gwf23915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium GW2011GWF23915 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumGw2011gwf23915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaGlycaniphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia glycaniphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaGlycaniphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusNubinhibensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius nubinhibens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusNubinhibensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSp302(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. 302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSp302", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaMaritimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hippea maritima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HippeaMaritimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpDd3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. DD3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpDd3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumNctc2916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum NCTC2916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumNctc2916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaSpTu14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma sp. TU-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSpTu14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasOryzaePvOryzaeKacc10331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas oryzae pv. oryzae KACC 10331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasOryzaePvOryzaeKacc10331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumTrifoliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum trifolii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTrifoliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSchleiferi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus schleiferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSchleiferi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MargulisbacteriaBacteriumGwd239127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWD239127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwd239127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRoot483d1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root483D1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot483d1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaZoogloeoidesAtcc25935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Duganella zoogloeoides ATCC 25935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DuganellaZoogloeoidesAtcc25935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27225(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27225", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSolventivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus solventivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSolventivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesIakyrusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces iakyrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesIakyrusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNigripulchritudoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio nigripulchritudo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioNigripulchritudoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusOpacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus opacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusOpacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_01_FULL_43_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumAlbertimagniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium albertimagni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumAlbertimagniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho202full3917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL3917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full3917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpKle1280(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. KLE1280 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpKle1280", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPHIGHO2_02_FULL_45_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumUrhe0068(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium URHE0068 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumUrhe0068", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBrassicacearumSubspBrassicacearumNfm421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum subsp. brassicacearum NFM421 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearumSubspBrassicacearumNfm421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcumNcimb8003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum NCIMB 8003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AzotobacterChroococcumNcimb8003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusKawachiiIfo4308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii IFO 4308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusKawachiiIfo4308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriovoraxSpMedpeswdeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. MedPESWde Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpMedpeswdeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisBaekryungensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis baekryungensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisBaekryungensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasGilvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas gilvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasGilvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaCt18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Salmonella enterica CT18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaCt18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IgnisphaeraAggregansDsm17230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans DSM 17230 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "IgnisphaeraAggregansDsm17230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 40-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumXinjiangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMcba15012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MCBA15_012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMcba15012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiAtcc8739(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli ATCC8739 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiAtcc8739", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp166amftsu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 166amftsu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSp166amftsu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumDg23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium DG_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumDg23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyb1full3916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYB1FULL3916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyb1full3916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumTwa4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TWA4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTwa4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusPertinaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus pertinax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusPertinaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpFw1012bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. FW1012B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSpFw1012bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa24416Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA24416 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa24416Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxIsoporae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax isoporae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxIsoporae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpTfc3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. TFC3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpTfc3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFOXYC1_FULL_48_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifoxyc1Full4826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerpentinomonasMccroryi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serpentinomonas mccroryi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerpentinomonasMccroryi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterosteliumAlbumPn500Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Heterostelium album PN500 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HeterosteliumAlbumPn500Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitaleaMyxolifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Robiginitalea myxolifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RobiginitaleaMyxolifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcusAnaerobiusVpi4330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius VPI4330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobiusVpi4330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc04h06Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC04H06 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc04h06Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasProfundimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas profundimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasProfundimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaUa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaUa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasidiobolusMeristosporusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaViridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora viridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaViridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExidiaGlandulosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exidia glandulosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExidiaGlandulosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaPetrophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga petrophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaPetrophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterSpHimb1321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HIMB1321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHimb1321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusGlycinifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus glycinifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusGlycinifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpExBiomphalariaGlabrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. (ex Biomphalaria glabrata) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpExBiomphalariaGlabrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfamplusMagnetovallimortis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfamplus magnetovallimortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfamplusMagnetovallimortis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot274Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root274 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot274Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesJohnsoniiDsm18315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii DSM 18315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsoniiDsm18315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpF0131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeophyllumTrabeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeophyllum trabeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeophyllumTrabeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaOxidasicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina oxidasica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaOxidasicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MadurellaMycetomatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Madurella mycetomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MadurellaMycetomatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithobacteriumRhinotracheale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithobacterium rhinotracheale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithobacteriumRhinotracheale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraSpKl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera sp. KL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraSpKl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterPapayaeJcm25143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter papayae JCM 25143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterPapayaeJcm25143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusAetherivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus aetherivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusAetherivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmazonaAestivaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amazona aestiva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmazonaAestivaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpAr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. AR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitrosopumilusSpAr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplorickettsiaMassiliensis20bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis 20B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensis20bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCns606Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNS606 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCns606Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumAethiopicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aethiopicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAethiopicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium3919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 39-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium3919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumHaoranii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium haoranii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHaoranii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KribbellaCatacumbaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kribbella catacumbae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KribbellaCatacumbaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeliconiusMelpomeneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Heliconius melpomene Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HeliconiusMelpomeneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureobasidiumSubglaciale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureobasidium subglaciale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureobasidiumSubglaciale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DasaniaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dasania marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DasaniaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot274Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot274Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAmicalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia amicalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaAmicalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastellaniellaCaeniNbrc101664(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Castellaniella caeni NBRC 101664 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CastellaniellaCaeniNbrc101664", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraSojaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora sojae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraSojaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasAxonopodisCitriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis citri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasAxonopodisCitriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterGlobiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter globiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterGlobiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumBal38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BAL38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBal38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpTolmEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. TolM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpTolmEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb1446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB1_44_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb1446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomonachusSchauinslandiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neomonachus schauinslandi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeomonachusSchauinslandiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatenaAgr2136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dorea longicatena AGR2136 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DoreaLongicatenaAgr2136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaAntimicrobicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora antimicrobica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaAntimicrobicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TropicimonasIsoalkanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tropicimonas isoalkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TropicimonasIsoalkanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg19ftcombo6917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO6917 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo6917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeitlerinemaSpPcc7407(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. PCC7407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpPcc7407", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaHaliotisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimia haliotis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimiaHaliotisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaCaviae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila caviae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaCaviae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusWatsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus watsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusWatsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabilibacterAurantiacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labilibacter aurantiacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabilibacterAurantiacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasAutotrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas autotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasAutotrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro09(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_09 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro09", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidimonasFonticaldi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas fonticaldi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidimonasFonticaldi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaMembranifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pichia membranifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PichiaMembranifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRubensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium rubens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRubensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYC1_FULL_38_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusAntranikianiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus antranikianii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusAntranikianiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaHypogeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga hypogea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermotogaHypogeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolophagaFoetidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holophaga foetida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HolophagaFoetidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaxillusRubicundulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaxillusRubicundulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeochlamydiaSpEps4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neochlamydia sp. EPS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeochlamydiaSpEps4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSpAe122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas sp. AE122 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasSpAe122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobiumNarugense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobium narugense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobiumNarugense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinopithecusRoxellana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus roxellana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusRoxellana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisVariantCaprae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis variant caprae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisVariantCaprae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasSpKa00067(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas sp. KA00067 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParvimonasSpKa00067", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBrassicacearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas brassicacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBrassicacearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 29_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxSaidenbachensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax saidenbachensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxSaidenbachensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXpb1003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XPB1003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXpb1003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterDonghicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter donghicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDonghicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpImhEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. IMH Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpImhEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloactinosynnemaIranicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema iranicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaIranicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyd1full5118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYD1FULL5118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyd1full5118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOligofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oligofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOligofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTerrigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerrigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhodospiraHalochlorisStrA(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halorhodospira halochloris str. A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalorhodospiraHalochlorisStrA", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicoccusSagamiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicoccus sagamiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicoccusSagamiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSalegensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas salegens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSalegensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4204(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4204", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPurpeofuscusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpeofuscus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesPurpeofuscusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUpsaliensisJv21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis JV21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensisJv21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CytophagaceaeBacteriumScn5212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cytophagaceae bacterium SCN 52-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CytophagaceaeBacteriumScn5212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumHumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium humi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusJohnsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus johnsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusJohnsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimonasVoraii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimonas voraii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimonasVoraii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpCag409(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. CAG:409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpCag409", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMalmoenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium malmoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMalmoenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxHongdengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax hongdengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxHongdengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatitaleaTepidiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea tepidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaTepidiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumChlorophenolicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum chlorophenolicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumChlorophenolicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParachlamydiaSpC2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia sp. C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaSpC2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaPortivictoriaeDsm23547Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gramella portivictoriae DSM 23547 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GramellaPortivictoriaeDsm23547Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VittaformaCorneaeAtcc50505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vittaforma corneae ATCC 50505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VittaformaCorneaeAtcc50505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumBaculatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium baculatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumBaculatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinospirillumCelereEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum celere Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumCelereEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLeaf58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFischeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio fischeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioFischeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusDictyosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus dictyosporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusDictyosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MortierellaVerticillataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mortierella verticillata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MortierellaVerticillataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GopherusAgassiziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gopherus agassizii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GopherusAgassiziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidocellaSpMxaz02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidocella sp. MXAZ02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidocellaSpMxaz02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterXylinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalidrisPygmaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calidris pygmaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalidrisPygmaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFOXYD2_FULL_36_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYA2_FULL_47_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxya2Full4719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpMs1601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. MS1601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpMs1601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerovibrioSpJc8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. JC8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpJc8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhyllobacteriumSpYr531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phyllobacterium sp. YR531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhyllobacteriumSpYr531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo212full4028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO212FULL4028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo212full4028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasJohnsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJohnsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusSojaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sojae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSojaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMjm8645Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MJM8645 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMjm8645Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MangrovimonasYunxiaonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas yunxiaonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasYunxiaonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilicibacterSpTrichch4bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter sp. TrichCH4B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SilicibacterSpTrichch4bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_01_FULL_45_34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4016b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4016b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4016b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaSpNg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella sp. NG2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilliamellaSpNg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterCryoconitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter cryoconitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterCryoconitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinimonasTaiwanensisDsm18899(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinimonas taiwanensis DSM 18899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinimonasTaiwanensisDsm18899", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_49_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterAcanthamoebae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caedibacter acanthamoebae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaedibacterAcanthamoebae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_42_41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4241Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomassiliicoccus intestinalis Issoire-Mx1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomassiliicoccusIntestinalisIssoireMx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AromatoleumAromaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum aromaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AromatoleumAromaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExiguobacteriumSpZwu0009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. ZWU0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpZwu0009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanisaetaSpJchs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta sp. JCHS_4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaSpJchs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpLeaf139(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Leaf139 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpLeaf139", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobiospirillumSucciniciproducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerobiospirillum succiniciproducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerobiospirillumSucciniciproducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlstoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alstonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlstoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaPortivictoriaeDsm23547(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gramella portivictoriae DSM 23547 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GramellaPortivictoriaeDsm23547", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumPhaseoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium phaseoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumPhaseoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpP1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. P1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpP1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeBvOfficinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. officinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOfficinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaceaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineaceae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaceaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeblenbacteriaBacteriumRifoxyc2full4211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veblenbacteria bacterium RIFOXYC2FULL4211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeblenbacteriaBacteriumRifoxyc2full4211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBiavatiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium biavatii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBiavatiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBrennaborenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema brennaborense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaBrennaborenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg16378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16378 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterCrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter crescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiberibacterCrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaLongicatenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea longicatena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaLongicatenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusZopfiiNbrc100606Jcm9919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii NBRC 100606 JCM 9919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusZopfiiNbrc100606Jcm9919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpPpcgb2223(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PPCGB 2223 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPpcgb2223", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5719 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusMulundensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus mulundensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusMulundensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoperedensNitroreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoperedens nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoperedensNitroreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaSpSsl1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba sp. SSL1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaSpSsl1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalsirhodobacterSpAlg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falsirhodobacter sp. alg1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalsirhodobacterSpAlg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpTb64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. TB64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpTb64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaPecorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia pecorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPecorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSaccharovorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum saccharovorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSaccharovorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpEs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpEs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumCg1023572(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG1_02_35_72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg1023572", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifcsplowo201full4519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFCSPLOWO201FULL4519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifcsplowo201full4519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraAlvinipulliAtcc51933(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli ATCC 51933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulliAtcc51933", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaNaganishiiCbs8797Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kazachstania naganishii CBS 8797 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KazachstaniaNaganishiiCbs8797Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAlkanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia alkanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaAlkanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaChauliocolaAtcc49578(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola ATCC 49578 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaChauliocolaAtcc49578", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisAnt505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ANT505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAnt505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaLettingaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga lettingae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermotogaLettingaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriaceaeArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnicellularCyanobacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnicellularCyanobacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSpHot286Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. HOT286 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TannerellaSpHot286Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24618Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24618 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24618Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpEui1cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. EuI1c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpEui1cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotusOchrogasterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microtus ochrogaster Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrotusOchrogasterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisTerraeSubspTerraeNbrc15098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis terrae subsp. terrae NBRC 15098 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisTerraeSubspTerraeNbrc15098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaEutrophaH16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia eutropha H16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaEutrophaH16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TolypocladiumOphioglossoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaElaeisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia elaeis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaElaeisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaCanimorsusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canimorsus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanimorsusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraCorneaHhb12733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Calocera cornea HHB12733 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaloceraCorneaHhb12733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurovumSpEnrichmentCultureCloneC5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurovum sp. enrichment culture clone C5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfurovumSpEnrichmentCultureCloneC5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasEnteropelogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas enteropelogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasEnteropelogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprinopsisCinereaOkayama7130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Coprinopsis cinerea okayama7#130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CoprinopsisCinereaOkayama7130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumGw2011gwf23720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWF23720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwf23720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterPneumotropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter pneumotropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterPneumotropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaAtcc43768(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea ATCC 43768 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaAtcc43768", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOceanisediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oceanisediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusOceanisediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYC12_FULL_36_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxyc12Full3613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumAgaricidamnosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium agaricidamnosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumAgaricidamnosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumIntestinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium intestinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIntestinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusLactarisCc59002dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus lactaris CC59_002D Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusLactarisCc59002dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSpPcc7103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurihydrogenibiumSubterraneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium subterraneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSubterraneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasBenzenivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas benzenivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBenzenivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DanioRerioEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Danio rerio Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DanioRerioEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifoxyc2full4512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFOXYC2FULL4512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifoxyc2full4512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumRifoxyb1Full4423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium RIFOXYB1_FULL_44_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumRifoxyb1Full4423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumPiperiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium piperi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumPiperiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterAsburiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter asburiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterAsburiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidisEmoy2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Emoy2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidisEmoy2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPachastrellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pachastrellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPachastrellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaminicellaSporogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caminicella sporogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaminicellaSporogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumNctc2916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum NCTC2916 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumNctc2916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaAlcalifaciensDsm30120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens DSM 30120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensDsm30120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasAbyssalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasAbyssalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumDg72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsellaGrandifloraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capsella grandiflora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CapsellaGrandifloraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlutamicibacterArilaitensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter arilaitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterArilaitensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaDumerili(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Seriola dumerili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SeriolaDumerili", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensisDsm11113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis DSM 11113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensisDsm11113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioCrossotus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio crossotus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioCrossotus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo201full5024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL5024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full5024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp11mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 11MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp11mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptobacillusHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWB1_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4222Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4222 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4222Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumLipoferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumLipoferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MangrovibacterPhragmitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mangrovibacter phragmitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MangrovibacterPhragmitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HabropodaLaboriosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Habropoda laboriosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HabropodaLaboriosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JetteniaCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jettenia caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JetteniaCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesLianchengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides lianchengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLianchengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag343Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:343 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag343Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenedentesBacteriumJgi0000039j10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenedentes bacterium JGI 0000039J10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenedentesBacteriumJgi0000039j10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumVivaxSal1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Sal-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVivaxSal1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterUrsingii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter ursingii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterUrsingii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenolepisDiminutaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenolepis diminuta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenolepisDiminutaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpHmp27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. HMP27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpHmp27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MahellaAustraliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mahella australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MahellaAustraliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaBlattaeCbs6284Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora blattae CBS 6284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaBlattaeCbs6284Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumRm5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium RM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumRm5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpPbn3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. PBN3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpPbn3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TremblayaPrinceps(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tremblaya princeps graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TremblayaPrinceps", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumWwei01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium WWEI_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumWwei01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusGnavusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gnavus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGnavusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpEp60837(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. EP60837 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpEp60837", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFastidiosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFastidiosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg1024015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanidioschyzonMerolaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SedimenticolaThiotaurini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sedimenticola thiotaurini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SedimenticolaThiotaurini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechenseLl01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium czechense LL01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumCzechenseLl01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaCypripediiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea cypripedii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaCypripediiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaFrigiditurris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella frigiditurris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaFrigiditurris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTermitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium termitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumTermitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraMegakaryaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora megakarya Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraMegakaryaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpJs211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. JS21-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpJs211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27445Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27445 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27445Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastochlorisViridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastochloris viridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastochlorisViridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesCerinusSubspCerinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agromyces cerinus subsp. cerinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgromycesCerinusSubspCerinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaViridescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella viridescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaViridescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiHardjoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Hardjo Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiHardjoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaSpF41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Belnapia sp. F-4-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BelnapiaSpF41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDeserti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumDeserti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpMl96(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ML96 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpMl96", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxyc12full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYC12FULL3613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyc12full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbaceaeBacteriumBrhc16aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium BRHc16a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumBrhc16aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentimicrobiumSaccharophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentimicrobium saccharophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentimicrobiumSaccharophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag768Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:768 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag768Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSalmonicidaAchromogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida achromogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaAchromogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusMit9301(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9301 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9301", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSinaloensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sinaloensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSinaloensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSharpeaeJcm1186Dsm20505Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae JCM 1186 DSM 20505 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSharpeaeJcm1186Dsm20505Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSaccharolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSaccharolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesMarimammaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarimammaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls1022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1022 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumNematocida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium nematocida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumNematocida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesViolaceusnigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceusniger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesViolaceusnigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrovumSpPnj185(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrovum sp. PNJ185 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrovumSpPnj185", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosaPls229Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa PLS229 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosaPls229Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpTrp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. TRP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpTrp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraHumireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera humireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraHumireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsplowo212full4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPLOWO212FULL4520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsplowo212full4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterArboriphilusAnor1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus ANOR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilusAnor1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfUnidentifiedCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of unidentified Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfUnidentifiedCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumSquillarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium squillarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSquillarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumZagget2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaOchraceaF0287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea F0287 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaF0287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaLoihicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella loihica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaLoihicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusLactisIl1403Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus lactis Il1403 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusLactisIl1403Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaeBacterium4920Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium 49_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacterium4920Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NasoniaVitripennisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nasonia vitripennis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NasoniaVitripennisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag594(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:594 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag594", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiAbcpw111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei ABCPW111 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiAbcpw111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumAc3007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC3007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc3007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumIranicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium iranicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumIranicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumSpCg232Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG23_2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg232Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusObesiensisPh10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus obesiensis ph10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusObesiensisPh10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJ14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. J14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpJ14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumSpCag1138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:1138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag1138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParastagonosporaNodorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParastagonosporaNodorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterCurvatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCurvatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3812Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3812 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3812Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpOr37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. OR37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpOr37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomonosporaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomonospora alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomonosporaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumActinocoloniiforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium actinocoloniiforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumActinocoloniiforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot112d2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root112D2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot112d2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpMarseillep3519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sp. MarseilleP3519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpMarseillep3519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpMc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisSpMc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentinulaEdodesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentinula edodes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentinulaEdodesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpUrmo17wk12i8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. URMO17WK12I8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpUrmo17wk12i8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolaciniaPetroleariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolacinia petrolearia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolaciniaPetroleariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusParasiticusSu1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus parasiticus SU-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusParasiticusSu1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHokkaidonensisJcm18461Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis JCM 18461 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensisJcm18461Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB262Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB262Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA2_43_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa24314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaBombycisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nosema bombycis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NosemaBombycisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpPh1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. PH1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPh1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LautropiaSpScn6989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lautropia sp. SCN 69-89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LautropiaSpScn6989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VombatusUrsinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vombatus ursinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VombatusUrsinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaDisparCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDisparCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaSpVc33Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma sp. Vc33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSpVc33Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaBettyaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella bettyae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaBettyaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AncylostomaCeylanicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ancylostoma ceylanicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AncylostomaCeylanicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTremblayaPhenacolaPave(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya phenacola PAVE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPhenacolaPave", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BatrachochytriumDendrobatidisJam81Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Batrachochytrium dendrobatidis JAM81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BatrachochytriumDendrobatidisJam81Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeucaenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leucaenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeucaenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaAquimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaAquimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraMobilisJlw8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis JLW8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilisJlw8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesAmestolkiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces amestolkiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAmestolkiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaProductaAtcc27340Dsm2950(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Blautia producta ATCC 27340 DSM 2950 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BlautiaProductaAtcc27340Dsm2950", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SagittulaStellata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sagittula stellata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SagittulaStellata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusTepidamansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus tepidamans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusTepidamansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinilactibacillusPiezotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus piezotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPiezotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb243498i20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB243_498I20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb243498i20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurocapsaSpPcc7327(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7327 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7327", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisFw213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis FW213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisFw213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumCentenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum centenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumCentenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasMacrotermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas macrotermitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMacrotermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDadabacteriaBacteriumRifcsphigho212Full5321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium RIFCSPHIGHO2_12_FULL_53_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumRifcsphigho212Full5321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpGwa26395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. GWA2_63_95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpGwa26395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeefgeaRivuliDsm18356Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Deefgea rivuli DSM 18356 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DeefgeaRivuliDsm18356Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AequorivitaViscosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AequorivitaViscosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpUsba49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. USBA 49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpUsba49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpBa94Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-94 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa94Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisOryzaeAtcc44560Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae ATCC 44560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BipolarisOryzaeAtcc44560Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelobacterSeleniigenesDsm18267Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pelobacter seleniigenes DSM 18267 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PelobacterSeleniigenesDsm18267Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaLambliaAtcc50803Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia ATCC 50803 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaAtcc50803Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpMb263Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. MB263 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpMb263Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpGwc16184Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. GWC1_61_84 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpGwc16184Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosilyticumLentocellumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulosilyticum lentocellum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulosilyticumLentocellumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAzureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio azureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioAzureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusHb8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolysaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polysaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolysaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpAr153Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. AR 15-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpAr153Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RamulariaCollocygniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ramularia collocygni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RamulariaCollocygniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSaguiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSaguiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaDairenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NaumovozymaDairenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumAb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium AB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumAb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinihabitansFlavidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinihabitans flavidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinihabitansFlavidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeggiatoaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beggiatoa alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeggiatoaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMoraviensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas moraviensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMoraviensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumS7086c20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium S7086C20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumS7086c20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TyzzerellaNexilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tyzzerella nexilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TyzzerellaNexilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHaemophilumDsm44634(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum DSM 44634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilumDsm44634", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerovirgaAcetigignens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerovirga acetigignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldanaerovirgaAcetigignens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumCosmeticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium cosmeticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumCosmeticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusPseudoficulneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus pseudoficulneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FructobacillusPseudoficulneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomicrobiaArchaeonJdfr19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon JdFR-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonJdfr19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCoatesbacteriaBacteriumRbg136614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Coatesbacteria bacterium RBG_13_66_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCoatesbacteriaBacteriumRbg136614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium GW2011_GWB1_54_7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TriticumUrartu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Triticum urartu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TriticumUrartu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaHutchinsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga hutchinsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CytophagaHutchinsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk307Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK307 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk307Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumSalsuginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSalsuginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaSpTw09308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia sp. TW09308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaSpTw09308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrolunatusPhosphovorus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus phosphovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusPhosphovorus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPHIGHO2_02_FULL_34_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterAilurogastricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter ailurogastricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAilurogastricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumInfernorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum infernorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumInfernorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumMesophilicumSr166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum SR1.6/6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicumSr166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumLentumNbrc107847Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium lentum NBRC 107847 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumLentumNbrc107847Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaMarinoflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaMorbillorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella morbillorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaMorbillorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSpOh31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylophilus sp. OH31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylophilusSpOh31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiCeThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii CE Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiCeThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlstonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alstonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlstonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalisGambiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Glossina palpalis gambiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GlossinaPalpalisGambiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumCg1023744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023744 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenturiaEffusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Venturia effusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VenturiaEffusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterMalorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter malorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterMalorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospiraSpQh2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospira sp. QH-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospiraSpQh2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfCulex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Culex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCulex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUltunenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ultunense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumUltunenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcidipropionici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acidipropionici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcidipropionici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTucceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusTucceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NevskiaRamosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nevskia ramosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NevskiaRamosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LichtheimiaCorymbiferaJmrcFsu9682Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera JMRC:FSU:9682 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LichtheimiaCorymbiferaJmrcFsu9682Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmpedobacterBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumSp5120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. 51_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSp5120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SubdoligranulumSp4354a2faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Subdoligranulum sp. 4354A2FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SubdoligranulumSp4354a2faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedTermiteGroup1BacteriumPhylotypeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpWsm2230Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WSM2230 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWsm2230Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterTroitsensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter troitsensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenibacterTroitsensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPuniceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium puniceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPuniceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaHaemulonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Candida] haemulonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaHaemulonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeyerozymaGuilliermondiiAtcc6260Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Meyerozyma guilliermondii ATCC 6260 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MeyerozymaGuilliermondiiAtcc6260Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSeminalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella seminalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSeminalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SubdoligranulumVariabile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Subdoligranulum variabile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SubdoligranulumVariabile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasKerstersiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Comamonas kerstersii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ComamonasKerstersiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusPseudoficulneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus pseudoficulneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FructobacillusPseudoficulneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusWarneriL37603Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri L37603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriL37603Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuritaleaHydrogenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusNantensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNantensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerasakiellaPusilla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terasakiella pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerasakiellaPusilla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSpScn65179Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. SCN 65-179 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpScn65179Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThamnocephalisSphaerospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thamnocephalis sphaerospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThamnocephalisSphaerospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeropyrumCamini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeropyrum camini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeropyrumCamini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraLatinaNbrc106108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura latina NBRC 106108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraLatinaNbrc106108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRu33bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. RU33B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu33bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CenarchaeumSymbiosumA(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosumA", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumManausense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium manausense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumManausense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaUsdaarsusmarc1261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia varigena USDAARSUSMARC1261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MannheimiaVarigenaUsdaarsusmarc1261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaSpHk05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Scytonema sp. HK-05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ScytonemaSpHk05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpScgcAg212e16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SCGC AG212E16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpScgcAg212e16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypothrixBouteilleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tolypothrix bouteillei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TolypothrixBouteilleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlb24484Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24484 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24484Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GasterosteusAculeatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gasterosteus aculeatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GasterosteusAculeatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYD2_FULL_35_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyd2Full3512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacebacteriaBacteriumGw2011gwa14610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium GW2011GWA14610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumGw2011gwa14610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu073Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU073 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu073Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsplowo212full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO212FULL4312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo212full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcalesBacterium7313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StomoxysCalcitransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stomoxys calcitrans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StomoxysCalcitransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumAerophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum aerophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumAerophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAtcc27244(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ATCC27244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAtcc27244", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077545(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077545", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumDigitatumPhi26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicillium digitatum PHI26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliumDigitatumPhi26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumResinovorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium resinovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumResinovorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifoxyb2full5012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYB2FULL5012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxyb2full5012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferSpZgt114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. ZGT114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpZgt114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo212full4526Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO212FULL4526 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo212full4526Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpNfr04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCimex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gramella salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GramellaSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusSaudimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusSaudimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusGobiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus gobiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGobiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwb14719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWB1_47_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwb14719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TulasnellaCalosporaMut4182(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tulasnella calospora MUT 4182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TulasnellaCalosporaMut4182", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot682(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root682 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot682", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kangiella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KangiellaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaHydrophobicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaHydrophobicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf262(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf262 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf262", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SegniliparusRugosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Segniliparus rugosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SegniliparusRugosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumParmentieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium parmentieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumParmentieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpSrsw22016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. SRSW22016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpSrsw22016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSp108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. 108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoefleaSp108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3789Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3789 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3789Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesExfoliatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces exfoliatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesExfoliatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusMulierisAtcc35239(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC 35239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35239", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpB72017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7(2017) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpB72017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTpa0874Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0874 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0874Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lindowbacteria bacterium RIFCSPLOWO2_12_FULL_62_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLindowbacteriaBacteriumRifcsplowo212Full6227Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosphaerulaPalustrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaerula palustris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosphaerulaPalustrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaBoydiiCdc308394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shigella boydii CDC 3083-94 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShigellaBoydiiCdc308394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaPoulsoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma poulsonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaPoulsoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubritaleaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNc2004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NC2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNc2004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobaculumTerrenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobaculum terrenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobaculumTerrenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlochmanniaPennsylvanicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia pennsylvanicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaPennsylvanicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumBaccatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capsicum baccatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapsicumBaccatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DysgonomonasSpBgc7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas sp. BGC7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasSpBgc7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisBrenneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis brenneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBrenneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumGw2011gwe13228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWE13228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwe13228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColeophomaCylindrosporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coleophoma cylindrospora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColeophomaCylindrosporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaUliginisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella uliginis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaUliginisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpMarseillep328Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. MarseilleP328 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpMarseillep328Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumUkl133(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium UKL13-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumUkl133", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifcsphigho201full5524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFCSPHIGHO201FULL5524 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifcsphigho201full5524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentolepisNanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentolepis nana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentolepisNanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRapiDsm19907Jcm15042(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rapi DSM 19907 JCM 15042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRapiDsm19907Jcm15042", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaSpielmaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia spielmanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaSpielmaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusLugdunensisN920143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis N920143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisN920143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioCosticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio costicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioCosticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SingulisphaeraAcidiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Singulisphaera acidiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SingulisphaeraAcidiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosarcinaPallida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halosarcina pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalosarcinaPallida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24260(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24260 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24260", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiCbdb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi CBDB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiCbdb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPuniciscabieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces puniciscabiei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPuniciscabieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinococcusGranulosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Echinococcus granulosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EchinococcusGranulosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNiger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusNiger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriaceaeBacteriumChkci004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumFb2012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium FB2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumFb2012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusPropionicusDsm2032(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus DSM 2032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicusDsm2032", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaDagmatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella dagmatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaDagmatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpongiibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAd3010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AD3010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAd3010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD1_FULL_56_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd1Full5627Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumLotiMaff303099Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti MAFF303099 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiMaff303099Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumHum1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGd11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GD11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpGd11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3719 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPseudoalcaligenesKf707Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes KF707 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesKf707Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscochytaRabieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ascochyta rabiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AscochytaRabieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TamlanaSedimentorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tamlana sedimentorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TamlanaSedimentorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraHibiscaNbrc15177Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura hibisca NBRC 15177 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraHibiscaNbrc15177Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumFoliorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium foliorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumFoliorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlomusCerebriforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glomus cerebriforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlomusCerebriforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesVaccimaxillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vaccimaxillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesVaccimaxillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumAngustumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium angustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidiphiliumAngustumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterSpRoot96Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root96 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot96Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParageobacillusGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parageobacillus genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParageobacillusGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumFlavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium flavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumFlavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumBrhc36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium BRHc36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumBrhc36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterLwoffiiWj10621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii WJ10621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiWj10621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaPhthalaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia phthalatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaPhthalaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumOranimense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium oranimense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumOranimense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaNigrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella nigrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaNigrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumLipolyticumDsm21995Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum lipolyticum DSM 21995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumLipolyticumDsm21995Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumRifoxyb12full5810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFOXYB12FULL5810 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifoxyb12full5810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFOXYD1_FULL_48_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MortierellaElongataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mortierella elongata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MortierellaElongataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeodactylibacterXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeodactylibacter xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeodactylibacterXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SistotremastrumNiveocremeumHhb9708(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum HHB9708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeumHhb9708", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinatimonasHippeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinatimonas hippei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinatimonasHippeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaDasiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachancea dasiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachanceaDasiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromicrobiumChoanaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium choanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumChoanaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosalibacterSpNd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. ND1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerosalibacterSpNd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusWynnii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wynnii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWynnii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusFiculneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus ficulneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FructobacillusFiculneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TamlanaAgarivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tamlana agarivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TamlanaAgarivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumGwf23715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWF23715 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwf23715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RasamsoniaEmersoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RasamsoniaEmersoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoclavibacterHelvolusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter helvolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterHelvolusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaMesophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala mesophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaMesophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusStipitatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxococcus stipitatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxococcusStipitatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsplowo202full5111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO202FULL5111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo202full5111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalviaSplendensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salvia splendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalviaSplendensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycomycesBlakesleeanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGilvigriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvigriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvigriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpOv096Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. OV096 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpOv096Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaLongibrachiatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumYl45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium YL45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumYl45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuenenbacteriaBacteriumRifcsphigho202full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kuenenbacteria bacterium RIFCSPHIGHO202FULL3913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KuenenbacteriaBacteriumRifcsphigho202full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl2004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl2004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiemerellaColumbina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riemerella columbina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiemerellaColumbina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaLuteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaLuteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialophoraAttae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialophora attae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialophoraAttae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IchthyophthiriusMultifiliisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ichthyophthirius multifiliis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IchthyophthiriusMultifiliisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo201full4724Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4724 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4724Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpP18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. P1.8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpP18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioLitoralisDsm17657Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio litoralis DSM 17657 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioLitoralisDsm17657Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTachikawaeaGelatinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tachikawaea gelatinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTachikawaeaGelatinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRbg166418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_64_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasHydrothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas hydrothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasHydrothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaDonghaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina donghaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaDonghaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPasteuriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pasteurii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPasteuriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumCg1024390Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium CG1024390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumCg1024390Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterEthanolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter ethanolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterEthanolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocoleusSpPcc7113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus sp. PCC7113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusSpPcc7113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongyloidesStercoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides stercoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesStercoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloligellaHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloligella halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloligellaHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptosporangiumRoseumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium roseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumRoseumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterSpUncmf366tsu51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF366Tsu5.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf366tsu51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpQd031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. qd031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSpQd031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaMallensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicella mallensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicellaMallensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSalinitoleransStrHayward0363Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans str. Hayward 0363 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitoleransStrHayward0363Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioPigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio piger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioPigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsplowo201full4610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO201FULL4610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo201full4610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpRoot135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxMediterraneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMediterraneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaSpScgcAaa288l16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. SCGC AAA288L16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpScgcAaa288l16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHaemophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium haemophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHaemophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumParvumIowaIi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Iowa II graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumParvumIowaIi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCedrinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cedrina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCedrinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterHolothuriorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter holothuriorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterHolothuriorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniKf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni KF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniKf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSp4681Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 4681 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSp4681Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraRamorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora ramorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraRamorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerpulaLacrymans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serpula lacrymans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerpulaLacrymans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonJdfr11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon JdFR11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonJdfr11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidicoccusFontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidicoccus fontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidicoccusFontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonasAustralicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas australica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasAustralicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full3811b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL3811b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full3811b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPsittaci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus psittaci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPsittaci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacterium13220cm2657(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_2_20CM_2_65_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13220cm2657", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterCibariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cibarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCibariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSuimastitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces suimastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSuimastitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalodesulfovibrioMarinisediminisDsm17456Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis DSM 17456 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminisDsm17456Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterDaltonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter daltonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterDaltonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaKunkeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma kunkelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaKunkeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisGranuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis granuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisGranuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumWsm2304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum WSM2304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumWsm2304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphopichiaBurtonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphopichia burtonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphopichiaBurtonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpGa6a2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. Ga6A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpGa6a2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaDenticariosiJcm15641Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella denticariosi JCM 15641 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaDenticariosiJcm15641Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCacaonumDsm21116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum DSM 21116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCacaonumDsm21116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumGriseofulvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium griseofulvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumGriseofulvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachipleistophoraHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trachipleistophora hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrachipleistophoraHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsormidiumNitensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klebsormidium nitens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlebsormidiumNitensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumRbg135518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_13_55_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg135518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaMultilocale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHarenaeNbrc108248(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia harenae NBRC 108248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaHarenaeNbrc108248", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAnguillarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio anguillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioAnguillarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpMan2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. MAN2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpMan2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusMangrovi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus mangrovi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMangrovi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niabella soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiabellaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaUniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia uniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaUniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusMicrosporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus microsporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopusMicrosporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumTusciae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium tusciae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumTusciae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifoxya1full4114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFOXYA1FULL4114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifoxya1full4114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpBtai1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. BTAi1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpBtai1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumLacustreDsm10312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronum lacustre DSM 10312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronumLacustreDsm10312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNanopusillusAcidilobi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nanopusillus acidilobi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNanopusillusAcidilobi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMundtiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus mundtii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMundtiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaArgininiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arginini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArgininiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 5-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanogenicArchaeonMixedCultureIso4G1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed culture ISO4-G1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixedCultureIso4G1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmobacterMegateriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter megaterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmobacterMegateriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaWadsworthii9715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii 9715 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaWadsworthii9715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpAb57(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb57", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpAst10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. AST10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfurimonasSpAst10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaAureofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora aureofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAureofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterHeparinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter heparinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterHeparinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf2580(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2580 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2580", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaeanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taeanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaeanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisXylanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis xylanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisXylanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpLappah95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. LaPpAH95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpLappah95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrabacterSp28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. 28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSp28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobrachiumCelere(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermobrachium celere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermobrachiumCelere", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriAtcc14405Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri ATCC14405 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriAtcc14405Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumPeriodonticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium periodonticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPeriodonticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDadantiiEch703Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dadantii Ech703 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DickeyaDadantiiEch703Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBiflexaSerovarPatocStrainPatoc1ParisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira biflexa serovar Patoc strain Patoc 1 (Paris) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBiflexaSerovarPatocStrainPatoc1ParisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilodermaCroceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piloderma croceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PilodermaCroceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpStf2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. STF2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpStf2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MedicagoTruncatulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Medicago truncatula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MedicagoTruncatulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythonBivittatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Python bivittatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PythonBivittatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh860(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH860 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh860", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusOdysseyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus odysseyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusOdysseyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGlucanolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glucanolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlucanolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_51_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumManausenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium manausense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumManausenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaZoodegmatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria zoodegmatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaZoodegmatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSpg23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SPG23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSpg23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StoquefichusSpKle1796(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stoquefichus sp. KLE1796 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StoquefichusSpKle1796", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. 01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSp01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSp22iis11gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. 22IIS11g Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanicolaSp22iis11gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtribacteriaBacteriumCg2303313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium CG2_30_33_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumCg2303313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaGottschalkiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaAtcc25996Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa ATCC25996 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaAtcc25996Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoHordei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ustilago hordei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UstilagoHordei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumToluclasticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AromatoleumToluclasticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraShabanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera shabanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraShabanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWorsleiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella worsleiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaWorsleiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaceaeBacteriumPbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiaceae bacterium PBA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaceaeBacteriumPbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpEpsl27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. EPSL27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpEpsl27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12SubstrW3110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. W3110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrW3110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumEligens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium eligens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumEligens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumGw2011gwa2359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium GW2011GWA2359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumGw2011gwa2359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HugenholtziaRoseolaDsm9546(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola DSM 9546 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HugenholtziaRoseolaDsm9546", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaTriticinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puccinia triticina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PucciniaTriticinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeocapsaSpPcc73106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gloeocapsa sp. PCC73106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GloeocapsaSpPcc73106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusZymae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus zymae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusZymae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRhodesiaeJs60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rhodesiae JS60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRhodesiaeJs60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenarchaeotaArchaeon13120cm25314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_20CM_2_53_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13120cm25314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCrocodyliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma crocodyli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCrocodyliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerulinaMusivaSo2202Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva SO2202 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphaerulinaMusivaSo2202Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubrivivaxGelatinosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubrivivax gelatinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubrivivaxGelatinosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizopusMicrosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus microsporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizopusMicrosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4281Fw2241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4281 (FW-2241) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4281Fw2241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteralesBacteriumAlpha01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Alpha_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumAlpha01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1023713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1023713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa1478(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA1478 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa1478", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CionaIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ciona intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CionaIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylohalobiusCrimeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylohalobius crimeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylohalobiusCrimeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaLacteaDsm19367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella lactea DSM 19367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NakamurellaLacteaDsm19367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGeorgiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces georgiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGeorgiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterOxydans621hCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gluconobacter oxydans 621H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GluconobacterOxydans621hCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeospirillumMolischianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum molischianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumMolischianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetragenococcusSolitariusNbrc100494Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius NBRC 100494 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetragenococcusSolitariusNbrc100494Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NotechisScutatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Notechis scutatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NotechisScutatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterIcosiumassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter icosiumassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterIcosiumassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnochordaPilosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnochorda pilosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnochordaPilosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParacuniculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paracuniculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParacuniculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24058Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_40_58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24058Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaPsittaci10139811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia psittaci 10139811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaPsittaci10139811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumCg1025621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium CG1_02_56_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumCg1025621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterXylosoxidansA8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter xylosoxidans A8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterXylosoxidansA8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaeruleatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caeruleatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaeruleatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosartoryaFischeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neosartorya fischeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeosartoryaFischeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicolaSp22iis11g(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola sp. 22IIS11g graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanicolaSp22iis11g", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAlbilineansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas albilineans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAlbilineansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasCupidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas cupida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasCupidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpDvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. DV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpDvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaXylanovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna xylanovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaXylanovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumGeorgienseDsm11526Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense DSM 11526 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgienseDsm11526Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRedseas39b2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. REDSEAS39B2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRedseas39b2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrodictiumOccultumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium occultum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumOccultumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixInsectorumRcef264(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix insectorum RCEF 264 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporothrixInsectorumRcef264", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpJs614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. JS614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJs614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReichenbachiellaFaecimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaFaecimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfuricurvumKujienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfuricurvum kujiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfuricurvumKujienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplodiaSeriataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diplodia seriata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiplodiaSeriataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfarculaceaeBacteriumJdfr97(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculaceae bacterium JdFR-97 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfarculaceaeBacteriumJdfr97", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JetteniaCaeni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jettenia caeni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JetteniaCaeni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc29g08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC29G08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc29g08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusModuliflexusFlocculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moduliflexus flocculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusModuliflexusFlocculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaMelaleucaeAtcc49191Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae ATCC 49191 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucaeAtcc49191Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropherymaWhipplei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tropheryma whipplei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TropherymaWhipplei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpMarseillep328Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. MarseilleP328 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpMarseillep328Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil782Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil782 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil782Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMooreiDsm22971(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei DSM22971 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiDsm22971", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraTigrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Panthera tigris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantheraTigrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAquamarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas aquamarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasAquamarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHelveticusCnrz32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus CNRZ32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusCnrz32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GabonibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gabonibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GabonibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolituusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolituusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminobacteriumColombienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminobacterium colombiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminobacteriumColombienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusRuberCbs135680Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ruber CBS 135680 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusRuberCbs135680Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FloricoccusTropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Floricoccus tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FloricoccusTropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumHalopraeferensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum halopraeferens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzospirillumHalopraeferensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScyliorhinusTorazameCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scyliorhinus torazame Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScyliorhinusTorazameCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrinemaVersiformeJcm10478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Natrinema versiforme JCM 10478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NatrinemaVersiformeJcm10478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumGa0074141Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0074141 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0074141Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWB1_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwb14311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaElarraichensisGillSymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Solemya elarraichensis gill symbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SolemyaElarraichensisGillSymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumSg847Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg847Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSiraeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Eubacterium] siraeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSiraeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAlhagi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea alhagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaAlhagi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot487d2y(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root487D2Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot487d2y", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_41_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMoukalabense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium moukalabense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMoukalabense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSporosphaeroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sporosphaeroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSporosphaeroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpY412mc10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Y412MC10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpY412mc10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumSanguinicancri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sanguinicancri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSanguinicancri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobacillusAlkalidiazotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobacillus alkalidiazotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobacillusAlkalidiazotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPsychrerythraea34hEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colwellia psychrerythraea 34H Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColwelliaPsychrerythraea34hEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumGwf23715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium GWF23715 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumGwf23715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaeniopygiaGuttataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taeniopygia guttata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaeniopygiaGuttataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusOmnitrophicaBacterium4484171Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium 4484_171 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacterium4484171Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthomonasSpRoot630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. Root630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpRoot630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriaceaeBacteriumP6a17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionibacteriaceae bacterium P6A17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriaceaeBacteriumP6a17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterSpLeaf185Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter sp. Leaf185 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RathayibacterSpLeaf185Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterAceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter aceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9902Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9902 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9902Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSp4557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sp. 4557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSp4557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumFe2018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium FE2018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumFe2018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumKoreenseCcug49689Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense CCUG 49689 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreenseCcug49689Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaHydrogenotrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blautia hydrogenotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlautiaHydrogenotrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAsbs410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASBs410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsbs410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbaceaeBacteriumDb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium DB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumDb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFumarioliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fumarioli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusFumarioliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymoseptoriaBrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymoseptoria brevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymoseptoriaBrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumSpAf6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterSpSoil728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janibacter sp. Soil728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanibacterSpSoil728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwd23614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWD2_36_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwd23614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaMirobrigensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora mirobrigensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMirobrigensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaBelliiOsu85389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia bellii OSU85389 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaBelliiOsu85389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNdongoniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ndongoniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNdongoniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAc2024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AC2024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAc2024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeauveriaBassianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Beauveria bassiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BeauveriaBassianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaArchaeonScgcAaa282k18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA282K18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa282k18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaTrematumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella trematum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaTrematumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WinogradskyellaSpPg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. PG-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpPg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSpSos3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia sp. SOS3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSpSos3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumPseudogrignonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum pseudogrignonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumPseudogrignonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumDakarenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium dakarense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumDakarenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptococcaceaeBacteriumBrhc4a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BRHc4a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBrhc4a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusPsychrotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus psychrotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusPsychrotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisTessellarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis tessellarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisTessellarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKsb1Bacterium448487(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return candidate division KSB1 bacterium 4484_87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1Bacterium448487", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpPsnih2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. PSNIH2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpPsnih2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc3789Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC3789 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3789Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumDg743(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg743", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettaeCvd059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae CVD059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusArlettaeCvd059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumAponinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanobacterium aponinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumAponinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumOlb7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium OLB7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumOlb7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NecropsobacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanioRerio(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Danio rerio graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DanioRerio", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf325Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf325 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf325Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusPasteuriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pasteuri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPasteuriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumUrhe0068Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium URHE0068 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumUrhe0068Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraBorgpeterseniiPomonaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii Pomona Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiPomonaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterPylori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter pylori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterPylori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBrennaborense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema brennaborense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaBrennaborense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimonasHalophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limimonas halophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimimonasHalophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus saliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YarrowiaLipolyticaClib122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica CLIB122 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YarrowiaLipolyticaClib122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensisHga0223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis HGA0223 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensisHga0223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumA37t11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium A37T11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumA37t11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanogenicArchaeonMixedCultureIso4G1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return methanogenic archaeon mixed culture ISO4-G1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanogenicArchaeonMixedCultureIso4G1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaAerocolonigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lechevalieria aerocolonigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LechevalieriaAerocolonigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMucosae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMucosae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesThermoautotrophicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermoautotrophicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermoautotrophicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpSbi22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. SBI22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpSbi22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110055Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110055 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110055Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FicedulaAlbicollisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ficedula albicollis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FicedulaAlbicollisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusEhimensisA2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis A2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusEhimensisA2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolophagaFoetidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holophaga foetida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HolophagaFoetidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpGfb01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. GFB01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpGfb01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRbg133914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RBG133914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRbg133914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrospiraPlatensisNies39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrospira platensis NIES39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisNies39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFjat26652Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-26652 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat26652Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpFh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceicoccusPelagius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus pelagius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusPelagius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwa25611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWA25611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwa25611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumGwa1448Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium GWA1448 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumGwa1448Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo201full4027Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO201FULL4027 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo201full4027Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusIlyisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus ilyis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichococcusIlyisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpMccc1a02491(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A02491 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a02491", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeraceosorusBombacis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus bombacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusBombacis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHph0090Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HPH0090 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHph0090Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosaetaHarundinacea6ac(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea 6Ac graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosaetaHarundinacea6ac", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusTolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius tolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusTolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaPulmonicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea pulmonicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaPulmonicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiesbergeriaAnulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giesbergeria anulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiesbergeriaAnulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumInersCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium iners Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumInersCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRapiDsm19907Jcm15042Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus rapi DSM 19907 JCM 15042 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusRapiDsm19907Jcm15042Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DolosicoccusPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dolosicoccus paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DolosicoccusPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaFaecigallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea faecigallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaFaecigallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusArculariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polyporus arcularius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolyporusArculariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpLeaf261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrysSpWjwCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Labrys sp. WJW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LabrysSpWjwCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PochoniaChlamydosporia170(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia170", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumUj101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium UJ101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumUj101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineActinobacteriumMedacidiG2bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusPicturae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus picturae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusPicturae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactococcusRaffinolactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharomonosporaPaurometabolicaYim90007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica YIM 90007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolicaYim90007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus oris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpJkg1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. JKG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpJkg1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBaroniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella baroniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaBaroniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesImmunogenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides immunogenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesImmunogenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphacelomaMurrayaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphaceloma murrayae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphacelomaMurrayaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasZinciduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zincidurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasZinciduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaMeyeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaalia meyeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaaliaMeyeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_43_11b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4311bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmithellaSpM82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. M82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpM82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorellaVariabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorella variabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorellaVariabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpF0442(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0442 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0442", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpPanfs17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PANFS17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPanfs17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAtroolivaceusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces atroolivaceus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAtroolivaceusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KetogulonicigeniumVulgareY25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare Y25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgareY25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteococcusJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Luteococcus japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LuteococcusJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaWaksmaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella waksmanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWaksmaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnatilineaApprimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ornatilinea apprima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrnatilineaApprimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPeregrinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium peregrinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPeregrinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpW8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_37_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa2377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaTuronicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma turonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTuronicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWaltersiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella waltersii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaWaltersiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaVervacti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea vervacti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaVervacti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosarcinaSpBus5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosarcina sp. BuS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosarcinaSpBus5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EthanoligenensHarbinense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ethanoligenens harbinense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EthanoligenensHarbinense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyd2full3916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYD2FULL3916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyd2full3916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusLactolyticusAtcc51172Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus ATCC51172 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusAtcc51172Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinocyclocheilusRhinocerousCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus rhinocerous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusRhinocerousCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPopuletiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] populeti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPopuletiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorangiineaeBacteriumNic37a2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sorangiineae bacterium NIC37A_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SorangiineaeBacteriumNic37a2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpGxf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumKamchatkenseKam1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylacidiphilum kamchatkense Kam1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylacidiphilumKamchatkenseKam1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIiEuryarchaeoteCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeoteCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusIbericusCbs121593Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ibericus CBS 121593 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusIbericusCbs121593Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinocatenisporaSera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinocatenispora sera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinocatenisporaSera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaxillusRubicundulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaxillusRubicundulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobonumTyrrellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobonum tyrrellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobonumTyrrellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendrobiumCatenatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dendrobium catenatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DendrobiumCatenatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EsoxLuciusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Esox lucius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EsoxLuciusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaceaeBacteriumIbvucb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNecrophorumD12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium necrophorum D12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNecrophorumD12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteriumSp457220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium sp. 4572_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumSp457220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmazonaAestivaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amazona aestiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmazonaAestivaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwd23811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWD23811 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwd23811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaAcaciaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia acaciae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAcaciaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenderiaElectrophaga(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenderia electrophaga graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenderiaElectrophaga", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HirschiaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hirschia maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HirschiaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium GW2011_GWA1_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumGw2011Gwa14311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterSpVk13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. VK13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpVk13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPactumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pactum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPactumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopseudomonasPalustrisHaa2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris HaA2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisHaa2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho201full4523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO201FULL4523 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho201full4523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporidium muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptosporidiumMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronovibrioMagnusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronovibrio magnus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronovibrioMagnusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpErgs101Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ERGS1:01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpErgs101Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrobacterVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaSpWa102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. WA102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpWa102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CulturomicaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Culturomica massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CulturomicaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAtribacteriaBacteriumRbg19ftCombo3514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium RBG_19FT_COMBO_35_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumRbg19ftCombo3514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpHyo08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. HYO08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpHyo08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmataMassilianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmata massiliana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmataMassilianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasVasicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vasicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVasicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothelomycesThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:524 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusLacusDsm15449Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus DSM 15449 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusLacusDsm15449Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HippeaMaritima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hippea maritima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HippeaMaritima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumBangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum bangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumBangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg135212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG135212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg135212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumRivuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium rivuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumRivuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesClarusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides clarus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesClarusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumErythreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium erythreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumErythreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VitellibacterAquimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vitellibacter aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VitellibacterAquimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribiusSalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Maribius salinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MaribiusSalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpCg3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumCg2303616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium CG2_30_36_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumCg2303616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineActinobacteriumMedacidiG3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassiosiraPseudonanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassiosira pseudonana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassiosiraPseudonanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMannanilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mannanilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMannanilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorAquibiodomus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor aquibiodomus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratireductorAquibiodomus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothrixThermoacetophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanothrix thermoacetophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanothrixThermoacetophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionSr1BacteriumAalborgaaw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium AalborgAAW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumAalborgaaw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitromicrobiumSpJl477Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JL477 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJl477Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriMf28(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri MF28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriMf28", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbaceaeBacteriumDb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium DB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumDb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngustibacterSpRoot456Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Angustibacter sp. Root456 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AngustibacterSpRoot456Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PocilloporaDamicornis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pocillopora damicornis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PocilloporaDamicornis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusXylanilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus xylanilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusXylanilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterLudwigiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter ludwigii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterLudwigiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprococcusCatusGd7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprococcus catus GD/7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoprococcusCatusGd7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterNanhaiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNanhaiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPhenoliruptrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phenoliruptrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhenoliruptrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumSpLf3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Bacterium sp. LF3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "BacteriumSpLf3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusKhoisanae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus khoisanae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKhoisanae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaWaywayandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea waywayandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaWaywayandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumGeofontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium geofontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumGeofontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SmithellaSpScadcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Smithella sp. SCADC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SmithellaSpScadcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifoxya2Full329(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFOXYA2_FULL_32_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifoxya2Full329", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSp1501Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. 1501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSp1501Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudanabaenaSpPcc6802Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC6802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc6802Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShigellaDysenteriaeSd197(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Sd197 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShigellaDysenteriaeSd197", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusTiberiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus Tiberius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusTiberiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwa25343Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWA2_53_43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwa25343Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenturiaNashicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Venturia nashicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VenturiaNashicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterPostgateiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter postgatei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterPostgateiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumCryptumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium cryptum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumCryptumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SideroxydansLithotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans lithotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SideroxydansLithotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocCitreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc citreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocCitreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiodiazotrophaEndoloripesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiodiazotropha endoloripes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiodiazotrophaEndoloripesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHimastatinicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces himastatinicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHimastatinicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVancouverensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vancouverensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVancouverensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FranconibacterPulverisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter pulveris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FranconibacterPulverisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SelenomonasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaOralisAtcc33269(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella oralis ATCC33269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaOralisAtcc33269", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaFelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Afipia felis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AfipiaFelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaceyellaSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Laceyella sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LaceyellaSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelissococcusPlutoniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melissococcus plutonius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelissococcusPlutoniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumT5br10b2g0Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium T5Br10B2g0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumT5br10b2g0Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerodermaCitrinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SclerodermaCitrinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterLipolyticusBf04cf4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus BF04CF4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusBf04cf4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrolunatusSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaVermiferaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serendipita vermifera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerendipitaVermiferaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OblitimonasAlkaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oblitimonas alkaliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OblitimonasAlkaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCassavae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cassavae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCassavae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonascusPurpureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monascus purpureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonascusPurpureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumPaxllaeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium paxllaeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumPaxllaeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSteigerwaltiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei steigerwaltii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSteigerwaltiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusFasciansD188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians D188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansD188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg16378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16378 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaSpAk20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Formosa sp. AK20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FormosaSpAk20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgiphilusAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algiphilus aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgiphilusAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf186(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf186 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf186", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAnatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma anatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAnatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KrasilnikoviellaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Krasilnikoviella flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KrasilnikoviellaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusAzorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius azorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusAzorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full5121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL5121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full5121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaBorealisF4128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia borealis F-4128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaBorealisF4128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumSalmoneumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalieaSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haliea salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalieaSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaTyrosinoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga tyrosinoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaTyrosinoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaMasoucidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida masoucida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaMasoucidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParastagonosporaNodorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parastagonospora nodorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParastagonosporaNodorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpTdk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. TDK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpTdk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumTcs55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium TCS55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumTcs55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumHydrothermaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum hydrothermale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumHydrothermaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusArsenophonusLipoptenaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus lipoptenae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusLipoptenaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_01_FULL_43_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho201Full4330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodotorulaTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetalesBacteriumSpiro05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetales bacterium Spiro_05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetalesBacteriumSpiro05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColeophomaCylindrosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coleophoma cylindrospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColeophomaCylindrosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenimonasThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenimonas thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenimonasThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumSpAk27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium sp. AK27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumSpAk27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSaguiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSaguiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulosimicrobiumSpTh20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulosimicrobium sp. TH-20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulosimicrobiumSpTh20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpRoot265(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot265", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpHmsc071c03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC071C03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc071c03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusAntriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus antri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAntriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulcanisaetaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSp109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leifsonia sp. 109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeifsoniaSp109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaDiobovata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula diobovata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaDiobovata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpLq44Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. LQ44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpLq44Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RufibacterSpDg15cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG15C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg15cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaGansuensisDsm44835(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Jiangella gansuensis DSM 44835 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JiangellaGansuensisDsm44835", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatenovulumAgarivoransDs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Catenovulum agarivorans DS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CatenovulumAgarivoransDs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMaculosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella maculosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMaculosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SlackiaExiguaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Slackia exigua Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SlackiaExiguaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactococcusGarvieaeLg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus garvieae Lg2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusGarvieaeLg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaSinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchotonaPrincepsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ochotona princeps Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OchotonaPrincepsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaceaeBacteriumAt8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eggerthellaceae bacterium AT8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EggerthellaceaeBacteriumAt8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermopetrobacterSpTc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermopetrobacter sp. TC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermopetrobacterSpTc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrateuriaTerreaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frateuria terrea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrateuriaTerreaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosemaBombycis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nosema bombycis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NosemaBombycis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMucogenicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mucogenicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMucogenicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGp183Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GP183 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGp183Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeblenbacteriaBacteriumRifoxyc2full4211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veblenbacteria bacterium RIFOXYC2FULL4211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeblenbacteriaBacteriumRifoxyc2full4211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpKgw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus sp. KGW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSpKgw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYB1_FULL_38_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyb1Full3837Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpCcge1001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodictyonPhaeoclathratiformeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon phaeoclathratiforme Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelodictyonPhaeoclathratiformeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParabuchneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parabuchneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParabuchneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriiaBacteriumRifoxyc2full3518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriia bacterium RIFOXYC2FULL3518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriiaBacteriumRifoxyc2full3518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanohaloarchaeaArchaeonB1br10u2g19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasSpDtu018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DichloromethanomonasElyunquensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dichloromethanomonas elyunquensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DichloromethanomonasElyunquensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumProfundumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium profundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProfundumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StegodyphusMimosarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stegodyphus mimosarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StegodyphusMimosarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaGariniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borreliella garinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliellaGariniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_38_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaFlagellatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola flagellatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaFlagellatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterHormaecheiSubspOharaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. oharae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspOharaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGoldsteinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaBovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasZinciduransB6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas zincidurans B6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasZinciduransB6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasSpCy54118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. CY54118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpCy54118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChlorophenolicumL1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum L-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicumL1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumF0431Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium F0431 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumF0431Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasEndodontalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas endodontalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasEndodontalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonnei53gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shigella sonnei 53G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShigellaSonnei53gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu084Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU084 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu084Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaConspicua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea conspicua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaConspicua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpQxt31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. QXT-31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpQxt31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAb2028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AB2028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAb2028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL3811 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusKamchatkensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfurococcus kamchatkensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfurococcusKamchatkensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpLeaf225(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf225 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf225", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLipophiloflavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lipophiloflavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLipophiloflavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobbsiaAndropogonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Robbsia andropogonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RobbsiaAndropogonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpPcc7103Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7103 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7103Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumVentriculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ventriculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumVentriculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium457213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4572_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium457213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronospiraThiodismutansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfonatronospira thiodismutans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfonatronospiraThiodismutansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaSp22iis11z7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. 22IIS11z7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSp22iis11z7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusPacificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius pacificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusPacificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full5121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL5121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full5121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRoot190Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root190 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot190Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_46_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc3832(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3832 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3832", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho202full5313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO202FULL5313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho202full5313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasSp22ii1619iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. 22II-16-19i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSp22ii1619iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMindensisDsm14500Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis DSM 14500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusMindensisDsm14500Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoduganellaViolaceinigraDsm15887Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra DSM 15887 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigraDsm15887Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaIndicaDsm11827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serendipita indica DSM 11827 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerendipitaIndicaDsm11827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5517", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumFlavum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium flavum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumFlavum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxya1full4011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYA1FULL4011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxya1full4011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaNanhaiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nanhaiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNanhaiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLpb0140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LPB0140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLpb0140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UstilagoMaydis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ustilago maydis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UstilagoMaydis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusPantotrophusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus pantotrophus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusPantotrophusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpKordi49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusFusiformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus fusiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusFusiformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraSpL2l1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera sp. L2L1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraSpL2l1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiwaeNbrc108934Dsm45340Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia niwae NBRC 108934 DSM 45340 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaNiwaeNbrc108934Dsm45340Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrarchaeotaArchaeonCg1024740(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrarchaeota archaeon CG1024740 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrarchaeotaArchaeonCg1024740", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiriDsm20587Jcm5818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri DSM 20587 JCM 5818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKefiriDsm20587Jcm5818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferSpHz11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. HZ11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpHz11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12451111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245111.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12451111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterCrusticolaDsm16708Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dyadobacter crusticola DSM 16708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DyadobacterCrusticolaDsm16708Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeomegalonemaPerideroedesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neomegalonema perideroedes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeomegalonemaPerideroedesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTanacetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tanaceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTanacetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GoniumPectorale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gonium pectorale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GoniumPectorale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaGriseolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora griseola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaGriseolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WenxiniaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wenxinia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WenxiniaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotodesmusBlepharusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus blepharus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusBlepharusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumCg1024134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium CG1024134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumCg1024134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumSenegalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium senegalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSenegalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisDiscipulorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis discipulorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisDiscipulorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquifexAeolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquifex aeolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquifexAeolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEndobugulaSertulaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Endobugula sertula Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusEndobugulaSertulaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusDuransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus durans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDuransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesMinimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles minimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesMinimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaHispanicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula hispanica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarculaHispanicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwb24136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWB2_41_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwb24136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithrixFerrooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidithrix ferrooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidithrixFerrooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DenitrovibrioAcetiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Denitrovibrio acetiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DenitrovibrioAcetiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaliobacillusSpPm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus sp. PM-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusSpPm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SodalisPierantoniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sodalis pierantonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SodalisPierantoniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobiusMediterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius mediterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusMediterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesPristinaespiralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces pristinaespiralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPristinaespiralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOdinarchaeotaArchaeonLcb4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Odinarchaeota archaeon LCB_4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusOdinarchaeotaArchaeonLcb4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpA2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. A2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpA2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacterium3541(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium 35_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacterium3541", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpWaoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. WAO Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpWaoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LarimichthysCroceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Larimichthys crocea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LarimichthysCroceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl2004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL2004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl2004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariniblastusFucicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mariniblastus fucicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MariniblastusFucicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixTonsillarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix tonsillarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixTonsillarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrilyobacterAtlanticusDsm19335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus DSM 19335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticusDsm19335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumSpB98Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. B9-8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpB98Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoelleriellaLiberaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moelleriella libera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoelleriellaLiberaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp3j1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 3J1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp3j1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesBikiniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bikiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBikiniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PirellulaStaleyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pirellula staleyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PirellulaStaleyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofamiliaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neofamilia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeofamiliaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rahnella aquatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RahnellaAquatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1285(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1285 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1285", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasBivalvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas bivalvium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasBivalvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumL41a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium L41A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumL41a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumAdornatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum adornatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermofilumAdornatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionimicrobiumSpBv2f7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. BV2F7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumSpBv2f7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermophagusXiamenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermophagus xiamenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermophagusXiamenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraAlvinipulliAtcc51933Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira alvinipulli ATCC 51933 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraAlvinipulliAtcc51933Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FournierellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fournierella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FournierellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasaccharibacterApium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parasaccharibacter apium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParasaccharibacterApium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaSp1155Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga sp. 1155 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinitogaSp1155Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterThermautotrophicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter thermautotrophicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterThermautotrophicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSp3cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. 3C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSp3cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagneticumAmb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum AMB-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticumAmb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumPyruvativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium pyruvativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumPyruvativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwf24413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWF2_44_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwf24413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumFaniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium faniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumFaniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Haloarchaeon3a1dgr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return haloarchaeon 3A1DGR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Haloarchaeon3a1dgr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTelluritireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas telluritireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTelluritireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FonticulaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fonticula alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FonticulaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCibariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cibarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCibariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpulopisciumSpNtMorphotypeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nt morphotype Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNtMorphotypeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCb0101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPLOWO2_01_FULL_43_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusLactolyticusAtcc51172Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus lactolyticus ATCC51172 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusLactolyticusAtcc51172Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full3816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL3816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full3816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicycliphilusDenitrificansK601Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicycliphilus denitrificans K601 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicycliphilusDenitrificansK601Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScheffersomycesStipitisCbs6054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis CBS 6054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ScheffersomycesStipitisCbs6054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag798Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:798 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag798Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumHeidelbergenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heidelbergense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeidelbergenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUrha0056(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHA0056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrha0056", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathycoccusPrasinosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathycoccus prasinos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathycoccusPrasinosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaMagadiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialba magadii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaMagadiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterSpDg31d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter sp. DG31D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RufibacterSpDg31d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomicrobiumGlacieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium glaciei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumGlacieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaMarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella marensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaMarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpLshc420b00Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSHC420B00 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLshc420b00Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMmlr14010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MMLR14_010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMmlr14010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumGossypiiAtcc10895Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium gossypii ATCC 10895 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EremotheciumGossypiiAtcc10895Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TamlanaAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tamlana agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TamlanaAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaJacobaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia jacobaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaJacobaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpEl159Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. EL159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpEl159Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaAntimicrobica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora antimicrobica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaAntimicrobica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTerpenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia terpenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaTerpenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasVesicatoriaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vesicatoria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVesicatoriaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconobacterJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpHl111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. HL-111 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpHl111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu032(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU032 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu032", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpH7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. H7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpH7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumWg36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium WG36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumWg36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OttowiaSpOralTaxon894Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ottowia sp. oral taxon 894 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OttowiaSpOralTaxon894Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipataDsm17808Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kaistia adipata DSM 17808 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KaistiaAdipataDsm17808Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrusUnshiu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrus unshiu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrusUnshiu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpHun102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HUN102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHun102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumCellobioparumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium cellobioparum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumCellobioparumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacillusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacillusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_45_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc2458Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaSp119Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. 1.19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaSp119Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavimarinaSpHeli48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavimarina sp. HelI48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavimarinaSpHeli48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa027j17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA027J17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa027j17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumBal199(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium BAL199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumBal199", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacterium5513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 55-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium5513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaSpSjp92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirga sp. SJP92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaSpSjp92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasThiophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas thiophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasThiophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosocomiicoccusSpNp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nosocomiicoccus sp. NP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NosocomiicoccusSpNp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpCrb83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. CRB-8-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpCrb83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpMarseillep3244Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP3244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep3244Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumSilenesdioicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum silenesdioicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSilenesdioicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRac01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. RAC01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRac01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAvermitilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avermitilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvermitilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColeophomaCylindrospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coleophoma cylindrospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColeophomaCylindrospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiAbcpw111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei ABCPW111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiAbcpw111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp453mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 453mf Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp453mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaFormicigeneransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea formicigenerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaFormicigeneransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorientalisRegularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorientalis regularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorientalisRegularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaimiriBoliviensisBoliviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis boliviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SaimiriBoliviensisBoliviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaStriiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Puccinia striiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PucciniaStriiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumOligotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium oligotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumOligotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaPruni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma pruni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaPruni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAggregataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina aggregata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAggregataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumVitaeruminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium vitaeruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumVitaeruminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalieaSalexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haliea salexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalieaSalexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MargulisbacteriaBacteriumGwd239127(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWD239127 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwd239127", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpScgcAaa160p02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. SCGC AAA160P02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpScgcAaa160p02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaTularensisHolarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis holarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrancisellaTularensisHolarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaglaciecolaHydrolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraglaciecola hydrolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaglaciecolaHydrolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasLykanthroporepellens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas lykanthroporepellens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasLykanthroporepellens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylopumilusPlanktonicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylopumilus planktonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylopumilusPlanktonicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumSpJ07hqx50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum sp. J07HQX50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumSpJ07hqx50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasAmylolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas amylolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAmylolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrellaAestuarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrella aestuarina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrellaAestuarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKryptobacterTengchongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptobacter tengchongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptobacterTengchongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaValaisianaVs116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana VS116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaVs116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumParvumAcb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium parvum ACB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OribacteriumParvumAcb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterPsychrophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter psychrophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterPsychrophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpNp3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Megasphaera sp. NP3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MegasphaeraSpNp3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4415 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesFranklinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides franklinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesFranklinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerinicoccusSpJlt9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus sp. JLT9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusSpJlt9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumGw2011gwe24058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag582Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:582 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag582Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4521Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KoribacterVersatilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Koribacter versatilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KoribacterVersatilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTestaceaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia testacea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaTestaceaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterCrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter crescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiberibacterCrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenispirillumSalinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenispirillum salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenispirillumSalinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPsychraerophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium psychraerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPsychraerophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillibacterRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSp6626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. 6626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSp6626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaNoatunensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Francisella noatunensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrancisellaNoatunensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansM341(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemella haemolysans M341 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemellaHaemolysansM341", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSalsusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus salsus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSalsusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaCarbekiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea carbekii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaCarbekiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_43_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7424 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot708Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot708Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAurantiacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAurantiacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAlgidicarnisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium algidicarnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAlgidicarnisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BellilineaCaldifistulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bellilinea caldifistulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BellilineaCaldifistulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph758Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH758 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph758Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulophagaAlgicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga algicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulophagaAlgicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DongiaSpUrhe0060(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dongia sp. URHE0060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DongiaSpUrhe0060", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothrixFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geothrix fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeothrixFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlebsiellaPneumoniaeSubspPneumoniaeHs11286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. pneumoniae HS11286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspPneumoniaeHs11286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpYab3001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. YAB3001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpYab3001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAntibioticophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus antibioticophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAntibioticophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusIbericusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus ibericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusIbericusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumGw2011gwa24413bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA24413b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa24413bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RicinusCommunisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ricinus communis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RicinusCommunisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophilaDsm15071Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiohalospira halophila DSM 15071 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiohalospiraHalophilaDsm15071Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavisporaLusitaniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClavisporaLusitaniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterLutiphocaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter lutiphocae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterLutiphocaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloquadratumWalsbyiDsm16790(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloquadratum walsbyi DSM16790 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloquadratumWalsbyiDsm16790", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaRhizospheraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia rhizosphera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaRhizospheraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasAquaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solimonas aquatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolimonasAquaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaLincolniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella lincolnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaLincolniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydocellaSpUlo1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carboxydocella sp. ULO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarboxydocellaSpUlo1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonisporaThiosulfatigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonispora thiosulfatigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonisporaThiosulfatigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastopirellulaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastopirellula marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastopirellulaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbiotrophiaDefectiva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Abiotrophia defectiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbiotrophiaDefectiva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaHalocynthiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria halocynthiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaHalocynthiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo212full4614Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO212FULL4614 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo212full4614Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusVietnamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vietnamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusVietnamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalostagnicolaLarsenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halostagnicola larsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalostagnicolaLarsenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrilyobacterAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesOleiciplenusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides oleiciplenus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOleiciplenusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KangiellaGeojedonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kangiella geojedonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KangiellaGeojedonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpJ54Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. J54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJ54Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumBrasilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium brasiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBrasilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEntericusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus entericus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEntericusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HypoxylonSpCo275Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hypoxylon sp. CO27-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HypoxylonSpCo275Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiumNeolycopersici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oidium neolycopersici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OidiumNeolycopersici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSuccinatiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister succinatiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterSuccinatiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpAli22iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. ALI22I Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpAli22iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasSpLeaf443Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. Leaf443 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSpLeaf443Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaLimicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena limicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaLimicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosigaBrevicollis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosiga brevicollis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosigaBrevicollis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc24417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc24417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacteraceaeBacteriumGwc25520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_55_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSanxanigenensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sanxanigenens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSanxanigenensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSilageiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus silagei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSilageiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumGwb1496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium GWB1_49_6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumGwb1496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumVexans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pythium vexans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PythiumVexans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisSk1074Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK1074 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk1074Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaSp6418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. 64-18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSp6418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaCentraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma centrale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaCentraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMelonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas melonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasMelonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantheraPardusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Panthera pardus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantheraPardusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCrk32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CrK32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCrk32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus tindarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolobusTindariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyclobacteriumLianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium lianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumLianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRubinfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rubinfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRubinfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeolamprologusBrichardiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neolamprologus brichardi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeolamprologusBrichardiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Valsa mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ValsaMaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoaciditogaLauensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoaciditoga lauensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoaciditogaLauensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSiamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio siamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSiamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomonasHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinomonas humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinomonasHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcusNiger(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcus niger graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcusNiger", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaumovozymaDairenensisCbs421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Naumovozyma dairenensis CBS 421 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NaumovozymaDairenensisCbs421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpCch5f6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. CCH5F6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpCch5f6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumRbg166821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_68_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcanthamoebaCastellaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acanthamoeba castellanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcanthamoebaCastellaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpJgi0001016m12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. JGI 0001016M12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpJgi0001016m12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumAmorphaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium amorphae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumAmorphaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIiiEuryarchaeoteCgEpi1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group III euryarchaeote CG-Epi1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiiEuryarchaeoteCgEpi1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg135723(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_13_57_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg135723", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpUrha0002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. URHA0002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpUrha0002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumDicentrarchiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum dicentrarchi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumDicentrarchiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetascardoviaCricetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metascardovia criceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetascardoviaCricetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpD5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpD5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4515(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4515 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4515", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RathayibacterToxicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rathayibacter toxicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RathayibacterToxicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMacquariensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus macquariensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMacquariensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg136510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_65_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfuromusaKysingiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromusa kysingii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfuromusaKysingiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassilioanorexiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilioanorexius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilioanorexiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSenegalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSenegalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGelidumKctc3527(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gelidum KCTC3527 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGelidumKctc3527", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full5620Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL5620 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full5620Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LynxCanadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lynx canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LynxCanadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpAgr2160Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. AGR2160 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpAgr2160Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag448Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:448 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag448Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WaddliaChondrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Waddlia chondrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WaddliaChondrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumLuticoctiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium luticocti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumLuticoctiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpKle1755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KLE1755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKle1755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeO1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae O1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "VibrioCholeraeO1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaTuronicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma turonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTuronicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobbsiaAndropogonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Robbsia andropogonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RobbsiaAndropogonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusCarbonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus carbonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrococcusCarbonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollimonasSpOk307(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collimonas sp. OK307 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollimonasSpOk307", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureococcusAnophagefferensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aureococcus anophagefferens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AureococcusAnophagefferensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatoriaAcuminataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria acuminata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaAcuminataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumBacl6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassilioanorexius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilioanorexius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilioanorexius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusAntri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus antri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusAntri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JacksonbacteriaBacteriumRifoxya2full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jacksonbacteria bacterium RIFOXYA2FULL4312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JacksonbacteriaBacteriumRifoxya2full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumRhizophilumDsm18822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum DSM 18822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilumDsm18822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpHl46Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. HL46 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpHl46Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0400Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0400 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0400Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterAnaerophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter anaerophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterAnaerophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot274(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot274", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OhtaekwangiaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ohtaekwangia koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OhtaekwangiaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumSpB510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. B510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpB510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpRac02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. RAC02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSpRac02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpD104Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. D104 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinomonasSpD104Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraPectinoschizaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospira pectinoschiza Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraPectinoschizaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EikenellaSpNml130454Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML130454 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml130454Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasPusilla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonas pusilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonasPusilla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumErythreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium erythreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumErythreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumSpS32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. S3-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpS32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumGbs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium GBS-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumGbs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSp9402080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. 9402080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSp9402080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeonamhaeicolaSpS23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Seonamhaeicola sp. S2-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SeonamhaeicolaSpS23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpBal6x(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. BAL6X graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpBal6x", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterColi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter coli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterColi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumGwa24615(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium GWA24615 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumGwa24615", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaetbulibacterSaemankumensisDsm17032Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaetbulibacter saemankumensis DSM 17032 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GaetbulibacterSaemankumensisDsm17032Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongyloidesRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbispora rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VenturiaEffusa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Venturia effusa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VenturiaEffusa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithiiAtcc35061Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii ATCC35061 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithiiAtcc35061Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHlucca12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HLUCCA12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHlucca12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumAnatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium anatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumAnatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPilosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pilosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPilosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumRifoxya2full3321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium RIFOXYA2FULL3321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumRifoxya2full3321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpBr18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Br18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpBr18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNamurensisDsm19117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus namurensis DSM 19117 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNamurensisDsm19117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpPf153Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Pf153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPf153Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasGlacialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas glacialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasGlacialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg1023846Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG1_02_38_46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg1023846Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesGraminisolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides graminisolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesGraminisolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisericumSpCg2303611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum sp. CG2_30_36_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldisericumSpCg2303611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDarwinianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus darwinianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDarwinianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumJaponicumUt26s(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium japonicum UT26S graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumJaponicumUt26s", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4512 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrarchaeotaArchaeonCg1025541Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_55_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1025541Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterSpJ41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. J41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpJ41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaBpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Bp Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpSy8519Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. SY8519 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpSy8519Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsplowo212full3822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO212FULL3822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo212full3822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PustulibacteriumMarinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pustulibacterium marinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PustulibacteriumMarinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_45_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGranuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGranuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc5054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpHmsc065f10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. HMSC065F10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpHmsc065f10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MadurellaMycetomatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Madurella mycetomatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MadurellaMycetomatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OxalobacterFormigenesOxcc13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oxalobacter formigenes OXCC13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OxalobacterFormigenesOxcc13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusEpiphyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus epiphyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEpiphyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBrumaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brumae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrumaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSuccinogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter succinogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSuccinogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusSpD1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus sp. D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusSpD1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TursiopsTruncatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tursiops truncatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TursiopsTruncatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo212full4614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO212FULL4614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo212full4614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSp9140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. 9140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSp9140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPalpalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina palpalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaPalpalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_12_FULL_44_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaEpidermidihirudinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia epidermidihirudinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaEpidermidihirudinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycicoccusJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpLeaf395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaTardaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella tarda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaTardaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraYegresii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraYegresii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWA2_56_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwa25611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifoxyc2full479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYC2FULL479 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyc2full479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusPoinariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus poinarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusPoinariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpAcn1ag(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. ACN1ag graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpAcn1ag", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifoxyb1full4033(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFOXYB1FULL4033 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifoxyb1full4033", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumAerolatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium aerolatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumAerolatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermaerobacterMarianensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter marianensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterMarianensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumPapyrosolvensC7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensC7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasGlacialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas glacialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaromonasGlacialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumAquatileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquatile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquatileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpAcv2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. ACV-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpAcv2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaFlocculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaFlocculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAap93(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap93", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltosporidiumTvaerminnensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium tvaerminnensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumTvaerminnensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlishewanellaAgri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alishewanella agri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlishewanellaAgri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaCypripedii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea cypripedii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaCypripedii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMutansUa159Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mutans UA159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMutansUa159Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumChabaudiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium chabaudi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumChabaudiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterLongusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter longus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLongusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MartelellaEndophyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Martelella endophytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MartelellaEndophyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumColumnareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium columnare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumColumnareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadalesBacteriumTw7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium TW7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumTw7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCapitovisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium capitovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCapitovisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOtakiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus otakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOtakiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusSpA20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus sp. A20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusSpA20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyorhinisSk76Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyorhinis SK76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyorhinisSk76Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusEurythermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus eurythermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusEurythermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a520k10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a520K10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a520k10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumNygamaiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium nygamai Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumNygamaiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulforhabdusNorvegicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulforhabdus norvegica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulforhabdusNorvegicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpRs39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. RS39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpRs39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSiraeumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Eubacterium] siraeum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSiraeumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaChrysanthemiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya chrysanthemi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaChrysanthemiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CheloniaMydasEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelonia mydas Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CheloniaMydasEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumRifcsphigho212full278(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full278", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaHofmanniiPcc7110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema hofmannii PCC 7110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ScytonemaHofmanniiPcc7110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRoot209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. Root209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRoot209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAlimentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus alimentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlimentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumPsi07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum PSI07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPsi07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleomorphomonasOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pleomorphomonas oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PleomorphomonasOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesDistasonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides distasonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesDistasonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpMccc1a01428Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01428 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01428Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastocystisSpAtcc50177NandIiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blastocystis sp. ATCC 50177/Nand II Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlastocystisSpAtcc50177NandIiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRuminococcusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Ruminococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedRuminococcusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FonticulaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fonticula alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FonticulaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpAap83(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP83 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap83", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlivibacterSitiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olivibacter sitiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlivibacterSitiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo201full4226Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO201FULL4226 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo201full4226Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaSpNp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. NP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NesterenkoniaSpNp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6677(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6677 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6677", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_47_33b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPacebacteriaBacteriumRifoxyd1Full3927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFOXYD1_FULL_39_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifoxyd1Full3927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesEggerthii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides eggerthii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesEggerthii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaElarraichensisGillSymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Solemya elarraichensis gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SolemyaElarraichensisGillSymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmoricolaAequoreusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola aequoreus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaAequoreusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpPbts1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. PBTS 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpPbts1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSporotrichioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sporotrichioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumSporotrichioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAtypicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium atypicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAtypicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumAbikonenseNbrc16140Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium abikonense NBRC 16140 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumAbikonenseNbrc16140Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusModuliflexusFlocculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moduliflexus flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusModuliflexusFlocculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumRedseas02b3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium REDSEAS02B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumRedseas02b3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterLariCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lari Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLariCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FalkowbacteriaBacteriumCg1023744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaccaAcetoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacca acetoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobaccaAcetoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4218Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4218 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4218Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoclostridiumPhocaeenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phocaeense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhocaeenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolyangiaceaeBacteriumUtpro1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polyangiaceae bacterium UTPRO1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolyangiaceaeBacteriumUtpro1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasRuminantiumAtcc12561Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium ATCC12561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAtcc12561Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoxanthobacterSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthobacter soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthobacterSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PajaroellobacterAbortibovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pajaroellobacter abortibovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PajaroellobacterAbortibovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_02_FULL_51_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo202Full5117Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisCf1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis CF1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisCf1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassiosiraPseudonanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassiosira pseudonana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassiosiraPseudonanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BergeyellaZoohelcumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bergeyella zoohelcum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BergeyellaZoohelcumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarlitoSyrichtaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carlito syrichta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarlitoSyrichtaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_42_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiyogibacteriaBacteriumRifcsplowo212full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO212FULL4113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo212full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpJcm18900Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. JCM18900 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpJcm18900Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCt34Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CT34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCt34Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AustrofundulusLimnaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Austrofundulus limnaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AustrofundulusLimnaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomarinumVadiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomarinum vadi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomarinumVadiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaxillusRubicundulusVe082h10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Ve08.2h10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaxillusRubicundulusVe082h10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSanguinisSk49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarum248Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum 248 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum248Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpCnq490Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CNQ490 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCnq490Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumHwasookiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium hwasookii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumHwasookiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeotheceCitriformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece citriformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeotheceCitriformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSeniorisDsm24302Jcm17472Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senioris DSM 24302 JCM 17472 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSeniorisDsm24302Jcm17472Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisSubspInaquosorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. inaquosorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspInaquosorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_63_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharopolysporaFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusNotomytisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus notomytis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusNotomytisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSpRim11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraFlavalbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura flavalba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraFlavalbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaCrassaOr74aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neurospora crassa OR74A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeurosporaCrassaOr74aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospinaGracilis3211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nitrospina gracilis 3/211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NitrospinaGracilis3211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltiarchaealesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altiarchaeales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltiarchaealesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTracheiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tracheiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTracheiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf24921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_49_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf24921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumThermocellumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium thermocellum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminiclostridiumThermocellumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytonemaTolypothrichoidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohaesibacterMarisflaviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cohaesibacter marisflavi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CohaesibacterMarisflaviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VogelbacteriaBacteriumRifoxyb1full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYB1FULL4216 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyb1full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GorillaGorilla(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gorilla gorilla graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GorillaGorilla", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusWynniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wynnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWynniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaMelaleucae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Entomoplasma melaleucae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EntomoplasmaMelaleucae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpSe50110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. SE50110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpSe50110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCf335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CF335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaVariabilisFEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hyaloscypha variabilis F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HyaloscyphaVariabilisFEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpLorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. LOR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpLorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibroporiaRadiculosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibroporia radiculosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibroporiaRadiculosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillumCentenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum centenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumCentenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PiriformosporaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Piriformospora indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PiriformosporaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpJb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. JB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpJb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaHydrophobicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaHydrophobicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumCg2303166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_31_66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CionaSavignyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ciona savignyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CionaSavignyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumCommuneCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium commune Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCommuneCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GastranaerophilalesBacteriumHum9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilales bacterium HUM9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilalesBacteriumHum9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumGwe25113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium GWE2_51_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumGwe25113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasSpD104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinomonas sp. D104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinomonasSpD104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaC102(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria mucosa C102 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMucosaC102", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPlantarumNbrc100936(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus plantarum NBRC 100936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusPlantarumNbrc100936", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCavendishiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cavendishii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCavendishiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaMuralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga muralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophagaMuralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DufoureaNovaeangliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dufourea novaeangliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DufoureaNovaeangliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpDd12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonnei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shigella sonnei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShigellaSonnei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagneticumAmb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum AMB-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticumAmb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSpYr403Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbiconiux sp. YR403 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbiconiuxSpYr403Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusSpretus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mus spretus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusSpretus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpF0494(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0494", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurospirillumArsenophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp150fb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 150FB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp150fb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFairfieldensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella fairfieldensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaFairfieldensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaTestudinisDsm23072Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella testudinis DSM 23072 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PasteurellaTestudinisDsm23072Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctopirusLimnophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctopirus limnophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctopirusLimnophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusAcidiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaOculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma oculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaOculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaPorci(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moraxella porci graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoraxellaPorci", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSaguini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter saguini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSaguini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwp2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWP2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwp2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaPhthalatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia phthalatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaPhthalatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylonaHeveae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylona heveae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylonaHeveae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumXinjiangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium xinjiangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumXinjiangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSeoulensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces seoulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSeoulensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxosarcinaSpGi1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myxosarcina sp. GI1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyxosarcinaSpGi1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdyssellaThessalonicensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Odyssella thessalonicensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OdyssellaThessalonicensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronococcusOccultusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus occultus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronococcusOccultusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBolteaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bolteae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBolteaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucinivoransHirudinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucinivorans hirudinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucinivoransHirudinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSaltansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter saltans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PedobacterSaltansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedPoseidonialesArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Poseidoniales archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedPoseidonialesArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterInsulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter insulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterInsulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMarisnigriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum marisnigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumMarisnigriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErpetoichthysCalabaricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erpetoichthys calabaricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErpetoichthysCalabaricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldisphaeraLagunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldisphaera lagunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldisphaeraLagunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterArsenitoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter arsenitoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterArsenitoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaLoihiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina loihiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaLoihiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidomycesRichmondensisBfwCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidomyces richmondensis BFW Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidomycesRichmondensisBfwCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterSpHtcc7211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HTCC7211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHtcc7211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavisporaLusitaniaeAtcc42720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae ATCC 42720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClavisporaLusitaniaeAtcc42720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaePvTagetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae pv. tagetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePvTagetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSpG161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter sp. G161 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSpG161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag182Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:182 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag182Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasTaetrolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taetrolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaetrolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumCg1025453Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG1025453 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg1025453Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpGp183(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GP183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGp183", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolinellaSuccinogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolinella succinogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolinellaSuccinogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBatumici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas batumici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBatumici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AttaColombicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atta colombica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AttaColombicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumSoleae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum soleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSoleae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasZehnderiOl4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi OL-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderiOl4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloprevotellaRavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella rava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaRavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiaePg2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae PG2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiaePg2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot1334Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1334 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1334Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumPerfringensAtcc13124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens ATCC13124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringensAtcc13124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraWolbachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolbachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolbachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalipigerThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salipiger thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalipigerThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesViscosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces viscosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesViscosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusPacaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus pacaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusPacaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumBbd199114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium BBD 1991-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumBbd199114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpBis7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. BIS7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpBis7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BarnesiellaIntestinihominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella intestinihominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaIntestinihominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermosulfidibacterTakaiiAbi70s6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermosulfidibacter takaii ABI70S6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermosulfidibacterTakaiiAbi70s6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCanadenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma canadense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCanadenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAquidurenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium aquidurense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAquidurenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaJinanensisNbrc108249(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia jinanensis NBRC 108249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaJinanensisNbrc108249", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrosporumCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microsporum canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrosporumCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho202full3913Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO202FULL3913 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho202full3913Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaValaisianaTom4006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia valaisiana Tom4006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaValaisianaTom4006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TurneriellaParvaDsm21527Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Turneriella parva DSM 21527 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TurneriellaParvaDsm21527Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioSpMilost1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MilosT1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMilost1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaVeroralisF0319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella veroralis F0319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaVeroralisF0319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasDiminuta4704(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta 4704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevundimonasDiminuta4704", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobiusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobiusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpPamc26605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. PAMC26605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpPamc26605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusJannaschiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus jannaschii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusJannaschiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpFw510t8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. FW510T8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpFw510t8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lambdaproteobacteria bacterium RIFOXYD2_FULL_50_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLambdaproteobacteriaBacteriumRifoxyd2Full5016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShigellaDysenteriaeSd197Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shigella dysenteriae Sd197 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShigellaDysenteriaeSd197Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidimonasBauzanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candidimonas bauzanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidimonasBauzanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpSk01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumMa2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return alpha proteobacterium MA2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlphaProteobacteriumMa2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusYunnanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusYunnanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusDenitrificansAtcc25259Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus denitrificans ATCC25259 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusDenitrificansAtcc25259Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiNtCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi NT Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiNtCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterAtlanticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter atlanticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterAtlanticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGallisepticumS6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum S6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumS6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioScophthalmiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio scophthalmi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioScophthalmiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbugoLaibachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Albugo laibachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlbugoLaibachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAlkanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia alkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaAlkanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSpTsri0078(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. TSRI0078 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpTsri0078", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhydraLutrisKenyoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enhydra lutris kenyoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnhydraLutrisKenyoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc034a01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC034A01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc034a01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaSpNb41y(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. NB4-1Y graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpNb41y", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumC7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumEtliMimosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli mimosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliMimosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaSpJchs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta sp. JCHS_4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaSpJchs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpV48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. V48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpV48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumGryphiswaldense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum gryphiswaldense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumGryphiswaldense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAmericanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAmericanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicocarpusGriseusUamh5409Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicocarpus griseus UAMH5409 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicocarpusGriseusUamh5409Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusRifietoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus rifietoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusRifietoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBaroniaeDsm16972Jcm13447(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella baroniae DSM 16972 JCM 13447 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBaroniaeDsm16972Jcm13447", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu065(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU065 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu065", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MongoliimonasTerrestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mongoliimonas terrestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MongoliimonasTerrestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpRoot494(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root494 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot494", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GelidibacterAlgensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter algens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GelidibacterAlgensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaTularensisNovicidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis novicida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisNovicidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmpedobacterBrevis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter brevis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterBrevis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpHmp27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. HMP27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpHmp27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumInfirmumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium infirmum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumInfirmumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterSpSk11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. SK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpSk11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxya2full3621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA2FULL3621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya2full3621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisSpNrrlb16309Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis sp. NRRLB16309 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSpNrrlb16309Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovoraxOdorimutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerovorax odorimutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerovoraxOdorimutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkiellaCookevillensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Berkiella cookevillensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BerkiellaCookevillensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbB17019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHB B 17019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbB17019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacteriumRifcsphigho202full3412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPHIGHO202FULL3412 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsphigho202full3412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPLOWO2_01_FULL_45_25b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsplowo201Full4525bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobrancaGottschalkiiDsm13577Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii DSM 13577 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkiiDsm13577Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaSeeligeri12b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria seeligeri 12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaSeeligeri12b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumRavenspurgenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium ravenspurgense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumRavenspurgenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaFrappieri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga frappieri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaFrappieri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp9mfcol31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 9MFCol31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp9mfcol31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSaccharogumia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharogumia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharogumia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpBc26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. BC26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpBc26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaBogorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asaia bogorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsaiaBogorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSpJl2009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. JL2009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MaricaulisSpJl2009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FerrimonasSenticii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferrimonas senticii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerrimonasSenticii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonghaparkiaSpRoot332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yonghaparkia sp. Root332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YonghaparkiaSpRoot332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMikamiiNbrc108933(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mikamii NBRC 108933 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaMikamiiNbrc108933", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasLykanthroporepellensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas lykanthroporepellens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasLykanthroporepellensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisUzonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis uzonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisUzonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpNm58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumBergheiAnka(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium berghei ANKA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumBergheiAnka", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatlockiaMicdadeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tatlockia micdadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TatlockiaMicdadeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaPseudohaemulonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Candida] pseudohaemulonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaPseudohaemulonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeobacteroidesBs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeobacteroides BS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeobacteroidesBs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfatitaleaSpBrhc12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfatitalea sp. BRHc12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfatitaleaSpBrhc12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaOris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella oris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaOris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NodulariaSpumigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nodularia spumigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NodulariaSpumigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpPa01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. PA01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpPa01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusProvencensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus provencensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusProvencensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumFc4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium FC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumFc4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumAquaticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium aquaticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumAquaticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscodesmisNigricansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ascodesmis nigricans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AscodesmisNigricansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerriglobusSaanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus saanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSaanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaEndosymbiontOfAmblyommaAmericanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont of Amblyomma americanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiontOfAmblyommaAmericanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAtypicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium atypicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAtypicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumNigrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum nigrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumNigrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwc24418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWC2_44_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwc24418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasBennonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas bennonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasBennonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaMelaninogenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella melaninogenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMelaninogenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSp831b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 831b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp831b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EchinicolaVietnamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Echinicola vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EchinicolaVietnamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaecibacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caecibacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaecibacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaSpCag351Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:351 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag351Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumNamnetenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Propionibacterium] namnetense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumNamnetenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ReinekeaBlandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Reinekea blandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ReinekeaBlandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa25134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_51_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosakoniaCowaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kosakonia cowanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KosakoniaCowaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPruniNbrc15498Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pruni NBRC 15498 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPruniNbrc15498Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LloydbacteriaBacteriumRifcsphigho202full5013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumDesouzaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium desouzaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumDesouzaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaGlobuliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina globuliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaGlobuliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSingulare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium singulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSingulare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiPvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii PV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiPvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaBronchialisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia bronchialis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaBronchialisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpBv3c26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. BV3C26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpBv3c26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KingellaDenitrificansAtcc33394Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kingella denitrificans ATCC 33394 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KingellaDenitrificansAtcc33394Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpFsc1006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. FSC1006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpFsc1006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaSpUcdthp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. UCDTHP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DietziaSpUcdthp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpHh13063007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. HH130630-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpHh13063007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspSteigerwaltii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. steigerwaltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspSteigerwaltii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacterium13140cm6414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 13_1_40CM_64_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium13140cm6414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaSpL21rpuld2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta sp. L21RPulD2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaSpL21rpuld2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterJuniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter junii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterJuniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpQd031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. qd031 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSpQd031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcanobacteriumHaemolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium haemolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumHaemolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteScgcAaa799D11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AAA799-D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAaa799D11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaOtitidiscaviarumIfm11049Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia otitidiscaviarum IFM 11049 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaOtitidiscaviarumIfm11049Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag345Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:345 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag345Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolysporaHalophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora halophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaHalophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpN3cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. N3C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpN3cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinimicrobiumXinjiangenseDsm19287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense DSM 19287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangenseDsm19287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusAcidocaldariusSusazCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius SUSAZ Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldariusSusazCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpOocEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Ooc Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpOocEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UlvibacterLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ulvibacter litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UlvibacterLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromyxobacterSpRbg166914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. RBG_16_69_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpRbg166914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovibrioAmmonificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermovibrio ammonificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermovibrioAmmonificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTofieldiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tofieldiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTofieldiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYk2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YK2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYk2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumPerfoetensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium perfoetens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPerfoetensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPsychrosaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus psychrosaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPsychrosaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsbacteriaBacteriumGwe25412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edwardsbacteria bacterium GWE25412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdwardsbacteriaBacteriumGwe25412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusGattiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus gattii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptococcusGattiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaRohdeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yersinia rohdei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YersiniaRohdeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifoxyd1full3611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFOXYD1FULL3611 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifoxyd1full3611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesJenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides jensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesJenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumSquillarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium squillarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSquillarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermaceaeBacteriumRa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium RA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumRa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrassicaNapus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brassica napus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrassicaNapus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusIshikawaellaCapsulataMpkobeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ishikawaella capsulata Mpkobe Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusIshikawaellaCapsulataMpkobeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaGlobispora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina globispora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaGlobispora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenatarsenatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenatarsenatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenatarsenatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCatoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas catoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCatoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterPersicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter persicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterPersicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraMurdochiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira murdochii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraMurdochiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquitaleaMagnusoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquitalea magnusonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquitaleaMagnusoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisSubspCapsici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis subsp. capsici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSubspCapsici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaSpOb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. OB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpOb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpA3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpA3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloranaerobacterAzorensisH53214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caloranaerobacter azorensis H53214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaloranaerobacterAzorensisH53214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusVaraniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus varani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusVaraniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TriticumAestivum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Triticum aestivum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TriticumAestivum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp135mfcol51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 135MFCol51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSp135mfcol51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiumFerrooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobium ferrooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiumFerrooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumStbin11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium STbin11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumStbin11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAsperellumCbs43397Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma asperellum CBS 433.97 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichodermaAsperellumCbs43397Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Meiothermus taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MeiothermusTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full6720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL6720 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full6720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PichiaMembranifaciensNrrlY2026Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pichia membranifaciens NRRL Y-2026 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PichiaMembranifaciensNrrlY2026Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpMits9508Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9508 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9508Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumThermoresistibileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium thermoresistibile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumThermoresistibileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonA07hn63Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon A07HN63 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonA07hn63Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelativoransSpJ32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. J32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpJ32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzoarcusSpPa01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. PA01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpPa01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumHimb5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium HIMB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumHimb5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSanguinisSk355Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk355Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidaminococcusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisSpGbsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis sp. GBS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisSpGbsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MariniblastusFucicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mariniblastus fucicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MariniblastusFucicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumBergheiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium berghei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumBergheiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusLuminyensisB10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis B10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensisB10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasPaucimobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas paucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPaucimobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSubtileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium subtile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSubtileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaAerofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella aerofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaAerofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkanindigesIllinoisensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges illinoisensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesIllinoisensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBchCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Bch Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBchCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrasphaeraElongataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera elongata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraElongataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KryptolebiasMarmoratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kryptolebias marmoratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KryptolebiasMarmoratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexistipesSinusarabiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flexistipes sinusarabici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlexistipesSinusarabiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquitaleaMagnusoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquitalea magnusonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquitaleaMagnusoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesMccartyiVsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi VS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyiVsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc13813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC13813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc13813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho2024118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_02_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho2024118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpKrmcy2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KRMCY2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKrmcy2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumKetosireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ketosireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumKetosireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusKuznetsoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus kuznetsovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusKuznetsoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdvenellaKashmirensisWt001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Advenella kashmirensis WT001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdvenellaKashmirensisWt001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterThiogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter thiogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterThiogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NectriaHaematococcaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nectria haematococca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NectriaHaematococcaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwc27318(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWC2_73_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwc27318", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAminicenantesBacteriumRbg166630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_16_66_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg166630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp6717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 67-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerotiniaBorealisF4128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia borealis F-4128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaBorealisF4128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumCarotovorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacteriaceaeBacteriumStrainEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacteriaceae bacterium strain Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacteriaceaeBacteriumStrainEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpCacia14h1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. CACIA14H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpCacia14h1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumActinocoloniiformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium actinocoloniiforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumActinocoloniiformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumRoopkundense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium roopkundense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumRoopkundense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwc26444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWC2_64_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwc26444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedAcidilobusSpCisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Acidilobus sp. CIS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedAcidilobusSpCisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHph0090(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HPH0090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHph0090", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium101Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 101 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium101Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrimonasKyonanensisDsm18153Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrimonas kyonanensis DSM 18153 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FerrimonasKyonanensisDsm18153Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelobacterAcetylenicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter acetylenicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelobacterAcetylenicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaApisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma apis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaApisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinibacterTainanensisDsm15459(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinibacter tainanensis DSM 15459 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinibacterTainanensisDsm15459", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4315bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4315b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4315bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraCorneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calocera cornea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloceraCorneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterRatti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter ratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRatti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTimonianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium timonianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTimonianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaAcidiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa acidiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaAcidiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EuryarchaeotaArchaeonRbg19ftcombo6917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG19FTCOMBO6917 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg19ftcombo6917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonchuraStriataDomesticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lonchura striata domestica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LonchuraStriataDomesticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacaAbyssi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibaca abyssi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacaAbyssi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp63ed372Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 63ED37-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp63ed372Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium maris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasTranslucensPvUndulosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas translucens pv. undulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "XanthomonasTranslucensPvUndulosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosocosmicusOleophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosocosmicus oleophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosocosmicusOleophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumFuchskuhlenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium fuchskuhlense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumFuchskuhlenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiumMinutum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumDoricumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium doricum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumDoricumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSophoraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sophorae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSophoraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpKnhs209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FructobacillusDurionisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus durionis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FructobacillusDurionisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocorpusculumBavaricumDsm4179(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanocorpusculum bavaricum DSM 4179 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanocorpusculumBavaricumDsm4179", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpLc81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. LC81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpLc81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasFuniformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megamonas funiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegamonasFuniformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpCag1963641Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CAG:196_36_41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpCag1963641Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpB72017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7(2017) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpB72017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumSp457220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium sp. 4572_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumSp457220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumPolonicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium polonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumPolonicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpongiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens spongiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpongiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxParadoxusEpsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax paradoxus EPS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxParadoxusEpsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHispalenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hispalense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHispalenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAlcaligenesNbrc14159Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alcaligenes NBRC14159 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlcaligenesNbrc14159Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsplowo202full4516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO202FULL4516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo202full4516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLcm4573Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. LCM 4573 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLcm4573Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpLeaf72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Leaf72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpLeaf72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpKk4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. KK4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpKk4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGlucanolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glucanolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlucanolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag302Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:302 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag302Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumSpF0437Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium sp. F0437 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumSpF0437Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa23418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23418 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf4489Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF4489 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf4489Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_51_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioCholeraeO395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vibrio cholerae O395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VibrioCholeraeO395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterReichenbachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter reichenbachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterReichenbachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeleagrisGallopavo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meleagris gallopavo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeleagrisGallopavo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MurdochiellaVaginalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella vaginalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaVaginalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumSpCf468Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF468 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf468Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinococcusLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinococcus luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinococcusLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumDenitrificans1nes1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium denitrificans 1NES1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumDenitrificans1nes1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaAraiiNbrc100433Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gordonia araii NBRC 100433 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GordoniaAraiiNbrc100433Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumIntermedium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum intermedium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumIntermedium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFaecichinchillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides faecichinchillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFaecichinchillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_12_FULL_60_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo212Full6015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpOv329Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OV329 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOv329Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CastellaniellaCaeniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Castellaniella caeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CastellaniellaCaeniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGwf16617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium GWF1_66_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGwf16617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SteccherinumOchraceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Steccherinum ochraceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SteccherinumOchraceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusPhoeniculicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus phoeniculicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPhoeniculicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensisDsm45107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis DSM 45107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensisDsm45107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZobelliaUliginosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zobellia uliginosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZobelliaUliginosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaHospitaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia hospita Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaHospitaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSp83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. 83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSp83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocGasicomitatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leuconostoc gasicomitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeuconostocGasicomitatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumBeijerinckii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum beijerinckii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumBeijerinckii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecobacterDebontiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prosthecobacter debontii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProsthecobacterDebontiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_43_32b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4332bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_52b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4152b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTropiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tropici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTropiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiusActivusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius activus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusActivusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaInohanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia inohanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaInohanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PortnoybacteriaBacteriumRifcsplowo201full4311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPLOWO201FULL4311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsplowo201full4311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumGw2011Gwb1378Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium GW2011_GWB1_37_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumGw2011Gwb1378Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFCSPHIGHO2_02_FULL_43_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifcsphigho202Full4313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BavariicoccusSeileriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bavariicoccus seileri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BavariicoccusSeileriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalonomonasRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malonomonas rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalonomonasRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiBNctc9691Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi B NCTC9691 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiBNctc9691Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SneathiaSanguinegensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sneathia sanguinegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SneathiaSanguinegensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpR575Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. R57-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpR575Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf99Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf99 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf99Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrycteropusAfer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Orycteropus afer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OrycteropusAfer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DebaryomycesHansenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Debaryomyces hansenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DebaryomycesHansenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4924 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arthritidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaArthritidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinovumAlgicolaDg898Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinovum algicola DG 898 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinovumAlgicolaDg898Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumPropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum propionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumPropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsplowo201full5020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPLOWO201FULL5020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsplowo201full5020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergomycesPasteurianusEp9510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Ep9510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EmergomycesPasteurianusEp9510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobiumGracileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium gracile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobiumGracileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpT3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. T3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpT3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0074141Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0074141 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0074141Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maribacter orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaribacterOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraProfundimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira profundimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraProfundimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusCaldusSm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus caldus SM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusCaldusSm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shimia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShimiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycomycesBlakesleeanusNrrl1555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus NRRL 1555(-) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanusNrrl1555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBciso3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Bciso3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBciso3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaDentasini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella dentasini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDentasini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp17376Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 17376 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSp17376Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpAcv2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. ACV-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpAcv2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumAnthropi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ochrobactrum anthropi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OchrobactrumAnthropi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsPolyrhachisFurcataBcc54312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps polyrhachis-furcata BCC 54312 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsPolyrhachisFurcataBcc54312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumCg1023722Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium CG1023722 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumCg1023722Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSchleiferiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus schleiferi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSchleiferiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumTrifoliiCb782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii CB782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiCb782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaBissettiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia bissettii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaBissettiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumParaoxydans77mftsu32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans 77MFTsu32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydans77mftsu32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnisphaeraAggregansDsm17230Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans DSM 17230 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IgnisphaeraAggregansDsm17230Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AneurinibacillusSpXh2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus sp. XH2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusSpXh2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusStelliferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus stellifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusStelliferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelusDromedarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Camelus dromedarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CamelusDromedarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaceaeBacteriumAt8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthellaceae bacterium AT8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaceaeBacteriumAt8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromatiumPalustreCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromatium palustre Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromatiumPalustreCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAsf502Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ASF502 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAsf502Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacaceaeArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo212full4526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO212FULL4526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo212full4526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaAfricanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta africana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaAfricanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhormidiumTenueCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phormidium tenue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhormidiumTenueCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquilegiaCoerulea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquilegia coerulea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquilegiaCoerulea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAbietaniphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas abietaniphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAbietaniphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKirkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia kirkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaKirkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasGingivicanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas gingivicanis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasGingivicanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full3725(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL3725 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full3725", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZhanjiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zhanjiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasZhanjiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogemmatisporaOnikobensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora onikobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaOnikobensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonScgcAaa007o23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA007O23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa007o23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiArupensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella vinsonii arupensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaVinsoniiArupensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAminophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium aminophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAminophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasUreilytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas ureilytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasUreilytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBicirculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bicirculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBicirculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumGa0077560Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium Ga0077560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumGa0077560Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpKnhs214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyrobacterNeustonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter neustonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterNeustonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PestalotiopsisFiciW1061Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pestalotiopsis fici W106-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PestalotiopsisFiciW1061Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvensLd2006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens LD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvensLd2006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAng1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAng1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifoxyd1full3611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFOXYD1FULL3611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifoxyd1full3611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaliobacillusRyukyuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus ryukyuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusRyukyuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmoebophilusSp3638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus sp. 3638 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusSp3638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsMilitarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps militaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CordycepsMilitarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaOblongaNbrc102422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella oblonga NBRC 102422 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoraxellaOblongaNbrc102422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtomycesLactucaedebilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Protomyces lactucaedebilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProtomycesLactucaedebilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerohalosphaeraLusitanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerohalosphaera lusitana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerohalosphaeraLusitanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasZehnderiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas zehnderi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasZehnderiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf176(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf176 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf176", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYB1_FULL_54_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelissococcusPlutoniusAtcc35311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Melissococcus plutonius ATCC 35311 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MelissococcusPlutoniusAtcc35311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpDnf00869Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. DNF00869 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpDnf00869Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MameliellaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mameliella alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MameliellaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBica18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpisthorchisViverriniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opisthorchis viverrini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpisthorchisViverriniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AurantimonasSp22ii1619iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. 22II-16-19i Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSp22ii1619iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaNanhaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanicola nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanicolaNanhaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusHamelinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halococcus hamelinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalococcusHamelinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusSpY3961(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. Y3961 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpY3961", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacterium13220cm2648(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium 13220CM2648 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacterium13220cm2648", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfMortierellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Mortierella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfMortierellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FulvivirgaImtechensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fulvivirga imtechensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FulvivirgaImtechensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumThoeniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium thoenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumThoeniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanicolaGranulosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanicola granulosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanicolaGranulosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpYqh10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. YQH10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShewanellaSpYqh10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1995Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1995 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1995Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PocilloporaDamicornisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pocillopora damicornis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PocilloporaDamicornisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrococcusLahaulensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus lahaulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrococcusLahaulensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaAcidipaludisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia acidipaludis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaAcidipaludisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchizosaccharomycesJaponicusYfs275Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Schizosaccharomyces japonicus yFS275 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SchizosaccharomycesJaponicusYfs275Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcusMaripaludisC7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TolypocladiumOphioglossoidesCbs100239Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tolypocladium ophioglossoides CBS 100239 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TolypocladiumOphioglossoidesCbs100239Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaCorrodensAtcc23834Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens ATCC23834 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EikenellaCorrodensAtcc23834Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatorialesCyanobacteriumCg2304421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_44_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMimosarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mimosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMimosarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumRosaNbrc15208(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium rosa NBRC 15208 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumRosaNbrc15208", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumIntestinaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium intestinale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIntestinaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalicatenaFissicatenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena fissicatena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaFissicatenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumVeterum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium veterum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumVeterum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHorikoshii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horikoshii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusHorikoshii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaDioxanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia dioxanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaDioxanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnionYellowsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Onion yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OnionYellowsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscodesmisNigricansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ascodesmis nigricans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AscodesmisNigricansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaBacilliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria bacilliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaBacilliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_01_FULL_40_98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho201Full4098Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full3911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumGenomosp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosGrunniensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bos grunniens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BosGrunniensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermaceaeBacteriumRaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium RA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumRaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichoplaxAdhaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxAdhaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBoevreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella boevrei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaBoevreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSpH105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterLongobardusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter longobardus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterLongobardusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterEthanolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter ethanolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterEthanolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumGalatheae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium galatheae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumGalatheae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilvibacteriumBohemicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Silvibacterium bohemicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SilvibacteriumBohemicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaFidelisAtccBaa318(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella fidelis ATCC BAA-318 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShewanellaFidelisAtccBaa318", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpIcm39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. ICM39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpIcm39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BarnesiellaIntestinihominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Barnesiella intestinihominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BarnesiellaIntestinihominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumCorienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum coriense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorubrumCorienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulforhopalusSingaporensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulforhopalus singaporensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulforhopalusSingaporensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusSpRs1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus sp. RS1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusSpRs1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncaeNbrc108251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia speluncae NBRC 108251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaSpeluncaeNbrc108251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasGeothermicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas geothermicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGeothermicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TremellaMesentericaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tremella mesenterica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TremellaMesentericaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifoxyd2full4310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD2FULL4310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd2full4310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpY412mc10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Y412MC10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpY412mc10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifoxyb12full359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYB12FULL359 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyb12full359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumM14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium M14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumM14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatiglansAniliniDsm4660Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini DSM 4660 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfatiglansAniliniDsm4660Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimonasFerrugineaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrimonasFerrugineaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonadaceaeBacteriumT822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonadaceae bacterium T82-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonadaceaeBacteriumT822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMacrocephaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina macrocephali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMacrocephaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusFicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus ficus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusFicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParafarraginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parafarraginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParafarraginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaSpHn41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. HN-41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpHn41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStoquefichusSpSb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. SB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpSb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioMagneticusRs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus RS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusRs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixMariniflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix mariniflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacinutrixMariniflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCuneatusDsm11391(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus DSM 11391 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatusDsm11391", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_02_FULL_40_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo202Full4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusKawachiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus kawachii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusKawachiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanibulbusIndolifex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanibulbus indolifex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanibulbusIndolifex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusConstellatusPharyngisSk1060Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus constellatus pharyngis SK1060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusConstellatusPharyngisSk1060Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermomonasFuscaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermomonasFuscaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolactibacillusAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:524 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXpb1003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XPB1003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXpb1003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumLongumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium longum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLongumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumE1Bont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum E1 BoNT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumE1Bont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilactibacillusSp15rCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinilactibacillus sp. 15R Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinilactibacillusSp15rCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SusScrofaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sus scrofa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SusScrofaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSpMh3r31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MH3R3-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMh3r31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolactobacillusTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptacidiphilusOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentimicrobiumSaccharophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentimicrobium saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentimicrobiumSaccharophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrdosporaColligataOc4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ordospora colligata OC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OrdosporaColligataOc4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSp9143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. 9143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSp9143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PajaroellobacterAbortibovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pajaroellobacter abortibovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PajaroellobacterAbortibovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RufibacterRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil777(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil777 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil777", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpRifoxyb12full359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYB12FULL359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyb12full359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRbg13408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_13_40_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg13408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSaccharolyticumK10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium saccharolyticum K10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSaccharolyticumK10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaEpimycesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capronia epimyces Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaproniaEpimycesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa23610(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA23610 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa23610", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSaskatchewanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium saskatchewanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSaskatchewanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpPstaah124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. PsTaAH124 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpPstaah124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusItalicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus italicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusItalicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusGuaymasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus guaymasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusGuaymasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpB7740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. B7740 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpB7740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAlbensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella albensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAlbensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUrhb0044Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. URHB0044 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUrhb0044Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFragilisYch46Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis YCH46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisYch46Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumThermophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium thermophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumThermophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypholomaSublateritiumFd334Ss4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium FD-334 SS-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HypholomaSublateritiumFd334Ss4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCinaediPagu611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter cinaedi PAGU611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterCinaediPagu611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlternariaAlternataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alternaria alternata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlternariaAlternataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacrophominaPhaseolinaMs6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina MS6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MacrophominaPhaseolinaMs6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLausannensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lausannensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLausannensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiumSpBvorr106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudanabaenaSpPcc7367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC7367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc7367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FabibacterMisakiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fabibacter misakiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FabibacterMisakiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KerfeldbacteriaBacteriumRifoxya2full3824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFOXYA2FULL3824 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifoxya2full3824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpFth1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. FTH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DehalobacterSpFth1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaNigrescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella nigrescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaNigrescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonBieneusiH348Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi H348 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusiH348Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptostreptococcaceaeBacteriumVa2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium VA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumVa2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelampsoraLaricipopulinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melampsora laricipopulina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelampsoraLaricipopulinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsphigho202full4528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4528 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumCuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRadiopugnans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces radiopugnans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRadiopugnans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSpUncmf366tsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF366Tsu5.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf366tsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_36_54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3654Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumFrigidariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasMontiporaeCl33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Endozoicomonas montiporae CL-33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndozoicomonasMontiporaeCl33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaFlocculosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudozyma flocculosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudozymaFlocculosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosynechococcusElongatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermosynechococcus elongatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermosynechococcusElongatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphaerulinaMusiva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphaerulina musiva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphaerulinaMusiva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocMesenteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc mesenteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeuconostocMesenteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumRubrisubalbicansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum rubrisubalbicans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumRubrisubalbicansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp1nla3eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 1NLA3E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSp1nla3eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobifidaCellulosilyticaTb100(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermobifida cellulosilytica TB100 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermobifidaCellulosilyticaTb100", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpWsf3629(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. WSF 3629 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpWsf3629", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_02_35_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo2023512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterRudisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter rudis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterRudisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeosynechococcusSphagnicolaSy1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola sy1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicolaSy1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusMontanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus montanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMontanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo201full4810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO201FULL4810 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo201full4810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_12_FULL_38_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo212Full3822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PodosporaAnserina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Podospora anserina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PodosporaAnserina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0077534Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077534 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077534Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuribacterMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muribacter muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuribacterMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpLf2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. LF2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpLf2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarithrixSpCanyon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marithrix sp. Canyon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarithrixSpCanyon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaShandongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora shandongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaShandongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo202full4011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO202FULL4011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo202full4011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomicrobiumGlaciei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium glaciei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumGlaciei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumAlbumArsef1941Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Metarhizium album ARSEF 1941 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MetarhiziumAlbumArsef1941Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DictyoglomusTurgidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dictyoglomus turgidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DictyoglomusTurgidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCc53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CC53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCc53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumFournieriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium fournierii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFournieriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndozoicomonasAscidiicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas ascidiicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasAscidiicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioMagneticusIfrc170(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus IFRC170 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusIfrc170", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProfftellaArmatura(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Profftella armatura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProfftellaArmatura", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesTurgidiscabiesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces turgidiscabies Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTurgidiscabiesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NakamurellaPanacisegetisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella panacisegetis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NakamurellaPanacisegetisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudozymaHubeiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudozyma hubeiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudozymaHubeiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfobacillusThermosulfidooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus thermosulfidooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusThermosulfidooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRbg13408(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_13_40_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg13408", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumCellulosolvens6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Eubacterium cellulosolvens 6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EubacteriumCellulosolvens6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisporaArenicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salinispora arenicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalinisporaArenicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumAcetoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum acetoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumAcetoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterLapidariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter lapidarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterLapidariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HylemonellaGracilisNiagaraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis Niagara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisNiagaraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumHimb11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HIMB11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHimb11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RouxiellaBadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rouxiella badensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RouxiellaBadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporobacterTermitidisDsm10068(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporobacter termitidis DSM 10068 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporobacterTermitidisDsm10068", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassomonasViridansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassomonas viridans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassomonasViridansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerohalosphaeraLusitanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerohalosphaera lusitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerohalosphaeraLusitanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumBdw918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BDW918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBdw918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumRifcsphigho212full6614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO212FULL6614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho212full6614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiBjab07104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii BJAB07104 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiBjab07104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiorhodococcusDrewsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiorhodococcus drewsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiorhodococcusDrewsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSpLeaf354Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. Leaf354 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSpLeaf354Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaedimonasVaricaedensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caedimonas varicaedens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaedimonasVaricaedensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaEchinicomitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga echinicomitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaEchinicomitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnobacterSpCaciam66h1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. CACIAM 66H1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpCaciam66h1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteobacteriaBacteriumCag495Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium CAG:495 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumCag495Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpRoot413d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root413D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot413d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOblongaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella oblonga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOblongaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuncoHyemalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Junco hyemalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JuncoHyemalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont of Epithemia turgida isolate EtSB Lake Yunoko Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiontOfEpithemiaTurgidaIsolateEtsbLakeYunokoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumDefluviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium defluvii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDefluviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesTurgidiscabiesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces turgidiscabies Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTurgidiscabiesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRapamycinicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces rapamycinicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRapamycinicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpX15166bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. X15-166B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpX15166bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumBrhc0Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium BRHc0 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumBrhc0Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumW1481(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum W1481 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumW1481", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptuniibacterCaesariensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter caesariensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterCaesariensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeogobiusMelanostomus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neogobius melanostomus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeogobiusMelanostomus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSancti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sancti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSancti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioLogeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio logei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliivibrioLogeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGenitaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma genitalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGenitaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_01_FULL_55_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho201Full5524", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot1257Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root1257 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot1257Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumCarotovorumOdoriferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum odoriferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumOdoriferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeribacteriaBacteriumRifcsplowo212full5515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO212FULL5515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo212full5515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacterLucknowensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter lucknowensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacterLucknowensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMusc93(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc93", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full3511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL3511 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full3511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ToxoplasmaGondiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Toxoplasma gondii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ToxoplasmaGondiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KineococcusRadiotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kineococcus radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KineococcusRadiotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumFrediiHh103(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii HH103 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiHh103", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpKiost1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. KIOST1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpKiost1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpBis7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. BIS7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpBis7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPolynesienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium polynesiense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolynesienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCattleyaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cattleya Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCattleyaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FormosaSpHel3a148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel3A148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel3a148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TidjanibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tidjanibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TidjanibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaHyalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia hyalina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LampropediaHyalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBs2016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BS-2016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBs2016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_44_15c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4415cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumChlorophenolicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumChlorophenolicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeophocaenaAsiaeorientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpHl48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophusFodinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophus fodinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophusFodinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumCalidifontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum calidifontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumCalidifontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_50_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HesseltinellaVesiculosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hesseltinella vesiculosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HesseltinellaVesiculosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellvibrioSpPealriver(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellvibrio sp. pealriver graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellvibrioSpPealriver", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterCarbinolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter carbinolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelobacterCarbinolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMexicana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia mexicana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaMexicana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf25093(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_50_93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25093", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumMiluonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium miluonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumMiluonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSmegmatisJs623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium smegmatis JS623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumSmegmatisJs623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpScgcAaa160p02Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. SCGC AAA160P02 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpScgcAaa160p02Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaRapaSubspPekinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica rapa subsp. pekinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrassicaRapaSubspPekinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusChondroitinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus chondroitinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusChondroitinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RosenbergiellaNectarea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rosenbergiella nectarea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RosenbergiellaNectarea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaNitratireducenticrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga nitratireducenticrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaNitratireducenticrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPestisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia pestis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaPestisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKisonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKisonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobialesBacteriumKi4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermomicrobiales bacterium KI4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermomicrobialesBacteriumKi4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaDumasianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dumasiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDumasianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RomboutsiaSpMt17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia sp. MT17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaSpMt17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraFaineiSerovarHurstbridgeStrBut6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira fainei serovar Hurstbridge str. BUT 6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraFaineiSerovarHurstbridgeStrBut6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasGardneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas gardneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasGardneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesGoldsteiniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides goldsteinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesGoldsteiniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumGa0077535Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium Ga0077535 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGa0077535Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4393Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 43-93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4393Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrettanomycesNaardenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces naardenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesNaardenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpHix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. HIX graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpHix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumJannaschiiDsm6295Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii DSM 6295 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschiiDsm6295Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediculusHumanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediculus humanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediculusHumanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter syzygii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSyzygii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TangfeifaniaDiversioriginumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tangfeifania diversioriginum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TangfeifaniaDiversioriginumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaSp111n121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dietzia sp. 111N12-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DietziaSp111n121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifoxyd12full5919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYD12FULL5919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyd12full5919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioSpMebic08052Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sp. MEBiC08052 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioSpMebic08052Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkiellaAquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella aquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaAquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpRoot1433d1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root1433D1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot1433d1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraCyclicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira cyclica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraCyclicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumAc2029Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2029 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2029Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNe2001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NE2001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNe2001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacebacteriaBacteriumRifcsphigho201full4610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillaceaeBacteriumG5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium G5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumG5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpH14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. H14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpH14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasBoliviensisLc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas boliviensis LC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasBoliviensisLc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpDsiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Dsi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpDsiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumMs4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium MS4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumMs4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSalivaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella salivae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSalivaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusHoagiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus hoagii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusHoagiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumPygmaeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium pygmaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumPygmaeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanococcusKocuriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus kocurii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusKocuriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaJiangningensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga jiangningensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaJiangningensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusTaiwanensisDsm18679(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis DSM 18679 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensisDsm18679", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavisolibacterGinsengisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavisolibacter ginsengisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavisolibacterGinsengisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaSulfidovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga sulfidovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophagaSulfidovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacteralesBacterium6714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacterales bacterium 67-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacteralesBacterium6714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StigmatellaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stigmatella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StigmatellaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinotignumSchaaliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum schaalii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinotignumSchaaliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpPh10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. PH10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpPh10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TurneriellaParva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Turneriella parva graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TurneriellaParva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaSpEc08061901Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia sp. EC080619-01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaSpEc08061901Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsCamponotirufipedis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps camponotirufipedis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsCamponotirufipedis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusNaphthalenovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus naphthalenovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNaphthalenovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanohalophilusSp2gbenrichEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus sp. 2GBenrich Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusSp2gbenrichEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbyssisolibacterFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Abyssisolibacter fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbyssisolibacterFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamponotusFloridanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Camponotus floridanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CamponotusFloridanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumLipoferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum lipoferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumLipoferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZygosaccharomycesRouxiiCbs732(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zygosaccharomyces rouxii CBS 732 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZygosaccharomycesRouxiiCbs732", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubidibacterLacunaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rubidibacter lacunae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RubidibacterLacunaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aerococcus viridans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AerococcusViridansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumHalorespiransDsm13726Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfurospirillum halorespirans DSM 13726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfurospirillumHalorespiransDsm13726Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EutremaSalsugineumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eutrema salsugineum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EutremaSalsugineumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterCryoconitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter cryoconitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterCryoconitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SorexAraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sorex araneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SorexAraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSp6717Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 67-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp6717Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesSpJdfr56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full487Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL487 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full487Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoschusMoschiferusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moschus moschiferus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoschusMoschiferusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_44_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaAfricana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania africana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaAfricana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterSalsiciusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter salsicius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterSalsiciusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag793(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:793 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag793", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusViolaceofuscusCbs115571Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus CBS 115571 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscusCbs115571Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdwardsiellaTarda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella tarda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaTarda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSelenitireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus selenitireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSelenitireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumArgentoratenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium argentoratense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumArgentoratenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpJ54(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. J54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpJ54", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpAi1a2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ai1a2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAi1a2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PneumocystisMurinaB123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis murina B123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PneumocystisMurinaB123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProsthecobacterDebontii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prosthecobacter debontii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProsthecobacterDebontii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaDrilacisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niabella drilacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiabellaDrilacisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YarrowiaLipolyticaClib122(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica CLIB122 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YarrowiaLipolyticaClib122", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo212full6621Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO212FULL6621 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo212full6621Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EdhazardiaAedisUsnm41457Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Edhazardia aedis USNM 41457 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EdhazardiaAedisUsnm41457Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTanneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tanneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusTanneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpRoot335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTayloriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella taylorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaTayloriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrocoleusSpPcc7113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus sp. PCC7113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusSpPcc7113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidobacteriumPennivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium pennivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumPennivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSp20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium sp. 20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSp20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialocephalaScopiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala scopiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaScopiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu089Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU089 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu089Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumEnshienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium enshiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumEnshienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusOzensisDsm23829Jcm17196Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ozensis DSM 23829 JCM 17196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOzensisDsm23829Jcm17196Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaAnanassaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila ananassae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaAnanassaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFioriniaePj7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae PJ7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFioriniaePj7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaBannensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia bannensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaBannensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HepatobacterPenaeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hepatobacter penaei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HepatobacterPenaeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSubflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria subflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSubflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteocatellaSphenisciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteocatella sphenisci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteocatellaSphenisciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchangiumGephyraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archangium gephyra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchangiumGephyraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusSpHmp52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. HMP52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpHmp52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaeromyxobacterSpFw1095Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter sp. Fw1095 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterSpFw1095Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumShimoideiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shimoidei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShimoideiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellalikeEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coxiellalike endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoxiellalikeEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar86ClusterBacteriumBacl1Mag120820Bin45(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium BACL1 MAG-120820-bin45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumBacl1Mag120820Bin45", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpV450Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. V450 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpV450Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaematospirillumJordaniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haematospirillum jordaniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaematospirillumJordaniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpB98Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. B9-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpB98Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBouchesdurhonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus bouchesdurhonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBouchesdurhonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSaudimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter saudimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSaudimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpE3251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsplowo201full4826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO201FULL4826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo201full4826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaInconspicua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Candida] inconspicua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidaInconspicua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaRettgeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia rettgeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRettgeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelistegaSpMc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelistega sp. MC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelistegaSpMc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylibiumPetroleiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylibium petroleiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylibiumPetroleiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterAnodireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacter anodireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacterAnodireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaEndosymbiontOfOrnithodorosMoubataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella endosymbiont of Ornithodoros moubata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiontOfOrnithodorosMoubataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaSpPbc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PBC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPbc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusFermentansJbw45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus fermentans JBW45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PelosinusFermentansJbw45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0087(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0087 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0087", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasAltamirensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas altamirensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasAltamirensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaFungorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia fungorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaFungorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumXenopi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium xenopi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumXenopi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPosidonica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas posidonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPosidonica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaStagnalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia stagnalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaStagnalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaSpCag351(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:351 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag351", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaGonorrhoeaeFa1090Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae FA 1090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeaeFa1090Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedTermiteGroup1BacteriumPhylotypeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Termite group 1 bacterium phylotype Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedTermiteGroup1BacteriumPhylotypeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VavraiaCulicisSubspFloridensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vavraia culicis subsp. floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VavraiaCulicisSubspFloridensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGorillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGorillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_43_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4327Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasHalodenitrificansDsm735(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas halodenitrificans DSM 735 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasHalodenitrificansDsm735", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VagococcusLutraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vagococcus lutrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VagococcusLutraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesObesi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes obesi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesObesi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_02_FULL_38_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag1219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full5017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL5017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full5017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesStercorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides stercoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesStercorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMurrayi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus murrayi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMurrayi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasNasturtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas nasturtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasNasturtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMaculosaOt289Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella maculosa OT 289 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaMaculosaOt289Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaAchromogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida achromogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaAchromogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTestisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus testis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusTestisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaSpiritensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella spiritensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaSpiritensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4717(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4717 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4717", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12W3110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 W3110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12W3110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasGranuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas granuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasGranuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNigerEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus niger Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusNigerEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpMd25aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. MD25a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpMd25aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChondrusCrispusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chondrus crispus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChondrusCrispusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraYegresiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraYegresiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacterium284Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium284Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JorgensenbacteriaBacteriumRifcsphigho202full4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPHIGHO202FULL4520 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsphigho202full4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpLeaf395Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf395 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf395Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKimchicusJcm15530(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kimchicus JCM 15530 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKimchicusJcm15530", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NdongobacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ndongobacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NdongobacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumSpPcc7702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. PCC7702 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpPcc7702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaIchthyophagaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WallemiaIchthyophagaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiSe8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii SE8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiSe8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusPropionicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisMaydisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris maydis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BipolarisMaydisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaTetrasperma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeurosporaTetrasperma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNku1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. NkU-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNku1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioDesulfuricansNd132(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ND132 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansNd132", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YangiaSpCcbmm3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yangia sp. CCBMM3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YangiaSpCcbmm3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAtribacteriaBacteriumCg2303313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Atribacteria bacterium CG2_30_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAtribacteriaBacteriumCg2303313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAlkylphenoliaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas alkylphenolia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasAlkylphenoliaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag440Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:440 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag440Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusZopfiiNbrc100606Jcm9919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus zopfii NBRC 100606 JCM 9919 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusZopfiiNbrc100606Jcm9919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktothrixTepidaPcc9214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix tepida PCC 9214 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlanktothrixTepidaPcc9214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelistegaSpMc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelistega sp. MC2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelistegaSpMc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiribacterCurvatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter curvatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiribacterCurvatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaDsm7271(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea DSM7271 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaDsm7271", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaLacteaDsm19367Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nakamurella lactea DSM 19367 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NakamurellaLacteaDsm19367Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesDurhamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces durhamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDurhamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumCamembertiFm013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Penicillium camemberti FM 013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PenicilliumCamembertiFm013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumRbg19ftcombo3514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium RBG19FTCOMBO3514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumRbg19ftcombo3514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloplasmaContractileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloplasma contractile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloplasmaContractileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpCs1bsmeth3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1BSMeth3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1bsmeth3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBaratiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium baratii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBaratiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonDl31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon DL31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonDl31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumArsenijeviciiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium arsenijevicii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumArsenijeviciiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot1220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1220 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaAurantifoliaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma aurantifolia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaAurantifoliaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EggerthiaCatenaformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthia catenaformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthiaCatenaformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiptonbacteriaBacteriumGwb1496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium GWB1_49_6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumGwb1496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumGwc23926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWC2_39_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwc23926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full3914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL3914 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full3914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpGxs13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXS13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxs13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArabidopsisLyrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis lyrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisLyrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KangiellaGeojedonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kangiella geojedonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KangiellaGeojedonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliopsisZonataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicilliopsis zonata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliopsisZonataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacteriumRbg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaAlgicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga algicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaAlgicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolectaIrregularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neolecta irregularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeolectaIrregularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumKb13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium KB13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumKb13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHokkaidonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpLc11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LC11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLc11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAsiaticusPsy62(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus psy62 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusPsy62", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusSanaruensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sanaruensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSanaruensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerroplasmaAcidiphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ferroplasma acidiphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FerroplasmaAcidiphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRaac3tm71(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RAAC3TM71 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRaac3tm71", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscirickettsiaSalmonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piscirickettsia salmonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PiscirickettsiaSalmonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UstilagoMaydisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ustilago maydis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UstilagoMaydisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidibacillusDecaturensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidibacillus decaturensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidibacillusDecaturensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwe24668Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWE2_46_68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwe24668Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumMassiliodielmoenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium massiliodielmoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMassiliodielmoenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterBorealisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter borealis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PedobacterBorealisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiCeIsolateThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii CE isolate Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiCeIsolateThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSpMc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. MC1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpMc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaSpMc24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. Mc24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSpMc24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSchoenbuchensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaSchlechtendaliaChinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Schlechtendalia chinensis) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaSchlechtendaliaChinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogulbenkianiaSubflavaDsm22618(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava DSM 22618 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflavaDsm22618", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAustralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus australis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAustralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CobetiaCrustatorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cobetia crustatorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CobetiaCrustatorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimonasFerrugineaDsm30193Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea DSM 30193 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TerrimonasFerrugineaDsm30193Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus jeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacillusJeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSydowii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sydowii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSydowii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterChlorophenolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter chlorophenolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterChlorophenolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldimonasTaiwanensisNbrc104434Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis NBRC 104434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensisNbrc104434Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesFragilisNctc9343Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides fragilis NCTC 9343 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesFragilisNctc9343Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelatococcusDaeguensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelatococcus daeguensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelatococcusDaeguensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSp7136(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. 71-36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSp7136", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumHerbicidovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium herbicidovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumHerbicidovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumOxydansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium oxydans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumOxydansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrateuriaSpSoil773Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frateuria sp. Soil773 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrateuriaSpSoil773Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpartinae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas spartinae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpartinae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumGa0077548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077548 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzohydromonasAustralicaDsm1124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Azohydromonas australica DSM 1124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AzohydromonasAustralicaDsm1124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpAntb3c2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. ANTB3C2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAntb3c2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusInfantisNrrlB14911Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus infantis NRRL B-14911 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusInfantisNrrlB14911Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasSpNm166Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. Nm166 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpNm166Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasCampaniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas campaniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasCampaniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WalczuchellaMonophlebidarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Walczuchella monophlebidarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WalczuchellaMonophlebidarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CutibacteriumAvidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cutibacterium avidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CutibacteriumAvidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlginolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alginolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlginolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMelainabacteriaBacteriumRifoxya2Full329Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFOXYA2_FULL_32_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifoxya2Full329Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpWg5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. WG5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpWg5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_01_FULL_39_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho201Full399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc13813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC1_38_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc13813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteraceaeBacteriumAt5844Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacteraceae bacterium AT5844 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacteraceaeBacteriumAt5844Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachyspiraSpCag484Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brachyspira sp. CAG:484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrachyspiraSpCag484Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioplocaIngrica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioploca ingrica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioplocaIngrica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumRuminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ruminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumRuminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloceanibacterSuperfactusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter superfactus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterSuperfactusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinarimonadaceaeBacteriumHl109(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonadaceae bacterium HL-109 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinarimonadaceaeBacteriumHl109", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferYueqingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer yueqingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferYueqingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSpMarseillep2143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus sp. MarseilleP2143 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSpMarseillep2143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedPoseidonialesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Poseidoniales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedPoseidonialesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusAmylolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusAmylolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesNourseiAtcc11455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces noursei ATCC 11455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesNourseiAtcc11455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconobacterJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeogobiusMelanostomusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neogobius melanostomus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeogobiusMelanostomusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaMortivallisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora mortivallis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaMortivallisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrackiellaOedipodisDsm13743Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brackiella oedipodis DSM 13743 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrackiellaOedipodisDsm13743Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaeroarchaeumSulfurireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaeroarchaeum sulfurireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaeroarchaeumSulfurireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat28004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-28004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat28004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpP5119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. P5-119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpP5119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp4414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 44_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMooreiF0204(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei F0204 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiF0204", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaCohaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lampropedia cohaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LampropediaCohaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacteriumKbs708Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium KBS708 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumKbs708Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrococcusLahaulensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrococcus lahaulensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrococcusLahaulensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioProteolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio proteolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioProteolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSpRim28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. Rim28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSpRim28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full3313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL3313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full3313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusProtochlamydiaNaegleriophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Protochlamydia naegleriophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusProtochlamydiaNaegleriophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaPneumoniaeAr39(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae AR39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeAr39", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurivirgaCaldicuraliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurivirga caldicuralii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurivirgaCaldicuraliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot1203(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root1203 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot1203", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaZeaeDsm19591Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Runella zeae DSM 19591 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RunellaZeaeDsm19591Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LatescibacterAnaerobius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Latescibacter anaerobius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LatescibacterAnaerobius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobiArchaeonJdfr42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Archaeoglobi archaeon JdFR-42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArchaeoglobiArchaeonJdfr42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsplowo202full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO202FULL4510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo202full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaMaltosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida maltosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaMaltosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMrmd2014Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MRMD2014 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMrmd2014Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpO77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. O-77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpO77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontStrain(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont strain graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontStrain", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioBacteriovorusStrTiberiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus str. Tiberius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusStrTiberiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSp303mfcol52Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. 303MFCol52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSp303mfcol52Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumJoostei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium joostei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJoostei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0386Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0386 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0386Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaHaemolyticaM42548Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mannheimia haemolytica M42548 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MannheimiaHaemolyticaM42548Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaThermophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaThermophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoflexibacterRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoflexibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoflexibacterRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchlesneriaPaludicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schlesneria paludicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchlesneriaPaludicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaceaeBacterium15036681Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium 15-036681 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacterium15036681Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaCoubleae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia coubleae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaCoubleae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromatiumPalustreEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromatium palustre Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromatiumPalustreEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 63-22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeriolaLalandiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Seriola lalandi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SeriolaLalandiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumSaccharolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium saccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumSaccharolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenophoraTriticiRepentisPt1cBfpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pyrenophora tritici-repentis Pt-1C-BFP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PyrenophoraTriticiRepentisPt1cBfpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRbg16439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16439 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusDestructans2063121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus destructans 20631-21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusDestructans2063121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaPolyisoprenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia polyisoprenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaPolyisoprenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesJohnsonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides johnsonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesJohnsonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterZhejiangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter zhejiangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterZhejiangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumLuteumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium luteum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLuteumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomeilibacteriaBacteriumRifcsplowo201full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO201FULL4510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo201full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NiabellaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niabella soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiabellaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RyanbacteriaBacteriumRifcsplowo202full4511c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPLOWO202FULL4511c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsplowo202full4511c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpNies3755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-3755 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies3755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StrongyloidesPapillosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Strongyloides papillosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StrongyloidesPapillosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumCag3125820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CAG:312_58_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCag3125820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusMeridieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus meridiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusMeridieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDurus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus durus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDurus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxyd1full5531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYD1FULL5531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxyd1full5531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusKuroshimensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus kuroshimensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusKuroshimensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesDirusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles dirus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesDirusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaceaeBacteriumTaa166(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium TAA166 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumTaa166", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BotrytisEllipticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Botrytis elliptica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BotrytisEllipticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serratia marcescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerratiaMarcescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinimicrobiumRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa024d14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA024D14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa024d14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrodermaBenhamiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthroderma benhamiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrodermaBenhamiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSp6654Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. 66-54 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSp6654Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterButzleriEd1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri ED1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriEd1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag609Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:609 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag609Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpElb17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ELB17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpElb17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf525(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF525 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf525", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusThermophilusHb8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermus thermophilus HB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermusThermophilusHb8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensNcimb11764Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NCIMB11764 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNcimb11764Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJenkinsiiBen74(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera jenkinsii Ben 74 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJenkinsiiBen74", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 40-19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumArcis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum arcis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumArcis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpHyo08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. HYO08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpHyo08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumG41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium G41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumG41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterLanceolatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurvibacterLanceolatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumTuscanienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium tuscaniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTuscanienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRbg16488(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_48_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg16488", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumGuttoideumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum guttoideum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumGuttoideumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcaceaeBacteriumPga8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcaceae bacterium pGA-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcaceaeBacteriumPga8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFlavescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium flavescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFlavescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaXyliCtcb07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia xyli CTCB07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaXyliCtcb07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR116 cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraAtramentariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura atramentaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraAtramentariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorhizobiumGalegaeBvOfficinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neorhizobium galegae bv. officinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeorhizobiumGalegaeBvOfficinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumYanoikuyae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium yanoikuyae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumYanoikuyae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumTrifoliiWsm2304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii WSM2304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiWsm2304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusAlcaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alcaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlcaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferThermotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer thermotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferThermotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimplicispiraPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Simplicispira psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SimplicispiraPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HamiltosporidiumMagnivora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium magnivora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumMagnivora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacteriumUtbcd1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium UTBCD1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacteriumUtbcd1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNidulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus nidulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusNidulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrioExovorusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio exovorus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioExovorusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonadaceaeBacteriumUkl131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium UKL13-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumUkl131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFonticolaRb25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola RB25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaRb25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho202full3814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO202FULL3814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho202full3814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSulciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sulci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSulciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaConcavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia concava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaConcavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoemansiaReversaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coemansia reversa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoemansiaReversaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurvibacterSpPaeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curvibacter sp. PAEUM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurvibacterSpPaeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PygocentrusNattereriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pygocentrus nattereri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PygocentrusNattereriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasEucrenophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas eucrenophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasEucrenophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermodesulfobacteriumCommune(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium commune graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumCommune", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWC2_33_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwc23313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpMctg268Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. MCTG268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpMctg268Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaOblongaNbrc102422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Moraxella oblonga NBRC 102422 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MoraxellaOblongaNbrc102422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicisCip107643Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis CIP 107643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicisCip107643Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaXishanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia xishanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaXishanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpOk098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. OK098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpOk098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaBritoviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichinella britovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichinellaBritoviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParauberisNcfd2020Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus parauberis NCFD2020 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusParauberisNcfd2020Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpKh9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. KH9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpKh9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCb00455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CB00455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCb00455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermaerobacterMarianensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermaerobacter marianensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermaerobacterMarianensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpCpu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cpu graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpCpu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorNaganoensisNa10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor naganoensis NA10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldicellulosiruptorNaganoensisNa10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGigas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gigas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGigas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaLoescheii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella loescheii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaLoescheii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EumetaJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eumeta japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EumetaJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusSpMucl43196(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizophagus sp. MUCL 43196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizophagusSpMucl43196", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaegleriaGruberi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Naegleria gruberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NaegleriaGruberi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumPseudocatenulatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium pseudocatenulatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumPseudocatenulatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSulfureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sulfureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSulfureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaminaeaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jaminaea rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JaminaeaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KnoelliaSubterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Knoellia subterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSubterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaRiboflavina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia riboflavina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaRiboflavina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrinomonasMethylaliphatogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrinomonas methylaliphatogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrinomonasMethylaliphatogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasVranovensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasVranovensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPetriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella petrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaPetriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full3718Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL3718 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full3718Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxVolcaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferax volcanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferaxVolcaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BathyarchaeotaArchaeonRbg136020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG136020 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg136020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterSegnisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter segnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSegnisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaHeveanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KwoniellaHeveanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaWoodyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella woodyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaWoodyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HamiltosporidiumMagnivoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hamiltosporidium magnivora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HamiltosporidiumMagnivoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaArabinofermentansNrrlYb2248(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] arabinofermentans NRRL YB-2248 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaArabinofermentansNrrlYb2248", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycetosporaChiangmaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomycetospora chiangmaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycetosporaChiangmaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_38_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full3811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CastorCanadensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Castor canadensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CastorCanadensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeuconostocLactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leuconostoc lactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeuconostocLactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full5124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL5124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full5124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumBohemicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumBohemicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPanaciterraeDsm19096Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae DSM 19096 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusPanaciterraeDsm19096Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacaBermudensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pelagibaca bermudensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PelagibacaBermudensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinocladiellaMackenziei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhinocladiella mackenziei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhinocladiellaMackenziei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormivibrioCitricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formivibrio citricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormivibrioCitricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlenkiaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klenkia marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlenkiaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_42_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4204Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4204 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4204Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot190(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root190 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot190", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpKmsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. KMS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpKmsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLnjc398b00Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNJC398B00 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnjc398b00Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusBrevisX23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus brevis X23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBrevisX23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolymyxaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaZeae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya zeae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaZeae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAbortusLlgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia abortus LLG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaAbortusLlgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium filum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRoot149Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root149 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot149Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVenezuelae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces venezuelae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVenezuelae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSulfidigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sulfidigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSulfidigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusLaterosporusDsm25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus laterosporus DSM25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusLaterosporusDsm25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SimiduiaAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Simiduia agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SimiduiaAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaseolibacterFlectens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaseolibacter flectens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaseolibacterFlectens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumHoustonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium houstonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHoustonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LagierellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lagierella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LagierellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermothelomycesThermophilusAtcc42464(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermothelomyces thermophilus ATCC 42464 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermothelomycesThermophilusAtcc42464", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg164813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_16_48_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg164813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasStutzeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosiphoAtlanticusDsm15807Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermosipho atlanticus DSM 15807 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermosiphoAtlanticusDsm15807Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusNakayamaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus nakayamae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusNakayamaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeochlamydiaSpEps4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neochlamydia sp. EPS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeochlamydiaSpEps4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaBovisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma bovis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaBovisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf402Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF402 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf402Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumMs0243cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS024-3C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0243cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumSublineolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum sublineola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumSublineolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiemerellaAnatipestiferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Riemerella anatipestifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RiemerellaAnatipestiferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumHibernumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hibernum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHibernumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpCf149(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. CF149 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpCf149", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PriciaAntarcticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pricia antarctica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PriciaAntarcticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterMicraerophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister micraerophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterMicraerophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasFormicexedens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas formicexedens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasFormicexedens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasTunicata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas tunicata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasTunicata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusBoroniphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus boroniphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusBoroniphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalolactibacillusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoramibacterAlactolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoramibacter alactolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoramibacterAlactolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermostaphylosporaChromogenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermostaphylospora chromogena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermostaphylosporaChromogenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBacilliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bacilliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaBacilliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_54_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full5423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAnorexicamassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium anorexicamassiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAnorexicamassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Beta vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BetaVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumFossorDsm15642Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Atopobium fossor DSM 15642 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AtopobiumFossorDsm15642Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaichungense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taichungense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaichungense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGwf25119(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium GWF2_51_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGwf25119", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalogenimonasFormicexedensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas formicexedens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasFormicexedensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusNatl2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus NATL2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusNatl2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApiotrichumPorosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apiotrichum porosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApiotrichumPorosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrispumAgresteDsm44070Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermocrispum agreste DSM 44070 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermocrispumAgresteDsm44070Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterAtlanticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter atlanticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterAtlanticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDentisani7747Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7747 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7747Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumNk3b98Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium NK3B98 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumNk3b98Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpHot20860m813i02(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. HOT208_60m_813I02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpHot20860m813i02", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaSpAb629b18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina sp. AB629B18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospinaSpAb629b18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpKrocy2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. KROCY2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpKrocy2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNealsonbacteriaBacteriumRbg134211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RBG_13_42_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRbg134211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWesteberhardiaCardiocondylaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Westeberhardia cardiocondylae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWesteberhardiaCardiocondylaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumLssobEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium LSSOB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumLssobEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpilithonimonasTenax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Epilithonimonas tenax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EpilithonimonasTenax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaElegansE1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Holospora elegans E1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HolosporaElegansE1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumSpCag1138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium sp. CAG:1138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumSpCag1138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisDavidii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Myotis davidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MyotisDavidii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveromycesLactisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KluyveromycesLactisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasSpRcc299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Micromonas sp. RCC299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicromonasSpRcc299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumMedpeswcel(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium MedPESWcel graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumMedpeswcel", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricellaOtitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Turicella otitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TuricellaOtitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpP2bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. P2b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpP2bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisSepedonicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis sepedonicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisSepedonicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHelveticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHelveticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpMarseillep3160Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. MarseilleP3160 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpMarseillep3160Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterSpS77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. S77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSpS77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaKururiensisM130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia kururiensis M130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaKururiensisM130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidimicrobiaceaeBacteriumRaap2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidimicrobiaceae bacterium RAAP-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidimicrobiaceaeBacteriumRaap2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllomycesMacrogynusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allomyces macrogynus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllomycesMacrogynusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TardiphagaSpOk245(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga sp. OK245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TardiphagaSpOk245", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHdn1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HdN1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHdn1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumWce2004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPerolensDsm12744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus perolens DSM 12744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPerolensDsm12744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumMetalliduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium metallidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumMetalliduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurisporaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispora thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurisporaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaEriocheirisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma eriocheiris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaEriocheirisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaCaldariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Treponema caldaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TreponemaCaldariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho202full3913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO202FULL3913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho202full3913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeleribacterHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferSpLc11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LC11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLc11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiflebacteriaBacteriumGwc2508Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riflebacteria bacterium GWC2_50_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiflebacteriaBacteriumGwc2508Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParachlamydiaceaeBacteriumHst3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydiaceae bacterium HST3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaceaeBacteriumHst3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalarchaeumAcidiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halarchaeum acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalarchaeumAcidiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRedseas03b5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS03B5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas03b5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaeniglutamicibacterAntarcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter antarcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterAntarcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpMedpeswcelCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. MedPESWcel Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpMedpeswcelCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerosalibacterSpMarseillep3206Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerosalibacter sp. MarseilleP3206 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerosalibacterSpMarseillep3206Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptosporangiumRoseum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumRoseum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSpKu26Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus sp. KU26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSpKu26Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MurdochiellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumOxysporumFSpRadiciscucumerinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. radiciscucumerinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpRadiciscucumerinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfRidgeiaPiscesae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia piscesae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeiaPiscesae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaConsociata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Massilia consociata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MassiliaConsociata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSpMs5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Collinsella sp. MS5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CollinsellaSpMs5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_45_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassiliogorillae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massiliogorillae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMassiliogorillae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumS714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium S714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumS714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanothermococcusThermolithotrophicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermococcus thermolithotrophicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermococcusThermolithotrophicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DendrosporobacterQuercicolusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dendrosporobacter quercicolus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DendrosporobacterQuercicolusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaGrimshawiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila grimshawi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaGrimshawiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaCarbonaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora carbonacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaCarbonaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpHun102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. HUN102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpHun102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumRifoxyc12full3455(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium RIFOXYC12FULL3455 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumRifoxyc12full3455", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusNautiliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus nautili Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusNautiliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAscendensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter ascendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAscendensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full5028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL5028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full5028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixCaldifontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix caldifontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiothrixCaldifontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpOmz838Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. OMZ838 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpOmz838Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PromicromonosporaKroppenstedtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Promicromonospora kroppenstedtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PromicromonosporaKroppenstedtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpL1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. L1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusSpL1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusSpLsaoaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus sp. LSAOA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusSpLsaoaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SucciniclasticumRuminisDsm9236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Succiniclasticum ruminis DSM 9236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SucciniclasticumRuminisDsm9236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpMarseillep299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. MarseilleP299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpMarseillep299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaPunctataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza punctata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaPunctataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpRoot186Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root186 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot186Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaDuttoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia duttonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaDuttoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifcsplowo2025612(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPLOWO2_02_56_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsplowo2025612", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSalarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter salarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSalarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseoflavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces griseoflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGriseoflavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSph1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSaerimneri30aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri 30a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaerimneri30aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBouvetiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter bouvetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBouvetiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminibacteriumSalmoneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasStellipolarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas stellipolaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonasStellipolarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KosmotogaArenicorallinaS304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kosmotoga arenicorallina S304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KosmotogaArenicorallinaS304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3821 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCellulovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cellulovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCellulovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrospiraPlatensisC1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisC1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptobacillusMoniliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus moniliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusMoniliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpPamc22219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. PAMC22219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpPamc22219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioflavicoccusMobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioflavicoccus mobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioflavicoccusMobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumGloeosporioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeferribacterDesulfuricansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deferribacter desulfuricans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeferribacterDesulfuricansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytoplasmaPeanutWitchesbroom(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma peanut witchesbroom graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaPeanutWitchesbroom", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPituitosaNbrc102491Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa NBRC 102491 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPituitosaNbrc102491Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaDavisaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cedecea davisae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CedeceaDavisaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpTsl51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. TSL5-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpTsl51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LinumUsitatissimumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Linum usitatissimum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LinumUsitatissimumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaVestfoldensisSka53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yoonia vestfoldensis SKA53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YooniaVestfoldensisSka53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFutsaiiJcm17355Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus futsaii JCM 17355 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFutsaiiJcm17355Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AkkermansiaMuciniphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia muciniphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaMuciniphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesReticulotermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides reticulotermitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesReticulotermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixDisciformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiothrix disciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiothrixDisciformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterEuropaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter europaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterEuropaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpOralTaxon847(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 847 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon847", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopelagicusSpRedseas31b2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopelagicus sp. REDSEAS31B2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopelagicusSpRedseas31b2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumCg104632(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_46_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104632", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPHIGHO2_01_FULL_57_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsphigho201Full5728", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterMedellinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter medellinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterMedellinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpScb241529c4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_529C4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241529c4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusChilensisDsm12352Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis DSM 12352 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensisDsm12352Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FurculomycesBoomerangusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Furculomyces boomerangus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FurculomycesBoomerangusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSp6829(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 68-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6829", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosulfurimonasDismutansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermosulfurimonas dismutans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermosulfurimonasDismutansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloiococcusOtitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloiococcus otitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloiococcusOtitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb241529c4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_529C4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241529c4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotignumBalticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfotignum balticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfotignumBalticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag624043Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:62_40_43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag624043Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpCua673Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CUA-673 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCua673Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonasSpAp64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas sp. AP64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GemmatimonasSpAp64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalvatorMerianaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salvator merianae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalvatorMerianaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAgglomerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea agglomerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaAgglomerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpNfr16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NFR16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNfr16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaNodosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia nodosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaNodosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaPohangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia pohangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JannaschiaPohangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonadaceaeBacteriumBs31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadaceae bacterium Bs31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonadaceaeBacteriumBs31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromohalobacterJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromohalobacter japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromohalobacterJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtrovirideEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma atroviride Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAtrovirideEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKisonensisF0435(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus kisonensis F0435 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusKisonensisF0435", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrochaeteSpPcc7126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microchaete sp. PCC7126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrochaeteSpPcc7126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHalstediiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces halstedii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHalstediiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusLuteusDsm17002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus luteus DSM 17002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusLuteusDsm17002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpA45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. A45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpA45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixSpCaciam69dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM 69d Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LimnothrixSpCaciam69dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalogenimonasAlkenigignens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas alkenigignens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasAlkenigignens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplodiaSeriata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diplodia seriata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiplodiaSeriata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpPamc21119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. PAMC21119 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpPamc21119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioBreoganiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio breoganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioBreoganiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBifidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBifidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpHmica12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HmicA12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHmica12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag38Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag38Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusBourgensisMs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis MS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanoculleusBourgensisMs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusSalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrenneriaSpEnid312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brenneria sp. EniD312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrenneriaSpEnid312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaSpMarseillep2844Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Holdemania sp. MarseilleP2844 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaSpMarseillep2844Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFermentumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fermentum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFermentumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumSg839Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium SG8_39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumSg839Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumGwa24115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_41_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa24115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasInfelix(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas infelix graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasInfelix", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemolamaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemolamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemolamaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PilibacterTermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pilibacter termitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PilibacterTermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaSpAtcc55076Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea sp. ATCC 55076 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaSpAtcc55076Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpDnf00663Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. DNF00663 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpDnf00663Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GastranaerophilusPhascolarctosicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilus phascolarctosicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilusPhascolarctosicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmatalesArchaeonSm150Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon SM1-50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonSm150Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaGingivalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga gingivalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGingivalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpGhviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ghvi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGhviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasViridiflavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas viridiflava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasViridiflavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasElodeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas elodea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasElodeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurispirillumIndicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispirillum indicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurispirillumIndicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpChkci003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CHKCI003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpChkci003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaAgarilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lewinella agarilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LewinellaAgarilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioParadoxusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisCampestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris campestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "XanthomonasCampestrisCampestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosotenuisCloacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosotenuis cloacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosotenuisCloacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaColumbinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma columbinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaColumbinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaludibacterPropionicigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter propionicigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaludibacterPropionicigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusGattii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus gattii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptococcusGattii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBlattaOrientalisStrTarazonaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. (Blatta orientalis) str. Tarazona Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBlattaOrientalisStrTarazonaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa1478Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA1478 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa1478Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumS7086c20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium S7086C20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumS7086c20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpNkbg15041c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. NKBG15041c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpNkbg15041c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotoleransDsm19514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans DSM 19514 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FerrithrixThermotoleransDsm19514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEhc04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EhC04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpEhc04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaesserellaParasuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaesserella parasuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaesserellaParasuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesMarneffeiAtcc18224(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces marneffei ATCC 18224 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TalaromycesMarneffeiAtcc18224", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe14915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_49_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe14915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaMarthiiFslS4120Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria marthii FSL S4-120 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaMarthiiFslS4120Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WeissellaOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasDonghaensisDsm18148Ho3R19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis DSM 18148 HO3-R19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArenimonasDonghaensisDsm18148Ho3R19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSiraeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Eubacterium] siraeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSiraeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScophthalmusMaximus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Scophthalmus maximus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ScophthalmusMaximus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1024126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_41_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumScgcAaa027k21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium SCGC AAA027K21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumScgcAaa027k21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FungalSpNo11243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.11243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo11243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWC1_49_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioRuminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio ruminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioRuminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusPhoceensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus phoceensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprococcusPhoceensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrigoribacteriumSpLeaf172(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf172 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf172", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraViennensisEn76Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis EN76 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitrososphaeraViennensisEn76Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumCsp12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium CSP12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumCsp12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaedibacterSp38128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 38-128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp38128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaSp3andimar09Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Loktanella sp. 3ANDIMAR09 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LoktanellaSp3andimar09Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpGas231Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. GAS231 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpGas231Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpC04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. C04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpC04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaSpHgh0030Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. HGH0030 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpHgh0030Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisSpRac08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis sp. RAC08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisSpRac08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParalimentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParalimentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeotaArchaeon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAntarcticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium antarcticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAntarcticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterExcellensHl55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter excellens HL-55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinobacterExcellensHl55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PterulaGracilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pterula gracilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PterulaGracilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd1full4023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD1FULL4023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd1full4023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumTimonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumTimonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosarcinaPallidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halosarcina pallida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalosarcinaPallidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterPedocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter pedocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPedocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpAnt17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. Ant17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpAnt17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacterAlgarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacter algarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacterAlgarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarsonellaRuddiiHcThao2000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HC Thao2000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHcThao2000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusGilvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gilvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGilvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutaceaeBacteriumTav5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12W3110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 W3110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12W3110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMelliferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMelliferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParascrofulaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium parascrofulaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumParascrofulaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSp831bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. 831b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSp831bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactonifactorLongoviformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactonifactor longoviformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactonifactorLongoviformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusHoagiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus hoagii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusHoagiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichosporonAsahiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichosporon asahii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichosporonAsahiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanimonasSmirnoviiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanimonas smirnovii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanimonasSmirnoviiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOkinawensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter okinawensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterOkinawensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterArcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter arcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterArcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovibacterPhragmitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mangrovibacter phragmitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MangrovibacterPhragmitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSubflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria subflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSubflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRoqueforti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium roqueforti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumRoqueforti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterKeddieiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter keddieii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SanguibacterKeddieiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobiusGelatinovorus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius gelatinovorus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusGelatinovorus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaSpVc33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma sp. Vc33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSpVc33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterIntestinalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter intestinalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterIntestinalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WesteberhardiaCardiocondylae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Westeberhardia cardiocondylae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WesteberhardiaCardiocondylae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaeBacteriumSm2339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium SM23_39 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumSm2339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpKordi52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. KORDI52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpKordi52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterPetaseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShuttleworthiaSpMsx8bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shuttleworthia sp. MSX8B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShuttleworthiaSpMsx8bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasViscosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas viscosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasViscosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermovenabulumGondwanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermovenabulum gondwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermovenabulumGondwanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TemnothoraxLongispinosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Temnothorax longispinosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TemnothoraxLongispinosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_51_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerulinaMusivaSo2202Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphaerulina musiva SO2202 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphaerulinaMusivaSo2202Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacterium1147Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 1147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium1147Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyroidesOdoratimimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Myroides odoratimimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MyroidesOdoratimimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:611 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WheatBlueCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wheat blue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WheatBlueCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusCoxiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus coxii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusCoxiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwc14715(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWC14715 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwc14715", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumDahliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verticillium dahliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerticilliumDahliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxRadicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax radicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxRadicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpLeaf148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHimb30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpMc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingopyxisSpMc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioplocaIngricaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioploca ingrica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioplocaIngricaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiofilumFlexile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiofilum flexile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiofilumFlexile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifcsphigho202full4518Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPHIGHO202FULL4518 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsphigho202full4518Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusAsinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Equus asinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EquusAsinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalomonasDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiohalomonas denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiohalomonasDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPseudoalcaligenesCect5344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes CECT5344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesCect5344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4515 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFimetariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] fimetarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFimetariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatrialbaceaeArchaeonTcbr11e2g28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquilunaSpUbmaderosw2redEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquiluna sp. UBMaderosW2red Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquilunaSpUbmaderosw2redEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NakamurellaPanacisegetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nakamurella panacisegetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NakamurellaPanacisegetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeBacteriumOralTaxon439Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium oral taxon 439 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacteriumOralTaxon439Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSpCs1gbmeth3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. CS1GBMeth3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpCs1gbmeth3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEntomophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas entomophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEntomophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusCaroliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mus caroli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusCaroliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StarkeyaNovellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Starkeya novella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StarkeyaNovellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemobos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemobos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemobos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesHelcogenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides helcogenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesHelcogenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MargulisbacteriaBacteriumGwd239127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Margulisbacteria bacterium GWD239127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MargulisbacteriaBacteriumGwd239127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorusNotabilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Morus notabilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MorusNotabilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseivivaxSp22iis10sCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Roseivivax sp. 22IIs10s Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RoseivivaxSp22iis10sCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanospirillumMarisDsm6286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanospirillum maris DSM 6286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanospirillumMarisDsm6286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColletotrichumTrifoliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum trifolii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTrifoliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumNyuble8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NYUBLE8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNyuble8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesMarneffeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces marneffei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TalaromycesMarneffeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BulleidiaExtructaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bulleidia extructa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BulleidiaExtructaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesThetaiotaomicron(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides thetaiotaomicron graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesThetaiotaomicron", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumKnowlesiStrainHEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium knowlesi strain H Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumKnowlesiStrainHEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraRifamyciniDsm43936(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini DSM 43936 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraRifamyciniDsm43936", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag492Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:492 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag492Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusCapsularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corchorus capsularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorchorusCapsularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthromitusSpSfbratyitEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthromitus sp. SFBratYit Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthromitusSpSfbratyitEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaPallida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pallida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPallida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSputigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sputigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSputigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp1513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. 1513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSp1513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogranumSalarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halogranum salarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalogranumSalarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPasteurianumDsm525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium pasteurianum DSM525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumPasteurianumDsm525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusCyriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus cyri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusCyriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquamicrobiumDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioVulnificusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio vulnificus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioVulnificusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloramatorQuimbayensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caloramator quimbayensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloramatorQuimbayensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfocurvibacterAfricanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfocurvibacter africanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfocurvibacterAfricanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSimiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas simiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AeromonasSimiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCtuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ctu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCtuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumScgcAaa300d14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA300D14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa300d14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonJ07hx64Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HX64 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hx64Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1024025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_40_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1024025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpicoccumNigrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epicoccum nigrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpicoccumNigrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusSpT2530(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. T2.5-30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpT2530", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerdibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Merdibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MerdibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot227Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root227 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot227Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiaciniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niacini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusNiaciniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronorubrumTibetenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum tibetense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTibetenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpOrs3359Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. ORS 3359 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpOrs3359Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpYe44Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. YE44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpYe44Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterSpW10330Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. W10330 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSpW10330Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_40_35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4035Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocapsaPalsarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa palsarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaPalsarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusScotoductus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus scotoductus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusScotoductus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaOtitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia otitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaOtitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaLucivoraxAtcc49196Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax ATCC 49196 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaLucivoraxAtcc49196Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOligofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oligofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOligofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumRifoxyb1full4319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium RIFOXYB1FULL4319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumRifoxyb1full4319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinisphaeraShabanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinisphaera shabanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisphaeraShabanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAlligatorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma alligatoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAlligatorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_52_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMarimammaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces marimammalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMarimammaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasFrigidaquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas frigidaquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AureimonasFrigidaquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpMadarEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. MADAR Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpMadarEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NesterenkoniaSpAn1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. AN1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpAn1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumGrantiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium grantii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumGrantiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiphophorusCouchianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xiphophorus couchianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XiphophorusCouchianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaToletanaDappPg735Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erwinia toletana DAPP-PG 735 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErwiniaToletanaDappPg735Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag471(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:471 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag471", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0384(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0384", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9312Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9312 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9312Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1025844Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_58_44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025844Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaDispar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDispar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaPhiladelphiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila Philadelphia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaPhiladelphiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccidioidesBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccidioides brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccidioidesBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerobacteriumSaccharolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium saccharolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumSaccharolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAzotifigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas azotifigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAzotifigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaNorimbergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea norimbergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PandoraeaNorimbergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumChauvoeiJf4335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium chauvoei JF4335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumChauvoeiJf4335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpUrha0056Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. URHA0056 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpUrha0056Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpPml113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. PML113 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpPml113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpUcdkl20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. UCDKL20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpUcdkl20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasKerstersii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Comamonas kerstersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ComamonasKerstersii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSp43bgom46m(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 43BGOM46m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp43bgom46m", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAtratusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces atratus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAtratusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag791(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:791 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag791", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot1310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpAtcc39006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. ATCC39006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpAtcc39006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dadabacteria bacterium RIFCSPHIGHO2_12_FULL_53_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDadabacteriaBacteriumRifcsphigho212Full5321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cucumibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CucumibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa027j17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA027J17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa027j17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumRbg166719Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium RBG_16_67_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumRbg166719Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicellaPectinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Granulicella pectinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GranulicellaPectinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc055a01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC055A01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc055a01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_02_FULL_51_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpRoot608Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root608 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot608Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaPiriflorinigransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia piriflorinigrans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaPiriflorinigransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterNitrophenolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter nitrophenolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterNitrophenolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPrimitiaZas1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema primitia ZAS-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPrimitiaZas1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumSalsuginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumSalsuginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapraHircusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capra hircus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapraHircusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumD5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaMorsitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina morsitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaMorsitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpMed193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. MED193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpMed193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioPiezophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio piezophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioPiezophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaCrocodyli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma crocodyli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCrocodyli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp161mfsha21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 161MFSha21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp161mfsha21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeanutWitchesbroomEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peanut witchesbroom Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeanutWitchesbroomEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AneurinibacillusMigulanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aneurinibacillus migulanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AneurinibacillusMigulanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TannerellaSpHot286(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tannerella sp. HOT286 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TannerellaSpHot286", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanaeolusCyanescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Panaeolus cyanescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PanaeolusCyanescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumKetosireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ketosireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumKetosireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasAquimarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas aquimarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasAquimarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_43_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpTb23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. TB23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpTb23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermogemmatisporaSpPm5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora sp. PM5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermogemmatisporaSpPm5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaBurhodogranarieaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia burhodogranariea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaBurhodogranarieaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraMultiformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira multiformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraMultiformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaccariaBicolorS238nH82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Laccaria bicolor S238N-H82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LaccariaBicolorS238nH82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaPanacarvi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cohnella panacarvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CohnellaPanacarvi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf525Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF525 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf525Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4516Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4516 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4516Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamponotusFloridanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Camponotus floridanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CamponotusFloridanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacteriumUtbcd1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium UTBCD1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacteriumUtbcd1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaDalianensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioclava dalianensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioclavaDalianensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa015n04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA015N04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa015n04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpEe36(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. EE36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpEe36", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterVibrioidesCb15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides CB15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesCb15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumShigenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium shigense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumShigenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpKhp7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. khp7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKhp7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def QuadrisphaeraSpDsm44207Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Quadrisphaera sp. DSM 44207 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "QuadrisphaeraSpDsm44207Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OleispiraAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oleispira antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OleispiraAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13910 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasCampestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCampestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HylemonellaGracilisNiagaraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hylemonella gracilis Niagara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HylemonellaGracilisNiagaraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg10243210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG10243210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg10243210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioHydrothermalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio hydrothermalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioHydrothermalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaceaeBacteriumNi1060(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium NI1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacteriumNi1060", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumCg1023744(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023744 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023744", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrifoliumPratenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trifolium pratense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrifoliumPratenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHayakitensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hayakitensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHayakitensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StackebrandtiaNassauensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stackebrandtia nassauensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StackebrandtiaNassauensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumSubrubescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Penicillium subrubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PenicilliumSubrubescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteococcusJaponicusLspLj1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Luteococcus japonicus LSP_Lj1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LuteococcusJaponicusLspLj1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensDsm10105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens DSM10105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensDsm10105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrabulsiellaGuamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trabulsiella guamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrabulsiellaGuamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaTestudinisDsm23072(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella testudinis DSM 23072 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PasteurellaTestudinisDsm23072", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMediterraneensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mediterraneensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMediterraneensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpNap1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. NAP1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpNap1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesHarbinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHarbinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaglaciecolaPolarisLmg21857Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paraglaciecola polaris LMG 21857 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParaglaciecolaPolarisLmg21857Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpRoot656(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root656 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot656", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumGw2011gwa1409Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium GW2011GWA1409 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumGw2011gwa1409Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpF0400(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0400 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0400", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2303716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2303716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAesculapii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium aesculapii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAesculapii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpOlga172Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. OLGA172 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpOlga172Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaInohanensisNbrc100128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia inohanensis NBRC 100128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaInohanensisNbrc100128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaMuelleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaMuelleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichomalopsisSarcophagaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichomalopsis sarcophagae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichomalopsisSarcophagaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaEnhydraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia enhydra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaEnhydraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot1221Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root1221 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot1221Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMangrovisoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mangrovisoli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMangrovisoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumCg2303331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium CG2_30_33_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumCg2303331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HespelliaStercorisuis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HespelliaStercorisuis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodothermusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesSpOralTaxon414Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. oral taxon 414 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpOralTaxon414Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OribacteriumSinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7425Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7425 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7425Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusAcidoterrestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus acidoterrestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusAcidoterrestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumCb782(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum CB782 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumCb782", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfallasGeothermicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfallas geothermicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfallasGeothermicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusVulcaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus vulcani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusVulcaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidithiobacillusFerrooxidansAtcc53993Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans ATCC53993 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansAtcc53993Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasElysicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas elysicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasElysicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslh70357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatagioenasFasciata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Patagioenas fasciata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PatagioenasFasciata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_49_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full4925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMaliNbrc15500(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas mali NBRC 15500 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMaliNbrc15500", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimicrobiumSacchariphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrimicrobium sacchariphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrimicrobiumSacchariphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaJacobaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia jacobaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaJacobaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AurantimonasSpLeaf443(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aurantimonas sp. Leaf443 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AurantimonasSpLeaf443", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaDokdonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola dokdonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaDokdonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCohniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cohnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCohniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpHel185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraViscosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calocera viscosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloceraViscosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitibacterAlkalitoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalaeococcusFerrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus ferrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusFerrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiumSpBvorr106Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. BvORR106 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpBvorr106Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpN324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. N324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpN324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobiformaNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobiformaNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriaceaeBacterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacteriaceae bacterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriaceaeBacterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpZor0009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. ZOR0009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZor0009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaSpSw150Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina sp. SW150 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquimarinaSpSw150Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusMediterraneusDsm13871(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus DSM 13871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneusDsm13871", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobaculumSpHo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobaculum sp. HO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenobaculumSpHo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloteneraVersatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylotenera versatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethyloteneraVersatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaGallisepticumFEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum F Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumFEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorothrixHollandica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorothrix hollandica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorothrixHollandica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaBirminghamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella birminghamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaBirminghamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesEpiroticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anopheles epiroticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnophelesEpiroticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumMagnetotacticumMs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magnetotacticum MS-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagnetotacticumMs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMoriokaense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium moriokaense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMoriokaense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinivibrioSiamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinivibrio siamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinivibrioSiamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_48_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterHydrocarbonoclasticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter hydrocarbonoclasticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterHydrocarbonoclasticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpGm2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. GM2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpGm2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumWds1c4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium WDS1C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumWds1c4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrimonasFerrugineaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrimonas ferruginea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrimonasFerrugineaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRifcsphigho212full439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFCSPHIGHO212FULL439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifcsphigho212full439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumRifcsplowo201full4613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium RIFCSPLOWO201FULL4613 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumRifcsplowo201full4613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaJaponicaGroup(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Group graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaJaponicaGroup", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaAmblyommatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsia amblyommatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiaAmblyommatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusBromiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus bromii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusBromiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumGossipiicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium gossipiicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumGossipiicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumArbustiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium arbusti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArbustiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp12458059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245805.9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12458059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothermothrixOreniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix orenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixOreniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpOralTaxon807(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. oral taxon 807 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OlsenellaSpOralTaxon807", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisTac125Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TAC125 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTac125Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full4315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPyrifoliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erwinia pyrifoliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPyrifoliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudohongiellaSpirulinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudohongiella spirulinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudohongiellaSpirulinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPeoriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus peoriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPeoriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonHepatopenaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterocytozoon hepatopenaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterocytozoonHepatopenaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmF4281Fw2241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKM F-4281 (FW-2241) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmF4281Fw2241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaAtroviride(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma atroviride graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaAtroviride", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineActinobacteriumMedacidiG2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusSpLeaf414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus sp. Leaf414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylophilusSpLeaf414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27986Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27986 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27986Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusJiangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusJiangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacteriaceaeBacteriumGd5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium GD5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumGd5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesStephensi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles stephensi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesStephensi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo202full5710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO202FULL5710 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo202full5710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesAnomalusNrrlY3668Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces anomalus NRRL Y-366-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesAnomalusNrrlY3668Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumCch3a5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH3A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch3a5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrenarchaeotaArchaeonScgcAaa471b05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon SCGC AAA471B05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeonScgcAaa471b05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpGa6a2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. Ga6A2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpGa6a2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaJejuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella jejuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaJejuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumSpA11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpA11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full4212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL4212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full4212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSpUrhd0082(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solirubrobacter sp. URHD0082 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolirubrobacterSpUrhd0082", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaAvicenniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kushneria avicenniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KushneriaAvicenniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3810 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetschnikowiaAffEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia aff. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaAffEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumMageritense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mageritense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMageritense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumFasciculatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium fasciculatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumFasciculatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocorpusculumLabreanumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocorpusculum labreanum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocorpusculumLabreanumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumCbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium CB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumCbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusKhoisanaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus khoisanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKhoisanaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTaa040Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TAA040 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTaa040Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwf236839Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF236839 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf236839Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor3BacteriumSm2342Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR_3 bacterium SM23_42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionWor3BacteriumSm2342Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterMethanicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter methanicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterMethanicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IzhakiellaCapsodis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella capsodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaCapsodis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSulfureusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sulfureus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSulfureusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntrasporangiumCalvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium calvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumCalvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaPertussis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella pertussis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaPertussis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpCag317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalocynthiibacterNamhaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halocynthiibacter namhaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalocynthiibacterNamhaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumHungateiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium hungatei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumHungateiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag563Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:563 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag563Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaHaemolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga haemolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaHaemolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaP74Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila P74 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaP74Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisEllipticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Botrytis elliptica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BotrytisEllipticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasSpCot239oh1446Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT239OH1446 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot239oh1446Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaDalianensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava dalianensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaDalianensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KordiaJejudonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordia jejudonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiaJejudonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterJaponicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter japonicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterJaponicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc8801(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC8801 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc8801", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosopumilusMaritimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusMaritimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiBl21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli BL21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiBl21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcromyrmexEchinatiorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acromyrmex echinatior Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcromyrmexEchinatiorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRbg16437Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG16437 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg16437Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremotheciumSinecaudumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eremothecium sinecaudum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EremotheciumSinecaudumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UreaplasmaUrealyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ureaplasma urealyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UreaplasmaUrealyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusAlveiTs15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei TS15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiTs15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumVaccaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium vaccae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumVaccaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolemyaVelesianaGillSymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Solemya velesiana gill symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SolemyaVelesianaGillSymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WohlfahrtiimonasPopuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas populi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasPopuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRifcsphigho201full6516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPHIGHO201FULL6516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsphigho201full6516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HypholomaSublateritiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hypholoma sublateritium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HypholomaSublateritiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpT16b2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. T16B2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpT16b2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaSpMc24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga sp. Mc24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaSpMc24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MandrillusLeucophaeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mandrillus leucophaeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MandrillusLeucophaeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumXbb1006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB1006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb1006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLentusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus lentus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusLentusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf2580Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF2580 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf2580Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmobacterMegaterium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter megaterium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmobacterMegaterium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusZhangzhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus zhangzhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusZhangzhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusSuccinogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus succinogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusSuccinogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhascolarctobacteriumSuccinatutensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium succinatutens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSuccinatutensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IndibacterAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Indibacter alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IndibacterAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaTucsonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella tucsonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaTucsonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaliaeetusLeucocephalusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haliaeetus leucocephalus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaliaeetusLeucocephalusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesTriticiR3111a1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces tritici R3-111a-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesTriticiR3111a1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythiumIrregulareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pythium irregulare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PythiumIrregulareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUnc41mfs5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC41MFS5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc41mfs5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicolaSpMit1003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MIT1003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMit1003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiCcug35545(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CCUG 35545 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCcug35545", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumBacteremicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium bacteremicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBacteremicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_38_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaBurhodogranariea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Providencia burhodogranariea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaBurhodogranariea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteigerwaltii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella steigerwaltii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteigerwaltii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathymodiolusAzoricusThioautotrophicGillSymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bathymodiolus azoricus thioautotrophic gill symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BathymodiolusAzoricusThioautotrophicGillSymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteibacterSpUncmf331sha31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteibacter sp. UNCMF331Sha3.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteibacterSpUncmf331sha31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosocosmicusExaquare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus exaquare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusExaquare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasXianhensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas xianhensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasXianhensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusSalinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus salinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSalinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterAdhaerens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter adhaerens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAdhaerens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4710bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4710b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4710bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpBpaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlattabacteriumSpBpaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpBa1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium sp. ba1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumSpBa1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpCag472Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:472 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag472Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwc26444Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWC2_64_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwc26444Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylanimonasCellulosilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylanimonas cellulosilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylanimonasCellulosilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stappia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StappiaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85201351886sch5428379(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85201351886SCH5428379 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85201351886sch5428379", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfobacillusThermosulfidooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfobacillus thermosulfidooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfobacillusThermosulfidooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcetotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acetotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcetotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAntibioticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces antibioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAntibioticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacterMathraniiSubspMathraniiStrA3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermoanaerobacter mathranii subsp. mathranii str. A3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermoanaerobacterMathraniiSubspMathraniiStrA3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis2159bfaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 2159BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis2159bfaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FacklamiaLanguida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Facklamia languida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FacklamiaLanguida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumGw2011gwc23922Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium GW2011GWC23922 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumGw2011gwc23922Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasCupidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas cupida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasCupidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusSpPh9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus sp. PH9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusSpPh9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpCpuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cpu Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpCpuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesBouchesdurhonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces bouchesdurhonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesBouchesdurhonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CinnamomumMicranthumFKanehiraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cinnamomum micranthum f. kanehirae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CinnamomumMicranthumFKanehiraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterWuhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter wuhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterWuhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaAlimentariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dietzia alimentaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DietziaAlimentariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSp83e34(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. 83E34 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSp83e34", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetalesBacterium457213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetales bacterium 4572_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetalesBacterium457213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KluyveromycesLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kluyveromyces lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KluyveromycesLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpMtm3w52(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. MTM3W5.2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpMtm3w52", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSp25mfcol41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. 25mfcol4.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSp25mfcol41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSporosphaeroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sporosphaeroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSporosphaeroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterFetusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GramellaPortivictoriaeDsm23547Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gramella portivictoriae DSM 23547 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GramellaPortivictoriaeDsm23547Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpVcd2006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcd2006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumGwa27023Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium GWA27023 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumGwa27023Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioBizertensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio bizertensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBizertensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PericoniaMacrospinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Periconia macrospinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PericoniaMacrospinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraTerpenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera terpenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraTerpenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpAlt199(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. ALT199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpAlt199", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC12_FULL_34_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkanindigesSpH1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkanindiges sp. H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkanindigesSpH1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaGenomosp9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HenriciellaPelagia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Henriciella pelagia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HenriciellaPelagia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratireductorSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaFonticolaAuap2c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola AUAP2C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaAuap2c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaGranulosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga granulosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaGranulosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaxillusRubicundulusVe082h10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paxillus rubicundulus Ve08.2h10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaxillusRubicundulusVe082h10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesantisbacteriaBacteriumCg1023846Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desantisbacteria bacterium CG1023846 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesantisbacteriaBacteriumCg1023846Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumLongum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium longum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLongum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShimiaAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shimia aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShimiaAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpScgcAg212e16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SCGC AG212E16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpScgcAg212e16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaBacteriumBrhc25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium BRHc25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumBrhc25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwb25436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_54_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb25436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterCurvusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter curvus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCurvusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloprevotellaRava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella rava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaRava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGregariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gregarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGregariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonadaceaeCot184oh4590(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonadaceae COT184OH4590 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PorphyromonadaceaeCot184oh4590", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kurthia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KurthiaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacterium4146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium 41-46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacterium4146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_54_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumHuakuii7653rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii 7653R Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuii7653rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwc14715Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWC14715 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwc14715Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydophilaAbortusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila abortus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaAbortusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAgilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus agilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAgilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodothermusProfundi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermus profundi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodothermusProfundi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpHl46Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. HL46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpHl46Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaSubspPasculleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. pascullei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspPasculleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomicrobiaArchaeonJdfr19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobia archaeon JdFR-19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiaArchaeonJdfr19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiobacteriumValvarumF0432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cardiobacterium valvarum F0432 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CardiobacteriumValvarumF0432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviitogaTunisiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Defluviitoga tunisiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DefluviitogaTunisiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSaliphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora saliphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaSaliphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBeckwithbacteriaBacteriumCg1024737Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium CG1_02_47_37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumCg1024737Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfTrichogrammaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Trichogramma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfTrichogrammaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusNakayamaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus nakayamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusNakayamaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaBajacaliforniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta bajacaliforniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaBajacaliforniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopirellulaEuropaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_68_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CenarchaeumSymbiosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cenarchaeum symbiosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CenarchaeumSymbiosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpOv335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. OV335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpOv335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusNishinomiyaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus nishinomiyaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DermacoccusNishinomiyaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaRwandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rwandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaRwandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusHimalayensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus himalayensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusHimalayensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobotryumLychnidisDioicaeP1a1LamoleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Microbotryum lychnidis-dioicae p1A1 Lamole Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicrobotryumLychnidisDioicaeP1a1LamoleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolaniAg1ia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1ia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf337 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassotaleaSpPp2459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea sp. PP2-459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaSpPp2459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphilaNbrc108938(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila NBRC 108938 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphilaNbrc108938", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobaculumMassilienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum massiliense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumMassilienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj24Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj24Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharophagusDegradansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharophagus degradans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharophagusDegradansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSp2gCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. 2G Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSp2gCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoflavibacterZeaxanthDsm18436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. DSM18436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthDsm18436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0875Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0875 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0875Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifcsplowo201full4925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFCSPLOWO201FULL4925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifcsplowo201full4925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSaguiniDsm23967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium saguini DSM 23967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumSaguiniDsm23967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLk11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLk11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumLianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium lianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumLianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SericytochromatiaBacteriumS15bmn24cbmw12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sericytochromatia bacterium S15BMN24CBMW_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SericytochromatiaBacteriumS15bmn24cbmw12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomascusLeucogenys(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomascus leucogenys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomascusLeucogenys", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg104632Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG10_46_32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg104632Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilusLmd9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMD9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmd9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFrigidimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium frigidimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFrigidimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumSalinarumNrc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium salinarum NRC-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalobacteriumSalinarumNrc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankineaeBacteriumMt45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankineae bacterium MT45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankineaeBacteriumMt45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaJeotgaliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia jeotgali Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaJeotgaliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CohaesibacterMarisflaviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cohaesibacter marisflavi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CohaesibacterMarisflaviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterRodentiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterRodentiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag1092(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1092 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1092", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaJacobaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia jacobaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaJacobaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwc24220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWC24220 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwc24220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodohalobacterHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodohalobacter halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodohalobacterHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides insulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesInsulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marine Group III graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesOdontolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces odontolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesOdontolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinotignumUrinaleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinotignum urinale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinotignumUrinaleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiBulgaricusAtcc11842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus ATCC 11842 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricusAtcc11842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterWuhouensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter wuhouensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterWuhouensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusHamelinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halococcus hamelinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalococcusHamelinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumHiltneriN3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum hiltneri N3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumHiltneriN3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavisporaLusitaniaeAtcc42720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae ATCC 42720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClavisporaLusitaniaeAtcc42720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovoraNrrlY12698Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Babjeviella inositovora NRRL Y-12698 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BabjeviellaInositovoraNrrlY12698Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizoctoniaSolaniAg1ibCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizoctonia solani AG1IB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizoctoniaSolaniAg1ibCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudaestuariivitaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudaestuariivita atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudaestuariivitaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteraceaeBacteriumRaap1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium RAAP-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumRaap1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_15b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionNc10BacteriumCsp15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division NC10 bacterium CSP1-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionNc10BacteriumCsp15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsathyrellaAberdarensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psathyrella aberdarensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsathyrellaAberdarensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasHaloplanktisAnt505(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis ANT505 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisAnt505", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpHel13378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. Hel1_33_78 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHel13378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaParisiiErtm3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nematocida parisii ERTm3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NematocidaParisiiErtm3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpLeaf191(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf191", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronincolaFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronincola ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronincolaFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioSpDv(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. DV graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpDv", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusFlavefaciensMa2007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens MA2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensMa2007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpSfbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. SFB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpSfbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumKoreenseCcug49689Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense CCUG 49689 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreenseCcug49689Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioVulnificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio vulnificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioVulnificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenarthrobacterNicotinovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenarthrobacter nicotinovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenarthrobacterNicotinovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrondihabitansSpLeaf304(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. Leaf304 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpLeaf304", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwe24015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LichtheimiaCorymbifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lichtheimia corymbifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LichtheimiaCorymbifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSharpeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sharpeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSharpeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPLOWO2_01_FULL_43_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg1025844(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_58_44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025844", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpRoot552Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. Root552 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpRoot552Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumTuberculosisH37rvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Rv Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37rvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpNc2002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC2002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc2002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaUniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia uniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaUniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpInlla21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. INlla21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpInlla21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriSdmlacEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri SDMLAC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriSdmlacEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_39_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraChlorobenzoicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thauera chlorobenzoica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaueraChlorobenzoicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VicugnaPacosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vicugna pacos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VicugnaPacosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SeriolaLalandi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Seriola lalandi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SeriolaLalandi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisSpJl2009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Maricaulis sp. JL2009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MaricaulisSpJl2009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlossinaPallidipesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glossina pallidipes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlossinaPallidipesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemobosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemobos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemobosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysolophusPictusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chrysolophus pictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChrysolophusPictusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumCiceriBiovarEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri biovar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriBiovarEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraSpBsl9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira sp. BSL-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraSpBsl9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraViennensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraViennensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaceaeBacteriumOralTaxon439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium oral taxon 439 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacteriumOralTaxon439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrovirgaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochrovirga pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchrovirgaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribiusSpMola401(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Maribius sp. MOLA401 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MaribiusSpMola401", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesSpF0330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusFerrariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ferrarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusFerrariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraSpMjr8396cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. MJR8396C Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpMjr8396cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpLtsp849Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. LTSP849 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpLtsp849Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraLicerasiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira licerasiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraLicerasiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumVincentii4113Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum vincentii 4113 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumVincentii4113Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSp7101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. 7101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSp7101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSetaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora setae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSetaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasWeihenstephanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas weihenstephanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasWeihenstephanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasBeringensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas beringensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasBeringensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm44205Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44205 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44205Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full5121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL5121 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full5121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprospiraGrandis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saprospira grandis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaprospiraGrandis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def QuasibacillusThermotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Quasibacillus thermotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "QuasibacillusThermotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumUlvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium ulvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumUlvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillaceaeBacteriumG5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium G5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumG5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCarnosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus carnosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusCarnosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_01_FULL_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho201Full4017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetakosakoniaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacteriaceaeBacteriumEmtcatb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium EMTCatB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacteriumEmtcatb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaCibaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella cibaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaCibaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromassilibacillusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaeromassilibacillus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaeromassilibacillusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyb1Full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYB1_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyb1Full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifoxyd2full369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFOXYD2FULL369 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifoxyd2full369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSpNbrc110051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110051 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaProteobacteriumScgcAb137C09Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return zeta proteobacterium SCGC AB-137-C09 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZetaProteobacteriumScgcAb137C09Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUnc267mfsha11m11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC267MFSha1.1M11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc267mfsha11m11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsphigho202full3919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPHIGHO202FULL3919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsphigho202full3919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumGenomosp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LaetiporusSulphureus9353Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Laetiporus sulphureus 93-53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LaetiporusSulphureus9353Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophusSpGwc25631Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus sp. GWC2_56_31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophusSpGwc25631Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:924 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaCohaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lewinella cohaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LewinellaCohaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TesticulariaCyperi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Testicularia cyperi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TesticulariaCyperi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaInefficaxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Frankia inefficax Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrankiaInefficaxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_44_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full4411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumRubensWisconsin541255(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Penicillium rubens Wisconsin 54-1255 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PenicilliumRubensWisconsin541255", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolfebacteriaBacteriumRifoxyd12full4821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolfebacteria bacterium RIFOXYD12FULL4821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolfebacteriaBacteriumRifoxyd12full4821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusShizuokensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus shizuokensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusShizuokensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpFcs014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaSolaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSolaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CesiribacterAndamanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cesiribacter andamanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CesiribacterAndamanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatusBairdiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus bairdii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeromyscusManiculatusBairdiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaArgininiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma arginini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaArgininiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GastranaerophilusPhascolarctosicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gastranaerophilus phascolarctosicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GastranaerophilusPhascolarctosicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylococcopsisSalinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dactylococcopsis salina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DactylococcopsisSalinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodothermaceaeBacteriumTcbr11b2g67(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodothermaceae bacterium TcBr11B2g67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodothermaceaeBacteriumTcbr11b2g67", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumCg2305767(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium CG2_30_57_67 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumCg2305767", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApisCeranaCeranaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Apis cerana cerana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ApisCeranaCeranaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidithiobacillusFerrooxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidithiobacillus ferrooxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidithiobacillusFerrooxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpSg611lEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. SG61-1L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpSg611lEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPHIGHO2_01_FULL_48_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsphigho201Full4827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusAetherivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus aetherivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusAetherivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterGlacincolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter glacincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterGlacincolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFOXYD1_FULL_48_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifoxyd1Full4821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumThiooxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum thiooxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumThiooxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaStellulataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stappia stellulata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StappiaStellulataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPHIGHO2_01_FULL_45_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsphigho201Full4515Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesEgdeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes EGDe Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesEgdeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniphilumSpEbm39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum sp. EBM-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSpEbm39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag793Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:793 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag793Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4214", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophobotulusGlycolicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophobotulus glycolicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophobotulusGlycolicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacillusCateniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coprobacillus cateniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoprobacillusCateniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitoreibacterAlbidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Litoreibacter albidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LitoreibacterAlbidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosocomiicoccusAmpullaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nosocomiicoccus ampullae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NosocomiicoccusAmpullaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusModuliflexusFlocculansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moduliflexus flocculans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusModuliflexusFlocculansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 27_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StagonosporaSpSrc1lsm3a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stagonospora sp. SRC1lsM3a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StagonosporaSpSrc1lsm3a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylovoransHollandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylovorans hollandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomethylovoransHollandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusVoltaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus voltae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanococcusVoltaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TokpelaiaHoelldobleriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tokpelaia hoelldoblerii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TokpelaiaHoelldobleriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumPusillumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium pusillum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumPusillumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrilyobacterAtlanticusDsm19335(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychrilyobacter atlanticus DSM 19335 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychrilyobacterAtlanticusDsm19335", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpRoot563Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Root563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpRoot563Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalotheceSpPcc7418Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothece sp. PCC7418 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalotheceSpPcc7418Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumSpLk11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sp. LK11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSpLk11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaF0398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia F0398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaF0398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc24220Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_42_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc24220Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalioglobusJaponicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halioglobus japonicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalioglobusJaponicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusThermodenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus thermodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusThermodenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsphigho212full4311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPHIGHO212FULL4311 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsphigho212full4311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HammondiaHammondi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hammondia hammondi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HammondiaHammondi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediculusHumanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediculus humanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediculusHumanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIiEuryarchaeoteRedseaS11B3n4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marine group II euryarchaeote REDSEA-S11_B3N4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIiEuryarchaeoteRedseaS11B3n4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFuchuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus fuchuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFuchuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioPaciniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio pacinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioPaciniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriSg1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri SG1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriSg1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobrancaCaliforniensisDsm14826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerobranca californiensis DSM 14826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerobrancaCaliforniensisDsm14826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacticigeniumNaphtaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacticigenium naphtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacticigeniumNaphtaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasAquimarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas aquimarina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromonasAquimarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeobacterViolaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter violaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeobacterViolaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPruniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pruni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPruniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MerionesUnguiculatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meriones unguiculatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MerionesUnguiculatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasArcticaDsm14288(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas arctica DSM 14288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychromonasArcticaDsm14288", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph12015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1(2015) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpSph12015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasCompostiDsm21721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas composti DSM 21721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonasCompostiDsm21721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusCnrz32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus CNRZ32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusCnrz32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterobasidionIrregulare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heterobasidion irregulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeterobasidionIrregulare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusLacrimalisDsm7455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus lacrimalis DSM 7455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusLacrimalisDsm7455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophaceaeBacteriumCg2304912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_49_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2304912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumSpCf059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylibium sp. CF059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylibiumSpCf059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPHIGHO2_12_FULL_42_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsphigho212Full4219Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParachlamydiaAcanthamoebaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parachlamydia acanthamoebae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParachlamydiaAcanthamoebaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumFoliorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium foliorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumFoliorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaParkeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borrelia parkeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliaParkeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumPlurifariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium plurifarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumPlurifariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarmoricolaSpLeaf446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola sp. Leaf446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaSpLeaf446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotaleaMetallivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotalea metallivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotaleaMetallivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonasAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonas aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonasAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaAlimentariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dietzia alimentaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DietziaAlimentariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DerxiaLacustrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Derxia lacustris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DerxiaLacustrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaSyrphidicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma syrphidicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaSyrphidicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoxiellaEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coxiella endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoxiellaEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloarculaVallismortis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula vallismortis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarculaVallismortis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaTsutsugamushi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orientia tsutsugamushi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrientiaTsutsugamushi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPLOWO2_02_FULL_47_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsplowo202Full4710Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProsthecobacterDebontiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prosthecobacter debontii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProsthecobacterDebontiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumHiranonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hiranonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHiranonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumRhizophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisBiprosthecumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis biprosthecum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBiprosthecumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpPcc7107Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. PCC7107 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocSpPcc7107Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusMarinusBvHnlc1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus bv. HNLC1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusBvHnlc1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpX13sy08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. X13SY08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpX13sy08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PvcGroupBacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return PVC group bacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PvcGroupBacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrantheGuttataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythranthe guttata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrantheGuttataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls646(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls646", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCanintestiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus canintestini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCanintestiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbidiferaxSpOv413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Albidiferax sp. OV413 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlbidiferaxSpOv413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitiniphilusShinanonensisDsm23277Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chitiniphilus shinanonensis DSM 23277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChitiniphilusShinanonensisDsm23277Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar116ClusterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR116 cluster Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar116ClusterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpBica19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BICA1-9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBica19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTestosteroniKf1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni KF1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniKf1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_37_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc23714Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusSpA2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius sp. A-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusSpA2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh70326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH70326 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh70326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRifoxyd12full5323Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RIFOXYD12FULL5323 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRifoxyd12full5323Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CrocosphaeraSubtropicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Crocosphaera subtropica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CrocosphaeraSubtropicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PuniceicoccalesBacteriumVerruco01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puniceicoccales bacterium Verruco_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PuniceicoccalesBacteriumVerruco01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterocytozoonBieneusiH348(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterocytozoon bieneusi H348 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterocytozoonBieneusiH348", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosarcinaFibrataAmlC10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina fibrata AML-C10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaFibrataAmlC10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LautropiaSpScn6989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lautropia sp. SCN 69-89 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LautropiaSpScn6989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrocadiaSpUtamx2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LamprocystisPurpureaDsm4197(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea DSM 4197 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LamprocystisPurpureaDsm4197", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzorhizobiumCaulinodans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium caulinodans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumCaulinodans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaPalleroniiNbrc102513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii NBRC 102513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaPalleroniiNbrc102513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HistoplasmaCapsulatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Histoplasma capsulatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HistoplasmaCapsulatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumGlycinophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium glycinophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumGlycinophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterChromiiresistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chromiiresistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChromiiresistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaRisticii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia risticii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaRisticii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaChukchiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellia chukchiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwelliaChukchiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalonotiusSpJ07hn4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halonotius sp. J07HN4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalonotiusSpJ07hn4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaNonliquefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella nonliquefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaNonliquefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BettaSplendensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Betta splendens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BettaSplendensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfoplanesFormicivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfoplanes formicivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfoplanesFormicivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusCapitisSubspCapitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus capitis subsp. capitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCapitisSubspCapitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumDeltaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium deltae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumDeltaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasArsenitoxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas arsenitoxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThiomonasArsenitoxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOleovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oleovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOleovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusHospitalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidianus hospitalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidianusHospitalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumBact13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kurthia senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KurthiaSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumDamselaeSubspDamselaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium damselae subsp. damselae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumDamselaeSubspDamselaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBerkiellaCookevillensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkiella cookevillensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkiellaCookevillensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShapirobacteriaBacteriumGw2011gwe23830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium GW2011GWE23830 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumGw2011gwe23830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioMagneticusIfrc170Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus IFRC170 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusIfrc170Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumAcnesKpa171202Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes KPA171202 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesKpa171202Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisCip7865(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis CIP78.65 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisCip7865", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia symbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitratireductorAquibiodomusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitratireductor aquibiodomus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitratireductorAquibiodomusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylophagaAminisulfidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga aminisulfidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaAminisulfidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRu33b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. RU33B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRu33b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvencibacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Provencibacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProvencibacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaTyrosinosolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella tyrosinosolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaTyrosinosolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpIdo(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. IDO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpIdo", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPellirubrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrinema pellirubrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrinemaPellirubrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAidingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aidingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAidingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterPiechaudiiHleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii HLE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiHleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiaeEquisimilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae equisimilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiaeEquisimilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSp3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa13330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_33_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa13330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCuatrocienegasensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cuatrocienegasensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCuatrocienegasensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphibacillusXylanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus xylanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusXylanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AstatotilapiaCallipteraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Astatotilapia calliptera Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AstatotilapiaCallipteraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusAlkaliphilusDsm16010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Salinicoccus alkaliphilus DSM 16010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SalinicoccusAlkaliphilusDsm16010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedEubacteriumSpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return uncultured Eubacterium sp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnculturedEubacteriumSpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full3921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3921 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterGangotriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter gangotriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterGangotriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthS86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. S86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthS86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PilodermaCroceumF1598Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Piloderma croceum F 1598 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PilodermaCroceumF1598Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPHIGHO2_02_FULL_39_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsphigho202Full399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhaeomarinobacterEctocarpiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phaeomarinobacter ectocarpi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhaeomarinobacterEctocarpiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSpRoot420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Root420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpRoot420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobacteroidesCellulosolvens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobacteroides cellulosolvens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobacteroidesCellulosolvens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumRifcsplowo202full5736Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFCSPLOWO202FULL5736 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifcsplowo202full5736Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreneyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium freneyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumFreneyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasOryzihabitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzihabitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzihabitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DiplodiaCorticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Diplodia corticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DiplodiaCorticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterHormaecheiSubspOharae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter hormaechei subsp. oharae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterobacterHormaecheiSubspOharae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpMrmr6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MRMR6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMrmr6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolytolypaHystricisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polytolypa hystricis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolytolypaHystricisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeF0167Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae F0167 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeF0167Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudanabaenaSpPcc6802(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC6802 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc6802", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoraliomargaritaAkajimensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coraliomargarita akajimensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoraliomargaritaAkajimensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKryptoniumThompsoni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptonium thompsoni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptoniumThompsoni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniborusSpDw1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus sp. DW1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusSpDw1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSilageiJcm19001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus silagei JCM 19001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSilageiJcm19001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantoeaAnanatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pantoea ananatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PantoeaAnanatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaGranularumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma granularum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaGranularumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanoperedensNitroreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoperedens nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoperedensNitroreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumCsp17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium CSP1-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumCsp17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfuritaleaHydrogenivoransSk43hCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfuritalea hydrogenivorans sk43H Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfuritaleaHydrogenivoransSk43hCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwd24019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWD2_40_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwd24019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpNd2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. ND2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpNd2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterSp5039Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter sp. 50-39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSp5039Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYD1_FULL_41_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaSpBmg111209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia sp. BMG111209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaSpBmg111209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PantheraTigrisAltaica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Panthera tigris altaica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantheraTigrisAltaica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprospiraGrandisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saprospira grandis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaprospiraGrandisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetomicrobiumHydrogeniformansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetomicrobium hydrogeniformans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetomicrobiumHydrogeniformansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JorgensenbacteriaBacteriumGw2011gwb15010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium GW2011GWB15010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumGw2011gwb15010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MustelaPutoriusFuro(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mustela putorius furo graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MustelaPutoriusFuro", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumCyclohexanicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium cyclohexanicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumCyclohexanicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAcetiAtcc23746Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter aceti ATCC23746 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterAcetiAtcc23746Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFormicaceticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium formicaceticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFormicaceticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterSpHtcc7211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter sp. HTCC7211 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterSpHtcc7211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4519 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudophaeobacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudophaeobacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudophaeobacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChelativoransSpJ32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chelativorans sp. J32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChelativoransSpJ32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsphigho201full4526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPHIGHO201FULL4526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsphigho201full4526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaMediumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema medium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaMediumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesLiubingyangiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces liubingyangii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesLiubingyangiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterEnclensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter enclensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterEnclensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSalegensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salegens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalegensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhasianusColchicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phasianus colchicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhasianusColchicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpUcdgka(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UCDGKA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUcdgka", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinimicrobiaBacteriumJgi0000039d08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinimicrobia bacterium JGI 0000039D08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinimicrobiaBacteriumJgi0000039d08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorogloeopsisFritschii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorogloeopsis fritschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorogloeopsisFritschii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAnticariensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas anticariensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasAnticariensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalococcoidesMccartyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides mccartyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesMccartyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZymaeDsm19395(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zymae DSM 19395 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZymaeDsm19395", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisBenevestitusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis benevestitus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisBenevestitusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlexibacterFlexilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flexibacter flexilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlexibacterFlexilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpBv3c161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. BV3C161 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpBv3c161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpChkci003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CHKCI003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpChkci003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumChabaudi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium chabaudi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumChabaudi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoleophilumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoleophilum album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoleophilumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp6736Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 67-36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6736Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSpAu1208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. AU1208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpAu1208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumGw2011gwa14610Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium GW2011GWA14610 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumGw2011gwa14610Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoplasmaChauliocola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesoplasmaChauliocola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpLa11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LA11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLa11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCsp11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon CSP1-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCsp11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasJejuensisNbrc106434Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis NBRC 106434 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolaromonasJejuensisNbrc106434Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenzhouxiangellaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wenzhouxiangella marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WenzhouxiangellaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusAnaerobius653l(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptostreptococcus anaerobius 653L graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptostreptococcusAnaerobius653l", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterDelicatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter delicatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterDelicatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDefluviiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter defluvii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterDefluviiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApisCeranaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apis cerana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApisCeranaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumRifoxyc12full6016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium RIFOXYC12FULL6016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumRifoxyc12full6016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCyaneogriseusSubspNoncyanogenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces cyaneogriseus subsp. noncyanogenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesCyaneogriseusSubspNoncyanogenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRoseburiaSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Roseburia sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedRoseburiaSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumGmi1000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum GMI1000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumGmi1000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumTf0111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium TF01-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumTf0111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraPerlucidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera perlucida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPerlucidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifoxyc2Full4316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYC2_FULL_43_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyc2Full4316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumGorillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium gorillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGorillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChisholmbacteriaBacteriumRifcsplowo201full4914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chisholmbacteria bacterium RIFCSPLOWO201FULL4914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChisholmbacteriaBacteriumRifcsplowo201full4914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonatronumThiosulfatophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiosulfatophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiosulfatophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5013 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaSublithincolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita sublithincola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AequorivitaSublithincolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesUncialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces uncialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesUncialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlorobaculumLimnaeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobaculum limnaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobaculumLimnaeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeribacteriaBacteriumRifcsplowo201full5118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peribacteria bacterium RIFCSPLOWO201FULL5118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeribacteriaBacteriumRifcsplowo201full5118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumBdw918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium BDW918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumBdw918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcidisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acidisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcidisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpMit115569(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT115569 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit115569", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFOXYA2_FULL_38_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifoxya2Full3824", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NippostrongylusBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nippostrongylus brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NippostrongylusBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasMosseliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mosselii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMosseliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRiesiaPthiripubis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia pthiripubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaPthiripubis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumUniformeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium uniforme Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumUniformeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaHaliotisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shewanella haliotis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShewanellaHaliotisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrospiraPlatensisYzEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrospira platensis YZ Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrospiraPlatensisYzEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnabaenaVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anabaena variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnabaenaVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpGpe39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. GPE 39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpGpe39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaSeeligeri12bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria seeligeri 12b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaSeeligeri12bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaylandiaZebra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Maylandia zebra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MaylandiaZebra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSimilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter similis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSimilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaFormicigeneransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dorea formicigenerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoreaFormicigeneransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MizuhopectenYessoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mizuhopecten yessoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MizuhopectenYessoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBms12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BMS12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBms12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParasitellaParasiticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parasitella parasitica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParasitellaParasiticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaPruni(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma pruni graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaPruni", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSulfureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sulfureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSulfureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumAurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aurum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeotomaLepida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neotoma lepida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeotomaLepida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaGranulomatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MannheimiaGranulomatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusApinorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apinorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApinorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaLongibrachiatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma longibrachiatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaLongibrachiatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr460Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr460Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumParmentieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium parmentieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumParmentieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFCSPLOWO2_01_FULL_47_33b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifcsplowo201Full4733bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4415cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4415c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4415cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumProvencenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium provencense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumProvencenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusMediterraneensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus mediterraneensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusMediterraneensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpP18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. P1.8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpP18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobialesBacteriumClorobi01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobiales bacterium Clorobi_01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobialesBacteriumClorobi01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliangiumOchraceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haliangium ochraceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaliangiumOchraceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLm7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LM7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLm7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHominisC80Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis C80 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisC80Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWeiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira weilii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWeiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag609Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:609 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag609Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumEligensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium eligens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumEligensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusClaussenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus claussenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusClaussenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAgalactiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma agalactiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaAgalactiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAmazonitimonenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium amazonitimonense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAmazonitimonenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSpZwu0011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. ZWU0011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpZwu0011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumImcc14465Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium IMCC14465 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumImcc14465Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlf5135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasDenitrificansDsm6059Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans DSM 6059 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificansDsm6059Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurimonasSpGwf2378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. GWF2_37_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpGwf2378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpKctc13219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] sp. KCTC 13219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpKctc13219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSolisilvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter solisilvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSolisilvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBiavatii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium biavatii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBiavatii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumChungangenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chungangense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChungangenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusRubeinfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus rubeinfantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusRubeinfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiNctc5866Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii NCTC 5866 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiNctc5866Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlackburnbacteriaBacteriumRifcsphigho201full4017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO201FULL4017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho201full4017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalimicrobiumFlavidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salimicrobium flavidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalimicrobiumFlavidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasDaejeonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas daejeonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasDaejeonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23338Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_38 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23338Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RaoultellaOrnithinolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Raoultella ornithinolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RaoultellaOrnithinolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaOdorifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia odorifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaOdorifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterLucknowensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter lucknowensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterLucknowensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesPosadasiiStrSilveira(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii str. Silveira graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesPosadasiiStrSilveira", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc13822Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC13822 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc13822Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlj16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfBathymodiolusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Bathymodiolus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfBathymodiolusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterSpS77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. S77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSpS77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaTypographiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia typographi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTypographiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaseolusVulgarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaseolus vulgaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaseolusVulgarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterLitoralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter litoralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterLitoralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanistesCaeruleus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanistes caeruleus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanistesCaeruleus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpBch(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Bch graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBch", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HanseniasporaUvarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hanseniaspora uvarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HanseniasporaUvarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZootermopsisNevadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zootermopsis nevadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZootermopsisNevadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaceaeBacteriumNi1060Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pasteurellaceae bacterium NI1060 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PasteurellaceaeBacteriumNi1060Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixEspanaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix espanaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixEspanaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumNitrativorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium nitrativorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumNitrativorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoeseiaOceaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woeseia oceani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoeseiaOceaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoraxellaCapraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella caprae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCapraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaSpCag351Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sutterella sp. CAG:351 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SutterellaSpCag351Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanithermusProfundusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanithermus profundus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanithermusProfundusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpW8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. W8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpW8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSp6113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 61-13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp6113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusKukulkaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus kukulkanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrococcusKukulkaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCny243Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNY243 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCny243Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumVeterumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium veterum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumVeterumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumChaponense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium chaponense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumChaponense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HafniaAlvei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hafnia alvei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HafniaAlvei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHerbarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus herbarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHerbarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumMesophilicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusAminophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus aminophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAminophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OreniaMarismortuiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orenia marismortui Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OreniaMarismortuiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusPantotrophusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus pantotrophus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusPantotrophusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumKushneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium kushneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumKushneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagnetobacteriumCasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magnetobacterium casensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagnetobacteriumCasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasNoxiaAtcc43541(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas noxia ATCC43541 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasNoxiaAtcc43541", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobacterSpRoot1221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobacter sp. Root1221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobacterSpRoot1221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxBorkumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax borkumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxBorkumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumPolonicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium polonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumPolonicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumMortiferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium mortiferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMortiferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumHainanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium hainanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumHainanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VulpesVulpesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulpes vulpes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulpesVulpesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NealsonbacteriaBacteriumRifcsplowo201full4332Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFCSPLOWO201FULL4332 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifcsplowo201full4332Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa25646(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_56_46 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25646", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutusSpGas368Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Opitutus sp. GAS368 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OpitutusSpGas368Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnicoccusIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryomorphaceaeBacteriumBacl7Mag120322Bin74Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryomorphaceae bacterium BACL7 MAG-120322-bin74 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryomorphaceaeBacteriumBacl7Mag120322Bin74Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PachysolenTannophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PachysolenTannophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaTropicalisMya3404(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida tropicalis MYA-3404 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaTropicalisMya3404", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm3983Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM3983 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm3983Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGasseriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gasseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGasseriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalasseziaGlobosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malassezia globosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalasseziaGlobosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCarboxidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium carboxidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCarboxidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat27264Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-27264 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat27264Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaPedrosoiCbs27137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi CBS 271.37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoiCbs27137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DubosiellaNewyorkensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dubosiella newyorkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DubosiellaNewyorkensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumGp1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium GP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumGp1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFloridensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria floridensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaFloridensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpCsivEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CSIV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCsivEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacterium34128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium 34_128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacterium34128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251057sch5723018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251057SCH5723018 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251057sch5723018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_40_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4018Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterMraziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter mrazii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMraziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyronemaOmphalodes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyronema omphalodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyronemaOmphalodes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynchytriumEndobioticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synchytrium endobioticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynchytriumEndobioticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClunioMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clunio marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClunioMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaAphisGlycinesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Aphis glycines) Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAphisGlycinesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesTenuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces tenuis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlycomycesTenuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusHominisC80Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus hominis C80 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusHominisC80Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslh7689Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH7689 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh7689Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPlecoglossicidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas plecoglossicida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPlecoglossicidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaArundinaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma arundinaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaArundinaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumTumefaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium tumefaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumTumefaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocellaConradiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocella conradii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocellaConradiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaHarzianumCbs22695Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma harzianum CBS 226.95 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichodermaHarzianumCbs22695Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpFslr70331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLR70331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslr70331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulpesVulpesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vulpes vulpes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VulpesVulpesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BotrytisCinereaBcdw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Botrytis cinerea BcDW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BotrytisCinereaBcdw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WilliamsiaSp1138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Williamsia sp. 1138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WilliamsiaSp1138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionSr1BacteriumAalborgaaw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division SR1 bacterium AalborgAAW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionSr1BacteriumAalborgaaw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OerskoviaTurbata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oerskovia turbata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OerskoviaTurbata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EutypaLataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eutypa lata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EutypaLataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoclostridiumStercorariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoclostridium stercorarium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoclostridiumStercorariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaSpKle1797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia sp. KLE1797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaSpKle1797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPectinovorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium pectinovorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPectinovorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilicibacterLacuscaerulensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Silicibacter lacuscaerulensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SilicibacterLacuscaerulensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaSpVcsa23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olleya sp. VCSA23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlleyaSpVcsa23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobisporaSpAtccPta5024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbispora sp. ATCC PTA-5024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobisporaSpAtccPta5024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaProteobacteriumMlsdCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return delta proteobacterium MLSD Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaProteobacteriumMlsdCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces violens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HordeumVulgareSubspVulgareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hordeum vulgare subsp. vulgare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HordeumVulgareSubspVulgareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRufumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rufum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRufumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusOlitoriusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corchorus olitorius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorchorusOlitoriusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0295Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0295 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0295Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumCelere(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum celere graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumCelere", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumGa0077528Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium Ga0077528 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumGa0077528Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2304012Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_40_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2304012Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LambdaproteobacteriaBacteriumRifoxyd2full5016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lambdaproteobacteria bacterium RIFOXYD2FULL5016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LambdaproteobacteriaBacteriumRifoxyd2full5016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom181602Daom197198Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 181602=DAOM 197198 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom181602Daom197198Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpTtu2014080ascEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TTU2014-080ASC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpTtu2014080ascEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusModasaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus modasa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusModasaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumGeorgienseDsm11526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium georgiense DSM 11526 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumGeorgienseDsm11526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseoverticillatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseoverticillatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseoverticillatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHelveticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter helveticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHelveticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArenimonasComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterHartonius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter hartonius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterHartonius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaIhuae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella ihuae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaIhuae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromicrobiumMarinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromicrobium marinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromicrobiumMarinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpRc2dEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc2d Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc2dEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGlobisporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces globisporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGlobisporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAbyssalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAbyssalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BosGrunniensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bos grunniens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BosGrunniensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumReducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum reducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumReducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioNitratireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio nitratireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioNitratireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpHu2014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. HU2014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpHu2014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NasuiaDeltocephalinicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nasuia deltocephalinicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NasuiaDeltocephalinicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaApisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma apis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaApisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesNordiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides nordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesNordiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSp6146afaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. 6146AFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioSp6146afaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaSpPdc51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. PDC51 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSpPdc51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpHeli88(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. HelI88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpHeli88", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaFormicigenerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea formicigenerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaFormicigenerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbugoCandida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Albugo candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlbugoCandida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLipophiloflavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lipophiloflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLipophiloflavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaSp4h37ye5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. 4H37YE5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSp4h37ye5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRbg165624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_56_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg165624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaFidelisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella fidelis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaFidelisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BabjeviellaInositovoraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Babjeviella inositovora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BabjeviellaInositovoraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitratifractorSalsuginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitratifractor salsuginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitratifractorSalsuginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilliamellaIntestiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gilliamella intestini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GilliamellaIntestiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaGlatheiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glathei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlatheiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColinusVirginianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colinus virginianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColinusVirginianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioCrunogenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio crunogenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioCrunogenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaGlauca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora glauca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaGlauca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LloydbacteriaBacteriumRifcsphigho202full5013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lloydbacteria bacterium RIFCSPHIGHO202FULL5013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LloydbacteriaBacteriumRifcsphigho202full5013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlbugoLaibachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Albugo laibachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlbugoLaibachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6820Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6820 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6820Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaceaeBacteriumAt8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eggerthellaceae bacterium AT8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EggerthellaceaeBacteriumAt8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirestonebacteriaBacteriumRifoxyc2full3967Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYC2FULL3967 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxyc2full3967Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusarium oxysporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusariumOxysporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamiellaSorbophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamiella sorbophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WickerhamiellaSorbophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusUvarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus uvarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUvarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPHIGHO2_01_FULL_41_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsphigho201Full4111Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylibiumPetroleiphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylibium petroleiphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylibiumPetroleiphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AndreprevotiaLacusDsm23236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Andreprevotia lacus DSM 23236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AndreprevotiaLacusDsm23236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterQingfengensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter qingfengensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterQingfengensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumColumnare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium columnare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumColumnare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvimonasMicraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parvimonas micra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParvimonasMicraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFragi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fragi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFragi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5421 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumPraevalens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium praevalens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumPraevalens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatisAj13355Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis AJ13355 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisAj13355Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalieaceaeBacteriumImcc3088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halieaceae bacterium IMCC3088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalieaceaeBacteriumImcc3088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpSk643Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. SK643 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpSk643Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpOk605(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. OK605 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpOk605", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioglobusSingularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioglobus singularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioglobusSingularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumSalinitoleransStrHayward0363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Agrobacterium salinitolerans str. Hayward 0363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AgrobacteriumSalinitoleransStrHayward0363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaBovoculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Moraxella bovoculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MoraxellaBovoculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFalloniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella fallonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaFalloniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptosporidiumParvumIowaIiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Iowa II Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumParvumIowaIiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlloprevotellaRavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloprevotella rava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloprevotellaRavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh7803Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 7803 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh7803Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumV9d3004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium V9D3004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumV9d3004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NectriaHaematococcaMpvi77134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Nectria] haematococca mpVI 77-13-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NectriaHaematococcaMpvi77134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NioellaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nioella nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NioellaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaGlumipatulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza glumipatula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaGlumipatulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumCsp18(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CSP1-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCsp18", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDianthicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dianthicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaDianthicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquaspirillumSpLm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquaspirillum sp. LM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquaspirillumSpLm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumPhenoxybenzoativoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium phenoxybenzoativorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumPhenoxybenzoativoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMucosaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mucosae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMucosaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDegerlacheiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium degerlachei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDegerlacheiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpBl107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. BL107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpBl107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSpAbm4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter sp. AbM4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterSpAbm4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaFarcinicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia farcinica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaFarcinicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifoxyb1full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFOXYB1FULL4113 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifoxyb1full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GalerinaMarginataCbs33988(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Galerina marginata CBS 339.88 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GalerinaMarginataCbs33988", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacillusKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacillus koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacillusKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_02_FULL_43_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho202Full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu069Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU069 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu069Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPLOWO2_02_FULL_43_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsplowo202Full4322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OctadecabacterTemperatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Octadecabacter temperatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OctadecabacterTemperatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwp2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWP2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwp2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntestinimonasButyriciproducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intestinimonas butyriciproducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntestinimonasButyriciproducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoecheraStricta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Boechera stricta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BoecheraStricta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusArculariusHhb13444Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polyporus arcularius HHB13444 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolyporusArculariusHhb13444Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisAtcc6249Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis ATCC6249 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisAtcc6249Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpYr522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. YR522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpYr522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpNies3754Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. NIES-3754 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpNies3754Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_51_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full5121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetragenococcusSolitarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetragenococcus solitarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetragenococcusSolitarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusWulumuqiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus wulumuqiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusWulumuqiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSeniorisDsm24302Jcm17472Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus senioris DSM 24302 JCM 17472 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSeniorisDsm24302Jcm17472Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonRubrumCbs118892Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton rubrum CBS 118892 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrichophytonRubrumCbs118892Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusAureusSubspAureusNctc8325Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus aureus subsp. aureus NCTC 8325 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusAureusSubspAureusNctc8325Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisCga009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris CGA009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisCga009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaLactamica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria lactamica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaLactamica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMarginalisIcmp9505Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas marginalis ICMP 9505 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMarginalisIcmp9505Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumChaponenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium chaponense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumChaponenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpinaciaOleraceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spinacia oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpinaciaOleraceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidimonasFonticaldiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tepidimonas fonticaldi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TepidimonasFonticaldiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterPolytrichastriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter polytrichastri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterPolytrichastriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrotetrasporaMalaysiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora malaysiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaMalaysiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMacraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura macra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMacraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetallosphaeraSedulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera sedula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraSedulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiothrixCaldifontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix caldifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiothrixCaldifontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BesnoitiaBesnoitiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Besnoitia besnoiti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BesnoitiaBesnoitiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterRuminantium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter ruminantium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterRuminantium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrigenaNbrc13299(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrigena NBRC 13299 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ComamonasTerrigenaNbrc13299", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKryptobacterTengchongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptobacter tengchongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptobacterTengchongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnserBrachyrhynchusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anser brachyrhynchus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnserBrachyrhynchusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptonemaIlliniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptonema illini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptonemaIlliniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSaskatchewanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium saskatchewanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSaskatchewanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusMethylotrophusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus methylotrophus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusMethylotrophusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifoxyb1Full4033(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFOXYB1_FULL_40_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifoxyb1Full4033", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaAsiaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba asiatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaAsiaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemellaCuniculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemella cuniculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemellaCuniculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutaceaeBacteriumTsb47(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TSB47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTsb47", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RomboutsiaLituseburensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaChilensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella chilensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaChilensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThermokryptusMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thermokryptus mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusThermokryptusMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHimb55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HIMB55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHimb55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrospiraeBacteriumCg10244142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium CG1_02_44_142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumCg10244142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusAntranikianiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermus antranikianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermusAntranikianiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridioidesDifficileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides difficile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesDifficileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CardiniumEndosymbiontCeper1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cEper1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCeper1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPrydzensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas prydzensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPrydzensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovermiculusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OpitutaceaeBacteriumTsb47Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TSB47 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTsb47Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusComposti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus composti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusComposti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThermophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThermophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpLs16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. LS16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLs16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaGinsenosidivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Niabella ginsenosidivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NiabellaGinsenosidivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpCacia14h1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. CACIA14H1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpCacia14h1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_52_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5225Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OchrobactrumRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OchrobactrumRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaMuscicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fischerella muscicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FischerellaMuscicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSchoenbuchensisR1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella schoenbuchensis R1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaSchoenbuchensisR1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium1147Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 1147 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium1147Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumProfundum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium profundum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProfundum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpDnf00869(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. DNF00869 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpDnf00869", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterSpRoot100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. Root100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpRoot100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteiniborusEthanoligenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteiniborus ethanoligenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteiniborusEthanoligenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusSpOralTaxon190(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arsenicicoccus sp. oral taxon 190 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArsenicicoccusSpOralTaxon190", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJirovecii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PneumocystisJirovecii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfarculusBaarsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculus baarsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfarculusBaarsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfococcusSp4484241Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus sp. 4484_241 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusSp4484241Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSpLeaf216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. Leaf216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpLeaf216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolobacteriumMooreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Solobacterium moorei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SolobacteriumMooreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMoukalabenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium moukalabense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMoukalabenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaPeucetiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora peucetia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPeucetiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CutaneotrichosporonOleaginosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cutaneotrichosporon oleaginosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CutaneotrichosporonOleaginosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaPersicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lewinella persica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LewinellaPersicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonquetellaAnthropiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jonquetella anthropi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JonquetellaAnthropiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumCg2303944(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2303944 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2303944", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpPamc26640Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PAMC 26640 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPamc26640Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AequorivitaCapsosiphonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aequorivita capsosiphonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AequorivitaCapsosiphonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumGwf24352(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR_2 bacterium GWF2_43_52 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumGwf24352", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPerflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria perflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaPerflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AedesAegyptiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aedes aegypti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AedesAegyptiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAsteroides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia asteroides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAsteroides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumGwd23219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium GWD2_32_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumGwd23219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaSpJ72Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natrinema sp. J72 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatrinemaSpJ72Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFOXYC1_FULL_38_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifoxyc1Full3818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChondromycesCrocatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chondromyces crocatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChondromycesCrocatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobellusRufusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobellus rufus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobellusRufusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSericytochromatiaBacteriumS15bMn24Raac196Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sericytochromatia bacterium S15B-MN24 RAAC_196 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSericytochromatiaBacteriumS15bMn24Raac196Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferulaSpBvorr071Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferula sp. BvORR071 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferulaSpBvorr071Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp123mfchir2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. 123MFChir2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSp123mfchir2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStoquefichusSpSb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Stoquefichus sp. SB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusStoquefichusSpSb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumH5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium RIFCSPLOWO2_01_FULL_56_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumRifcsplowo201Full5620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslp40081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLP40081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpFslp40081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpSoil772(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Soil772 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpSoil772", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusArlettaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus arlettae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusArlettaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRoot483d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root483D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot483d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpRoot265Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. Root265 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpRoot265Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzambacteriaBacteriumRifcsphigho202full4518Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPHIGHO202FULL4518 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsphigho202full4518Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaColwelliana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella colwelliana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaColwelliana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasSpBrhc22Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas sp. BRHc22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasSpBrhc22Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TulasnellaCalosporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tulasnella calospora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TulasnellaCalosporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterSakazakiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter sakazakii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CronobacterSakazakiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterGlacialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter glacialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterGlacialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpHk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. HK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpHk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SparusAurataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sparus aurata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SparusAurataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KalmanozymaBrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerstersiaGyiorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kerstersia gyiorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KerstersiaGyiorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJ37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. J37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpJ37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZymobacterPalmaeDsm10491Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Zymobacter palmae DSM 10491 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ZymobacterPalmaeDsm10491Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho202full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3713 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalodesulfovibrioMarinisediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halodesulfovibrio marinisediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalodesulfovibrioMarinisediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4235(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4235 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4235", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DacryopinaxPrimogenitus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dacryopinax primogenitus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DacryopinaxPrimogenitus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpQxt31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. QXT-31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpQxt31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioGalatheaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio galatheae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioGalatheaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusNantongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus nantongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNantongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaAstilbis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Asaia astilbis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AsaiaAstilbis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaInefficax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia inefficax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaInefficax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosphaeraAminiphilaDsm21120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerosphaera aminiphila DSM 21120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerosphaeraAminiphilaDsm21120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusMelliferCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellifer Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMelliferCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZimmermannellaAlbaNbrc15616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] alba NBRC 15616 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaAlbaNbrc15616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrochothrixThermosphactaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix thermosphacta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrochothrixThermosphactaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterSpRoot672Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. Root672 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpRoot672Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinusE25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus E25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusE25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalibacaDankookensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalibaca dankookensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JeotgalibacaDankookensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FulvimarinaPelagi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fulvimarina pelagi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FulvimarinaPelagi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaAcidipaludisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia acidipaludis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaAcidipaludisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacteriumYongneupenseDsm18731(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paludibacterium yongneupense DSM 18731 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaludibacteriumYongneupenseDsm18731", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag557Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:557 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag557Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HomoSapiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Homo sapiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HomoSapiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrorhabdusChilensisDsm12352(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis DSM 12352 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensisDsm12352", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpCag324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sp. CAG:324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSpCag324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FluoribacterDumoffiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter dumoffii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FluoribacterDumoffiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisSpAc466Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. AC466 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpAc466Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalonatronumSaccharophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halonatronum saccharophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalonatronumSaccharophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumGwa2509(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GWA2509 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGwa2509", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSimulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium simulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSimulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothiobacillusSpLs2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. LS2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpLs2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDarwinianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus darwinianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDarwinianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumP6b14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6B14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6b14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpHsism1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HSISM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpHsism1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHygroscopicusSubspHygroscopicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces hygroscopicus subsp. hygroscopicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesHygroscopicusSubspHygroscopicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusGattiiVgiiR265(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus gattii VGII R265 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CryptococcusGattiiVgiiR265", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyadobacterTibetensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyadobacterTibetensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioBreoganiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio breoganii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioBreoganiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKuenenbacteriaBacteriumCg2303924(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium CG2_30_39_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumCg2303924", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf5065Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF5065 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf5065Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumCg2303944Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2303944 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2303944Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa24512Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_45_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24512Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAviariusSubspAraffinosusDsm20653Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius subsp. araffinosus DSM 20653 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAviariusSubspAraffinosusDsm20653Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyellaSpOk004Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella sp. OK004 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaSpOk004Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasAsturiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas asturiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAsturiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscibacillusSalipiscariusJcm13188Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius JCM 13188 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscariusJcm13188Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf28Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf28Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VaribaculumCambrienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum cambriense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VaribaculumCambrienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RomboutsiaLituseburensisDsm797(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Romboutsia lituseburensis DSM 797 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RomboutsiaLituseburensisDsm797", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OligellaUreolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oligella ureolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OligellaUreolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasBacteroidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas bacteroides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasBacteroidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusMetallicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfolobusMetallicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfCtenarytainaEucalyptiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Ctenarytaina eucalypti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfCtenarytainaEucalyptiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SetariaItalicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Setaria italica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SetariaItalicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonadalesBacterium6970Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonadales bacterium 69-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonadalesBacterium6970Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrarchaeotaArchaeonCg1026051Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Micrarchaeota archaeon CG1_02_60_51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrarchaeotaArchaeonCg1026051Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSalinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_37_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSp20gpm1509mCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. 20GPM1509m Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSp20gpm1509mCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterSpPpn85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter sp. Ppn85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RodentibacterSpPpn85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpMusc14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. MUSC 14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpMusc14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCg2303430Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CG2_30_34_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCg2303430Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumClostridioforme2149faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium clostridioforme 2149FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumClostridioforme2149faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminiclostridiumPapyrosolvensC7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminiclostridium papyrosolvens C7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminiclostridiumPapyrosolvensC7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_38_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3821Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaGrayiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria grayi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrayiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumPiscinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium piscinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumPiscinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactococcusChungangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FischerellaSpPcc9339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FischerellaSpPcc9339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium6417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 64-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_02_FULL_51_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo202Full5111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_59_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5916Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumYoelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium yoelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumYoelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJaponicaT1X7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica T1-X7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TetrasphaeraJaponicaT1X7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumCitreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium citreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumCitreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterHeraklionensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter heraklionensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHeraklionensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBatumiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas batumici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBatumiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmobacterAquatilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmobacter aquatilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmobacterAquatilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumGwb25436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_54_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb25436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDaejeonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter daejeonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterDaejeonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag702(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:702 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag702", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraProfundimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira profundimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraProfundimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraNoguchiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira noguchii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraNoguchiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocoleusVaginatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus vaginatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusVaginatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPaurosaccharolyticusJcm15092Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus JCM 15092 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticusJcm15092Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteraceaeBacteriumGwf1657Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium GWF1_65_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumGwf1657Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrsusAmericanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ursus americanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrsusAmericanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumSpF0372(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionibacterium sp. F0372 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionibacteriumSpF0372", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnc496mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC496MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc496mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterOleivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter oleivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterOleivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusHippeiDsm8344(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus hippei DSM 8344 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusHippeiDsm8344", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TypebSymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return TypeB symbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TypebSymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsukibacteriumSpMj3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium sp. MJ3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumSpMj3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSteyniiIbt23096Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus steynii IBT 23096 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusSteyniiIbt23096Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusSputorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus sputorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusSputorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBacteremicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium bacteremicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBacteremicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiolineaDisciformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiolinea disciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiolineaDisciformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaIhumii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaIhumii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gillisia marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GillisiaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCf097Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF097 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf097Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterAquaticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algibacter aquaticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAquaticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesAlbimanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles albimanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesAlbimanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumOmnivorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium omnivorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumOmnivorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusEquigenerosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equigenerosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquigenerosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumVentriosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ventriosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumVentriosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromobacteriumPiscinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium piscinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumPiscinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidicoccusFontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidicoccus fontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidicoccusFontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumGb30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum GB30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumGb30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasSpFb6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiomonas sp. FB-6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiomonasSpFb6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusOnnurineusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus onnurineus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermococcusOnnurineusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasMacacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasMacacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CavenderiaFasciculataSh3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata SH3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CavenderiaFasciculataSh3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeraceosorusBombacisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ceraceosorus bombacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CeraceosorusBombacisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumGranuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumGranuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrchesellaCinctaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orchesella cincta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrchesellaCinctaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BelnapiaMoabensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Belnapia moabensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BelnapiaMoabensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterAlbidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter albidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GluconobacterAlbidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg1025345(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_53_45 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1025345", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasJannaschianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas jannaschiana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJannaschianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinovumAlgicolaDg898Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinovum algicola DG 898 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinovumAlgicolaDg898Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaSpDiamantCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Diamant Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpDiamantCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubritepidaFlocculansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubritepida flocculans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubritepidaFlocculansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StomoxysCalcitransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stomoxys calcitrans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StomoxysCalcitransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterCryoconitisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter cryoconitis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterCryoconitisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraNitrosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira nitrosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraNitrosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumMedacidig2bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp6529Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6529Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteibacterRhizovicinusDsm16549(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Luteibacter rhizovicinus DSM 16549 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LuteibacterRhizovicinusDsm16549", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpCfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dehalobacter sp. CF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DehalobacterSpCfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumRoopkundenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium roopkundense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumRoopkundenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilvanigrellaAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Silvanigrella aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SilvanigrellaAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumCdBkt12695(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum CD BKT12695 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumCdBkt12695", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisSubspLactaridiLmg23825(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis subsp. lactaridi LMG 23825 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CronobacterDublinensisSubspLactaridiLmg23825", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilusRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylophilus rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylophilusRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusPittmaniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus pittmaniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaemophilusPittmaniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzambacteriaBacteriumRifcsplowo201full4626Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azambacteria bacterium RIFCSPLOWO201FULL4626 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzambacteriaBacteriumRifcsplowo201full4626Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusAetherivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus aetherivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusAetherivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloligellaHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methyloligella halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethyloligellaHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp85200251971sch5477799a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251971SCH5477799a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251971sch5477799a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumArthrosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arthrosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArthrosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full3513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaematomicrobiumSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haematomicrobium sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaematomicrobiumSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurivibrioAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurivibrio alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurivibrioAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDadantiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dadantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DickeyaDadantiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbyssisolibacterFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Abyssisolibacter fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbyssisolibacterFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumPalustre(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium palustre graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumPalustre", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterTyphloniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter typhlonius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTyphloniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSediminicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus sediminicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusSediminicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpPg2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. PG-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpPg2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumGw2011gwc23714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium GW2011GWC23714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumGw2011gwc23714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferAgarilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer agarilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAgarilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GardnerellaVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpPbh53(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. PBH53 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpPbh53", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaHumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia humi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaHumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusPeraridilitorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus peraridilitoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusPeraridilitorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPaurosaccharolyticusJcm15092(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus JCM 15092 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticusJcm15092", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaTamlensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yoonia tamlensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YooniaTamlensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCuneatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterSp638(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. 638 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSp638", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpFh1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnohabitansSp63ed372Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 63ED37-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp63ed372Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumFrediiHh103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium fredii HH103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumFrediiHh103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumChungangense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium chungangense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumChungangense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSputiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Gordonia sputi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GordoniaSputiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmphibacillusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphibacillus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphibacillusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPropionicifaciensDsm19291Jcm14649(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens DSM 19291 JCM 14649 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciensDsm19291Jcm14649", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudothermotogaLettingae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudothermotoga lettingae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudothermotogaLettingae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumNorvegicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium norvegicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumNorvegicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EthanoligenensHarbinenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ethanoligenens harbinense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EthanoligenensHarbinenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterSp4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter sp. 47-17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaludibacterSp4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag330(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:330 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag330", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarichromatiumPurpuratumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marichromatium purpuratum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarichromatiumPurpuratumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho202full3713b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO202FULL3713b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho202full3713b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5519 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeclerciaAdecarboxylata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leclercia adecarboxylata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeclerciaAdecarboxylata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisMinervae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis minervae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisMinervae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaPediCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia pedi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaPediCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumKashiwanohensePv202Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense PV20-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohensePv202Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovibacterSpMfb070Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mangrovibacter sp. MFB070 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MangrovibacterSpMfb070Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariniradiusSaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mariniradius saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MariniradiusSaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumLp2aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium LP2A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumLp2aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanoperedensNitroreducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoperedens nitroreducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoperedensNitroreducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaPickettii12d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii 12D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettii12d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaBronchialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella bronchialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaBronchialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSpF0412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonella sp. F0412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSpF0412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasMexicanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas mexicana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasMexicanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpAt0102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. AT01-02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpAt0102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaOligospermaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exophiala oligosperma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExophialaOligospermaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag770(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:770 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag770", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar116ClusterCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR116 cluster Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar116ClusterCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasXinjiangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas xinjiangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasXinjiangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumGw2011gwe24058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCryaerophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cryaerophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCryaerophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasCircumdentaria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas circumdentaria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCircumdentaria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaNegevensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kingella negevensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KingellaNegevensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusParaphrohaemolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus paraphrohaemolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusParaphrohaemolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FodinicurvataFenggangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fodinicurvata fenggangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FodinicurvataFenggangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpWmma185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. WMMA185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpWmma185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeophocaenaAsiaeorientalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neophocaena asiaeorientalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeophocaenaAsiaeorientalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosopumilusKoreensisAr1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopumilus koreensis AR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopumilusKoreensisAr1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmmonifexDegensiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ammonifex degensii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmmonifexDegensiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaDumasianaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dumasiana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDumasianaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlexilineaFlocculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flexilinea flocculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlexilineaFlocculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAbyssalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus abyssalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAbyssalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KuraishiaCapsulataCbs1993Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kuraishia capsulata CBS 1993 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KuraishiaCapsulataCbs1993Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiphonobacterAquaeclarae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Siphonobacter aquaeclarae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SiphonobacterAquaeclarae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFlavidovirensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces flavidovirens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFlavidovirensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacteriumDehalogenansDsm11527Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacterium dehalogenans DSM 11527 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacteriumDehalogenansDsm11527Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusSpSoil748Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus sp. Soil748 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusSpSoil748Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumLentiflavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium lentiflavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumLentiflavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiumNeolycopersiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oidium neolycopersici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OidiumNeolycopersiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCuneatusDsm11391Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus DSM 11391 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatusDsm11391Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpHj(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. HJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpHj", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaSpAd6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola sp. AD6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrincolaSpAd6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusJurassicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusJurassicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0382Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0382Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacteraceaeBacteriumGwc25311Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacteraceae bacterium GWC2_53_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacteraceaeBacteriumGwc25311Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiberibacterAsiaticusGxpsyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Liberibacter asiaticus gxpsy Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LiberibacterAsiaticusGxpsyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YuhushiellaDesertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yuhushiella deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YuhushiellaDesertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumXbd2001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBD2001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbd2001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLionensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lionensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasLionensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLitoralisDsm11393(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis DSM 11393 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralisDsm11393", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGenitalium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma genitalium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaGenitalium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusNeutrinimicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus neutrinimicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusNeutrinimicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_50_50 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5050Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPiezophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia piezophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPiezophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaNitratireducenticrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga nitratireducenticrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaNitratireducenticrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapillibacterCinnamivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PapillibacterCinnamivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumMageritenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium mageritense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumMageritenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpGha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Gha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaLambliaP15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia P15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaP15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusMediterraneusDsm13871Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus DSM 13871 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneusDsm13871Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf2479Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF2479 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf2479Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterovibrioPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterovibrio pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterovibrioPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsphigho201full4623(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPHIGHO201FULL4623 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsphigho201full4623", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinocyclocheilusRhinocerous(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinocyclocheilus rhinocerous graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinocyclocheilusRhinocerous", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpF0040Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. F0040 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpF0040Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomeilibacteriaBacteriumRifcsplowo202full4811Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Komeilibacteria bacterium RIFCSPLOWO202FULL4811 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KomeilibacteriaBacteriumRifcsplowo202full4811Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaSimulansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila simulans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaSimulansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSpNd2010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sp. ND2010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSpNd2010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlycomycesHarbinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces harbinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycomycesHarbinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptacidiphilusOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptacidiphilus oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptacidiphilusOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaSinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brocadia sinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrocadiaSinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKazanBacteriumRbg13509Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division Kazan bacterium RBG_13_50_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKazanBacteriumRbg13509Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb1438bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB1438b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb1438bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifoxya12Full3519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFOXYA12_FULL_35_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifoxya12Full3519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpVer3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. Ver3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpVer3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesMinimusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anopheles minimus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnophelesMinimusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterSp38128Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 38-128 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp38128Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaSqualenifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea squalenifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubritaleaSqualenifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolactobacillusInulinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusInulinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllobaculumStercoricanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allobaculum stercoricanis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllobaculumStercoricanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusCapsulatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus capsulatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusCapsulatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_38_11b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full3811bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomonasSpAap53Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. AAP53 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpAap53Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterArboriphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter arboriphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterArboriphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho202full3815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO202FULL3815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho202full3815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SanguibacterGelidistatuariaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter gelidistatuariae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SanguibacterGelidistatuariaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf325(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf325 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf325", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaTomentosiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nicotiana tomentosiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NicotianaTomentosiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovermiculusHalophilusDsm18834Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovermiculus halophilus DSM 18834 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovermiculusHalophilusDsm18834Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterNitrofigilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter nitrofigilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterNitrofigilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag1060Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag1060Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomegalonemaPerideroedes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neomegalonema perideroedes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeomegalonemaPerideroedes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlwc3626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheionarchaeaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Theionarchaea archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TheionarchaeaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3630(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3630 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3630", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterWoliniiShCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii SH Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterWoliniiShCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudanabaenaSpPcc7367(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudanabaena sp. PCC7367 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudanabaenaSpPcc7367", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaApistaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea apista Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaApistaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaAfzeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia afzelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaAfzeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusUltunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ultunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusUltunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloceanibacterStevinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloceanibacter stevinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloceanibacterStevinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat25496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-25496 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat25496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusGauvreauiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus gauvreauii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusGauvreauiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsConfragosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps confragosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CordycepsConfragosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzovibrioRestrictusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azovibrio restrictus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzovibrioRestrictusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaGrenadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia grenadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaGrenadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpDd13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. DD13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpDd13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpTnd4ek4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. TND4EK4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpTnd4ek4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndosymbiontOfAcanthamoebaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Acanthamoeba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfAcanthamoebaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisIgneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris igneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisIgneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc13813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC1_38_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc13813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MonoraphidiumNeglectumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monoraphidium neglectum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonoraphidiumNeglectumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaMultilocaleAtcc49900(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acholeplasma multilocale ATCC 49900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcholeplasmaMultilocaleAtcc49900", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorocebusSabaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlorocebus sabaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlorocebusSabaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoorellaThermoaceticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moorella thermoacetica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoorellaThermoaceticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumGwa2349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium GWA2_34_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumGwa2349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitromicrobiumSpJlt1363Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citromicrobium sp. JLT1363 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitromicrobiumSpJlt1363Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XiphinematobacterSpIdahoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xiphinematobacter sp. Idaho Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XiphinematobacterSpIdahoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium RIFCSPHIGHO2_02_FULL_45_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumRifcsphigho202Full4520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPHIGHO2_02_FULL_40_12b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsphigho202Full4012b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HathewayaProteolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hathewaya proteolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HathewayaProteolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SanguibacterKeddieiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sanguibacter keddieii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SanguibacterKeddieiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasPolymorpha(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas polymorpha graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasPolymorpha", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesLianchengensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides lianchengensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesLianchengensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesDokdonensisFr1436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides dokdonensis FR1436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardioidesDokdonensisFr1436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg136212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG136212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg136212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomonasFuscaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermomonas fusca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermomonasFuscaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CuniculiplasmaDivulgatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cuniculiplasma divulgatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CuniculiplasmaDivulgatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Komeilibacteria bacterium RIFOXYD1_FULL_37_29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKomeilibacteriaBacteriumRifoxyd1Full3729Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo212full4413b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO212FULL4413b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo212full4413b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DanausPlexippusPlexippus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Danaus plexippus plexippus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DanausPlexippusPlexippus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaHaradaeaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia haradaeae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaHaradaeaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpDb56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. DB56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpDb56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumSpWn1359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Carnobacterium sp. WN1359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CarnobacteriumSpWn1359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminobacterHydrogenoformansDsm2784(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidaminobacter hydrogenoformans DSM 2784 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidaminobacterHydrogenoformansDsm2784", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumFlavumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium flavum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumFlavumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumFontis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium fontis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumFontis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira vanthielii serovar Holland str. Waz Holland ATCC 700522 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraVanthieliiSerovarHollandStrWazHollandAtcc700522", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesOleiciplenusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides oleiciplenus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOleiciplenusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaUrininfantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella urininfantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUrininfantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCancerogenusAtcc35316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus ATCC 35316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCancerogenusAtcc35316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodoferaxAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpMl3wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ML3W Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpMl3wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OncorhynchusMykissCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oncorhynchus mykiss Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OncorhynchusMykissCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusEquuli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus equuli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusEquuli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraCorneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calocera cornea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloceraCorneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpAe3006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. AE3006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpAe3006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesDermatitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces dermatitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlastomycesDermatitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlteromonasMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusPantotrophus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus pantotrophus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusPantotrophus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpTv2a2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Tv2a2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpTv2a2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinimicrobiumPekingense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinimicrobium pekingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinimicrobiumPekingense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaToluolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaToluolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyxococcalesBacterium6820Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myxococcales bacterium 68-20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyxococcalesBacterium6820Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NumidumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Numidum massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NumidumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWirthbacteriaBacteriumCg2305411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wirthbacteria bacterium CG2_30_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWirthbacteriaBacteriumCg2305411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoplasmaChauliocolaAtcc49578Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mesoplasma chauliocola ATCC 49578 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MesoplasmaChauliocolaAtcc49578Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferaxVolcanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferax volcanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferaxVolcanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonadaceaeBacteriumCg2303812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonadaceae bacterium CG2_30_38_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyromonadaceaeBacteriumCg2303812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterNecessariusStir1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius STIR1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusStir1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IndibacterAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Indibacter alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IndibacterAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocladiumSpEchb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermocladium sp. ECHB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermocladiumSpEchb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbaceaeBacteriumBrhc16a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbaceae bacterium BRHc16a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbaceaeBacteriumBrhc16a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaIgnavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Facklamia ignava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FacklamiaIgnavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaAichiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia aichiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaAichiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachybacteriumMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriumAilaaui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium ailaaui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumAilaaui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RaineyellaAntarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Raineyella antarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RaineyellaAntarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaSalexigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella salexigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaSalexigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermobacterMarburgensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermobacter marburgensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermobacterMarburgensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyramidobacterSpC128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyramidobacter sp. C12-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyramidobacterSpC128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RummeliibacillusStabekisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rummeliibacillus stabekisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RummeliibacillusStabekisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumSg813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SG8_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSg813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCollinoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus collinoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCollinoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisChungbukensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis chungbukensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisChungbukensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag678Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:678 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag678Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumMerycicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium merycicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMerycicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaTaiwanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma taiwanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaTaiwanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumOlb19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium OLB19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumOlb19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesQuadriannulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles quadriannulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesQuadriannulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesNaeslundii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces naeslundii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesNaeslundii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaaliaCardiffensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schaalia cardiffensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchaaliaCardiffensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpRoot122Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root122 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot122Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSaltans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter saltans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PedobacterSaltans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraMesophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira mesophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraMesophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusNeoformansVarNeoformansJec21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans var. neoformans JEC21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptococcusNeoformansVarNeoformansJec21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaccinostercusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumSg813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium SG8_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumSg813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusOremlandii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus oremlandii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusOremlandii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAegiribacteriaBacteriumMlsC(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aegiribacteria bacterium MLS_C graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAegiribacteriaBacteriumMlsC", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumAcnesSk182bjcviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium acnes SK182BJCVI Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumAcnesSk182bjcviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPallidula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola pallidula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaPallidula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterAurescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter aurescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterAurescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAlbus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp32146Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3214.6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp32146Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSenegalensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus senegalensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSenegalensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NisaeaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nisaea denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NisaeaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusPhoeniculicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus phoeniculicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusPhoeniculicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMethanolicusMga3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus MGA3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusMga3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_41_26 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CallorhinchusMiliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Callorhinchus milii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CallorhinchusMiliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterDuraquaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter duraquae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterDuraquaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioPaciniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio pacinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioPaciniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusAlkeniferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus alkenifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusAlkeniferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumFragaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium fragae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFragaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumMesophilicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium mesophilicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumMesophilicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag1193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:1193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag1193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumFerrireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum ferrireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumFerrireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacterium4787(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium 47-87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacterium4787", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrennerbacteriaBacteriumRifoxyd1full4116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brennerbacteria bacterium RIFOXYD1FULL4116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrennerbacteriaBacteriumRifoxyd1full4116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHimb30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium HIMB30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumHimb30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsphigho201full4827Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO201FULL4827 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho201full4827Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeotheceCitriformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gloeothece citriformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GloeotheceCitriformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaTyphi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica Typhi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaTyphi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpSoapLake7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Lake #7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpSoapLake7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterSubantarcticusLmg24377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter subantarcticus LMG 24377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterSubantarcticusLmg24377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsphigho202full4024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO202FULL4024 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho202full4024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsplowo212full4116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPLOWO212FULL4116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsplowo212full4116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterHydrocarbonoclasticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter hydrocarbonoclasticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterHydrocarbonoclasticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpPacm27299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. PACM 27299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpPacm27299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumUterequiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium uterequi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumUterequiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesTsukubensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces tsukubensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTsukubensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGobiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gobiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGobiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusLentulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus lentulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusLentulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasMoolapensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas moolapensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronomonasMoolapensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasSpAl212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas sp. AL212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasSpAl212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisNattoEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis natto Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisNattoEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_44_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumPhaseoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium phaseoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumPhaseoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArachidicoccusRhizosphaeraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus rhizosphaerae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusRhizosphaeraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpPcc7376Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. PCC7376 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpPcc7376Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterGracilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter gracilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterGracilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpLcm4579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LCM 4579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLcm4579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDesulfopertinaxCowenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfopertinax cowenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfopertinaxCowenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSp6728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 67-28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph2100Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH2100 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph2100Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPatagoniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus patagoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusPatagoniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoflexibacterRuberCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoflexibacter ruber Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoflexibacterRuberCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaAestuariiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina aestuarii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaAestuariiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzohydromonasAustralica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azohydromonas australica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzohydromonasAustralica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusReuteri10023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus reuteri 10023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusReuteri10023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB2_FULL_45_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb2Full4511Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAccumulibacterSpBa92(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. BA-92 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpBa92", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpC9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. C9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpC9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelobdellaRobustaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helobdella robusta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelobdellaRobustaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusEqui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEqui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumGwa2528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_52_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa2528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_44_22b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaCornellensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria cornellensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaCornellensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DevosiaSpLc5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. LC5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLc5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumShimoidei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shimoidei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShimoidei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpRoot381(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. Root381 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpRoot381", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNitrosopumilusKoreensisAr1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopumilus koreensis AR1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopumilusKoreensisAr1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryomycesMinteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryomyces minteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryomycesMinteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaPiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella pini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KwoniellaPiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CharaBraunii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chara braunii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CharaBraunii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenesDsm13106Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes DSM 13106 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenesDsm13106Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSp43bgom46mEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax sp. 43BGOM46m Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxSp43bgom46mEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_53_31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full5331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusViolaceofuscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DolosigranulumPigrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dolosigranulum pigrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DolosigranulumPigrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RyanbacteriaBacteriumRifcsphigho202full4513bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ryanbacteria bacterium RIFCSPHIGHO202FULL4513b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RyanbacteriaBacteriumRifcsphigho202full4513bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag95(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:95 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag95", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaProteobacteriumAap65Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium AAP65 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumAap65Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfarculaceaeBacteriumJdfr97Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculaceae bacterium JdFR-97 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfarculaceaeBacteriumJdfr97Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesInsulaeDsm17944Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardioides insulae DSM 17944 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardioidesInsulaeDsm17944Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoizmanbacteriaBacteriumGw2011gwa2377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA2377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa2377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumPhleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium phlei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumPhleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPLOWO2_02_FULL_42_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNucleicultrixAmoebiphilaFs5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nucleicultrix amoebiphila FS5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNucleicultrixAmoebiphilaFs5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwd26328(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWD2_63_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwd26328", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. arizonae serovar 62:z4,z23:- Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspArizonaeSerovar62Z4Z23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAsini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus asini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAsini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumProfundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium profundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumProfundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetakosakoniaMassiliensisJc163Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Metakosakonia massiliensis JC163 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MetakosakoniaMassiliensisJc163Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBalticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella baltica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBalticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrueperellaBernardiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trueperella bernardiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrueperellaBernardiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaGerundensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erwinia gerundensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErwiniaGerundensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethylopumilusTuricensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methylopumilus turicensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethylopumilusTuricensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorticoccusHydrocarbonoclasticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porticoccus hydrocarbonoclasticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorticoccusHydrocarbonoclasticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp131216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 13-12-16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp131216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViolaceusnigerCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces violaceusniger Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesViolaceusnigerCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SimonsiellaMuelleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Simonsiella muelleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SimonsiellaMuelleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPhaeoluteigriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces phaeoluteigriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPhaeoluteigriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KushneriaAvicenniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kushneria avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KushneriaAvicenniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioInopinatusDsm10711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio inopinatus DSM 10711 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioInopinatusDsm10711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaMinorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Weissella minor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WeissellaMinorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLiptonbacteriaBacteriumGwb1496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Liptonbacteria bacterium GWB1_49_6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLiptonbacteriaBacteriumGwb1496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomalleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaPseudomalleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematocidaParisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nematocida parisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NematocidaParisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwf23272Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWF23272 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwf23272Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterTropicalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter tropicalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetobacterTropicalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpJcm10914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 10914 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm10914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeAtcc13047Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae ATCC13047 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeAtcc13047Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaTularensisSchus4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella tularensis SCHUS4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaTularensisSchus4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UhrbacteriaBacteriumGw2011gwe24668Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWE24668 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwe24668Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KallipygaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KallipygaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNiigatensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia niigatensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaNiigatensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrigoribacteriumSpLeaf186Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frigoribacterium sp. Leaf186 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrigoribacteriumSpLeaf186Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaBeijingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea beijingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaBeijingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterArcticusA12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter arcticus A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PedobacterArcticusA12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacterium4484213Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484213 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484213Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaloceraViscosaTufc12733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Calocera viscosa TUFC12733 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaloceraViscosaTufc12733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisPotensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis potens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisPotensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaAmphilecti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina amphilecti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAmphilecti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumRifcsphigho212full5321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium RIFCSPHIGHO212FULL5321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumRifcsphigho212full5321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaAurantia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kushneria aurantia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KushneriaAurantia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloplanusVescusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus vescus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloplanusVescusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusEurythermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus eurythermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermococcusEurythermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumGlacieiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium glaciei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGlacieiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpNfr15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EndozoicomonasAscidiicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Endozoicomonas ascidiicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EndozoicomonasAscidiicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacteriaBacteriumGut307Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacteria bacterium GUT307 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FibrobacteriaBacteriumGut307Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FructobacillusTropaeoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fructobacillus tropaeoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FructobacillusTropaeoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusRaffinosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus raffinosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusRaffinosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterChlorophenolicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter chlorophenolicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterChlorophenolicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaChrysopicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma chrysopicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaChrysopicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacterium5254faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 5254FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium5254faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs4331Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4331 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4331Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLemmy01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LEMMY01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLemmy01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSp14b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum sp. 14B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSp14b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroscillaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microscilla marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicroscillaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU015 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12458059Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245805.9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12458059Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioAscidiaceicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio ascidiaceicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAscidiaceicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp4f(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 4F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp4f", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaceaeBacteriumKbs83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriaceae bacterium KBS83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaceaeBacteriumKbs83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitisVinifera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vitis vinifera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VitisVinifera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPLOWO2_01_FULL_43_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag508Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:508 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag508Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumGw2011Gwa24110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium GW2011_GWA2_41_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumGw2011Gwa24110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBiviaJcvihmp010(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia JCVIHMP010 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaJcvihmp010", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasUtahensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas utahensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasUtahensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasMediaWsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas media WS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AeromonasMediaWsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraMethylohalidivoransDsm14336Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans DSM 14336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivoransDsm14336Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JeotgalicoccusSp13mg44air(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Jeotgalicoccus sp. 13MG44air graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JeotgalicoccusSp13mg44air", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCibiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cibi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCibiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrettanomycesBruxellensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brettanomyces bruxellensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrettanomycesBruxellensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TsukamurellaPaurometabolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella paurometabola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPaurometabolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterRarusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter rarus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRarusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterDelicatusNbrc14919Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter delicatus NBRC 14919 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CurvibacterDelicatusNbrc14919Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6258Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6258 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6258Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidiphiliumAngustumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidiphilium angustum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidiphiliumAngustumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisLucifugusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myotis lucifugus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyotisLucifugusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaSiderisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Exophiala sideris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ExophialaSiderisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastomycesGilchristii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomycesGilchristii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacterium7018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium 70-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacterium7018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumChoerinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium choerinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumChoerinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumMarseillep2986Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium MarseilleP2986 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumMarseillep2986Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusOlitoriusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corchorus olitorius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorchorusOlitoriusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaAnatis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma anatis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAnatis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraImmundaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora immunda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraImmundaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FuerstiaMarisgermanicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fuerstia marisgermanicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FuerstiaMarisgermanicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpTd01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. TD01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpTd01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumA2KyotoCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium botulinum A2 Kyoto Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBotulinumA2KyotoCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZhouiaAmylolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zhouia amylolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZhouiaAmylolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaSpOralTaxon847Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptotrichia sp. oral taxon 847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptotrichiaSpOralTaxon847Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpJ14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. J14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpJ14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBohemicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter bohemicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBohemicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JorgensenbacteriaBacteriumRifcsphigho202full4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jorgensenbacteria bacterium RIFCSPHIGHO202FULL4520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JorgensenbacteriaBacteriumRifcsphigho202full4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium9143bfaaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 9143BFAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium9143bfaaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionZixibacteriaBacteriumSm2381(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium SM23_81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumSm2381", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCichoriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cichorii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCichoriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhialemoniopsisCurvataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phialemoniopsis curvata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhialemoniopsisCurvataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaGlathei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia glathei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaGlathei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTuaregiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus tuaregi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusTuaregiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusFulgidusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus fulgidus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusFulgidusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerocolumnaJejuensisDsm15929(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerocolumna jejuensis DSM 15929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerocolumnaJejuensisDsm15929", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_02_FULL_47_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho202Full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZonotrichiaAlbicollisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zonotrichia albicollis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZonotrichiaAlbicollisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCattleyaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cattleya Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCattleyaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpRoot83Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. Root83 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpRoot83Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag245(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:245 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag245", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusThoraltensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thoraltensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThoraltensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosospiraSpNsp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosospira sp. Nsp1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosospiraSpNsp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9605Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9605 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9605Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusAcidilactici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PediococcusAcidilactici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSph12015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Sph1(2015) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpSph12015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaBicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaBicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpJ56(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J56 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ56", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaGonorrhoeaeFa1090(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria gonorrhoeae FA 1090 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaGonorrhoeaeFa1090", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TimonellaSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Timonella senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TimonellaSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot1304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1304 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraMethylohalidivoransDsm14336(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leisingera methylohalidivorans DSM 14336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeisingeraMethylohalidivoransDsm14336", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasArabiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas arabiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasArabiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4246(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4246", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpAt1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. AT1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpAt1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumKbs146Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium KBS146 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumKbs146Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerratiaSpM24t3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia sp. M24T3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaSpM24t3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinosporangiumAlbumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinosporangium album Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinosporangiumAlbumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrotaleaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrotalea flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrotaleaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_01_FULL_39_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo201Full3928Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPHIGHO2_01_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaculaSpTsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. TS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpTsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterAnophelisNbrc107843Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter anophelis NBRC 107843 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JanibacterAnophelisNbrc107843Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusNantongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus nantongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNantongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_12_FULL_42_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho212Full4234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsphigho201full3717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO201FULL3717 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho201full3717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesBungoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces bungoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesBungoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrisporobacterGlycolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter glycolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterGlycolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifoxyd1full5236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFOXYD1FULL5236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifoxyd1full5236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusOryziterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus oryziterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusOryziterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaceaeBacteriumKa00182(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Veillonellaceae bacterium KA00182 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VeillonellaceaeBacteriumKa00182", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiellaIsopodorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella isopodorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaIsopodorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRbg16439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RBG_16_43_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRbg16439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumGa0074137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu023(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU023 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu023", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KazachstaniaSaulgeensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kazachstania saulgeensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KazachstaniaSaulgeensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesBacteriumUtcpr1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates bacterium UTCPR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesBacteriumUtcpr1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NevskiaSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nevskia soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NevskiaSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParoeduraPicta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paroedura picta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParoeduraPicta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaHeveanensisBcc8398Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella heveanensis BCC8398 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KwoniellaHeveanensisBcc8398Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerorhabdusFurcosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerorhabdus furcosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerorhabdusFurcosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumDesertiGimn1010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium deserti GIMN1.010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDesertiGimn1010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC4105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LutibacterSpLpb0138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lutibacter sp. LPB0138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LutibacterSpLpb0138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrochothrixThermosphacta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix thermosphacta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrochothrixThermosphacta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Beckwithbacteria bacterium GW2011_GWC1_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBeckwithbacteriaBacteriumGw2011Gwc14916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolbachiiSerovarCodiceStrCdcCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolbachii serovar Codice str. CDC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolbachiiSerovarCodiceStrCdcCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusAnthracisAmesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus anthracis Ames Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusAnthracisAmesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WinogradskyellaSpRha55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. RHA_55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpRha55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLugdunensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteriovoraxMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAlbulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces albulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAlbulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrothermaeBacteriumJdfr72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrothermae bacterium JdFR72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrothermaeBacteriumJdfr72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SparassisCrispaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sparassis crispa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SparassisCrispaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaProteobacteriumHtcc2080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return gamma proteobacterium HTCC2080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GammaProteobacteriumHtcc2080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PimelobacterSimplexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pimelobacter simplex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PimelobacterSimplexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriaceaeBacteriumDw12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriaceae bacterium DW12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriaceaeBacteriumDw12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArmillariaGallica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Armillaria gallica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArmillariaGallica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaSibiricaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia sibirica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaSibiricaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomonasSpRac04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastomonas sp. RAC04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastomonasSpRac04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusEvansiaMuelleri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Evansia muelleri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusEvansiaMuelleri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylopilaSp73bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylopila sp. 73B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylopilaSp73bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoanaerosceptrumFracticalcisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerosceptrum fracticalcis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerosceptrumFracticalcisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumGa0077551Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077551 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077551Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Klebsiella pneumoniae subsp. rhinoscleromatis ATCC 13884 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KlebsiellaPneumoniaeSubspRhinoscleromatisAtcc13884Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronohydrobacterThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronohydrobacter thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronohydrobacterThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PezolomaEricaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pezoloma ericae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PezolomaEricaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpMrmr6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MRMR6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMrmr6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium acetireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAcetireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AbsidiaRepens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Absidia repens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AbsidiaRepens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSalyersiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salyersiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalyersiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusManzaensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidianus manzaensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidianusManzaensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaSeeligeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria seeligeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaSeeligeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidaDubliniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candida dubliniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaDubliniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinibacterRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinibacter ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinibacterRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaThermophilaTm1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila TM-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaThermophilaTm1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CosenzaeaMyxofaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cosenzaea myxofaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CosenzaeaMyxofaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPHIGHO2_02_FULL_44_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsphigho202Full4412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpLeaf359Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. Leaf359 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpLeaf359Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpHun007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. HUN007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpHun007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRifcsplowo202full5016Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPLOWO202FULL5016 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsplowo202full5016Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpCf614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. CF614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpCf614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpNor37Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. NOR37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpNor37Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomonasJannaschiana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas jannaschiana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonasJannaschiana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusLarvaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus larvae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusLarvaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaProvencensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella provencensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaProvencensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EntomoplasmaLucivoraxAtcc49196(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax ATCC 49196 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaLucivoraxAtcc49196", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpCaviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpCaviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpF3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. F-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpF3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotruncusSpG3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotruncus sp. G3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotruncusSpG3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium4337Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 43-37 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium4337Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorellaEquigenitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorella equigenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorellaEquigenitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpCmf222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. Cmf 22.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpCmf222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsConfragosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps confragosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CordycepsConfragosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlb24484(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24484 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24484", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu033(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU033 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu033", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaTerpenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia terpenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaTerpenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FonsecaeaPedrosoiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fonsecaea pedrosoi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FonsecaeaPedrosoiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachybacteriumSpP610x1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brachybacterium sp. P610X1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrachybacteriumSpP610x1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteusHauseriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Proteus hauseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProteusHauseriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabaenaSpPcc7108Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anabaena sp. PCC7108 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnabaenaSpPcc7108Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasDenitrificansDsm6059(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas denitrificans DSM 6059 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasDenitrificansDsm6059", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumPhocae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium phocae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumPhocae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenopusTropicalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenopus tropicalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenopusTropicalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophothermusSpDtu052Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophothermus sp. DTU052 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophothermusSpDtu052Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SharpeaAzabuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sharpea azabuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SharpeaAzabuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobifidaHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermobifida halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermobifidaHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPeloridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter peloridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPeloridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CharaBrauniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chara braunii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CharaBrauniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaWadsworthiiDsm21896Atcc33877Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella wadsworthii DSM 21896 ATCC 33877 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaWadsworthiiDsm21896Atcc33877Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisChungbukensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis chungbukensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisChungbukensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpGw2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GW2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGw2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermacetogeniumPhaeumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermacetogenium phaeum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermacetogeniumPhaeumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisBriggsaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis briggsae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBriggsaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomagnumIshizawaiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylomagnum ishizawai Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylomagnumIshizawaiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusAlbus7Dsm20455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7  DSM 20455 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7Dsm20455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho202full5616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO202FULL5616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho202full5616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ItalianCloverEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Italian clover Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ItalianCloverEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterFormicigenesDsm15518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter formicigenes DSM 15518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TepidibacterFormicigenesDsm15518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobrancaGottschalkiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobranca gottschalkii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobrancaGottschalkiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GrimontiaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Grimontia indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GrimontiaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillibacterSpEr4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oscillibacter sp. ER4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OscillibacterSpEr4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag460(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:460 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag460", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaMagnaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella magna Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaMagnaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpNctc13003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. NCTC 13003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpNctc13003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterThereiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter thereius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcobacterThereiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho201full4012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL4012 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full4012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_37_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3713", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhlebiopsisGigantea110611Cr56Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phlebiopsis gigantea 11061_1 CR5-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhlebiopsisGigantea110611Cr56Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmoSalar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmo salar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmoSalar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiBacteriumNicil2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobi bacterium NICIL-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiBacteriumNicil2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNasuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusNasuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag568(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:568 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag568", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSabinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sabinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSabinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CercocebusAtys(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cercocebus atys graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CercocebusAtys", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_46_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella washoensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaWashoensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentisphaeraeBacteriumGwf23869Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_38_69 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf23869Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaCheerisanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kitasatospora cheerisanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KitasatosporaCheerisanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BerkelbacteriaBacteriumRifcsphigho212full369(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium RIFCSPHIGHO212FULL369 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumRifcsphigho212full369", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSacchari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Duganella sacchari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DuganellaSacchari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaLupiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea lupini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaLupiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDaejeonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus daejeonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDaejeonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_41_86 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4186", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAle23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALE23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAle23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumCg1023251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium CG1_02_32_51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumCg1023251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaViolaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella violacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaViolaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PatulibacterMinatonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Patulibacter minatonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PatulibacterMinatonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumZucineumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium zucineum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumZucineumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RufibacterTibetensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rufibacter tibetensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RufibacterTibetensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifoxyc12full6523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYC12FULL6523 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyc12full6523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaBenthicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella benthica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBenthicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciecolaPsychrophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Glaciecola psychrophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlaciecolaPsychrophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionCpr2BacteriumGw2011gwc23910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR2 bacterium GW2011GWC23910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr2BacteriumGw2011gwc23910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterAphrophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter aphrophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterAphrophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPyogenesJcm10003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides pyogenes JCM10003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPyogenesJcm10003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumKh1t2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium KH1T2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumKh1t2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaPallidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora pallida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaPallidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAltamirensisNbrc108246(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia altamirensis NBRC 108246 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaAltamirensisNbrc108246", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillibacterSpPc13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillibacter sp. PC13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillibacterSpPc13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEquorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus equorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusEquorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCaatingaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces caatingaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCaatingaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalusBaccata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Malus baccata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MalusBaccata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolffiiSerovarKhoratStrKhoratH2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Leptospira wolffii serovar Khorat str. Khorat-H2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LeptospiraWolffiiSerovarKhoratStrKhoratH2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CamelliaSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Camellia sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CamelliaSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicoccusRoseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus roseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusRoseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlf6676(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLF6676 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlf6676", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaWashoeensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella washoeensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaWashoeensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerdimonasFaecisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Merdimonas faecis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MerdimonasFaecisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110055(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110055", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusErwiniaHaradaeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Erwinia haradaeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusErwiniaHaradaeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MedicagoTruncatula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Medicago truncatula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MedicagoTruncatula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumGwa15114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium GWA15114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumGwa15114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCaspium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium caspium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCaspium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumRosaNbrc15208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium rosa NBRC 15208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumRosaNbrc15208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusMetallicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobus metallicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfolobusMetallicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCytotoxicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cytotoxicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCytotoxicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeminocystisHerdmaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geminocystis herdmanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeminocystisHerdmaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuillusLuteusUhSluLm8N1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Suillus luteus UH-Slu-Lm8-n1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SuillusLuteusUhSluLm8N1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaPiezophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia piezophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaPiezophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TyzzerellaNexilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tyzzerella nexilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TyzzerellaNexilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpWh8020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpNb68Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. NB68 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpNb68Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4186Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4186 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4186Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitritaleaHalalkaliphilaLw7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila LW7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphilaLw7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusDucreyiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus ducreyi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaemophilusDucreyiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusZeaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus zeae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusZeaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPseudotuberculosis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pseudotuberculosis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPseudotuberculosis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InsolitispirillumPeregrinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Insolitispirillum peregrinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "InsolitispirillumPeregrinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporobacterTermitidisDsm10068Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporobacter termitidis DSM 10068 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporobacterTermitidisDsm10068Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RIFCSPLOWO2_01_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRifcsplowo201Full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SistotremastrumSuecicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum suecicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumSuecicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSa213aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SA213A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSa213aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RheinheimeraPerlucida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera perlucida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPerlucida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuraishiaCapsulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kuraishia capsulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KuraishiaCapsulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpUnc438cl73tsus30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. UNC438CL73TsuS30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpUnc438cl73tsus30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisPb013t23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris PB013T23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisPb013t23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysiogenesArsenatisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chrysiogenes arsenatis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChrysiogenesArsenatisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DactylosporangiumAurantiacumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dactylosporangium aurantiacum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DactylosporangiumAurantiacumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisPvCampestrisStrAtcc33913Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris pv. campestris str. ATCC 33913 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisPvCampestrisStrAtcc33913Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchaedlerellaArabinosiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schaedlerella arabinosiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchaedlerellaArabinosiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KitasatosporaAureofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora aureofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAureofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OhtaekwangiaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ohtaekwangia koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OhtaekwangiaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_36_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasAsaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas asaccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasAsaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumHassiacum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium hassiacum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumHassiacum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu002(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU002 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu002", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumRifcsplowo212full317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium RIFCSPLOWO212FULL317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumRifcsplowo212full317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9301Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9301 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9301Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpX13sy08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. X13SY08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpX13sy08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaAuratinigra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora auratinigra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAuratinigra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AggregatibacterSpW10330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter sp. W10330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterSpW10330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OhtaekwangiaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ohtaekwangia koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OhtaekwangiaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRbg167010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RBG_16_70_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRbg167010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag533Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag533Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NioellaSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nioella sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NioellaSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacterium4920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4920 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoeciliaReticulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poecilia reticulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoeciliaReticulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaAureofaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora aureofaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaAureofaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNk4a179Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A179 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a179Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumCv2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium cv2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCv2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumL13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium L13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumL13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusFijiensisDsm17918Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis DSM 17918 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensisDsm17918Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaBalticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella baltica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaBalticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WildermuthbacteriaBacteriumGwa24615Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium GWA24615 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumGwa24615Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9322Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9322 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9322Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemophilus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemophilusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumGbs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium GBS-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumGbs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterMacacae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter macacae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterMacacae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidicaulisMarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tepidicaulis marinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TepidicaulisMarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpRitpieEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. RITPIe Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpRitpieEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus minor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusMinorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacillusKuerlensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacillus kuerlensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacillusKuerlensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFennelliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter fennelliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFennelliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSp73h25apCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 73H25AP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp73h25apCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterLuteus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter luteus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterLuteus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalobiumEvestigatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalobium evestigatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalobiumEvestigatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRifcsplowo201full4314(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPLOWO201FULL4314 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsplowo201full4314", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpNies3754(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. NIES-3754 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpNies3754", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifcsphigho201full4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4616 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodictyonLuteolum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelodictyon luteolum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelodictyonLuteolum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp2kl27Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 2KL-27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp2kl27Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaSp22iis9z10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stappia sp. 22IIS9Z10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StappiaSp22iis9z10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaPickettiiDtp0602Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia pickettii DTP0602 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaPickettiiDtp0602Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusSaccharolyticusDsm5350Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus DSM 5350 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticusDsm5350Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GluconobacterRoseus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter roseus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconobacterRoseus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisAtcc49296(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis ATCC49296 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisAtcc49296", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifcsplowo212full459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPLOWO212FULL459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsplowo212full459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPhytoplasmaPruniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Phytoplasma pruni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPhytoplasmaPruniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRhodniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodnii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeptunomonasPhycophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas phycophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasPhycophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaFlocculareAtcc27399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma flocculare ATCC 27399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaFlocculareAtcc27399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PortnoybacteriaBacteriumRifcsphigho212full389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portnoybacteria bacterium RIFCSPHIGHO212FULL389 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortnoybacteriaBacteriumRifcsphigho212full389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusSpBgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. BG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpBgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelampsoraLariciPopulina98ag31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Melampsora larici-populina 98AG31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MelampsoraLariciPopulina98ag31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuccinivibrioDextrinosolvensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Succinivibrio dextrinosolvens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SuccinivibrioDextrinosolvensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrispumMunicipaleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrispum municipale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrispumMunicipaleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpMwhadlerw8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. MWHAdlerW8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpMwhadlerw8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixCaldifontisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix caldifontis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiothrixCaldifontisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterTowneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter towneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTowneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsicumChinenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Capsicum chinense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CapsicumChinenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaCynosEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma cynos Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaCynosEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchlesneriaPaludicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schlesneria paludicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchlesneriaPaludicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_60_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwe13228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWE1_32_28 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwe13228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_49_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSpNh8bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania sp. NH8B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSpNh8bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumGilvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gilvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumGilvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDentisani7746Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7746 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7746Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusMulierisAtcc35239Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC 35239 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35239Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotodesmusKatoptronCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus katoptron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusKatoptronCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCastoreus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus castoreus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCastoreus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Azambacteria bacterium RIFCSPLOWO2_01_FULL_46_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAzambacteriaBacteriumRifcsplowo201Full4625Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumYuanmingenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium yuanmingense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumYuanmingenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsphigho202full4611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPHIGHO202FULL4611 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsphigho202full4611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaerovibrioVeloxCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermanaerovibrio velox Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermanaerovibrioVeloxCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalovivaxAsiaticusJcm14624Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halovivax asiaticus JCM 14624 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalovivaxAsiaticusJcm14624Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSilaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces silaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSilaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpAi1a2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ai1a2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpAi1a2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterGinsenosidimutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ginsenosidimutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PedobacterGinsenosidimutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTigurinusAz3aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus tigurinus AZ3a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusTigurinusAz3aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaRhamnosiphilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia rhamnosiphila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaRhamnosiphilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEntericus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus entericus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEntericus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPlatycodiJcm25414Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Asaia platycodi JCM 25414 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AsaiaPlatycodiJcm25414Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemonchusPlaceiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haemonchus placei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaemonchusPlaceiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AkkermansiaGlycaniphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Akkermansia glycaniphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AkkermansiaGlycaniphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumFirm05(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_05 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm05", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSubterrani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter subterrani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSubterrani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusStrNatl2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus str. NATL2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusStrNatl2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPontisDsm8475Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus pontis DSM 8475 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPontisDsm8475Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaMultacidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella multacida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaMultacidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ComamonasTestosteroniCnb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonas testosteroni CNB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonasTestosteroniCnb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpS5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. S5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OceanobacillusSpS5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YarrowiaLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YarrowiaLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesShahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes shahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesShahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaAtlanticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioclava atlantica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioclavaAtlanticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYD1_FULL_41_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyd1Full4124", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbugoCandidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Albugo candida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlbugoCandidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaPanamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leishmania panamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeishmaniaPanamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumMongolenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium mongolense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumMongolenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKimchiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRifcsplowo202full7116(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RIFCSPLOWO202FULL7116 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRifcsplowo202full7116", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho201full4111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO201FULL4111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho201full4111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRbg134613Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RBG134613 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRbg134613Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidianusCopahuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidianus copahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidianusCopahuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumUtcfx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscibacillusSalipiscarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentinulaEdodesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentinula edodes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentinulaEdodesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCoelicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces coelicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCoelicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaWadeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia wadei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaWadeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArsenophonusTriatominarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsenophonus triatominarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArsenophonusTriatominarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGinsengihumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus ginsengihumi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGinsengihumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseospirillumParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseospirillum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseospirillumParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaprolegniaParasitica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saprolegnia parasitica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaprolegniaParasitica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMedpeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MedPE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMedpeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium GW2011_GWA1_41_61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumGw2011Gwa14161Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSp4681(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. 4681 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSp4681", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifoxya2full3824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFOXYA2FULL3824 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifoxya2full3824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBirtlesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella birtlesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaBirtlesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpIs1264Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1264 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1264Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumEtliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium etli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumEtliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisMaydisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris maydis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BipolarisMaydisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentisphaeraeBacteriumGwf25093Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentisphaerae bacterium GWF2_50_93 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentisphaeraeBacteriumGwf25093Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag127Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:127 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag127Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpWmmb322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraGenomospEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera genomosp. Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraGenomospEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaBoryanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya boryana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaBoryanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterGuillouiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter guillouiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGuillouiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterPneumosintes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dialister pneumosintes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DialisterPneumosintes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCetiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus ceti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCetiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomonileTiedjei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomonile tiedjei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomonileTiedjei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsphigho201full4098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPHIGHO201FULL4098 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsphigho201full4098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpHensonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. hensonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpHensonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerXanaduensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halopiger xanaduensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalopigerXanaduensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaRattimassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella rattimassiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaRattimassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaPaurometabolica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora paurometabolica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaPaurometabolica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSrs2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SRS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSrs2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusVeneficusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus veneficus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusVeneficusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrachyspiraIntermediaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Brachyspira intermedia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BrachyspiraIntermediaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalococcoidesSpJdfr54(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dehalococcoides sp. JdFR-54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DehalococcoidesSpJdfr54", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseomonasRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseomonasRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacteralesBacteriumY4iEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacterales bacterium Y4I Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteralesBacteriumY4iEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_01_FULL_48_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterGudaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter gudaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterGudaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo2024111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_02_41_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo2024111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaSpRoot187Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora sp. Root187 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaSpRoot187Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumRifcsplowo201full5912Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFCSPLOWO201FULL5912 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifcsplowo201full5912Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraBorgpeterseniiSerovarPomonaStr200901868(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Leptospira borgpetersenii serovar Pomona str. 200901868 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LeptospiraBorgpeterseniiSerovarPomonaStr200901868", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerriphaselusSpR1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferriphaselus sp. R1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerriphaselusSpR1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinisporaPacificaDsm45544(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinispora pacifica DSM 45544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinisporaPacificaDsm45544", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusEllipticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusEllipticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_51_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full5114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusPicturaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus picturae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusPicturaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseburiaIntestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseburia intestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseburiaIntestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyc2full398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYC2FULL398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyc2full398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchotonaPrincepsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ochotona princeps Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OchotonaPrincepsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoriobacterialesBacteriumDnf00809Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriales bacterium DNF00809 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoriobacterialesBacteriumDnf00809Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaGrimmiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia grimmiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaGrimmiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DechloromonasAromaticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas aromatica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAromaticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE3251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E3251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE3251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumLimnosediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium limnosediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumLimnosediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LoktanellaCinnabarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Loktanella cinnabarina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LoktanellaCinnabarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacteriumPaucimobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium paucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumPaucimobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumDesouzaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium desouzaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumDesouzaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg135211(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_52_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg135211", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxFermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax fermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaHydrogenitoleransDsm16785Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinitoga hydrogenitolerans DSM 16785 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinitogaHydrogenitoleransDsm16785Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumLemurumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium lemurum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumLemurumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9107(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9107 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9107", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaSpCp2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda sp. CP2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaSpCp2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasChromatireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas chromatireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasChromatireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaBryantiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema bryantii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaBryantiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifcsphigho201full4213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFCSPHIGHO201FULL4213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifcsphigho201full4213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioEzuraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio ezurae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioEzuraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PristionchusPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pristionchus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PristionchusPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinoplanesSpTfc3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. TFC3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpTfc3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumToluclasticumAtcc700605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum ATCC 700605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AromatoleumToluclasticumAtcc700605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ApiotrichumPorosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Apiotrichum porosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ApiotrichumPorosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhydraLutrisKenyoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enhydra lutris kenyoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnhydraLutrisKenyoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchaedlerellaArabinosiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schaedlerella arabinosiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchaedlerellaArabinosiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwf13410Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWF13410 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwf13410Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodobacterAquimarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter aquimaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAquimarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpRtaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter sp. RTa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterSpRtaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaSpTm1040Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria sp. TM1040 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuegeriaSpTm1040Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm18996Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 18996 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm18996Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoactinomycesSpDsm45892Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces sp. DSM 45892 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesSpDsm45892Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterIndonesiensis5h1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis 5H-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensis5h1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoclostridiumPhytofermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium phytofermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumPhytofermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumSpAgr2158Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium sp. AGR2158 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumSpAgr2158Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OidiodendronMaiusZn(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oidiodendron maius Zn graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OidiodendronMaiusZn", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumTcs42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium tcs-42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumTcs42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMisasensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus misasensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMisasensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnidentifiedEubacteriumScb49(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return unidentified eubacterium SCB49 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnidentifiedEubacteriumScb49", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasDiminuta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas diminuta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasDiminuta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaTamuraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia tamurae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RickettsiaTamuraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_44_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConiochaetaLigniariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coniochaeta ligniaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConiochaetaLigniariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpMsp13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. MSP13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpMsp13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaBrassicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma brassicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaBrassicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusShapirobacteriaBacteriumGw2011Gwe23830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Shapirobacteria bacterium GW2011_GWE2_38_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusShapirobacteriaBacteriumGw2011Gwe23830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmoebophilusAsiaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amoebophilus asiaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmoebophilusAsiaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalypteAnnaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calypte anna Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalypteAnnaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RosaChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rosa chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RosaChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOk095(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OK095 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOk095", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp12451111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1245111.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp12451111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacterium5513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 55-13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium5513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_38_29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorellaAsinigenitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorella asinigenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorellaAsinigenitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EmpedobacterFalsenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Empedobacter falsenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EmpedobacterFalsenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumYoeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Plasmodium yoelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlasmodiumYoeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSalyersiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides salyersiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSalyersiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificansPd1222(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans PD1222 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ParacoccusDenitrificansPd1222", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Vogelbacteria bacterium RIFOXYB1_FULL_42_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusVogelbacteriaBacteriumRifoxyb1Full4216Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpErmr104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. ERMR1:04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpErmr104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumC7867004Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-004 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867004Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumAAtcc3502(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum A ATCC 3502 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumAAtcc3502", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaSaharensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinopolyspora saharensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinopolysporaSaharensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaFormicicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula formicica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaFormicicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumImcc26207(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium IMCC26207 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumImcc26207", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_47_33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSobriaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sobria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSobriaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelidibacterAlgensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter algens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GelidibacterAlgensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LebetimonasSpJs170Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lebetimonas sp. JS170 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LebetimonasSpJs170Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesKebangsaanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces kebangsaanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesKebangsaanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MailhellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mailhella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MailhellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentinusTigrinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentinus tigrinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentinusTigrinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CasaltellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Casaltella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CasaltellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusTuccetiDsm20183Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus tucceti DSM 20183 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusTuccetiDsm20183Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedAnaerotruncusSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Anaerotruncus sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedAnaerotruncusSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumEhc02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium EhC02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumEhc02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonadaceaeBacteriumH1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Comamonadaceae bacterium H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ComamonadaceaeBacteriumH1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaRochalimaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella rochalimae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaRochalimaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaHarenaeNbrc108248Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia harenae NBRC 108248 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaHarenaeNbrc108248Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoriobacteriaceaeBacterium6813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coriobacteriaceae bacterium 68-1-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoriobacteriaceaeBacterium6813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GrosmanniaClavigeraKw1407Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera kw1407 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GrosmanniaClavigeraKw1407Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaProfundaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga profunda Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaProfundaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusMesonae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus mesonae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMesonae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo201full4122Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO201FULL4122 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo201full4122Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiroplasmaEriocheiris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma eriocheiris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaEriocheiris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaSeminalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella seminalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaSeminalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscobolusImmersusRn42Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ascobolus immersus RN42 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AscobolusImmersusRn42Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg134322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_43_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc13712bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC13712b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc13712bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumChimaeraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium chimaera Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumChimaeraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusBrevisAtcc367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus brevis ATCC367 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBrevisAtcc367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccalesArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccales archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccalesArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiothrixLacustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiothrix lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiothrixLacustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GopherusAgassiziiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gopherus agassizii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GopherusAgassiziiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerotiniaSclerotiorum1980Uf70(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sclerotinia sclerotiorum 1980 UF-70 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SclerotiniaSclerotiorum1980Uf70", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumThermolithotrophumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium thermolithotrophum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumThermolithotrophumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpCci3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CcI3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCci3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PandoraeaSpIstkbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sp. ISTKB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSpIstkbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesJeddahensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces jeddahensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesJeddahensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPectinilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pectinilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPectinilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_01_FULL_41_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho201Full4120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumBbfl7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BBFL7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBbfl7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_56_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full5616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharicrinisFermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharicrinis fermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharicrinisFermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusDamuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus damuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusDamuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StereumHirsutumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stereum hirsutum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StereumHirsutumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusLocisalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus locisalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusLocisalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycisphaeraMikurensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaera mikurensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraMikurensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaFlavescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina flavescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaFlavescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterBaumanniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter baumannii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterBaumanniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloversatilisUniversalisEhg5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis universalis EHg5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisUniversalisEhg5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc24220(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_42_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc24220", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaceaeBacteriumScn5212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cytophagaceae bacterium SCN 52-12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CytophagaceaeBacteriumScn5212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaLutaonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muricauda lutaonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuricaudaLutaonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14912 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumSpScc3193(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium sp. SCC3193 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumSpScc3193", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusDuerdenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus duerdenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusDuerdenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSediminicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina sediminicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaSediminicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaCorporisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella corporis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaCorporisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusXylosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus xylosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusXylosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DermabacterVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dermabacter vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DermabacterVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp4g2div0659(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 4G2DIV0659 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp4g2div0659", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaZhangzhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muricauda zhangzhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuricaudaZhangzhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBacteroidesPeriocalifornicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus [Bacteroides] periocalifornicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBacteroidesPeriocalifornicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFicariaNbrc102596Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia ficaria NBRC 102596 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaFicariaNbrc102596Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynergistesSp31syn1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synergistes sp. 31syn1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynergistesSp31syn1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasEndodontalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas endodontalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasEndodontalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionisporaVibrioides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Propionispora vibrioides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PropionisporaVibrioides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasSpDtu019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas sp. DTU019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasSpDtu019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromicrobiumLacuslunaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychromicrobium lacuslunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychromicrobiumLacuslunaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarsonellaRuddiiHcThao2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carsonella ruddii HC Thao2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarsonellaRuddiiHcThao2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaFormicicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula formicica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaFormicicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoheibacterSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moheibacter sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoheibacterSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinosynnemaSpAli144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema sp. ALI-1.44 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaSpAli144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KwoniellaPiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella pini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KwoniellaPiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobaculumLitoreumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSoil761(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil761 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil761", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb1388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb1388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_45_11c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsphigho202full4332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPHIGHO202FULL4332 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsphigho202full4332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMediterraneenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium mediterraneense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMediterraneenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesThetaiotaomicronCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides thetaiotaomicron Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesThetaiotaomicronCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRiesiaSpGbbuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Riesia sp. GBBU Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRiesiaSpGbbuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DietziaSpUcdthpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dietzia sp. UCDTHP Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DietziaSpUcdthpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaRiguiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma rigui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRiguiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcaceaeBacteriumD16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpWcd3002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. WCD3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioSpWcd3002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeopsychrobacterElectrodiphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geopsychrobacter electrodiphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeopsychrobacterElectrodiphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwa24319Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWA2_43_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwa24319Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycisphaeraMikurensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycisphaera mikurensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycisphaeraMikurensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorhabdusTiamateaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus tiamatea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusTiamateaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWs6BacteriumOlb21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WS6 bacterium OLB21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWs6BacteriumOlb21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusHnlc2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus HNLC2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusHnlc2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenibacillusSchlegelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenibacillus schlegelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenibacillusSchlegelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixInsectorumRcef264Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix insectorum RCEF 264 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporothrixInsectorumRcef264Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces canus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpFf12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FF12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFf12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusNuruki(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus nuruki graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusNuruki", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm9796Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 9796 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm9796Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeodactylumTricornutumCcap10551(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phaeodactylum tricornutum CCAP 1055/1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhaeodactylumTricornutumCcap10551", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterIndicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter indicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterIndicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumGwf24113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWF2_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwf24113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylothermusHellenicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylothermus hellenicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylothermusHellenicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KyrpidiaTusciaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kyrpidia tusciae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KyrpidiaTusciaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbaspirillum massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HerbaspirillumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BilophilaWadsworthiaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BilophilaWadsworthiaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NealsonbacteriaBacteriumRifoxyb1full4015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nealsonbacteria bacterium RIFOXYB1FULL4015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NealsonbacteriaBacteriumRifoxyb1full4015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WuchereriaBancrofti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wuchereria bancrofti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WuchereriaBancrofti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaGlabrataCbs138(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return [Candida] glabrata CBS 138 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidaGlabrataCbs138", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusSpSdbEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sp. SDB Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSpSdbEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSaccharophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema saccharophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSaccharophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercocebusAtysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cercocebus atys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CercocebusAtysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraImmundaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora immunda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraImmundaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilumDsm21637(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum DSM 21637 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilumDsm21637", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioLogei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio logei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliivibrioLogei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNbrc109706(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NBRC 109706 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNbrc109706", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeomarinobacterEctocarpi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeomarinobacter ectocarpi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeomarinobacterEctocarpi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSteeleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella steelei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaSteeleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaMiroungaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Facklamia miroungae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FacklamiaMiroungaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumBetavasculorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium betavasculorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBetavasculorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusLimiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus limi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusLimiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychromonasArcticaDsm14288Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Psychromonas arctica DSM 14288 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PsychromonasArcticaDsm14288Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MiscellaneousCrenarchaeotaGroup6ArchaeonAd81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return miscellaneous Crenarchaeota group-6 archaeon AD8-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MiscellaneousCrenarchaeotaGroup6ArchaeonAd81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophorhabdusAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophorhabdus aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophorhabdusAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSeriolaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia seriolae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaSeriolaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPLOWO2_01_FULL_48_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSpongiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas spongiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpongiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IsoptericolaVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterSpAm1d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. AM1D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterSpAm1d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRifcsphigho212full4510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RIFCSPHIGHO212FULL4510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRifcsphigho212full4510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenericutesBacteriumGwf235184(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenericutes bacterium GWF2_35_184 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenericutesBacteriumGwf235184", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSpCag156(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag156", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpHun007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. HUN007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpHun007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:555 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusManasiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus manasiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusManasiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpWsm3626Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. WSM3626 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpWsm3626Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaSpH567Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. H567 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpH567Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaReeseiQm6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichoderma reesei QM6a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichodermaReeseiQm6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaMargrebowieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma margrebowiei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMargrebowieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMicrogenomatusAuricolaScgcAaa011E14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Microgenomatus auricola SCGC AAA011-E14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMicrogenomatusAuricolaScgcAaa011E14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwa14424(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWA1_44_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwa14424", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium32(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium32", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusMucosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius mucosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMucosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full4212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumNebraskense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium nebraskense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumNebraskense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaMellicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wallemia mellicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WallemiaMellicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsukibacteriumIkkense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsukibacterium ikkense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArsukibacteriumIkkense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterCryaerophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter cryaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterCryaerophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13140cm2607Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_1_40CM_2_60_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13140cm2607Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BasidiobolusMeristosporusCbs93173Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Basidiobolus meristosporus CBS 931.73 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BasidiobolusMeristosporusCbs93173Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpCfcc11742Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. CFCC 11742 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumSpCfcc11742Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsphigho201full4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPHIGHO201FULL4520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsphigho201full4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasStutzeri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterPinnipediorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter pinnipediorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterPinnipediorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariniphagaAnaerophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mariniphaga anaerophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MariniphagaAnaerophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifcsphigho202full3412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPHIGHO202FULL3412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsphigho202full3412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraNanhaiensisE4078Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rheinheimera nanhaiensis E407-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RheinheimeraNanhaiensisE4078Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosocosmicusOleophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus oleophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusOleophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasSpRu39bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas sp. RU39B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeromonasSpRu39bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacunisphaeraLimnophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lacunisphaera limnophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LacunisphaeraLimnophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwc14518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWC14518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwc14518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpSgdv85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. SGDV85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpSgdv85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitibacterAlkalitoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumThalpophilumDsm11723Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium thalpophilum DSM 11723 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumThalpophilumDsm11723Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusTaiwanensisDsm18679Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus taiwanensis DSM 18679 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusTaiwanensisDsm18679Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrocoleusVaginatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus vaginatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusVaginatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumMedacidig2a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium MedAcidiG2A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumMedacidig2a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCancerogenusAtcc35316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus ATCC 35316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCancerogenusAtcc35316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaJogaejeotgali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Weissella jogaejeotgali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WeissellaJogaejeotgali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuegeriaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuegeriaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilvibacteriumBohemicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Silvibacterium bohemicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SilvibacteriumBohemicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSp2gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. 2G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSp2gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EncephalitozoonCuniculiGbM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi GB-M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculiGbM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasParafulvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas parafulva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasParafulvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterLuteusImvB3098Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter luteus IMV-B-3098 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacterLuteusImvB3098Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumPhosphoreumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium phosphoreum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumPhosphoreumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraYegresiiCbs114405Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii CBS 114405 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CladophialophoraYegresiiCbs114405Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumMs4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium MS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumMs4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscobolusImmersusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ascobolus immersus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AscobolusImmersusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGuanduensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces guanduensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGuanduensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaThermophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia thermophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaThermophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaThermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Fischerella thermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FischerellaThermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumHochstenium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum hochstenium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumHochstenium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophoarchaeumButanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum butanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumButanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaLaterculaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina latercula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaLaterculaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaSuccinifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema succinifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSuccinifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpPamc26561Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. PAMC 26561 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpPamc26561Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKullabergensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kullabergensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKullabergensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexusSpMsgCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. MSG Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpMsgCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurospirillumArsenophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfurospirillum arsenophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfurospirillumArsenophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumRufumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rufum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRufumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurellaAmilsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfurella amilsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfurellaAmilsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZetaproteobacteriaBacteriumCg1025345Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_53_45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1025345Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerobiusPolysaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerobius polysaccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldanaerobiusPolysaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaIndicaGroupEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Group Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OryzaSativaIndicaGroupEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriaceaeBacteriumChkci005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricibacterSanguinisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sanguinis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSanguinisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsCamponotirufipedisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps camponotirufipedis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsCamponotirufipedisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumLactilyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium lactilytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumLactilyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlasmodiumFalciparum3d7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium falciparum 3D7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumFalciparum3d7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpSt2l15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpWri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. wRi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaSpWri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsplowo212full4712Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPLOWO212FULL4712 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsplowo212full4712Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSp2742308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia sp. 2742-308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaSp2742308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusObscurusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus obscurus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusObscurusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaSp1Ertm2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nematocida sp. 1 ERTm2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NematocidaSp1Ertm2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpCny243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNY243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpCny243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaOblongaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moraxella oblonga Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoraxellaOblongaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_01_FULL_46_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho201Full4623Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSp446Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 446 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp446Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberibacillusSpMarseillep3662Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tuberibacillus sp. MarseilleP3662 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuberibacillusSpMarseillep3662Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiardiaLambliaAtcc50803(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giardia lamblia ATCC 50803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiardiaLambliaAtcc50803", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPLOWO2_01_FULL_48_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsplowo201Full4811", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaPalythoaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella palythoae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaPalythoaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpRlCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RL Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpRlCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCristatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus cristatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCristatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaGallinaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia gallinacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaGallinaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHungaricumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hungaricum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHungaricumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSpOcn003Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. OCN003 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpOcn003Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IntrasporangiumCalvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Intrasporangium calvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IntrasporangiumCalvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwa24315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWA2_43_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwa24315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParambassisRangaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parambassis ranga Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParambassisRangaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaWenyoniiStrMassachusetts(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii str. Massachusetts graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaWenyoniiStrMassachusetts", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasNeptuniumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas neptunium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomonasNeptuniumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpCag268(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. CAG:268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpCag268", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnserCygnoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anser cygnoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnserCygnoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYr528(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YR528 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYr528", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf24518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF24518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf24518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSpKk1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. KK1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpKk1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterIshigakiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter ishigakiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterIshigakiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLiaoningense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium liaoningense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLiaoningense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTofieldiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tofieldiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTofieldiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterIshigakiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter ishigakiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterIshigakiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SmittiumMucronatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Smittium mucronatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SmittiumMucronatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag1058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpRoot1279Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root1279 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot1279Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusPanaciterraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusPanaciterraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAap1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaKt2440(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida KT2440 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaKt2440", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusMusculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mus musculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MusMusculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelomonasSpRoot1217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelomonas sp. Root1217 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelomonasSpRoot1217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomicrobiumSulfonivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sulfonivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSulfonivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumHimb11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium HIMB11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumHimb11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKuenenbacteriaBacteriumCg2303924Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium CG2_30_39_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumCg2303924Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusVaccinostercusDsm20634(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus vaccinostercus DSM 20634 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusVaccinostercusDsm20634", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaChokoriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora chokoriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaChokoriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasParapaucimobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas parapaucimobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasParapaucimobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioMediterraneiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio mediterranei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioMediterraneiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumCarotovorumOdoriferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum odoriferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumOdoriferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterSpBa92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter sp. BA92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterSpBa92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor3BacteriumSm2342(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return candidate division WOR_3 bacterium SM23_42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidateDivisionWor3BacteriumSm2342", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelodiscusSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pelodiscus sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PelodiscusSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumCanariasenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium canariasense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCanariasenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacellibacteroidesSpHhzs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macellibacteroides sp. HHZS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacellibacteroidesSpHhzs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCamelliaeDsm22697Jcm13995Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae DSM 22697 JCM 13995 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCamelliaeDsm22697Jcm13995Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropherymaWhippleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tropheryma whipplei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TropherymaWhippleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacillusPleuropneumoniae14074(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 1 4074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae14074", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusPauculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pauculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPauculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridioidesMangenotiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridioides mangenotii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridioidesMangenotiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfolobusAcidocaldarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sulfolobus acidocaldarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SulfolobusAcidocaldarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxWautersii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax wautersii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxWautersii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeovibrioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeovibrioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeovibrioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MooreaProducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moorea producens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MooreaProducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPseudogenitaliumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium pseudogenitalium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumPseudogenitaliumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNiameyenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium niameyense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumNiameyenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpMbes04Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. MBES04 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpMbes04Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumTegetincolaDsm22377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium tegetincola DSM 22377 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumTegetincolaDsm22377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumAzadirachtaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium azadirachtae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAzadirachtaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaDilworthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia dilworthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaDilworthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho2024118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO2024118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho2024118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LepidothrixCoronataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lepidothrix coronata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LepidothrixCoronataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536k22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536K22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536k22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaDrilacis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niabella drilacis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiabellaDrilacis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensHk44Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens HK44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensHk44Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpOralTaxon020StrF0370Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. oral taxon 020 str. F0370 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSpOralTaxon020StrF0370Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCitronellolisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas citronellolis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCitronellolisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpFf4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. FF4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusSpFf4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaErectaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Drosophila erecta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DrosophilaErectaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaDisparEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Veillonella dispar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDisparEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE1747(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E1747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE1747", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusGallinarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus gallinarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusGallinarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesSaopaulenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides saopaulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesSaopaulenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaburkholderiaXenovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia xenovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaXenovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumHibernum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium hibernum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumHibernum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrypanosomaCruziStrainClBrener(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trypanosoma cruzi strain CL Brener graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrypanosomaCruziStrainClBrener", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumBlastocrithidii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium blastocrithidii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumBlastocrithidii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriumAlbumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacterium album Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriumAlbumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSp6829Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 68-29 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6829Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCrhEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CRH Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCrhEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaConceptionensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella conceptionensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaConceptionensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5424Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5424 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5424Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumRifcsplowo202full6721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaFraseriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila fraseri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaFraseriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSp5c6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. 5C6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSp5c6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpLpb0142(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. LPB0142 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpLpb0142", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu013Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU013 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu013Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumSpXm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. XM-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpXm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpBs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasShengliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas shengliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasShengliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptoalloteichusHindustanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptoalloteichus hindustanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptoalloteichusHindustanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpPamc26628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. PAMC 26628 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpPamc26628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusLuminyensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FalkowbacteriaBacteriumCg1023721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Falkowbacteria bacterium CG1023721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FalkowbacteriaBacteriumCg1023721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRbg166620(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_66_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166620", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaballeroniaTellurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia telluris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTellurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:555 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBeijingensisNbrc16342Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia beijingensis NBRC 16342 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaBeijingensisNbrc16342Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp4g2div0659Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 4G2DIV0659 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp4g2div0659Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFluorescensPf01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens Pf01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensPf01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpLf2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. LF2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpLf2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumThermoalcaliphilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] thermoalcaliphilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumThermoalcaliphilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiothermusRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiothermusRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaNelsoniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella nelsoni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaNelsoniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionibacteriumGranulosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium granulosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumGranulosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumAutotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium autotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumAutotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterXylinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterXylinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusAfricanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus africanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAfricanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSpMb263(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. MB263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpMb263", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdoniaSpMed134(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dokdonia sp. MED134 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DokdoniaSpMed134", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerosporomusaSubterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerosporomusa subterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerosporomusaSubterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaDioxanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia dioxanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaDioxanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaCellobiosiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta cellobiosiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaCellobiosiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOk095Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. OK095 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOk095Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKryptobacterTengchongensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kryptobacter tengchongensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKryptobacterTengchongensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusViolaceofuscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpGib2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. GIB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpGib2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpGfaj1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. GFAJ1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpGfaj1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloperonosporaArabidopsidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyaloperonospora arabidopsidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyaloperonosporaArabidopsidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronomonasPharaonisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas pharaonis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronomonasPharaonisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpAp23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. AP23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAp23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeromyxobacterDehalogenans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeromyxobacter dehalogenans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeromyxobacterDehalogenans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolicicoccusSubflavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Amycolicicoccus subflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AmycolicicoccusSubflavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumAb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium AB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumAb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUzinuraDiaspidicolaStrAsner(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uzinura diaspidicola str. ASNER graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUzinuraDiaspidicolaStrAsner", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaGlaucaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora glauca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaGlaucaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_60_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full6025Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenorhabditisJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSaprophyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus saprophyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSaprophyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5421bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5421b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5421bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumGwa25134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_51_34 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa25134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpDoa9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. DOA9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpDoa9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GaeumannomycesGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gaeumannomyces graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GaeumannomycesGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAlgidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus algidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAlgidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYD12_FULL_48_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyd12Full4821Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KozakiaBaliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kozakia baliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KozakiaBaliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaCynodegmiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga cynodegmi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCynodegmiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusParafarraginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus parafarraginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusParafarraginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc24031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC24031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc24031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaSinica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sinica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSinica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PectobacteriumBrasiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pectobacterium brasiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PectobacteriumBrasiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsplowo201full4249Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPLOWO201FULL4249 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsplowo201full4249Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElectrophorusElectricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Electrophorus electricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElectrophorusElectricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusAgarilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halococcus agarilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalococcusAgarilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpHl58Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. HL58 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpHl58Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiimonasLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kordiimonas lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KordiimonasLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumDamselae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium damselae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumDamselae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ValsaMalicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Valsa malicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ValsaMalicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpJ31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. J31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpJ31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrusClementinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrus clementina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrusClementinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasSpLeaf131Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Leaf131 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpLeaf131Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineActinobacteriumMedacidiG3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return marine actinobacterium MedAcidi-G3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineActinobacteriumMedacidiG3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterLuteolusNbrc107841Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter luteolus NBRC 107841 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterLuteolusNbrc107841Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLipolyticusSm19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus SM19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusSm19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPanisDsm6035Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus panis DSM 6035 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusPanisDsm6035Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporothrixSchenckiiAtcc58251Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii ATCC 58251 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SporothrixSchenckiiAtcc58251Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EremotheciumCymbalariaeDbvpg7215(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eremothecium cymbalariae DBVPG#7215 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EremotheciumCymbalariaeDbvpg7215", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwc23313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWC23313 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwc23313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_68_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachymonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpEr16(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. ER1/6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpEr16", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckiiExf2000(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hortaea werneckii EXF-2000 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HortaeaWerneckiiExf2000", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NdongobacterMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ndongobacter massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NdongobacterMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaDentiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria dentiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaDentiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSpLeaf369Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. Leaf369 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpLeaf369Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSomaliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces somaliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSomaliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16437(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_43_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16437", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaSpApa3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bizionia sp. APA-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BizioniaSpApa3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanomethylicusMesodigestumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus mesodigestum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusMesodigestumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiacini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niacini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusNiacini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpP6a1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. P6A1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpP6a1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSp23gom1509mEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 23GOM1509m Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HalomonasSp23gom1509mEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LampropediaHyalinaDsm16112Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lampropedia hyalina DSM 16112 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LampropediaHyalinaDsm16112Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumFrigidisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium frigidisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumFrigidisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoduganellaViolaceinigraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaSonneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shigella sonnei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShigellaSonneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPHIGHO2_12_FULL_46_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsphigho212Full4616", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusUreilyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureilyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreilyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryctolagusCuniculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryctolagus cuniculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryctolagusCuniculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocaldumSp14bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum sp. 14B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSp14bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmoTrutta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salmo trutta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalmoTrutta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTetani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaludibacterPropionicigenesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paludibacter propionicigenes Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaludibacterPropionicigenesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaChrysopicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma chrysopicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaChrysopicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudarthrobacterChlorophenolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter chlorophenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterChlorophenolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterAntibioticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter antibioticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterAntibioticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnt360Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNT360 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnt360Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpAap93Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. AAP93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpAap93Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumChubuenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chubuense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChubuenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ConchiformibiusSteedaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Conchiformibius steedae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConchiformibiusSteedaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArtemisiaAnnua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Artemisia annua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArtemisiaAnnua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpHl93(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL-93 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl93", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesUrogenitalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces urogenitalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesUrogenitalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorDanieliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor danielii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorDanieliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasStutzeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSpC05Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C05 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC05Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ExophialaDermatitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaDermatitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSpYr573(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. YR573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpYr573", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_02_FULL_38_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo202Full3818", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSaoudiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella saoudiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSaoudiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSuisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter suis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSuisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacterium5254faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium 5254FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacterium5254faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMycoplasmaHaemolamaeStrPurdue(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemolamae str. Purdue graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemolamaeStrPurdue", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaTestudinisDsm23072Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella testudinis DSM 23072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaTestudinisDsm23072Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HespelliaStercorisuisDsm15480Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hespellia stercorisuis DSM 15480 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HespelliaStercorisuisDsm15480Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErysipelotrichaceaeBacteriumI46Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium I46 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumI46Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumCg1024390Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium CG1_02_43_90 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumCg1024390Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasSpMex14Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas sp. Mex14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasSpMex14Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwa2319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_31_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa2319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiO157h7Edl933Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Escherichia coli O157H7 EDL933 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EscherichiaColiO157h7Edl933Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelcococcusKunziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helcococcus kunzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelcococcusKunziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrogenomatesGroupBacteriumGw2011gwc13712b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWC13712b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwc13712b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusChampanellensis18p13Jcm17042Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus champanellensis 18P13 JCM 17042 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusChampanellensis18p13Jcm17042Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanomicrobiumGlacieiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planomicrobium glaciei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanomicrobiumGlacieiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OphiocordycepsSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ophiocordyceps sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OphiocordycepsSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPneumoniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pneumoniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaPneumoniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanocaldococcusBathoardescensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus bathoardescens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusBathoardescensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAminophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio aminophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAminophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosovibrioSpNv6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosovibrio sp. Nv6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosovibrioSpNv6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpYr651Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. YR651 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpYr651Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BipolarisZeicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bipolaris zeicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BipolarisZeicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifcsphigho201full4029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFCSPHIGHO201FULL4029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifcsphigho201full4029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFreiburgenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium freiburgense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFreiburgenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFOXYA1_FULL_41_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifoxya1Full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrdosporaColligataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ordospora colligata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrdosporaColligataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifoxyb1full3744Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYB1FULL3744 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyb1full3744Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium GW2011_GWB1_54_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumGw2011Gwb1547Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpNiph758(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph758", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloceraCornea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calocera cornea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaloceraCornea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusFusiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus fusiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusFusiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobisporaBisporaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobispora bispora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobisporaBisporaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GuillardiaThetaCcmp2712(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Guillardia theta CCMP2712 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GuillardiaThetaCcmp2712", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumThermophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium thermophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumThermophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMandeliiPd30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas mandelii PD30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMandeliiPd30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumMs0242a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium MS0242A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumMs0242a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospinaGracilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospina gracilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospinaGracilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaSpiralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella spiralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaSpiralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCoccineaBrfm310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trametes coccinea BRFM310 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrametesCoccineaBrfm310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTetanomorphum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tetanomorphum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTetanomorphum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpVk13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. VK13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpVk13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnhygromyxaSalina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enhygromyxa salina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnhygromyxaSalina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TardiphagaRobiniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tardiphaga robiniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TardiphagaRobiniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraInopinataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira inopinata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrospiraInopinataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrls87Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS87 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls87Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCelerecrescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] celerecrescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelerecrescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaAzureaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora azurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaAzureaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioDesulfuricansNd132Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio desulfuricans ND132 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioDesulfuricansNd132Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaPiniCbs10737Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella pini CBS 10737 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "KwoniellaPiniCbs10737Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacillusCaeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus caeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusCaeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumRifcsphigho212full4911Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPHIGHO212FULL4911 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsphigho212full4911Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriaceaeBacteriumChkci005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacteriaceae bacterium CHKCI005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriaceaeBacteriumChkci005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZimmermannellaBifidaNbrc103089Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return [Zimmermannella] bifida NBRC 103089 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ZimmermannellaBifidaNbrc103089Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaAttenuataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana attenuata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NicotianaAttenuataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalibacteriumPrausnitziiKle1255Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii KLE1255 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiKle1255Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumTimonense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Varibaculum timonense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VaribaculumTimonense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusSpYr651(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. YR651 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpYr651", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicola5a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola 5A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicola5a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SediminicolaSpYik13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sediminicola sp. YIK13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SediminicolaSpYik13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterMarinusA45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter marinus A45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacterMarinusA45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusVitulinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus vitulinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusVitulinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCaccae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus caccae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusCaccae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag927Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:927 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag927Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaLaeviribosi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cohnella laeviribosi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CohnellaLaeviribosi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycesSpShpl14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomyces sp. SHPL14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycesSpShpl14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAnanatisAj13355Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pantoea ananatis AJ13355 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PantoeaAnanatisAj13355Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusMurrayiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus murrayi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMurrayiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaDejecticolaCbs10117Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola CBS 10117 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KwoniellaDejecticolaCbs10117Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaQueenslandensisAustNh15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis AUST/NH15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaQueenslandensisAustNh15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonoraphidiumNeglectumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monoraphidium neglectum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonoraphidiumNeglectumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacterialesBacteriumBrhc54Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium BRHc54 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumBrhc54Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeon13140cm3386Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon 13_1_40CM_3_38_6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeon13140cm3386Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwc2387(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWC2387 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwc2387", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterLusitanusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter lusitanus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterLusitanusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassospiraSpMccc1a01148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. MCCC 1A01148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpMccc1a01148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmaVolcanium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma volcanium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaVolcanium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serendipita indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerendipitaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaRustigianiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Providencia rustigianii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProvidenciaRustigianiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphimedonQueenslandicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphimedon queenslandica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphimedonQueenslandicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumStanieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumStanieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpTpa0875Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0875 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0875Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusSpJcm19060(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus sp. JCM 19060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusSpJcm19060", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisSalinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis salina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisSalinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasSpEur3121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. EUR3 1.2.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpEur3121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillaceaeBacteriumGas479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillaceae bacterium GAS479 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillaceaeBacteriumGas479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararheinheimeraTexasensisDsm17496Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pararheinheimera texasensis DSM 17496 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PararheinheimeraTexasensisDsm17496Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa1377(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_37_7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa1377", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwb14719Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWB14719 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwb14719Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaCanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga canis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaCanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaAuratinigraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora auratinigra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaAuratinigraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelotomaculumThermopropionicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelotomaculum thermopropionicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelotomaculumThermopropionicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusAmargosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus amargosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusAmargosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PoeciliaFormosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poecilia formosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoeciliaFormosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgarivoransAlbusMkt106(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Agarivorans albus MKT 106 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AgarivoransAlbusMkt106", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpXpd2006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XPD2006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXpd2006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmataSpShpl17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmata sp. SHPL17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmataSpShpl17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidesmisPriestleyiUlc007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phormidesmis priestleyi ULC007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhormidesmisPriestleyiUlc007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchneraAphidicolaCinaraPseudotaxifoliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara pseudotaxifoliae) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraPseudotaxifoliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSp73h25ap(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 73H25AP graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp73h25ap", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusChungangensisCau28Dsm22330Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus chungangensis CAU 28 DSM 22330 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactococcusChungangensisCau28Dsm22330Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumTexcoconenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum texcoconense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTexcoconenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumHalperniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium halperniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHalperniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaSpHmsc064e01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC064E01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc064e01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonasSpAp64(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonas sp. AP64 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemmatimonasSpAp64", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumCsp12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium CSP12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumCsp12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPanaciterraeDsm19096(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus panaciterrae DSM 19096 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusPanaciterraeDsm19096", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmanniiSubspFleischmanniiLu20061Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria fleischmannii subsp. fleischmannii LU2006-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaFleischmanniiSubspFleischmanniiLu20061Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanthinobacteriumAgaricidamnosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium agaricidamnosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumAgaricidamnosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmantichitinumUrsilacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amantichitinum ursilacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmantichitinumUrsilacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiophoraPuteanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coniophora puteana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ConiophoraPuteanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasSp520p1No423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. 520P1 No. 423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSp520p1No423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFulvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas fulva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFulvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag10605727Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060_57_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag10605727Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinophytocolaXanthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinophytocola xanthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinophytocolaXanthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PortieraAleyrodidarumTvCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Portiera aleyrodidarum TV Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PortieraAleyrodidarumTvCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumVe20213(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20213 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20213", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoniaPhycicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesonia phycicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesoniaPhycicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaProteobacteriumScgcAaa076p13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return gamma proteobacterium SCGC AAA076P13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaProteobacteriumScgcAaa076p13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3630Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3630 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3630Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DokdonellaImmobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella immobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DokdonellaImmobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxHalotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHalotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpNbrc111131(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. NBRC 111131 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpNbrc111131", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioAlcoholivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alcoholivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlcoholivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaArthritidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia arthritidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaArthritidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusOdysseyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus odysseyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusOdysseyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonCaspthauma3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon caspthauma3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonCaspthauma3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeromonasSalmonicidaSubspSalmonicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aeromonas salmonicida subsp. salmonicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AeromonasSalmonicidaSubspSalmonicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisPretoriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis pretoriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisPretoriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OphiocordycepsAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ophiocordyceps australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OphiocordycepsAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumEndosymbiontOfMortierellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Mortierella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfMortierellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusThermomutatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus thermomutatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusThermomutatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EntomoplasmaLucivoraxAtcc49196Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Entomoplasma lucivorax ATCC 49196 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EntomoplasmaLucivoraxAtcc49196Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumChlorophenolicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chlorophenolicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChlorophenolicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUltunenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ultunense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumUltunenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumMarseillep2935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium MarseilleP2935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumMarseillep2935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasPhenolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas phenolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPhenolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPutidaNbrc14164Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida NBRC14164 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaNbrc14164Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophomonasPalmitaticaJcm14374Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Syntrophomonas palmitatica JCM 14374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SyntrophomonasPalmitaticaJcm14374Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusMarinonascensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus marinonascens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusMarinonascensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFluxusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fluxus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFluxusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LodderomycesElongisporusNrrlYb4239(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lodderomyces elongisporus NRRL YB-4239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LodderomycesElongisporusNrrlYb4239", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryhalocaulisCaribicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Euryhalocaulis caribicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EuryhalocaulisCaribicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumAzorenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium azorense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumAzorenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAltamirensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia altamirensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaAltamirensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSp14657030Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 1465703.0 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp14657030Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SilvanigrellaAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Silvanigrella aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SilvanigrellaAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumHumireducensNbrc106098Dsm45392Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium humireducens NBRC 106098 DSM 45392 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumHumireducensNbrc106098Dsm45392Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethermicoccusShengliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methermicoccus shengliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethermicoccusShengliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterJejuni414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter jejuni 414 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterJejuni414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb14314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_43_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb14314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaTropicalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Candida tropicalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidaTropicalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatimonadetesBacterium13120cm46611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_1_20CM_4_66_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13120cm46611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumFe2018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium FE2018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumFe2018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_01_FULL_44_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho201Full4422b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioProteoclasticusB316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Butyrivibrio proteoclasticus B316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ButyrivibrioProteoclasticusB316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaSpTw09308Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia sp. TW09308 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaSpTw09308Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinopolysporaErythraea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinopolyspora erythraea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinopolysporaErythraea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeofilumRubicundumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geofilum rubicundum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeofilumRubicundumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaShahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia shahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaShahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesUniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides uniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesUniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Olsenella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Olsenella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumEzzemoulenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum ezzemoulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalorubrumEzzemoulenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacillusUreilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus ureilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusUreilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag182Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:182 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag182Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium GW2011_GWA2_44_13b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumGw2011Gwa24413b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SnodgrassellaAlviWkb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella alvi wkB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaAlviWkb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriumLacusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium lacus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumLacusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAcidophilus30scCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus acidophilus 30SC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAcidophilus30scCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusAntarcticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planococcus antarcticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanococcusAntarcticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobacillusSpC254(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobacillus sp. C254 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobacillusSpC254", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSpDg25bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. DG25B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpDg25bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpChol1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Chol1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpChol1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpRoot1304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root1304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot1304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacterialesBacterium5955Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteriales bacterium 59-55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacterialesBacterium5955Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumTestaceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium testaceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTestaceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaTularensisHolarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella tularensis holarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrancisellaTularensisHolarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParascardoviaDenticolensIpla20019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Parascardovia denticolens IPLA20019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParascardoviaDenticolensIpla20019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterReichenbachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter reichenbachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterReichenbachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterInvisusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister invisus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterInvisusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaSubspFraseriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella pneumophila subsp. fraseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaPneumophilaSubspFraseriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavisporaLusitaniaeAtcc42720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae ATCC 42720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClavisporaLusitaniaeAtcc42720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpS6spd3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. S6Spd3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpS6spd3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JanibacterLimosusNbrc16128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Janibacter limosus NBRC 16128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JanibacterLimosusNbrc16128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CollinsellaVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonB261Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B26-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB261Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasCapeferrumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas capeferrum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCapeferrumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBrisouiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter brisouii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBrisouiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpP11g5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. P11G5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpP11g5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaGlobuliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Demequina globuliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DemequinaGlobuliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYD2_FULL_39_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyd2Full3916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumLacus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium lacus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumLacus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetusTestudinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter fetus testudinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterFetusTestudinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpAnt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Ant graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpAnt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumCg10239135(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium CG1_02_39_135 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumCg10239135", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaPohangensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia pohangensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaPohangensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctobacteriumSpCag207Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctobacterium sp. CAG207 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhascolarctobacteriumSpCag207Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusIctaluriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ictaluri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusIctaluriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichechusManatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichechus manatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichechusManatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPobuzihii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pobuzihii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPobuzihii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemolamae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemolamae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemolamae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KangiellaSediminilitorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kangiella sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KangiellaSediminilitorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AliiroseovariusSediminilitorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aliiroseovarius sediminilitoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AliiroseovariusSediminilitorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarivivensSpJlt3646(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivivens sp. JLT3646 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivivensSpJlt3646", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHaemolamaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma haemolamae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaHaemolamaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrimontiaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Grimontia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GrimontiaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaAmazonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella amazonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaAmazonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisFormicicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris formicicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisFormicicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusThiodiazotrophaEndoloripesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thiodiazotropha endoloripes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusThiodiazotrophaEndoloripesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KallipygaGabonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kallipyga gabonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KallipygaGabonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasLuteoviolaceaBAtcc29581Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas luteoviolacea B  ATCC 29581 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasLuteoviolaceaBAtcc29581Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioSpRm50(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. RM50 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpRm50", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLiaoningenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium liaoningense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLiaoningenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaPseudobrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliscomenobacterHydrossis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haliscomenobacter hydrossis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaliscomenobacterHydrossis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermanaeromonasToyohensisTobeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thermanaeromonas toyohensis ToBE Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThermanaeromonasToyohensisTobeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu072Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU072 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu072Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotignumBalticumDsm7044Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfotignum balticum DSM 7044 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfotignumBalticumDsm7044Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GynuellaSunshinyiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gynuella sunshinyii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GynuellaSunshinyiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusBrockianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus brockianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusBrockianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumHainanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium hainanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumHainanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumElephantisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium elephantis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumElephantisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceicoccusMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusMarinaDsm22363(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina DSM 22363 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingorhabdusMarinaDsm22363", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumRifcsphigho212full4716bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO212FULL4716b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho212full4716bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscovopsisWeberi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Escovopsis weberi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EscovopsisWeberi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfococcusOleovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus oleovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusOleovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AngelakisellaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Angelakisella massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AngelakisellaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpulaLacrymansVarLacrymansS73Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serpula lacrymans var. lacrymans S7.3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerpulaLacrymansVarLacrymansS73Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaGerundensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia gerundensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaGerundensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYonathbacteriaBacteriumRifoxyc2Full479Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yonathbacteria bacterium RIFOXYC2_FULL_47_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYonathbacteriaBacteriumRifoxyc2Full479Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArachisHypogaea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arachis hypogaea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArachisHypogaea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCulicicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma culicicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCulicicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfolobalesArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfolobales archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfolobalesArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoreaSp52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaSp52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusMarincolaDsm16067Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola DSM16067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaDsm16067Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesVenezuelaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces venezuelae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVenezuelaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumRbg16408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RBG_16_40_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRbg16408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KibdelosporangiumPhytohabitans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kibdelosporangium phytohabitans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KibdelosporangiumPhytohabitans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGleum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gleum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGleum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpKmsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. KMS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpKmsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumRifcsplowo201full4818Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO201FULL4818 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo201full4818Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpKnhs209(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs209 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs209", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwf24415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWF2_44_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwf24415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZosteraMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zostera marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZosteraMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumRbg19ftcombo4210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium RBG19FTCOMBO4210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumRbg19ftcombo4210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHsism1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. HSISM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpHsism1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaThermarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga thermarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermotogaThermarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_41_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4113Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag386Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:386 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag386Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf337(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf337 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf337", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesFragilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides fragilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesFragilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeptunomonasJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neptunomonas japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeptunomonasJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaInagensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora inagensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaInagensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrococcusLuteusModasa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micrococcus luteus modasa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrococcusLuteusModasa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasEndophytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas endophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasEndophytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioCuneatusDsm11391Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus DSM 11391 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatusDsm11391Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaPaucivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia paucivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaPaucivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesulfofervidusAuxilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfofervidus auxilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfofervidusAuxilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaDermatitidisNihUt8656Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Exophiala dermatitidis NIH/UT8656 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ExophialaDermatitidisNihUt8656Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4081Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 40-81 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4081Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpUnc362mftsu51Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNC362MFTsu51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpUnc362mftsu51Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusTengchongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus tengchongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusTengchongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinilyticumLitopenaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinilyticum litopenaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinilyticumLitopenaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurivirgaCaldicuraliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurivirga caldicuralii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurivirgaCaldicuraliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSpX2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio sp. X2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSpX2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaplasmaMarginaleSt(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaplasma marginale St. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaplasmaMarginaleSt", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterCorallicolaNbrc107790(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter corallicola NBRC 107790 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JanibacterCorallicolaNbrc107790", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonJ07hx64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HX64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hx64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaEriocheirisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma eriocheiris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaEriocheirisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaSucciniciproducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia succiniciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaSucciniciproducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumGenomosp3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium genomosp. 3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumGenomosp3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiromycesSpE2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piromyces sp. E2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiromycesSpE2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterToleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter tolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterToleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeregrinibacteriaBacteriumGw2011gwa2447Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA2447 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa2447Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaMexicanaNbrc108244Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mexicana NBRC 108244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaMexicanaNbrc108244Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SutterellaParvirubraYit11816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sutterella parvirubra YIT 11816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SutterellaParvirubraYit11816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesMediterraneaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces mediterranea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesMediterraneaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1989Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1989 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1989Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BipolarisOryzaeAtcc44560Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bipolaris oryzae ATCC 44560 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BipolarisOryzaeAtcc44560Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaViridisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora viridis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaViridisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamiellaSorbophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wickerhamiella sorbophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WickerhamiellaSorbophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAcidiproducensDsm23148(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacillus acidiproducens DSM 23148 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacillusAcidiproducensDsm23148", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoproteusTenaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus tenax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusTenaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofusicoccumParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neofusicoccum parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeofusicoccumParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitritaleaHalalkaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitritalea halalkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitritaleaHalalkaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAg109o510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Ag109O510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAg109o510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OnchocercaOchengiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca ochengi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OnchocercaOchengiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu075Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU075 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu075Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloracidobacteriumThermophilumBEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilumBEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaLimicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena limicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaLimicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb241529c4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB241_529C4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb241529c4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcetothermiaBacteriumJdfr48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acetothermia bacterium JdFR-48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcetothermiaBacteriumJdfr48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full6025(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_60_25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full6025", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnoclostridiumSpYl32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnoclostridium sp. YL32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnoclostridiumSpYl32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpSgbin2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. SGbin2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpSgbin2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_44_24b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full4424bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusCorynebacterioidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus corynebacterioides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusCorynebacterioidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizophagusIrregularisDaom197198wEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizophagus irregularis DAOM 197198w Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizophagusIrregularisDaom197198wEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaTanakaei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collinsella tanakaei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollinsellaTanakaei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliiglaciecolaLipolytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliiglaciecola lipolytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliiglaciecolaLipolytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumBangenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum bangense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumBangenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesLiubingyangiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces liubingyangii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomycesLiubingyangiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaDrozanskiiLlap1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Legionella drozanskii LLAP-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LegionellaDrozanskiiLlap1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacillus minor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacillusMinor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp3211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 3211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp3211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BeijerinckiaMobilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Beijerinckia mobilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BeijerinckiaMobilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomirabilisOxyfera(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomirabilis oxyfera graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomirabilisOxyfera", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpMitacek01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. Mitacek01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpMitacek01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusTorquesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Ruminococcus] torques Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusTorquesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaproteobacteriaBacteriumCg1024617(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium CG1_02_46_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumCg1024617", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GhiorseaBivora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ghiorsea bivora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GhiorseaBivora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraViennensisEn76Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nitrososphaera viennensis EN76 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NitrososphaeraViennensisEn76Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumAngustumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium angustum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumAngustumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AggregatibacterAphrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aggregatibacter aphrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AggregatibacterAphrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltererythrobacterDongtanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter dongtanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterDongtanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnc451mfCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC451MF Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc451mfCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BoseaSpLc85Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. LC85 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLc85Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBeijingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia beijingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaBeijingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag449Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:449 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag449Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DielmaFastidiosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dielma fastidiosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DielmaFastidiosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusDamnosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus damnosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusDamnosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpSoil774Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Soil774 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpSoil774Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusHaloduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus halodurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentibacillusHaloduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliellaBissettiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella bissettii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBissettiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus saliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacteraceaeBacteriumGoma1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacteraceae bacterium GOMA1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacteraceaeBacteriumGoma1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisSpSc2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SC2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSc2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodoferaxSpLeaf267(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf267 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf267", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasMediterranea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas mediterranea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasMediterranea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrochaeteSpPcc7126Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microchaete sp. PCC7126 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrochaeteSpPcc7126Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolanumLycopersicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solanum lycopersicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolanumLycopersicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusFasciansLmg3625Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians LMG 3625 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansLmg3625Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumAmericanum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium americanum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumAmericanum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaVeroralisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella veroralis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaVeroralisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrobacterRodentiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter rodentium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitrobacterRodentiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpUnccl28Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNCCL28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpUnccl28Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwc23922Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWC2_39_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwc23922Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpJccEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. JCC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpJccEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaTractuosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivirga tractuosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivirgaTractuosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpRoot710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Root710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpRoot710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterCloacaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cloacae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCloacaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParamesorhizobiumDeserti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paramesorhizobium deserti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParamesorhizobiumDeserti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSpCag105Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. CAG:105 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DoreaSpCag105Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaMangroviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KwoniellaMangroviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpCn3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CN3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCn3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumA52c2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium A52C2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumA52c2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def InquilinusLimosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Inquilinus limosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "InquilinusLimosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumTanaceti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum tanaceti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumTanaceti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaThermolimosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerolinea thermolimosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaThermolimosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacificimonasFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacificimonas flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacificimonasFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldanaerovirgaAcetigignensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldanaerovirga acetigignens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldanaerovirgaAcetigignensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterSpRoot672(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter sp. Root672 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterSpRoot672", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaChukchiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Colwellia chukchiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ColwelliaChukchiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassotaleaAgarivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassotalea agarivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassotaleaAgarivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaSpheciospongiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora spheciospongiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaSpheciospongiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_02_FULL_36_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho202Full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpNc3005Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. NC3005 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpNc3005Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterArcticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter arcticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterArcticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NumidaMeleagrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Numida meleagris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NumidaMeleagrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpPcc7336(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. PCC7336 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpPcc7336", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_49_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb1499Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VogesellaSpEb(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vogesella sp. EB graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VogesellaSpEb", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusVulcaniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus vulcanius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusVulcaniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnteractinococcusHelveticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enteractinococcus helveticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnteractinococcusHelveticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitobacteriumHafnienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium hafniense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumHafnienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaLacunae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia lacunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaLacunae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumGa0077551Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077551 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077551Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpMs1601Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. MS1601 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpMs1601Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaPurpeofuscaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora purpeofusca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaPurpeofuscaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCamelliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus camelliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCamelliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusChinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus chinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParacoccusChinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesThermolilacinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces thermolilacinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesThermolilacinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeofamiliaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neofamilia massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeofamiliaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaviesbacteriaBacteriumRifcsplowo202full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Daviesbacteria bacterium RIFCSPLOWO202FULL3815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DaviesbacteriaBacteriumRifcsplowo202full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoanaerobacteriumXylanolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoanaerobacterium xylanolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoanaerobacteriumXylanolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChromobacteriumSphagniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromobacterium sphagni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromobacteriumSphagniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaemophilusSpFf7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus sp. FF7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HaemophilusSpFf7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSpNb41yCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia sp. NB4-1Y Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaSpNb41yCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MandrillusLeucophaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mandrillus leucophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MandrillusLeucophaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnothrixRosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix rosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnothrixRosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensPf5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Pf5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensPf5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucispirillumSchaedleriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucispirillum schaedleri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucispirillumSchaedleriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCapillatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus capillatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCapillatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAzotoformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus azotoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusAzotoformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfacinumInfernum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfacinum infernum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfacinumInfernum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumQingshengii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium qingshengii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumQingshengii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp2621(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 26_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2621", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFloridensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas floridensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFloridensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermocrinisAlbusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis albus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisAlbusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MuproteobacteriaBacteriumRbg166534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RBG166534 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRbg166534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSpE463(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus sp. E463 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusSpE463", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumJdfr77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium JdFR77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumJdfr77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrenneriaGoodwiniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brenneria goodwinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrenneriaGoodwiniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaPhymatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phymatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhymatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaLascolaiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella lascolaii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaLascolaiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaMelophagiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bartonella melophagi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BartonellaMelophagiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusMarincolaDsm16067Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus marincola DSM16067 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusMarincolaDsm16067Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalicoccusPleomorphusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Faecalicoccus pleomorphus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FaecalicoccusPleomorphusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolymyxaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpUrha0020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. URHA0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpUrha0020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4967Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4967 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4967Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpLb2008Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LB2008 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLb2008Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsplowo212full4415c(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPLOWO212FULL4415c graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsplowo212full4415c", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpImcc20628Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. IMCC20628 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpImcc20628Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumMcbrellneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium mcbrellneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumMcbrellneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicocarpusGriseusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicocarpus griseus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicocarpusGriseusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatibacillumAlkenivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfatibacillum alkenivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfatibacillumAlkenivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaThermophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina thermophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaThermophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoduganellaViolaceinigraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoduganella violaceinigra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoduganellaViolaceinigraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlackburnbacteriaBacteriumRifcsphigho202full4420Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO202FULL4420 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho202full4420Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg164410Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG164410 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg164410Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAtcc29733(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ATCC29733 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAtcc29733", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BilophilaWadsworthiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteococcusJaponicusLspLj1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Luteococcus japonicus LSP_Lj1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LuteococcusJaponicusLspLj1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpRoot411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. Root411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpRoot411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumAb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium AB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumAb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlcanivoraxJadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax jadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxJadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusDenitrificansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus denitrificans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusDenitrificansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAviumAvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Mycobacterium avium avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "MycobacteriumAviumAvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAvicenniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces avicenniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAvicenniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSordidicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sordidicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSordidicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacalesArchaeonDl31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Haloferacales archaeon DL31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "HaloferacalesArchaeonDl31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. enterica serovar Typhimurium str. LT2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspEntericaSerovarTyphimuriumStrLt2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhycicoccusDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phycicoccus dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhycicoccusDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusDpc4571(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus DPC4571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusDpc4571", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusRaffinolactis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactococcus raffinolactis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactococcusRaffinolactis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpIbvhs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. IBVHS1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpIbvhs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium GW2011_GWA2_35_19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumGw2011Gwa23519Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifoxyd12full6137Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFOXYD12FULL6137 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifoxyd12full6137Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGorillaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gorillae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGorillaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsplowo201full4424b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL4424b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full4424b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbus7Dsm20455Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus albus 7  DSM 20455 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusAlbus7Dsm20455Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchistocephalusSolidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistocephalus solidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistocephalusSolidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaMarcescensDb11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Serratia marcescens Db11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SerratiaMarcescensDb11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrodictiumOccultum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrodictium occultum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrodictiumOccultum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CastorCanadensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Castor canadensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CastorCanadensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidanaerobacterSpEbm38(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidanaerobacter sp. EBM-38 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidanaerobacterSpEbm38", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrusBergyltaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrus bergylta Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrusBergyltaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloramatorSpAld01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloramator sp. ALD01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloramatorSpAld01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasSpBiir7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. BIIR7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpBiir7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpF0436(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. F0436 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpF0436", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellamassiliaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotellamassilia timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellamassiliaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaFlexneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shigella flexneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShigellaFlexneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AchromobacterInsuavisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Achromobacter insuavis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AchromobacterInsuavisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalipaludibacillusAgaradhaerensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salipaludibacillus agaradhaerens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalipaludibacillusAgaradhaerensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumGracile(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium gracile graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobiumGracile", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpRoot55(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Root55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpRoot55", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlkaliphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alkaliphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlkaliphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwa13413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA13413 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa13413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcaromycesIngoldii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acaromyces ingoldii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcaromycesIngoldii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13322 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpG2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. G2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpG2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpKks102Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. KKS102 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpKks102Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMaricopensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus maricopensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeinococcusMaricopensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenovibrioKuenenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio kuenenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioKuenenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaCherriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella cherrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaCherriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EquusCaballusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Equus caballus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EquusCaballusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumResinovorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium resinovorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumResinovorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusCarbonarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus carbonarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusCarbonarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluviicolaTaffensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fluviicola taffensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FluviicolaTaffensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsanoaIshikariensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asanoa ishikariensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsanoaIshikariensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquamicrobiumDefluvii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquamicrobium defluvii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquamicrobiumDefluvii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilabiliaSalmonicolorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinilabilia salmonicolor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinilabiliaSalmonicolorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermusBrockianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermus brockianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermusBrockianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RokubacteriaBacteriumCsp16Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rokubacteria bacterium CSP16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RokubacteriaBacteriumCsp16Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesXanthophaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xanthophaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXanthophaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensHk44(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens HK44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensHk44", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumDeltaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium deltae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumDeltaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinactinosporaThermotoleransDsm45154Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans DSM 45154 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinactinosporaThermotoleransDsm45154Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusPushchinoensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus pushchinoensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusPushchinoensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpIs3022Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-3022 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs3022Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full6720Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL6720 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full6720Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OoceraeaBiroiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ooceraea biroi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OoceraeaBiroiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioMagneticusIfrc170Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio magneticus IFRC170 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioMagneticusIfrc170Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusJeotgaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronococcusJeotgaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus saccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsplowo201full3820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPLOWO201FULL3820 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsplowo201full3820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpLeaf288(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Leaf288 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpLeaf288", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaAurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma auris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaAurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrassicaOleraceaVarOleraceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Brassica oleracea var. oleracea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BrassicaOleraceaVarOleraceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrigopsHabroptila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strigops habroptila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrigopsHabroptila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf238335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_38_335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf238335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchekmanbacteriaBacteriumRifcsplowo212full3815Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schekmanbacteria bacterium RIFCSPLOWO212FULL3815 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchekmanbacteriaBacteriumRifcsplowo212full3815Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDokdonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter dokdonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterDokdonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraMayottensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira mayottensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMayottensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiisalibacterPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiisalibacter paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiisalibacterPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag302(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:302 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag302", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaOrientalisStrainShintokuCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Theileria orientalis strain Shintoku Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TheileriaOrientalisStrainShintokuCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPlantarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus plantarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPlantarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaBacteriumOlb19Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium OLB19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumOlb19Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusMinorNm305Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus minor NM305 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusMinorNm305Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumBalustinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium balustinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumBalustinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf198(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf198 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf198", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumHalliiVarHalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Panicum hallii var. hallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PanicumHalliiVarHalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MusMusculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mus musculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MusMusculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimimaricolaPyoseonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limimaricola pyoseonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimimaricolaPyoseonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb13910Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_39_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb13910Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonRbg13389Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_38_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg13389Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJcm10914(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JCM 10914 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJcm10914", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaElaeisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Devosia elaeis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DevosiaElaeisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrococcusRivularisNies593Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis NIES-593 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HydrococcusRivularisNies593Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LiptonbacteriaBacteriumGwb1496Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium GWB1496 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumGwb1496Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapilioMachaonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Papilio machaon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PapilioMachaonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSpitsbergenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma spitsbergense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSpitsbergenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetradesmusObliquusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tetradesmus obliquus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TetradesmusObliquusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumMd2004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd2004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSubglaciescolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas subglaciescola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSubglaciescolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGottesmanbacteriaBacteriumRbg16378(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RBG_16_37_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRbg16378", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumAcidaminophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium acidaminophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumAcidaminophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCarboxidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium carboxidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCarboxidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusThermophilusLmd9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus thermophilus LMD9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusThermophilusLmd9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterChroococcumNcimb8003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Azotobacter chroococcum NCIMB 8003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AzotobacterChroococcumNcimb8003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_59_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5921Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesDavaonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces davaonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDavaonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacteriumCg2303313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium CG2303313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacteriumCg2303313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSticklandiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sticklandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSticklandiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpLq44(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. LQ44 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpLq44", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LabrenziaAlexandriiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia alexandrii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaAlexandriiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUltunense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium ultunense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumUltunense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidaminococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidaminococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidaminococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacterium3541Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium 3541 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacterium3541Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4322Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4322 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4322Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfomicrobiumBaculatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium baculatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumBaculatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho212full4234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO212FULL4234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho212full4234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_50_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioZosteraeDsm11974Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae DSM 11974 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioZosteraeDsm11974Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusTanneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus tanneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusTanneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsplowo212Full5310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPLOWO2_12_FULL_53_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsplowo212Full5310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc3903Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 3903 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc3903Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnncaliiaAlgerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anncaliia algerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnncaliiaAlgerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solimonas soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolimonasSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorselliaAnophelisDsm18579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thorsellia anophelis DSM 18579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThorselliaAnophelisDsm18579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosocosmicusOleophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosocosmicus oleophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosocosmicusOleophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSaccharolyticaF0055(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica F0055 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSaccharolyticaF0055", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpDh1fEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. DH1f Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpDh1fEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOralisSk1074(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oralis SK1074 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOralisSk1074", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMethanolicusPb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus methanolicus PB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMethanolicusPb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophilalesBacteriumMbrsf5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophilales bacterium MBRSF5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophilalesBacteriumMbrsf5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosarchaeumKoreense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusUreilyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus ureilyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusUreilyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaFleischmanniiSubspFleischmanniiLu20061(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria fleischmannii subsp. fleischmannii LU2006-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaFleischmanniiSubspFleischmanniiLu20061", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermomicrobiumRoseum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermomicrobium roseum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermomicrobiumRoseum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp7f3div0205Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 7F3DIV0205 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp7f3div0205Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarichromatiumPurpuratumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marichromatium purpuratum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarichromatiumPurpuratumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumThailandense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium thailandense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumThailandense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPruniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pruni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPruniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOvisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ovis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOvisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VariovoraxSpRoot411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. Root411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpRoot411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OdobenusRosmarusDivergensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Odobenus rosmarus divergens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OdobenusRosmarusDivergensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychroflexusTropicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus tropicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusTropicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBifermentansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Clostridium bifermentans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ClostridiumBifermentansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetofabaAustralisIt1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Magnetofaba australis IT-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MagnetofabaAustralisIt1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermocrinisSpGbsEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermocrinis sp. GBS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermocrinisSpGbsEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsbolusVerrucosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asbolus verrucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsbolusVerrucosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanococcusMaritimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planococcus maritimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanococcusMaritimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumLotiR88bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mesorhizobium loti R88b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MesorhizobiumLotiR88bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaPinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga pinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaPinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCc9605Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CC9605 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCc9605Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaportheHelianthi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diaporthe helianthi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiaportheHelianthi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusPanacihumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus panacihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusPanacihumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusShenzhenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus shenzhenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusShenzhenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumVentriosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ventriosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumVentriosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusProfundus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus profundus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusProfundus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumOraleEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium orale Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumOraleEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenoxybacterAcetivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenoxybacter acetivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenoxybacterAcetivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa25110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA25110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa25110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RodentibacterMyodisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter myodis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterMyodisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusCurtisiiAtcc35241(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus curtisii ATCC35241 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MobiluncusCurtisiiAtcc35241", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrolunatusPhosphovorusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microlunatus phosphovorus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrolunatusPhosphovorusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterSpNb311aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. Nb-311A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSpNb311aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulcanisaetaDistributaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulcanisaeta distributa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulcanisaetaDistributaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag557(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:557 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag557", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerminiimonasArsenitoxidans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herminiimonas arsenitoxidans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerminiimonasArsenitoxidans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpibacteriumMultivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epibacterium multivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpibacteriumMultivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSacchariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sacchari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSacchariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PatagioenasFasciataMonilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Patagioenas fasciata monilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PatagioenasFasciataMonilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaFlavescensNrl30031h210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria flavescens NRL30031H210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaFlavescensNrl30031h210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpMrs7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. MRS7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpMrs7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosomonasEuropaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEuropaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsFumosoroseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CordycepsFumosoroseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermotogaNeapolitanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermotoga neapolitana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermotogaNeapolitanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumGraminearumPh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fusarium graminearum PH-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FusariumGraminearumPh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosphaeraStadtmanaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosphaera stadtmanae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosphaeraStadtmanaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FolsomiaCandida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Folsomia candida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FolsomiaCandida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasAxonopodis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas axonopodis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasAxonopodis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusIlyisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus ilyis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichococcusIlyisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterLobularisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter lobularis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterLobularisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTaeniosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium taeniosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTaeniosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpCg232Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. CG23_2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpCg232Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyxococcusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Myxococcus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MyxococcusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PythiumVexansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pythium vexans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PythiumVexansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AllosalinactinosporaLopnorensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Allosalinactinospora lopnorensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AllosalinactinosporaLopnorensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChlorophenolicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBotulinumBkt015925Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum BKT015925 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumBkt015925Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TetrapisisporaPhaffiiCbs4417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tetrapisispora phaffii CBS 4417 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TetrapisisporaPhaffiiCbs4417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpJdr2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. JDR2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpJdr2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParafilimonasTerraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parafilimonas terrae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParafilimonasTerraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliivibrioSp1s175(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aliivibrio sp. 1S175 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AliivibrioSp1s175", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAcidianusCopahuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Acidianus copahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusAcidianusCopahuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpD27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. D27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpD27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusClavatusNrrl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus clavatus NRRL 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusClavatusNrrl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusAlkaliphilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus alkaliphilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAlkaliphilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronumThiodismutans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thiodismutans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThiodismutans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB261(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B261 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB261", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillospiraceaeBacteriumZagget6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oscillospiraceae bacterium Zagget6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OscillospiraceaeBacteriumZagget6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpadixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas spadix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpadixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BerkelbacteriaBacteriumCg2304320Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Berkelbacteria bacterium CG2304320 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BerkelbacteriaBacteriumCg2304320Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitrusSinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrus sinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrusSinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumGw2011gwa24110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium GW2011GWA24110 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumGw2011gwa24110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaProteobacteriumL13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return beta proteobacterium L13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaProteobacteriumL13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumPhleiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium phlei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumPhleiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr221Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR221 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr221Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallibacteriumAnatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium anatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumAnatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpHl48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. HL48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpHl48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMastitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium mastitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumMastitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumibacterMarinusDsm18995Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cucumibacter marinus DSM 18995 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CucumibacterMarinusDsm18995Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg164813Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_16_48_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg164813Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaMatsumotoenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora matsumotoense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaMatsumotoenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumLeiognathi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RugosibacterAromaticivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rugosibacter aromaticivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RugosibacterAromaticivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumCag646Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag646Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ScytalidiumLignicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Scytalidium lignicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ScytalidiumLignicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLm7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. LM7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLm7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBombicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus bombicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusBombicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAlkalitellurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus alkalitelluris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusAlkalitellurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzoarcusSpBh72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azoarcus sp. BH72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzoarcusSpBh72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaSpNml02a017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eikenella sp. NML02A017 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EikenellaSpNml02a017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasIssachenkoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas issachenkonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasIssachenkoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpN5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. N5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpN5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacteriumSiliguriense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium siliguriense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSiliguriense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusAlbusAd2013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus albus AD2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusAlbusAd2013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSaerimneri30a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus saerimneri 30a graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSaerimneri30a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosomonasEuropaeaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrosomonas europaea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrosomonasEuropaeaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColwelliaSpPamc21821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia sp. PAMC 21821 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaSpPamc21821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPutrefaciensKs1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma putrefaciens KS1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaPutrefaciensKs1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterGlobiformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter globiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterGlobiformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NereidaIgnavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nereida ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NereidaIgnavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PediococcusAcidilacticiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus acidilactici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PediococcusAcidilacticiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSiamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus siamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSiamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomonosporaAlbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomonospora alba Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomonosporaAlbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterPhenylpyruvicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter phenylpyruvicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPhenylpyruvicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocellaSilvestrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocella silvestris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocellaSilvestrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SandaracinusAmylolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sandaracinus amylolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SandaracinusAmylolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_54_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CesiribacterAndamanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cesiribacter andamanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CesiribacterAndamanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaranusKomodoensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Varanus komodoensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VaranusKomodoensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusWarneriL37603Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus warneri L37603 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusWarneriL37603Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa288n07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA288N07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa288n07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPiezophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio piezophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPiezophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat18019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-18019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat18019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24726Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24726 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24726Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NigeriumMassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nigerium massiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NigeriumMassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpJm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. JM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpJm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachypodiumDistachyon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brachypodium distachyon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrachypodiumDistachyon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisCampestrisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Xanthomonas campestris campestris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "XanthomonasCampestrisCampestrisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumFreireiPrf81(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium freirei PRF 81 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhizobiumFreireiPrf81", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalispirochaetaAlkalicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkalispirochaeta alkalica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkalispirochaetaAlkalicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlb24484Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24484 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24484Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusSpHmp52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. HMP52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusSpHmp52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YooniaRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yoonia rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YooniaRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yersinia intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YersiniaIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusariumOxysporumFSpCubenseRace1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium oxysporum f. sp. cubense race 1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumOxysporumFSpCubenseRace1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsathyrellaAberdarensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psathyrella aberdarensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsathyrellaAberdarensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusGeothermalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus geothermalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusGeothermalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaGuangxiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microvirga guangxiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaGuangxiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohaesibacterMarisflavi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cohaesibacter marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CohaesibacterMarisflavi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterSteyniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter steynii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSteyniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidipropionibacteriumJenseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidipropionibacterium jensenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidipropionibacteriumJenseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraKmetyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptospira kmetyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptospiraKmetyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaRodhaini(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma rodhaini graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaRodhaini", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacteriumSalinarumNrc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halobacterium salinarum NRC-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalobacteriumSalinarumNrc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrovirgaLotononidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microvirga lotononidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaLotononidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumCeleriflavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium celeriflavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCeleriflavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaUmbonata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Olsenella umbonata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUmbonata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacterium41269(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium 41_269 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacterium41269", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelosinusPropionicusDsm13327Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pelosinus propionicus DSM 13327 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PelosinusPropionicusDsm13327Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasArgentinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas argentinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasArgentinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaSp111n121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dietzia sp. 111N12-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DietziaSp111n121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumNovyiBNctc9691(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium novyi B NCTC9691 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumNovyiBNctc9691", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurihydrogenibiumSubterraneum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium subterraneum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSubterraneum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo202full6614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO202FULL6614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo202full6614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaFlabelliformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xylaria flabelliformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XylariaFlabelliformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorhabdusTiamatea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorhabdus tiamatea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorhabdusTiamatea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwf23917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWF23917 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwf23917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solimonas flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolimonasFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSpLnjc398b00(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNJC398B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnjc398b00", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpRd62Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. RD6.2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpRd62Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusVaginalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Anaerococcus vaginalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AnaerococcusVaginalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpAntb3c2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. ANTB3C2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpAntb3c2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClupeaHarengusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clupea harengus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClupeaHarengusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacterium351910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium 351910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacterium351910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterLobularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter lobularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterLobularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaGrenadensisNbrc108939(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia grenadensis NBRC 108939 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaGrenadensisNbrc108939", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSp25mfcol41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. 25mfcol4.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSp25mfcol41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldithrixAbyssiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix abyssi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldithrixAbyssiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpOralTaxon020StrF0370(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria sp. oral taxon 020 str. F0370 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaSpOralTaxon020StrF0370", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPLOWO2_01_FULL_47_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsplowo201Full4724Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpXbb1001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XBB1001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXbb1001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpN418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. N418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioSpN418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinosporaRubra(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinospora rubra graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoactinosporaRubra", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumColicanis209318Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium colicanis 209318 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumColicanis209318Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiaceaeBacteriumDtu054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiaceae bacterium DTU054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiaceaeBacteriumDtu054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterNanhaisediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter nanhaisediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterNanhaisediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_02_43_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho2024316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothermothrixSpDtu029Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix sp. DTU029 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixSpDtu029Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermococcusSibiricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus sibiricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusSibiricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpLc300Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus sp. LC300 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSpLc300Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFastidiosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFastidiosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusParasanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus parasanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusParasanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaSativaJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudodesulfovibrioIndicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio indicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioIndicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesAlpinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides alpinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardioidesAlpinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalococcusMorrhuaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus morrhuae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusMorrhuaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_01_FULL_46_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho201Full4622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusThermophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus thermophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusThermophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0382(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0382", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CedeceaDavisaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cedecea davisae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CedeceaDavisaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpHw567Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. HW567 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpHw567Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelliellaBaltica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Belliella baltica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BelliellaBaltica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusSpTolmCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus sp. TolM Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusSpTolmCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumPseudosasicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium pseudosasicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPseudosasicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar92BacteriumBacl16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMellisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mellis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMellisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicocarpusGriseusUamh5409Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicocarpus griseus UAMH5409 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicocarpusGriseusUamh5409Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OenococcusOeniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oenococcus oeni Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OenococcusOeniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasSpJs666Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas sp. JS666 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaromonasSpJs666Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaEllipticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia elliptica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaEllipticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaSp9120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. 9120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSp9120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusTindarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus tindarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanolobusTindarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tectomicrobia bacterium RIFCSPLOWO2_02_FULL_70_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTectomicrobiaBacteriumRifcsplowo202Full7019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenisporosarcinaSpHgh0030(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina sp. HGH0030 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaSpHgh0030", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumBrachiatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium brachiatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumBrachiatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaSpEg49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora sp. EG49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaSpEg49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiK12SubstrW3110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli K12 substr. W3110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiK12SubstrW3110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumGw2011Gwe14915(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium GW2011_GWE1_49_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumGw2011Gwe14915", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaSpP37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. P37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpP37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho201full4622b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO201FULL4622b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho201full4622b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg134322(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_43_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg134322", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminobacterSpRoot100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aminobacter sp. Root100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AminobacterSpRoot100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SiccibacterTuricensisLmg23730Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter turicensis LMG 23730 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SiccibacterTuricensisLmg23730Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptothrixCholodniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptothrix cholodnii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptothrixCholodniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusSpEllin185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dermacoccus sp. Ellin185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DermacoccusSpEllin185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterOrientalis21f2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orientalis 21F-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcetobacterOrientalis21f2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCiconiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium ciconiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCiconiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_01_FULL_42_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho201Full4212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpLcm4579(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. LCM 4579 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpLcm4579", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesCellostaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces cellostaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesCellostaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFrigidicarnisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium frigidicarnis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFrigidicarnisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPilosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium pilosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPilosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBplan(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. BPLAN graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBplan", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAkagii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium akagii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumAkagii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterPetaseusNbrc106054(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavihumibacter petaseus NBRC 106054 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavihumibacterPetaseusNbrc106054", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterGallaeciensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter gallaeciensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterGallaeciensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteralesBacteriumCg2306027Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterales bacterium CG2_30_60_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteralesBacteriumCg2306027Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterSp6223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. 62-23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSp6223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingorhabdusMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingorhabdus marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingorhabdusMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumEscambienseDsm10707(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfomicrobium escambiense DSM 10707 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfomicrobiumEscambienseDsm10707", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterHyointestinalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterAquivivusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter aquivivus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterAquivivusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ModestobacterCaceresiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter caceresii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ModestobacterCaceresiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumEndosymbiontOfMortierella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium endosymbiont of Mortierella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumEndosymbiontOfMortierella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrantheGuttata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythranthe guttata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrantheGuttata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4624Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4624 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4624Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedAnaerotruncusSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Anaerotruncus sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedAnaerotruncusSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElusimicrobiaBacteriumRifoxya2full4753Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium RIFOXYA2FULL4753 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumRifoxya2full4753Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumCoe1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium COE1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumCoe1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusBarengoltziiG22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii G22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltziiG22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylomonasSp11b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomonas sp. 11b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomonasSp11b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothermothrixOrenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halothermothrix orenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalothermothrixOrenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaVacuolata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina vacuolata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaVacuolata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonBenhamiaeCbs112371Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae CBS 112371 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichophytonBenhamiaeCbs112371Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaMaltophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema maltophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaMaltophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpOhsuic4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. OHSUIC4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpOhsuic4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethyloversatilisSpRac08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methyloversatilis sp. RAC08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloversatilisSpRac08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberibacillusCalidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus calidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TuberibacillusCalidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumTcs42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium tcs-42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumTcs42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SistotremastrumNiveocremeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sistotremastrum niveocremeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SistotremastrumNiveocremeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Staskawiczbacteria bacterium RIFCSPHIGHO2_02_FULL_34_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusStaskawiczbacteriaBacteriumRifcsphigho202Full349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumGiardinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium giardinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumGiardinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaSp209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma sp. 209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirosomaSp209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaenarcanumBioreactoricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenarcanum bioreactoricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenarcanumBioreactoricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloplanusNatans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloplanus natans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloplanusNatans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpOr444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OR444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOr444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TranquillimonasAlkanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tranquillimonas alkanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TranquillimonasAlkanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantheraTigris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Panthera tigris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantheraTigris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpPh1b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. PH1b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpPh1b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SunxiuqiniaElliptica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sunxiuqinia elliptica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SunxiuqiniaElliptica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivirgaSeohaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivirga seohaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivirgaSeohaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTremblayaPrincepsPcvalEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya princeps PCVAL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPrincepsPcvalEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaHaliotis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Formosa haliotis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FormosaHaliotis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioclavaSpDt234Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thioclava sp. DT234 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThioclavaSpDt234Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixSpCaciamEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LimnothrixSpCaciamEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusBovimastitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus bovimastitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusBovimastitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesulfopertinaxCoweniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desulfopertinax cowenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesulfopertinaxCoweniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavigranumRuoffiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavigranum ruoffiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavigranumRuoffiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TheropithecusGelada(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Theropithecus gelada graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TheropithecusGelada", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLugdunensisHku0901Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis HKU0901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisHku0901Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCancerogenus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter cancerogenus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterobacterCancerogenus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumAromaticivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium aromaticivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumAromaticivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CognatiyooniaSediminumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cognatiyoonia sediminum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CognatiyooniaSediminumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaInfantumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leishmania infantum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaInfantumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Sungbacteria bacterium RIFCSPLOWO2_01_FULL_54_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSungbacteriaBacteriumRifcsplowo201Full5421Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BhargavaeaCecembensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea cecembensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaCecembensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSpTx077308Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella sp. TX077308 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrancisellaSpTx077308Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaSpW121067Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. W121067 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpW121067Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospirillumSpCag239(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum sp. CAG:239 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumSpCag239", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MidichloriaMitochondrii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Midichloria mitochondrii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MidichloriaMitochondrii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaProfundaAzm34c06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga profunda AZM34c06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermotogaProfundaAzm34c06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfCimexLectularius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Cimex lectularius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCimexLectularius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TriboliumCastaneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tribolium castaneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TriboliumCastaneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaSpielmaniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borreliella spielmanii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliellaSpielmaniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCaldiarchaeumSubterraneumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Caldiarchaeum subterraneum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCaldiarchaeumSubterraneumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Haloarchaeon3a1dgrCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return haloarchaeon 3A1DGR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Haloarchaeon3a1dgrCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiribacterCurvatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter curvatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiribacterCurvatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumBangladeshenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium bangladeshense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumBangladeshenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermusFervidusDsm2088Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanothermus fervidus DSM 2088 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanothermusFervidusDsm2088Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumSpJcm19050(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium sp. JCM 19050 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumSpJcm19050", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AvibacteriumParagallinarum221(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Avibacterium paragallinarum 221 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AvibacteriumParagallinarum221", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDichloromethanomonasElyunquensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Dichloromethanomonas elyunquensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDichloromethanomonasElyunquensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsonellaClevelandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lawsonella clevelandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LawsonellaClevelandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CellulomonasSpRoot930(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root930 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot930", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScardoviaInopinataJcm12537(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scardovia inopinata JCM 12537 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ScardoviaInopinataJcm12537", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionibacteriumSpOralTaxon193Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionibacterium sp. oral taxon 193 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionibacteriumSpOralTaxon193Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPituitosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas pituitosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPituitosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoranbacteriaBacteriumGw2011gwe14915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE14915 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe14915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OttowiaThiooxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ottowia thiooxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OttowiaThiooxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaSpeluncaeNbrc108251Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia speluncae NBRC 108251 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaSpeluncaeNbrc108251Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaWenyoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma wenyonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaWenyoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronorubrumTexcoconenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum texcoconense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTexcoconenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg136510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_65_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc2012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumJicamaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium jicamae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJicamaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomyceteKsu1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return planctomycete KSU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlanctomyceteKsu1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumP6a3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium P6A3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumP6a3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AeromonasEncheleia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aeromonas encheleia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AeromonasEncheleia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpMit115569Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT115569 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpMit115569Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamesorhizobiumDesertiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paramesorhizobium deserti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParamesorhizobiumDesertiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusPhenolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus phenolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusPhenolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeganemaPerideroedes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Meganema perideroedes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MeganemaPerideroedes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusPettenkoferiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus pettenkoferi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusPettenkoferiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasAlkaliantarctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas alkaliantarctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasAlkaliantarctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesXanthophaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces xanthophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesXanthophaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VirgibacillusAlimentariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus alimentarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusAlimentariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumHalliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Panicum hallii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PanicumHalliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerticilliumAlfalfaeVams102Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Verticillium alfalfae VaMs.102 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VerticilliumAlfalfaeVams102Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf412(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf412 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf412", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaSpYr573Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga sp. YR573 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaSpYr573Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumCg1025844Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG1_02_58_44 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg1025844Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccomyxaSubellipsoideaC169(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coccomyxa subellipsoidea C-169 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoccomyxaSubellipsoideaC169", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloiococcusOtitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alloiococcus otitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlloiococcusOtitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnncaliiaAlgeraePra339Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anncaliia algerae PRA339 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnncaliiaAlgeraePra339Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EhrlichiaMurisAs145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ehrlichia muris AS145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EhrlichiaMurisAs145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpTksEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. TKS Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpTksEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsplowo201full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPLOWO201FULL4515 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsplowo201full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodonellumPsychrophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodonellum psychrophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodonellumPsychrophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaceaeBacteriumOralTaxon439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anaerolineaceae bacterium oral taxon 439 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnaerolineaceaeBacteriumOralTaxon439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhialocephalaSubalpina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phialocephala subalpina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhialocephalaSubalpina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPsittaciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus psittaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPsittaciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProvidenciaAlcalifaciensR901475Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens R90-1475 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensR901475Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSviceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sviceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSviceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacterium5419Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium 54-19 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacterium5419Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeomicrococcusAestuarii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neomicrococcus aestuarii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeomicrococcusAestuarii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudooceanicolaNitratireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola nitratireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaNitratireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLaterculaDsm2041Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina latercula DSM 2041 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLaterculaDsm2041Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium RIFCSPHIGHO2_02_FULL_47_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumRifcsphigho202Full4714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardioidesSpCf8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. CF8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpCf8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProsekii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas prosekii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasProsekii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoplasmatalesArchaeonIplasmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasmatales archaeon Iplasma Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmatalesArchaeonIplasmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseorubensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseorubensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BernardetiaLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bernardetia litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BernardetiaLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitricoccusSpCh26aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citricoccus sp. CH26A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitricoccusSpCh26aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StrongylocentrotusPurpuratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Strongylocentrotus purpuratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StrongylocentrotusPurpuratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaZimbabwensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella zimbabwensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaZimbabwensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_12_FULL_43_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo212Full4311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoagulans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus coagulans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCoagulans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InsolitispirillumPeregrinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Insolitispirillum peregrinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "InsolitispirillumPeregrinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterSpKt25bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. KT25b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpKt25bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_01_FULL_45_34 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo201Full4534Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EmergomycesPasteurianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Emergomyces pasteurianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EmergomycesPasteurianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumSpBv1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. BV1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpBv1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaBovis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella bovis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaBovis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WickerhamomycesCiferriiNrrlY1031(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wickerhamomyces ciferrii NRRL Y-1031 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WickerhamomycesCiferriiNrrlY1031", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrenarchaeotaArchaeon13140cm35217(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Crenarchaeota archaeon 13_1_40CM_3_52_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CrenarchaeotaArchaeon13140cm35217", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaFelisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila felis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaFelisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiflebacteriaBacteriumGwc2508Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Riflebacteria bacterium GWC2508 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RiflebacteriaBacteriumGwc2508Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KomagataeibacterRhaeticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter rhaeticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterRhaeticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpWao(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. WAO graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BoseaSpWao", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CasaltellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Casaltella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CasaltellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerovibrioSpRm50Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerovibrio sp. RM50 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerovibrioSpRm50Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CytophagaFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cytophaga fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CytophagaFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusPeptidifermentansDsm18978Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans DSM 18978 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentansDsm18978Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumParaputrificum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium paraputrificum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumParaputrificum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterPorticolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter porticola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterPorticolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasParapaucimobilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas parapaucimobilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasParapaucimobilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusFerrooxydansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus ferrooxydans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusFerrooxydansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeriophthalmusMagnuspinnatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Periophthalmus magnuspinnatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeriophthalmusMagnuspinnatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErythrobacterSpNap1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. NAP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpNap1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumFioriniaePj7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum fioriniae PJ7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumFioriniaePj7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMirumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma mirum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaMirumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaHydrophobica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia hydrophobica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaHydrophobica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeratocystisFimbriataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ceratocystis fimbriata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeratocystisFimbriataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusSpDsm45219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. DSM 45219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpDsm45219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterCryohalolentisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter cryohalolentis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterCryohalolentisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AeribacillusPallidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aeribacillus pallidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AeribacillusPallidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FaecalicatenaFissicatena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Faecalicatena fissicatena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FaecalicatenaFissicatena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaucisalibacillusGlobulusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus globulus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusGlobulusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoccidioidesImmitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides immitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesImmitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaIowaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma iowae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaIowaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPolysaccharolyticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] polysaccharolyticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPolysaccharolyticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocapsaPalsarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylocapsa palsarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylocapsaPalsarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusMurrayiDsm11303Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus murrayi DSM 11303 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DeinococcusMurrayiDsm11303Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaHaemolysansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella haemolysans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaHaemolysansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanothermusFervidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanothermus fervidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanothermusFervidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpBmaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. BMA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpBmaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpFjat25496(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. FJAT-25496 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpFjat25496", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaBeijingensisNbrc16342Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia beijingensis NBRC 16342 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaBeijingensisNbrc16342Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaHaemolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga haemolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaHaemolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumLarrymooreiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium larrymoorei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumLarrymooreiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OpitutaceaeBacteriumTav4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Opitutaceae bacterium TAV4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OpitutaceaeBacteriumTav4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColibacterMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colibacter massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColibacterMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnculturedRoseburiaSpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return uncultured Roseburia sp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnculturedRoseburiaSpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpXpd2006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. XPD2006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpXpd2006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumHtcc2148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium HTCC2148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumHtcc2148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacterium4484171Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium 4484171 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacterium4484171Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpCect5382(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. CECT 5382 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpCect5382", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpLeaf420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Leaf420 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpLeaf420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlaviramulusIchthyoenteriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flaviramulus ichthyoenteri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlaviramulusIchthyoenteriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpCn3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. CN3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpCn3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterDaejeonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter daejeonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterDaejeonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CompetibacterDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Competibacter denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CompetibacterDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuricaudaRuestringensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Muricauda ruestringensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MuricaudaRuestringensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpP5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. P5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpP5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumRbg16439(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG_16_43_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg16439", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylovulumMiyakonenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylovulum miyakonense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylovulumMiyakonenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSedentarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sedentarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSedentarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumNk3b98(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium NK3B98 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumNk3b98", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TorulasporaDelbrueckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Torulaspora delbrueckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TorulasporaDelbrueckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoudnabacteriaBacteriumRifcsphigho201full4323(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO201FULL4323 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho201full4323", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasFloridensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas floridensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasFloridensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfuromonasSpTf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfuromonas sp. TF graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfuromonasSpTf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho202full4213Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO202FULL4213 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho202full4213Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OchrobactrumRhizosphaerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ochrobactrum rhizosphaerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OchrobactrumRhizosphaerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaPseudomallei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia pseudomallei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaPseudomallei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioSpN1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio sp. N1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioSpN1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorchorusCapsularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corchorus capsularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorchorusCapsularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumArachidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium arachidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumArachidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphellophoraEuropaeaCbs101466Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cyphellophora europaea CBS 101466 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CyphellophoraEuropaeaCbs101466Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaHoronobensisHb1Jcm15518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina horonobensis HB-1 JCM 15518 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaHoronobensisHb1Jcm15518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwa14423Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWA1_44_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwa14423Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrametesCoccineaBrfm310Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Trametes coccinea BRFM310 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TrametesCoccineaBrfm310Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SarcophilusHarrisii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sarcophilus harrisii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SarcophilusHarrisii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorvusBrachyrhynchos(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corvus brachyrhynchos graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorvusBrachyrhynchos", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg166485Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_64_85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg166485Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanobacteriumSpPcc7702Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Cyanobacterium sp. PCC7702 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "CyanobacteriumSpPcc7702Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTerrybacteriaBacteriumRifcsplowo2024220Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPLOWO2_02_42_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsplowo2024220Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PeptoniphilusSpBv3c26(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. BV3C26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSpBv3c26", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSpongiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina spongiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquimarinaSpongiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiechaudiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piechaudii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiechaudiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterCupressiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter cupressi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterCupressiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraLucentensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira lucentensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraLucentensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroscillaMarinaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microscilla marina Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicroscillaMarinaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KaiserbacteriaBacteriumRifcsphigho202full5422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO202FULL5422 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho202full5422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusAmylolentus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptococcusAmylolentus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumRifcsphigho212full3622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium RIFCSPHIGHO212FULL3622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumRifcsphigho212full3622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumPerfringensAtcc13124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium perfringens ATCC13124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumPerfringensAtcc13124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1986Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1986 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1986Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DonghicolaXiamenensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Donghicola xiamenensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DonghicolaXiamenensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag274(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:274 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag274", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaPhytofirmans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia phytofirmans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaPhytofirmans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp150fbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 150FB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp150fbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1989Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1989 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1989Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaHuakuiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kurthia huakuii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KurthiaHuakuiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DrosophilaPseudoobscuraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila pseudoobscura Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaPseudoobscuraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusMarisnigriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus marisnigri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusMarisnigriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HugenholtziaRoseolaDsm9546Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hugenholtzia roseola DSM 9546 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HugenholtziaRoseolaDsm9546Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumEfficiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium efficiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumEfficiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tuber melanosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TuberMelanosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaAbyssalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina abyssalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaAbyssalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKefiri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kefiri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKefiri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeroglobusGeminatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaeroglobus geminatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaeroglobusGeminatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpGxt6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. GXT6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpGxt6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusSclerotialisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotialis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotialisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaTestudinis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella testudinis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PasteurellaTestudinis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpLeaf126Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. Leaf126 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpLeaf126Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaCsv86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas putida CSV86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPutidaCsv86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMarinimicrobiaBacteriumCg1024814Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Marinimicrobia bacterium CG1_02_48_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMarinimicrobiaBacteriumCg1024814Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OnchocercaVolvulus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Onchocerca volvulus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OnchocercaVolvulus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprobacillusSp291(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Coprobacillus sp. 291 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CoprobacillusSp291", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasTranslucensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas translucens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XanthomonasTranslucensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterReichenbachii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter reichenbachii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterReichenbachii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusSpCcbus3uf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus sp. CCBUS3UF1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusSpCcbus3uf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacterToluenoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter toluenoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterToluenoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarchaeobiusIranensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloarchaeobius iranensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloarchaeobiusIranensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusEhimensisA2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus ehimensis A2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusEhimensisA2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCcge510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CCGE510 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCcge510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisCga009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris CGA009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisCga009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwc23423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWC23423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwc23423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudescherichiaVulnerisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudescherichia vulneris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudescherichiaVulnerisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaErecta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Drosophila erecta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DrosophilaErecta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Harrisonbacteria bacterium RIFCSPHIGHO2_02_FULL_42_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHarrisonbacteriaBacteriumRifcsphigho202Full4216", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpTv2a2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Tv2a2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpTv2a2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaAkEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola Ak Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAkEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptostreptococcusRussellii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptostreptococcus russellii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptostreptococcusRussellii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GilvimarinusAgarilyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gilvimarinus agarilyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GilvimarinusAgarilyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrochothrixThermosphactaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brochothrix thermosphacta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrochothrixThermosphactaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpPrm31Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. PRM31 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpPrm31Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumGwa23526(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium GWA2_35_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumGwa23526", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusTerraeHkm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sporolactobacillus terrae HKM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SporolactobacillusTerraeHkm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JeotgalicoccusMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jeotgalicoccus marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JeotgalicoccusMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlercreutziaEquolifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlercreutzia equolifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlercreutziaEquolifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpFcs006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. FCS006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpFcs006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocystisParvusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis parvus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocystisParvusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumScgcAaa164e04(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium SCGC AAA164E04 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumScgcAaa164e04", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaAff(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia aff. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaAff", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerpulaLacrymansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Serpula lacrymans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SerpulaLacrymansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpLeaf334(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf334 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf334", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasCapnocytophagoidesDsm22835Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Dysgonomonas capnocytophagoides DSM 22835 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DysgonomonasCapnocytophagoidesDsm22835Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaCinaraConfinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Cinara confinis) Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaCinaraConfinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ManacusVitellinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Manacus vitellinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ManacusVitellinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpMs1601(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. MS1601 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpMs1601", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonRbg13389Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon RBG_13_38_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonRbg13389Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MacleayaCordataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Macleaya cordata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MacleayaCordataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFicariaNbrc102596(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia ficaria NBRC 102596 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaFicariaNbrc102596", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LepidothrixCoronata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lepidothrix coronata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LepidothrixCoronata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloracidobacteriumThermophilumB(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilumB", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesVariegatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces variegatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesVariegatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChroogloeocystisSiderophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KiritimatiellaGlycovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kiritimatiella glycovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KiritimatiellaGlycovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpCag776Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. CAG:776 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpCag776Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeothrixFermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geothrix fermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeothrixFermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaStellulataDsm5886Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Stappia stellulata DSM 5886 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StappiaStellulataDsm5886Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacterium688(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 68-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium688", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusArsenophonusLipoptenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Arsenophonus lipoptenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusArsenophonusLipoptenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumOlb14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium OLB14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumOlb14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbiconiuxSolaniNbrc106740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Herbiconiux solani NBRC 106740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HerbiconiuxSolaniNbrc106740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThorarchaeotaArchaeonAb25Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon AB25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonAb25Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotodesmusBlepharusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus blepharus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusBlepharusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanobisporaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planobispora rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanobisporaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumNk3d112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NK3D112 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNk3d112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolobusSpT824Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus sp. T82-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanolobusSpT824Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiphiliumRubrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidiphilium rubrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidiphiliumRubrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PalleroniaMarisminorisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Palleronia marisminoris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PalleroniaMarisminorisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMycoplasmaHaemominutumBirmingham1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Mycoplasma haemominutum Birmingham 1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMycoplasmaHaemominutumBirmingham1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpM143Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. M143 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSpM143Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaParvumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma parvum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaParvumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EpibacteriumMobileF1926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Epibacterium mobile F1926 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EpibacteriumMobileF1926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSp2009Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. 2009 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSp2009Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumGa0077551(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium Ga0077551 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumGa0077551", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumUliginosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium uliginosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumUliginosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSusongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia susongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaSusongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_02_FULL_39_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho202Full3917Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24711bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_47_11b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24711bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeishmaniaInfantum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leishmania infantum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeishmaniaInfantum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProvidenciaAlcalifaciensDsm30120Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Providencia alcalifaciens DSM 30120 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProvidenciaAlcalifaciensDsm30120Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterFerrireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter ferrireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterFerrireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosarcinaSiciliaeC2jCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae C2J Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliaeC2jCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LatescibacterAnaerobiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Latescibacter anaerobius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LatescibacterAnaerobiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorellaEquigenitalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorella equigenitalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorellaEquigenitalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpS17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas sp. S17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingomonasSpS17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraMultiparaLb2003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lachnospira multipara LB2003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LachnospiraMultiparaLb2003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusFaecimarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus faecimaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusFaecimarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAsaccharolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia asaccharolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAsaccharolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterEnzymogenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter enzymogenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterEnzymogenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilibacterSpBrhc7aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacter sp. BRHc7a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacterSpBrhc7aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcholeplasmaAxanthum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma axanthum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaAxanthum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RegiellaInsecticola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Regiella insecticola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RegiellaInsecticola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DoreaSp428(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dorea sp. 42_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DoreaSp428", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterSp3749Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 37-49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp3749Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImhoffiellaPurpureaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Imhoffiella purpurea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ImhoffiellaPurpureaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRbg134510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RBG134510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRbg134510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TypeBSymbiontOfPlautiaStali(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Type-B symbiont of Plautia stali graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TypeBSymbiontOfPlautiaStali", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesHadrusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes hadrus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesHadrusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanohaloarchaeaArchaeonB1br10u2g19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanohaloarchaea archaeon B1Br10U2g19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanohaloarchaeaArchaeonB1br10u2g19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusWasatchensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus wasatchensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusWasatchensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPobuzihiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pobuzihii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPobuzihiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBiomig1nEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. BIOMIG1N Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBiomig1nEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeribacteriaBacteriumRifcsphigho202Full4916(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacteria bacterium RIFCSPHIGHO2_02_FULL_49_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacteriaBacteriumRifcsphigho202Full4916", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaSpFsc1006(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella sp. FSC1006 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaSpFsc1006", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPunonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas punonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPunonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MusaAcuminataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Musa acuminata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MusaAcuminataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterNitrogenifigensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter nitrogenifigens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterNitrogenifigensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BilophilaWadsworthiaAtcc49260Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia ATCC49260 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthiaAtcc49260Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusPantherisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus pantheris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPantherisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaPneumophilaFraseriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella pneumophila fraseri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaPneumophilaFraseriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusLutraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus lutrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusLutraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HyphomicrobiumSpNdb2meth4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyphomicrobium sp. NDB2Meth4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyphomicrobiumSpNdb2meth4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacterium6eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium 6E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacterium6eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpCpuEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Cpu Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpCpuEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusShackletonii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus shackletonii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusShackletonii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DefluviimonasAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Defluviimonas alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DefluviimonasAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPersica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella persica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaPersica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumMagneticumAmb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Magnetospirillum magneticum AMB-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MagnetospirillumMagneticumAmb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterSpLeaf380Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. Leaf380 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpLeaf380Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HolosporaElegansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holospora elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HolosporaElegansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg136114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_13_61_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg136114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolituusThermophilusDsm23256(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporolituus thermophilus DSM 23256 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporolituusThermophilusDsm23256", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSpPbaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia sp. PBA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSpPbaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacteriumThalassiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium thalassium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumThalassiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumRifcsphigho212full429Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO212FULL429 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho212full429Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachanceaFermentati(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachancea fermentati graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachanceaFermentati", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychroflexusHalocaseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychroflexus halocasei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychroflexusHalocaseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo201full4534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO201FULL4534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo201full4534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusPolymyxa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaThalassocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella thalassocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaThalassocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrisomaLimi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrisoma limi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrisomaLimi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoldemaniaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Holdemania massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HoldemaniaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumGw2011gwa14311Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA14311 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa14311Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Andersenbacteria bacterium RIFCSPHIGHO2_01_FULL_46_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAndersenbacteriaBacteriumRifcsphigho201Full4636", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerotignumNeopropionicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerotignum neopropionicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerotignumNeopropionicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpTab87(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium sp. TAB 87 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSpTab87", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanospirillumLinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanospirillum linum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanospirillumLinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AhrensiaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegiribacteriaBacteriumMlscCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aegiribacteria bacterium MLSC Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AegiribacteriaBacteriumMlscCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MeiraMiltonrushii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Meira miltonrushii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MeiraMiltonrushii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter syzygii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterSyzygiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurihydrogenibiumSpYo3aop1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurihydrogenibium sp. YO3AOP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurihydrogenibiumSpYo3aop1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAureofaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces aureofaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesAureofaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumRadiotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium radiotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumRadiotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArhodomonasAquaeolei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arhodomonas aquaeolei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArhodomonasAquaeolei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumTrichothecenolyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium trichothecenolyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumTrichothecenolyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhydraLutris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enhydra lutris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnhydraLutris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlackburnbacteriaBacteriumRifcsphigho212full4113bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blackburnbacteria bacterium RIFCSPHIGHO212FULL4113b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlackburnbacteriaBacteriumRifcsphigho212full4113bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterMusarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter musarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeucobacterMusarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermithiobacillusTepidariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermithiobacillus tepidarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermithiobacillusTepidariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpYr710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. YR710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpYr710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoruegeriaSpSk021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoruegeria sp. SK021 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoruegeriaSpSk021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumDegerlacheiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium degerlachei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumDegerlacheiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RubidibacterLacunaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rubidibacter lacunae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RubidibacterLacunaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSp453mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 453mf Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp453mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EikenellaCorrodensAtcc23834Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eikenella corrodens ATCC23834 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EikenellaCorrodensAtcc23834Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumCalidifontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum calidifontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumCalidifontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcholeplasmaAxanthumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acholeplasma axanthum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcholeplasmaAxanthumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FischerellaSpPcc9339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScytonemaTolypothrichoidesVb61278(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scytonema tolypothrichoides VB-61278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ScytonemaTolypothrichoidesVb61278", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSuisR61(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus suis R61 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSuisR61", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nealsonbacteria bacterium RIFOXYB1_FULL_40_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNealsonbacteriaBacteriumRifoxyb1Full4015Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RippkaeaOrientalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rippkaea orientalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RippkaeaOrientalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusOnnurineus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus onnurineus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusOnnurineus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumGwc26514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWC2_65_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwc26514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpH105(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. H105 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasSpH105", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FranconibacterPulveris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Franconibacter pulveris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FranconibacterPulveris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterSpLEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. L Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSp162mfsha11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. 162MFSha11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSp162mfsha11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusDisparCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus dispar Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDisparCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwe24063Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWE2_40_63 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwe24063Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpE2479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. E2479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpE2479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocellaArvoryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanocella arvoryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanocellaArvoryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumAlamiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium alamii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumAlamiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaNoatunensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Francisella noatunensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FrancisellaNoatunensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcidisoliDsm12555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidisoli DSM 12555 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcidisoliDsm12555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpYs1rEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. YS1r Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpYs1rEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpMwb1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. MWB1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpMwb1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5236(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5236 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5236", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenibacillusSchlegeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenibacillus schlegelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenibacillusSchlegeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_43_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf24317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacteriumSpLeaf104(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf104 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf104", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermaeBacteriumJdfr72(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermae bacterium JdFR-72 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermaeBacteriumJdfr72", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifoxyd1full3935Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD1FULL3935 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd1full3935Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfCulexEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Culex Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfCulexEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFslh80548Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FSLH80548 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFslh80548Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OleispiraAntarcticaRb8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oleispira antarctica RB-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OleispiraAntarcticaRb8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterTrogontumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter trogontum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterTrogontumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpTnhr37bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. TNHR37B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpTnhr37bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumCiceriCa181(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium ciceri ca181 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumCiceriCa181", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusBuchneriNrrlb30929(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus buchneri NRRLB30929 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusBuchneriNrrlb30929", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodniusProlixusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodnius prolixus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodniusProlixusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumGw2011gwa24314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium GW2011GWA24314 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumGw2011gwa24314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium GW2011_GWC2_48_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumGw2011Gwc2489Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KockovaellaImperataeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kockovaella imperatae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KockovaellaImperataeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag10605727Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060_57_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag10605727Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpSpg23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SPG23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSpg23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumYurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium yurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumYurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaQueenslandensisAustNh15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bartonella queenslandensis AUST/NH15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BartonellaQueenslandensisAustNh15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumRifoxya2Full4620Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium RIFOXYA2_FULL_46_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumRifoxya2Full4620Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonB1br10e2g2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon B1Br10E2g2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonB1br10e2g2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumSenegalense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium senegalense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumSenegalense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GranulicellaPectinivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Granulicella pectinivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GranulicellaPectinivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNantensisDsm16982(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nantensis DSM 16982 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNantensisDsm16982", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AromatoleumToluclasticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum toluclasticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AromatoleumToluclasticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermogemmatisporaCarboxidivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora carboxidivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaCarboxidivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidetesBacteriumGwf23316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasJeddahensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas jeddahensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasJeddahensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpBls98Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. BLS98 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpBls98Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterRodentiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter rodentium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CitrobacterRodentiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMelliferumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma melliferum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaMelliferumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumGw2011gwa1409(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium GW2011GWA1409 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumGw2011gwa1409", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpFc2011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium sp. FC2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumSpFc2011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumKutscheri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium kutscheri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumKutscheri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCf046Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. cf046 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCf046Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusPauculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus pauculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusPauculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapsellaRubellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capsella rubella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapsellaRubellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisa53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisA53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisa53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesAureus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces aureus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAureus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo201full3939Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO201FULL3939 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo201full3939Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumCrh(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium CRH graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumCrh", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSuwonensisJ43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas suwonensis J43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSuwonensisJ43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GallusGallusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallus gallus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallusGallusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaLyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga lytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulophagaLyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IntestinibacterBartlettiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Intestinibacter bartlettii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IntestinibacterBartlettiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporolactobacillusLaevolacticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus laevolacticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusLaevolacticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAltamirensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia altamirensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAltamirensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumSmegmatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium smegmatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumSmegmatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaitoellaComplicataNrrlY17804Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Saitoella complicata NRRL Y-17804 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SaitoellaComplicataNrrlY17804Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiumMinutumPei191(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Elusimicrobium minutum Pei191 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ElusimicrobiumMinutumPei191", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDrosophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Drosophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDrosophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DichantheliumOligosanthes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dichanthelium oligosanthes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DichantheliumOligosanthes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium RIFOXYA2_FULL_41_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumRifoxya2Full4118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChromatialesBacteriumUscgtaylorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chromatiales bacterium USCgTaylor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChromatialesBacteriumUscgtaylorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophilaceaeBacteriumCg10262390Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophilaceae bacterium CG1_02_62_390 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophilaceaeBacteriumCg10262390Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_42_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTrypoxylicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus trypoxylicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusTrypoxylicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonocardiaDioxanivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia dioxanivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaDioxanivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinactinosporaThermotoleransDsm45154Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Marinactinospora thermotolerans DSM 45154 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MarinactinosporaThermotoleransDsm45154Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusDuransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus durans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDuransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanicaulisSpBbd199110Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanicaulis sp. BBD 1991-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanicaulisSpBbd199110Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysobacterArseniciresistensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter arseniciresistens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysobacterArseniciresistensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu083(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU083 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu083", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnophelesFarauti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles farauti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesFarauti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelainabacteriaBacteriumRifcsplowo212full3511Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium RIFCSPLOWO212FULL3511 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacteriumRifcsplowo212full3511Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPHIGHO2_01_FULL_44_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsphigho201Full4422Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrnithinibacillusScapharcae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ornithinibacillus scapharcae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrnithinibacillusScapharcae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaWenchangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea wenchangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaWenchangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PongoAbeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pongo abelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PongoAbeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpXt11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. XT11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpXt11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumCg2303520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium CG2303520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumCg2303520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPohangensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas pohangensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPohangensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpIs2118Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. IS2118 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpIs2118Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumCaucaseumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum caucaseum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumCaucaseumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalorubrumAidingenseJcm13560Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halorubrum aidingense JCM 13560 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalorubrumAidingenseJcm13560Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:411 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsJavanica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps javanica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CordycepsJavanica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusBarengoltzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus barengoltzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusBarengoltzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_12_FULL_38_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusSuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus suis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusSuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProsthecomicrobiumHirschii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prosthecomicrobium hirschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProsthecomicrobiumHirschii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_47_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaviaAperea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cavia aperea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaviaAperea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gordonia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GordoniaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobacteriaceaeArchaeon41258(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanobacteriaceae archaeon 41_258 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanobacteriaceaeArchaeon41258", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumRifcsphigho201full4616Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium RIFCSPHIGHO201FULL4616 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumRifcsphigho201full4616Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpO77(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. O-77 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpO77", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraLatinaNbrc106108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomadura latina NBRC 106108 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomaduraLatinaNbrc106108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CarnobacteriumMaltaromaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium maltaromaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumMaltaromaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumMedicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium medicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumMedicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpNml140438(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. NML140438 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpNml140438", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylellaFastidiosa9a5cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xylella fastidiosa 9a5c Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XylellaFastidiosa9a5cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaPolysacchareaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria polysaccharea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaPolysacchareaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumPolymorphumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum polymorphum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumPolymorphumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiansivirgaZeaxanthinifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Siansivirga zeaxanthinifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SiansivirgaZeaxanthinifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MandrillusLeucophaeusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mandrillus leucophaeus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MandrillusLeucophaeusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmycolatopsisAustraliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis australiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisAustraliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpRoot485Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Root485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpRoot485Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusParabrevisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus parabrevis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusParabrevisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifoxyd1Full4619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFOXYD1_FULL_46_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifoxyd1Full4619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BizioniaSpApa3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bizionia sp. APA-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BizioniaSpApa3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FluoribacterBozemanaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fluoribacter bozemanae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FluoribacterBozemanaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodanobacterSp6829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. 68-29 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSp6829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusApodemiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus apodemi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusApodemiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusFlavusNrrl3357(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus flavus NRRL3357 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusFlavusNrrl3357", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApostasiaShenzhenicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Apostasia shenzhenica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ApostasiaShenzhenicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GrosmanniaClavigeraKw1407Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Grosmannia clavigera kw1407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GrosmanniaClavigeraKw1407Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElsinoeAustralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elsinoe australis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElsinoeAustralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaDianthicolaNcppb3534(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya dianthicola NCPPB 3534 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DickeyaDianthicolaNcppb3534", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaphrinaDeformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taphrina deformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaphrinaDeformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonEquinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton equinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichophytonEquinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassospiraSpTsl51Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassospira sp. TSL5-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassospiraSpTsl51Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudorhodobacterAquimaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodobacter aquimaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudorhodobacterAquimaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolirubrobacterSoliDsm22325Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Solirubrobacter soli DSM 22325 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SolirubrobacterSoliDsm22325Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MobiluncusMulierisAtcc35243(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris ATCC35243 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MobiluncusMulierisAtcc35243", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidalesBacteriumH9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium H9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumH9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TubulinosemaRatisbonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tubulinosema ratisbonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TubulinosemaRatisbonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumLeiognathiLrivu41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Photobacterium leiognathi lrivu41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhotobacteriumLeiognathiLrivu41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumAntarcticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium antarcticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumAntarcticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumPaxllaeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium paxllaeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumPaxllaeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaloranaerobacterFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caloranaerobacter ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaloranaerobacterFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaceaeArchaeonTcbr11e2g14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialbaceae archaeon TcBr11E2g14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaceaeArchaeonTcbr11e2g14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaMonocytogenesScottCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria monocytogenes Scott Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaMonocytogenesScottCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MalusBaccataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Malus baccata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MalusBaccataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporidiumParvumIowaIiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cryptosporidium parvum Iowa II Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CryptosporidiumParvumIowaIiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonauticusSubmarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus submarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSubmarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumSpMb1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium sp. MB1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumSpMb1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusLoiseleuriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus loiseleuriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusLoiseleuriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAzizii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus azizii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAzizii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAppendicisCip107643Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium appendicis CIP 107643 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAppendicisCip107643Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PasteurellaSkyensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pasteurella skyensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PasteurellaSkyensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSolanacearumPo82Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum Po82 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumPo82Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpVcd2006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. VCD2006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpVcd2006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CladophialophoraYegresiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora yegresii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraYegresiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BremiaLactucae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bremia lactucae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BremiaLactucae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSoil782Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Soil782 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSoil782Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BaudoiniaPanamericanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Baudoinia panamericana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BaudoiniaPanamericanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMelainabacteriaBacteriumRifoxya2Full329Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFOXYA2_FULL_32_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifoxya2Full329Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CompetibacterDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Competibacter denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CompetibacterDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioThiocyanoxidansArh4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanoxidans ARh4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanoxidansArh4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfovibrioYellowstoniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfovibrio yellowstonii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfovibrioYellowstoniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpSoil787(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. Soil787 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpSoil787", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BdellovibrionalesBacteriumRifoxya1full3614(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium RIFOXYA1FULL3614 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumRifoxya1full3614", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceibacterAtlanticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Croceibacter atlanticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CroceibacterAtlanticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRickettsiellaIsopodorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rickettsiella isopodorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRickettsiellaIsopodorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_34b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4534bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumOl1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium OL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumOl1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSputorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sputorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSputorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhascolarctosCinereus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phascolarctos cinereus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhascolarctosCinereus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TalaromycesStipitatusAtcc10500Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Talaromyces stipitatus ATCC 10500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TalaromycesStipitatusAtcc10500Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphriteaAtlantica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amphritea atlantica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmphriteaAtlantica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGlucanolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus glucanolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGlucanolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsplowo201full3613Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO201FULL3613 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo201full3613Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesDurhamensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces durhamensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesDurhamensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RalstoniaSolanacearumGmi1000Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ralstonia solanacearum GMI1000 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RalstoniaSolanacearumGmi1000Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCelatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium celatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCelatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterSmithiiAtcc35061Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter smithii ATCC35061 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterSmithiiAtcc35061Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidiplasmaSpMba1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidiplasma sp. MBA-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidiplasmaSpMba1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSpEjy3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Vibrio sp. EJY3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "VibrioSpEjy3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgromycesSubbeticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agromyces subbeticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgromycesSubbeticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzorhizobiumCaulinodansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium caulinodans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumCaulinodansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacteriumCg2305140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium CG2_30_51_40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacteriumCg2305140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterMicroaerophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dialister microaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DialisterMicroaerophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptosporangiumAmethystogenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptosporangium amethystogenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptosporangiumAmethystogenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentibacterRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rodentibacter ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RodentibacterRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterSpRedseas34b3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter sp. REDSEAS34B3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterSpRedseas34b3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMitisAtcc6249(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis ATCC6249 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisAtcc6249", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasSpCba1134Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas sp. CBA1134 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NatronomonasSpCba1134Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPhocaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus phocae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPhocaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixSpCaciam69d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Limnothrix sp. CACIAM 69d graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LimnothrixSpCaciam69d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaPacifica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella pacifica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaPacifica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpAap58(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. AAP58 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpAap58", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusPleuropneumoniae5bL20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus pleuropneumoniae 5b L20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusPleuropneumoniae5bL20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HebelomaCylindrosporumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HebelomaCylindrosporumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCapeferrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas capeferrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCapeferrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumKansasiiAtcc12478Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium kansasii ATCC12478 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumKansasiiAtcc12478Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumPropinquumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium propinquum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPropinquumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioNorvegicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio norvegicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioNorvegicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpAtcc29733Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. ATCC29733 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpAtcc29733Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTachikawaeaGelatinosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tachikawaea gelatinosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTachikawaeaGelatinosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterExcellensHl55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter excellens HL-55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacterExcellensHl55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpKimEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. KIM Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpKimEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLevybacteriaBacteriumRifcsplowo201Full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPLOWO2_01_FULL_39_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsplowo201Full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenispirillumSalinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenispirillum salinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenispirillumSalinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExserohilumTurcicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Exserohilum turcica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ExserohilumTurcicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumA37t11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return bacterium A37T11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteriumA37t11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpS2151Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. S2151 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpS2151Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium RIFCSPLOWO2_12_FULL_48_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumRifcsplowo212Full4812Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacteralesBacteriumRifcsphigho201full7019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacterales bacterium RIFCSPHIGHO201FULL7019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacteralesBacteriumRifcsphigho201full7019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaAlbertiiTw07627(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii TW07627 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiTw07627", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinkiaNeuiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winkia neuii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinkiaNeuiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpTrpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. TRP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpTrpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterAcetiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter aceti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcetobacterAcetiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacterium13220cm5827Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium 13_2_20CM_58_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacterium13220cm5827Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParaliobacillusRyukyuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraliobacillus ryukyuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaliobacillusRyukyuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc5054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EncephalitozoonCuniculiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Encephalitozoon cuniculi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EncephalitozoonCuniculiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaNova(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia nova graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaNova", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpRoot1279(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. Root1279 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpRoot1279", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GardnerellaVaginalis101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gardnerella vaginalis 101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GardnerellaVaginalis101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaistiaAdipataDsm17808(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kaistia adipata DSM 17808 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KaistiaAdipataDsm17808", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLundense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium lundense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLundense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptosporangiumAurantiacumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptosporangium aurantiacum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptosporangiumAurantiacumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobulbiferSpHz11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. HZ11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpHz11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LuteitaleaPratensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Luteitalea pratensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LuteitaleaPratensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonBenhamiaeCbs112371(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae CBS 112371 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichophytonBenhamiaeCbs112371", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NostocSpMbr210(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. MBR 210 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NostocSpMbr210", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichoplaxSpH2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax sp. H2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxSpH2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_01_FULL_44_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyberlindneraFabianii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyberlindnera fabianii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyberlindneraFabianii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesPosadasiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides posadasii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesPosadasiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirochaetaBajacaliforniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirochaeta bajacaliforniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirochaetaBajacaliforniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirillosporaAlbidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirillospora albida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirillosporaAlbidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasMariniglutinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas mariniglutinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasMariniglutinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesMassiliensisDnlkv3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides massiliensis dnLKV3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteroidesMassiliensisDnlkv3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylorubrumExtorquensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylorubrum extorquens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylorubrumExtorquensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AegiribacteriaBacteriumMlsc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aegiribacteria bacterium MLSC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AegiribacteriaBacteriumMlsc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusIhumii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ihumii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusIhumii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConexibacterWoeseiIso977nCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei Iso977N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiIso977nCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumSpYl23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YL23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYl23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpLb2011Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. LB2011 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpLb2011Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumKa00274Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium KA00274 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumKa00274Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumRbg19ftcombo6530Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO6530 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo6530Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFarciminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farciminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarciminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaSpF0382Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0382 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0382Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusRhamnosus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rhamnosus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRhamnosus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpBp1148Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. BP1-148 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpBp1148Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumAquaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium aquae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumAquaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiabellaGinsenosidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Niabella ginsenosidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NiabellaGinsenosidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasSputigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Selenomonas sputigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SelenomonasSputigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg166413Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_64_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166413Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycetocolaSaprophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycetocola saprophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycetocolaSaprophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerrabacterSpSoil810Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terrabacter sp. Soil810 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerrabacterSpSoil810Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspDiarizonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. diarizonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspDiarizonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumArsenaticum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum arsenaticum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumArsenaticum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot342(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root342 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot342", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWwe3BacteriumGw2011gwf24242Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWF24242 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwf24242Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPLOWO2_01_FULL_45_31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsplowo201Full4531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterFelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter felis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HelicobacterFelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiHtIsolateThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HT isolate Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHtIsolateThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusOrnithinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus ornithinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusOrnithinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LacinutrixMariniflavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lacinutrix mariniflava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LacinutrixMariniflavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HebelomaCylindrosporumH7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hebeloma cylindrosporum h7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HebelomaCylindrosporumH7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumScgcAaa252n14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium SCGC AAA252N14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumScgcAaa252n14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaSpRha55Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. RHA_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpRha55Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SiccibacterTuricensisLmg23730(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Siccibacter turicensis LMG 23730 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SiccibacterTuricensisLmg23730", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesTsukubensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces tsukubensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesTsukubensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DelphinapterusLeucas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Delphinapterus leucas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DelphinapterusLeucas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarchaeobiusIranensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloarchaeobius iranensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloarchaeobiusIranensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFlexus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus flexus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusFlexus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeurosporaTetraspermaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neurospora tetrasperma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeurosporaTetraspermaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmesbacteriaBacteriumGw2011gwa24212Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24212 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24212Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisSpH050Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H050 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH050Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DemequinaSpNbrc110054Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sp. NBRC 110054 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSpNbrc110054Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaEndophytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Martelella endophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MartelellaEndophytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitomaculumAntarcticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Robiginitomaculum antarcticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RobiginitomaculumAntarcticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNxc14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NXC14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNxc14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusStellifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus stellifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusStellifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4645Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4645 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4645Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeucobacterChironomiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter chironomi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeucobacterChironomiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpPw1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. PW1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpPw1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg165611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_56_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumFalseniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium falsenii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFalseniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusKoppenhoeferi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus koppenhoeferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusKoppenhoeferi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExophialaXenobiotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exophiala xenobiotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExophialaXenobiotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GryllotalpicolaGinsengisoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gryllotalpicola ginsengisoli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GryllotalpicolaGinsengisoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatusAuricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microgenomatus auricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatusAuricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumScgcAaa027n21Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium SCGC AAA027N21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumScgcAaa027n21Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSherrisiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sherrisii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSherrisiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kocuria flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KocuriaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpBg2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma sp. Bg2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaSpBg2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasDonghaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenimonasDonghaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediculusHumanusCorporisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pediculus humanus corporis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PediculusHumanusCorporisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOrisF0423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus oris F0423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusOrisF0423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusFasciansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusFasciansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentinulaEdodes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentinula edodes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentinulaEdodes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrochaeteSpPcc7126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microchaete sp. PCC7126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrochaeteSpPcc7126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaminaeaRoseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jaminaea rosea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JaminaeaRoseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaGlaberrimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Oryza glaberrima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OryzaGlaberrimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioSonorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio sonorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioSonorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag571(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag571", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacterium6732Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium 67-32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacterium6732Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBrocadiaCaroliniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia caroliniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaCaroliniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_01_FULL_45_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichechusManatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichechus manatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichechusManatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyotisBrandtii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Myotis brandtii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MyotisBrandtii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaColiAtcc8739Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Escherichia coli ATCC8739 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EscherichiaColiAtcc8739Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzotobacterBeijerinckiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azotobacter beijerinckii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzotobacterBeijerinckiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuproteobacteriaBacteriumRifcsplowo201full6018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Muproteobacteria bacterium RIFCSPLOWO201FULL6018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MuproteobacteriaBacteriumRifcsplowo201full6018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumGwf24151Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium GWF2_41_51 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumGwf24151Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraGenomospCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera genomosp. Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraGenomospCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhinolophusFerrumequinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhinolophus ferrumequinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhinolophusFerrumequinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriaSymbiontBfo2OfFrankliniellaOccidentalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return bacteria symbiont BFo2 of Frankliniella occidentalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriaSymbiontBfo2OfFrankliniellaOccidentalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerasakiellaMagnetica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terasakiella magnetica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerasakiellaMagnetica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6714(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6714 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6714", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobaculumTerrenumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobaculum terrenum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobaculumTerrenumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpGa1199(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. GA-1199 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpGa1199", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CucumibacterMarinusDsm18995(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cucumibacter marinus DSM 18995 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CucumibacterMarinusDsm18995", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CystobacterFuscusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cystobacter fuscus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CystobacterFuscusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaHaemocanisStrIllinoisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma haemocanis str. Illinois Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHaemocanisStrIllinoisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiberibacterAfricanus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Liberibacter africanus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LiberibacterAfricanus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpLeaf7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. Leaf7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpLeaf7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SeonamhaeicolaSpS23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Seonamhaeicola sp. S2-3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SeonamhaeicolaSpS23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WeissellaParamesenteroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Weissella paramesenteroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WeissellaParamesenteroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWesteberhardiaCardiocondylae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Westeberhardia cardiocondylae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWesteberhardiaCardiocondylae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTepidiprofundiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidiprofundi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidiprofundiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermocisternusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermocisternus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermocisternusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThecamonasTrahensAtcc50062Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens ATCC 50062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThecamonasTrahensAtcc50062Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusKunkeei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kunkeei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKunkeei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaSpAd6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola sp. AD6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrincolaSpAd6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSalegens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas salegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSalegens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusKawachiiIfo4308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus kawachii IFO 4308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusKawachiiIfo4308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterVibrioidesOr37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter vibrioides OR37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterVibrioidesOr37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusFasciansLmg3625Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus fascians LMG 3625 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodococcusFasciansLmg3625Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSp88aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. 88A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSp88aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusEnclensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus enclensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusEnclensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioParadoxusArh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus ARh 1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxusArh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166443Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166443Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OstreococcusLucimarinusCce9901Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ostreococcus lucimarinus CCE9901 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OstreococcusLucimarinusCce9901Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicromonosporaSpCb01531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora sp. CB01531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaSpCb01531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderialesBacteriumGa0077544(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium Ga0077544 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumGa0077544", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydomonasEustigma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydomonas eustigma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydomonasEustigma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharibacteria bacterium RIFCSPLOWO2_01_FULL_48_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharibacteriaBacteriumRifcsplowo201Full4813", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MonosporascusSpMg133Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Monosporascus sp. MG133 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MonosporascusSpMg133Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpLeaf48Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Leaf48 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLeaf48Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSp1501Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. 1501 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSp1501Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProlemurSimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prolemur simus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProlemurSimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasPutidaH8234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas putida H8234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPutidaH8234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHayakitensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hayakitensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHayakitensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlleyaMarilimosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olleya marilimosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlleyaMarilimosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaSpBmg512(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG512 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBmg512", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiobacillusSp6529(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. 65-29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSp6529", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulpesVulpes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vulpes vulpes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VulpesVulpes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AliterellaAtlanticaCena595Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aliterella atlantica CENA595 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AliterellaAtlanticaCena595Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusFaeciumC68(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus faecium C68 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterococcusFaeciumC68", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpBjeddEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. Bjedd Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSpBjeddEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifoxyd12full3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFOXYD12FULL3317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifoxyd12full3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WallemiaIchthyophagaExf994Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Wallemia ichthyophaga EXF-994 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "WallemiaIchthyophagaExf994Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaParvaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora parva Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaParvaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RamlibacterSpLeaf400Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ramlibacter sp. Leaf400 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RamlibacterSpLeaf400Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusCapraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus caprae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusCapraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusThermoglucosidasius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus thermoglucosidasius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GeobacillusThermoglucosidasius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodopseudomonasPalustrisBisb18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris BisB18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisBisb18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioAlginolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio alginolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioAlginolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpScn7031Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 70-31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn7031Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShewanellaSpUcdkl12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoritellaDasanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Moritella dasanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MoritellaDasanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrosopumilusPiranensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosopumilus piranensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosopumilusPiranensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCereusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus cereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCereusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LacunisphaeraLimnophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lacunisphaera limnophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LacunisphaeraLimnophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSanguinisSk355Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK355 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk355Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaPneumoniaeM129(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma pneumoniae M129 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaPneumoniaeM129", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaStellulata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stappia stellulata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StappiaStellulata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumPerfoetensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium perfoetens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumPerfoetensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumChubuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium chubuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumChubuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kerfeldbacteria bacterium RIFCSPHIGHO2_02_FULL_42_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKerfeldbacteriaBacteriumRifcsphigho202Full4214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusAculeatusAtcc16872Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus aculeatus ATCC 16872 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusAculeatusAtcc16872Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkalibacteriumPutridalgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium putridalgicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumPutridalgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClavibacterMichiganensisCapsiciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clavibacter michiganensis capsici Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClavibacterMichiganensisCapsiciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapnocytophagaOchraceaDsm7271Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capnocytophaga ochracea DSM7271 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CapnocytophagaOchraceaDsm7271Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalegentibacterSalegensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salegens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalegensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubritaleaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubritalea marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubritaleaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPanacisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas panacis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPanacisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhinopithecusBieti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhinopithecus bieti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhinopithecusBieti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusSciuriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sciuri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSciuriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaDenticariosiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella denticariosi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaDenticariosiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzorhizobiumDoebereineraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Azorhizobium doebereinerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AzorhizobiumDoebereineraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalovivaxAsiaticusJcm14624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halovivax asiaticus JCM 14624 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalovivaxAsiaticusJcm14624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciecolaSpHtcc2999Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciecola sp. HTCC2999 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciecolaSpHtcc2999Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeregrinibacteriaBacteriumCg2304417Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium CG2_30_44_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumCg2304417Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumCg10243210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG10243210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg10243210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusOxalaticusNbrc13593Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus oxalaticus NBRC 13593 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CupriavidusOxalaticusNbrc13593Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterPiechaudiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter piechaudii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AchromobacterPiechaudiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaGrandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Listeria grandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ListeriaGrandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PandoraeaSputorum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pandoraea sputorum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PandoraeaSputorum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylothermaceaeBacteriaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteriaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CephaloticoccusCapnophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cephaloticoccus capnophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CephaloticoccusCapnophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumAeronauticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum aeronauticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumAeronauticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumNucleatumW1481Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum W1481 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumW1481Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaEndosymbiontOfDactylopiusCoccusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius coccus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopiusCoccusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiumSpGas474(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobium sp. GAS474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiumSpGas474", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSalivariusUcc118(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus salivarius UCC118 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSalivariusUcc118", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaDiobovataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula diobovata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaDiobovataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaWelshimeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria welshimeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaWelshimeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFukatsuiaSymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Fukatsuia symbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFukatsuiaSymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFrederiksbergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas frederiksbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFrederiksbergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoactinomycesDaqusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermoactinomyces daqus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermoactinomycesDaqusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GouaniaWilldenowi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gouania willdenowi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GouaniaWilldenowi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhocaeicolaAbscessusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioLitoralisDsm11393Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis DSM 11393 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralisDsm11393Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PoseidonocellaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Poseidonocella pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PoseidonocellaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumSubspAnimalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum subsp. animalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumSubspAnimalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDentisani7747(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus dentisani 7747 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusDentisani7747", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichechusManatusLatirostrisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Trichechus manatus latirostris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TrichechusManatusLatirostrisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasAstaxanthinifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas astaxanthinifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasAstaxanthinifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusRenniniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus rennini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusRenniniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParastrongyloidesTrichosuriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parastrongyloides trichosuri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParastrongyloidesTrichosuriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CronobacterDublinensisLausannensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cronobacter dublinensis lausannensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CronobacterDublinensisLausannensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaromonasNaphthalenivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaromonas naphthalenivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaromonasNaphthalenivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnohabitansSp103dpr2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Limnohabitans sp. 103DPR2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LimnohabitansSp103dpr2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobrevibacterWoliniiShEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanobrevibacter wolinii SH Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanobrevibacterWoliniiShEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwb1388Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWB1_38_8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwb1388Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermoflavimicrobiumDichotomicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoflavimicrobium dichotomicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoflavimicrobiumDichotomicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnicellularCyanobacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return unicellular cyanobacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UnicellularCyanobacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HymenobacterSpCra2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter sp. CRA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSpCra2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_46_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceicoccusNaphthovoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus naphthovorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusNaphthovoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwb1471(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWB1_47_1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwb1471", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EndosymbiontOfRidgeia(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return endosymbiont of Ridgeia graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EndosymbiontOfRidgeia", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VaribaculumCambrienseDsm15806(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Varibaculum cambriense DSM15806 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VaribaculumCambrienseDsm15806", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EggerthellaSpCag298(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eggerthella sp. CAG:298 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EggerthellaSpCag298", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrococcusCanis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Macrococcus canis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MacrococcusCanis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc11e11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC11E11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc11e11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioCuneatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio cuneatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioCuneatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TsukamurellaPaurometabolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tsukamurella paurometabola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TsukamurellaPaurometabolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesOnderdonkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes onderdonkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesOnderdonkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaParisiiErtm3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nematocida parisii ERTm3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NematocidaParisiiErtm3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnsiferSpWsm1721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sp. WSM1721 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnsiferSpWsm1721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasRubraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas rubra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasRubraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaMuris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia muris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMuris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaPallidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema pallidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaPallidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AzospirillumOryzae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Azospirillum oryzae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AzospirillumOryzae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumArbusti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium arbusti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumArbusti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumSpAk27Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium sp. AK27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumSpAk27Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotobacteriumProteolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium proteolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumProteolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolobacteriumMooreiDsm22971Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Solobacterium moorei DSM22971 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SolobacteriumMooreiDsm22971Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinicellaSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinicella sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinicellaSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumCch3a5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium CCH3A5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumCch3a5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaBalticaOs145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Idiomarina baltica OS145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "IdiomarinaBalticaOs145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCuatrocienegasensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas cuatrocienegasensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasCuatrocienegasensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGilichinskyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio gilichinskyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioGilichinskyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaMeningitidisMc58Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Neisseria meningitidis MC58 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NeisseriaMeningitidisMc58Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_01_FULL_44_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo201Full4421Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algibacter aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraMaduraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura madurae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraMaduraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_02_FULL_44_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumIndoltheticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium indoltheticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumIndoltheticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaPorcinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema porcinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaPorcinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHeilmanniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterHeilmanniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaRwandensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea rwandensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaRwandensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSoleaferreaMassiliensisAp7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Soleaferrea massiliensis AP7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSoleaferreaMassiliensisAp7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135136Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135136Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BelnapiaMoabensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Belnapia moabensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BelnapiaMoabensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusShenzhenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus shenzhenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusShenzhenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpP838Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. P838 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpP838Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxKoreense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax koreense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxKoreense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaRiboflavinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia riboflavina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaRiboflavinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterKomagataeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucobacter komagatae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucobacterKomagataeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RalstoniaSpA12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ralstonia sp. A12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RalstoniaSpA12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraSpAle5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira sp. ALE5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraSpAle5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAurantiacaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella aurantiaca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAurantiacaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_01_FULL_47_33 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo201Full4733Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPLOWO2_02_FULL_38_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsplowo202Full388", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KurthiaSpJc8eCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kurthia sp. JC8E Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KurthiaSpJc8eCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeisingeraSpAng1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAng1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MolaMolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mola mola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MolaMolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwa24015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWA2_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwa24015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusSpOv096Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus sp. OV096 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusSpOv096Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KosmotogaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kosmotoga pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KosmotogaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TuberibacillusCalidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tuberibacillus calidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TuberibacillusCalidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteriumOl1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return bacterium OL1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteriumOl1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4411Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4411 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4411Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumWce2004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium WCE2004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumWce2004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DysgonomonasMossii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dysgonomonas mossii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DysgonomonasMossii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaccharosporaIrregularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asaccharospora irregularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsaccharosporaIrregularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioCholerae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio cholerae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioCholerae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZambryskibacteriaBacteriumRifcsplowo202full3813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFCSPLOWO202FULL3813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifcsplowo202full3813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DomibacillusMangroviEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus mangrovi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DomibacillusMangroviEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs39Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs39Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusDelbrueckiiBulgaricus2038Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus 2038 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricus2038Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusAgnetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus agnetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusAgnetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AromatoleumTolulyticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aromatoleum tolulyticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AromatoleumTolulyticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlutamicibacterHalophytocolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glutamicibacter halophytocola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlutamicibacterHalophytocolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg164813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG164813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg164813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesLavenduligriseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces lavenduligriseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLavenduligriseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarvinbryantiaFormatexigensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marvinbryantia formatexigens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarvinbryantiaFormatexigensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SerinicoccusProfundiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Serinicoccus profundi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SerinicoccusProfundiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinosporangiumAlbum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sinosporangium album graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SinosporangiumAlbum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terrybacteria bacterium RIFCSPHIGHO2_01_FULL_58_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerrybacteriaBacteriumRifcsphigho201Full5815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParamesorhizobiumDesertiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paramesorhizobium deserti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParamesorhizobiumDesertiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VeillonellaRattiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Veillonella ratti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VeillonellaRattiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSolimangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solimangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSolimangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpCipa165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. CIPA165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpCipa165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriumPhsc20c1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium PHSC20C1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumPhsc20c1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasLinyingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas linyingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasLinyingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpD20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides sp. D20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacteroidesSpD20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AltibacterLentusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altibacter lentus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltibacterLentusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumAlsenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium alsense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumAlsenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusNasuensisJcm17158Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus nasuensis JCM 17158 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusNasuensisJcm17158Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPHIGHO2_02_FULL_54_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsphigho202Full5417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaExalbidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia exalbida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaExalbidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalolactibacillusMiurensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halolactibacillus miurensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalolactibacillusMiurensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomyceteKsu1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return planctomycete KSU1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PlanctomyceteKsu1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterSyzygii9h2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter syzygii 9H-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcetobacterSyzygii9h2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckiiAtcc11842Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii ATCC11842 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiAtcc11842Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaParvulaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Veillonella parvula Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VeillonellaParvulaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfitobacterSpMm124Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sulfitobacter sp. MM124 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SulfitobacterSpMm124Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldanaerobiusFijiensisDsm17918Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldanaerobius fijiensis DSM 17918 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldanaerobiusFijiensisDsm17918Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGambriniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gambrini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGambriniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusVaraniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus varani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusVaraniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DokdonellaKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AbiotrophiaDefectivaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Abiotrophia defectiva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AbiotrophiaDefectivaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLarrymooreiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium larrymoorei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLarrymooreiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusSzentirmaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesGeorgiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces georgiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesGeorgiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumHominisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium hominis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumHominisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycesBrasiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Planctomyces brasiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlanctomycesBrasiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporolactobacillusInulinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporolactobacillus inulinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporolactobacillusInulinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaTamiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bartonella tamiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BartonellaTamiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaAncashensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella ancashensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaAncashensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarithrixSpCanyonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marithrix sp. Canyon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarithrixSpCanyonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GoniumPectoraleCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gonium pectorale Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GoniumPectoraleCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SediminibacteriumSalmoneumNbrc103935(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sediminibacterium salmoneum NBRC 103935 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SediminibacteriumSalmoneumNbrc103935", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KerfeldbacteriaBacteriumRifcsphigho212full4817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kerfeldbacteria bacterium RIFCSPHIGHO212FULL4817 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KerfeldbacteriaBacteriumRifcsphigho212full4817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusThermokryptusMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Thermokryptus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusThermokryptusMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusParviboronicapiensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus parviboronicapiens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusParviboronicapiensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSp23gom1509m(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. 23GOM1509m graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasSp23gom1509m", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaCuniculi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemella cuniculi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemellaCuniculi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifoxyb1full4614Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFOXYB1FULL4614 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifoxyb1full4614Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSubtilisSubspSpizizeniiTuB10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus subtilis subsp. spizizenii TU-B-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSubtilisSubspSpizizeniiTuB10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacteriumNrl2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium NRL2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumNrl2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallusGallusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gallus gallus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GallusGallusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AerococcusViridansAtcc11563Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans ATCC11563 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansAtcc11563Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaGranulomatisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia granulomatis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaGranulomatisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaPhymatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia phymatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaPhymatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_02_FULL_37_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho202Full3713Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TranquillimonasAlkanivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tranquillimonas alkanivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TranquillimonasAlkanivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KetogulonicigeniumVulgare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ketogulonicigenium vulgare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KetogulonicigeniumVulgare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSunkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sunkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSunkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IzhakiellaAustraliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Izhakiella australiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IzhakiellaAustraliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CribrihabitansMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cribrihabitans marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CribrihabitansMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaAlliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pantoea allii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PantoeaAlliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpUnc267mfsha11m11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UNC267MFSha1.1M11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUnc267mfsha11m11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobialesBacteriumGa0077555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium Ga0077555 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacteriumGa0077555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensis3145bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis 3145B Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SutterellaWadsworthensis3145bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CucumisMeloVarMakuwaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cucumis melo var. makuwa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CucumisMeloVarMakuwaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RubellimicrobiumMesophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rubellimicrobium mesophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RubellimicrobiumMesophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumZagget3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium Zagget3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumZagget3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobaculumSpF0552(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobaculum sp. F0552 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobaculumSpF0552", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf23316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_33_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf23316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumSpYl23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium sp. YL23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumSpYl23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JaculusJaculusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jaculus jaculus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JaculusJaculusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumBrachyEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium brachy Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumBrachyEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaPseudobrasiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia pseudobrasiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaPseudobrasiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumAlkaliphilum121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Exiguobacterium alkaliphilum 12/1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ExiguobacteriumAlkaliphilum121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanoculleusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermococcusNautili(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermococcus nautili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermococcusNautili", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSaphenumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium saphenum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSaphenumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AureimonasFrigidaquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas frigidaquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AureimonasFrigidaquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpC01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. C01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpC01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusMarimammaliumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus marimammalium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusMarimammaliumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyroidesGuanonis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myroides guanonis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyroidesGuanonis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_35_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaAlbensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella albensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaAlbensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaceaeBacteriumIbvucb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinophagaceae bacterium IBVUCB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaceaeBacteriumIbvucb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterHeraklionensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter heraklionensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterHeraklionensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SchwartziaSuccinivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schwartzia succinivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchwartziaSuccinivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeefgeaRivuliDsm18356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Deefgea rivuli DSM 18356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DeefgeaRivuliDsm18356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg1024923(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_49_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1024923", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptococcusNeoformans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryptococcus neoformans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryptococcusNeoformans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaribacterStanieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter stanieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterStanieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumRifcsplowo202full5016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPLOWO202FULL5016 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsplowo202full5016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPeribacterRiflensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peribacter riflensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeribacterRiflensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFirestonebacteriaBacteriumRifoxya2Full408Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Firestonebacteria bacterium RIFOXYA2_FULL_40_8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFirestonebacteriaBacteriumRifoxya2Full408Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpF0384Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. F0384 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpF0384Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeonectriaDitissimaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neonectria ditissima Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeonectriaDitissimaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobiumJaponicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingobium japonicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingobiumJaponicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KushneriaSpYcwa18Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kushneria sp. YCWA18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KushneriaSpYcwa18Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesSpHgb5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alistipes sp. HGB5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlistipesSpHgb5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyromonasSpCot290oh3588Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas sp. COT290OH3588 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasSpCot290oh3588Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusIndolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus indolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusIndolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EctothiorhodospiraMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ectothiorhodospira marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EctothiorhodospiraMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanotheceSpPcc7425Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyanothece sp. PCC7425 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyanotheceSpPcc7425Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShigellaBoydii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shigella boydii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShigellaBoydii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalegentibacterSalinarumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salegentibacter salinarum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalegentibacterSalinarumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaNamucuonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Massilia namucuonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MassiliaNamucuonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhotodesmusBlepharus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photodesmus blepharus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotodesmusBlepharus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLongaSw024Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina longa SW024 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLongaSw024Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterSpHeli7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Maribacter sp. HelI7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MaribacterSpHeli7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFarciminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus farciminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFarciminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_41_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full4112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobiusMediterraneus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thalassobius mediterraneus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThalassobiusMediterraneus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaSpongiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina spongiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AquimarinaSpongiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwelliaMytili(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellia mytili graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwelliaMytili", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaPlymuthica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia plymuthica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaPlymuthica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumHeidelbergenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium heidelbergense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumHeidelbergenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumCosmeticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium cosmeticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumCosmeticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioclavaMarinaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioclava marina Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioclavaMarinaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpAap43Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. AAP43 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpAap43Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumBifidumPrl2010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum PRL2010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumPrl2010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpHeli29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gillisia sp. HelI29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GillisiaSpHeli29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ComamonasTerrigenaNbrc13299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Comamonas terrigena NBRC 13299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ComamonasTerrigenaNbrc13299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasVranovensisDsm16006Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas vranovensis DSM 16006 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasVranovensisDsm16006Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusBromiiL263Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus bromii L2-63 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RuminococcusBromiiL263Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaFonticolaRb25(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Serratia fonticola RB25 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SerratiaFonticolaRb25", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsilocybeCyanescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psilocybe cyanescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsilocybeCyanescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlistipesMarseilloanorexicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alistipes marseilloanorexicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlistipesMarseilloanorexicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptonychotesWeddelliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptonychotes weddellii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptonychotesWeddelliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CylindrobasidiumTorrendiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cylindrobasidium torrendii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CylindrobasidiumTorrendiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusSpCag382Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:382 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag382Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermobisporaBisporaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thermobispora bispora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThermobisporaBisporaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumSg830Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg830Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumGa0077531Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium Ga0077531 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumGa0077531Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAbscessus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardia abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiaAbscessus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldimonasTaiwanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferDonghaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer donghaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferDonghaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMoranbacteriaBacteriumCg2304514(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_45_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg2304514", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag1295924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:129_59_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag1295924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaStercoreaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella stercorea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaStercoreaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DehalogenimonasSpWbc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dehalogenimonas sp. WBC-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DehalogenimonasSpWbc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasNitroreducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MalasseziaRestrictaCbs7877Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Malassezia restricta CBS 7877 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MalasseziaRestrictaCbs7877Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteraceaeBacterium4572123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacteraceae bacterium 4572_123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteraceaeBacterium4572123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteScgcAb629i23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote SCGC AB629I23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteScgcAb629i23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSpChdcEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus sp. ChDC Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusSpChdcEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitricoccusSpCh26a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citricoccus sp. CH26A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitricoccusSpCh26a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaHominisCcug36813Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Facklamia hominis CCUG 36813 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FacklamiaHominisCcug36813Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PersephonellaSpIf05l8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Persephonella sp. IF05L8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PersephonellaSpIf05l8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmanitaMuscariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amanita muscaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmanitaMuscariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumAcetireducensDsm10703Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acetireducens DSM 10703 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcetireducensDsm10703Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaFuscaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella fusca Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaFuscaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermogemmatisporaSpPm5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thermogemmatispora sp. PM5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThermogemmatisporaSpPm5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TinamusGuttatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tinamus guttatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TinamusGuttatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusGelatiniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus gelatini Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FictibacillusGelatiniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeoglobusAhangari(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geoglobus ahangari graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeoglobusAhangari", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShinellaSpDd12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Shinella sp. DD12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ShinellaSpDd12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Portnoybacteria bacterium RBG_19FT_COMBO_36_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPortnoybacteriaBacteriumRbg19ftCombo367Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumParaseoulenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium paraseoulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumParaseoulenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSp6610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. 66-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSp6610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaParvaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Micromonospora parva Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicromonosporaParvaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichodermaArundinaceumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma arundinaceum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichodermaArundinaceumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LomentosporaProlificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lomentospora prolificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LomentosporaProlificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpC1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. C-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpC1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSpLm6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sp. LM 6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSpLm6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSp4414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 44_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp4414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProcaviaCapensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Procavia capensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProcaviaCapensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumLlatzerenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium llatzerense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumLlatzerenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhycomycesBlakesleeanusNrrl1555(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phycomyces blakesleeanus NRRL 1555(-) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhycomycesBlakesleeanusNrrl1555", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9313Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9313 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9313Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicavibrioAeruginosavorusEpbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micavibrio aeruginosavorus EPB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicavibrioAeruginosavorusEpbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerodermaCitrinumFougACluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Foug A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SclerodermaCitrinumFougACluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRbg166418(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RBG_16_64_18 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRbg166418", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmatimonadetesBacterium5513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Armatimonadetes bacterium 55-13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArmatimonadetesBacterium5513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifoxyd2full4310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYD2FULL4310 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyd2full4310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSaccharophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saccharophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaccharophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusOdoratitofui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus odoratitofui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusOdoratitofui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RikenellaceaeBacteriumDtu001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rikenellaceae bacterium DTU001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RikenellaceaeBacteriumDtu001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaHoshinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella hoshinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaHoshinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TorrubiellaHemipterigena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Torrubiella hemipterigena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TorrubiellaHemipterigena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaAerocolonigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lentzea aerocolonigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LentzeaAerocolonigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesotogaPrimaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesotoga prima Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesotogaPrimaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSpCag474(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:474 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag474", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThalassobaculumLitoreumDsm18839Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thalassobaculum litoreum DSM 18839 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThalassobaculumLitoreumDsm18839Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterAsburiaeLf7aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter asburiae LF7a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterAsburiaeLf7aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusFastidiosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus fastidiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFastidiosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesGordoniiMs1Dsm23371Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Parabacteroides gordonii MS-1 DSM 23371 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParabacteroidesGordoniiMs1Dsm23371Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlistipesSpZor0009Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alistipes sp. ZOR0009 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlistipesSpZor0009Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrococcusRivularisNies593(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hydrococcus rivularis NIES-593 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HydrococcusRivularisNies593", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumYsd2013Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSD2013 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsd2013Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MoniliophthoraRoreriMca2997Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Moniliophthora roreri MCA 2997 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MoniliophthoraRoreriMca2997Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WallemiaSebi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Wallemia sebi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "WallemiaSebi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenitaleaLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arenitalea lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArenitaleaLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrinemaPallidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natrinema pallidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatrinemaPallidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifcsplowo202full3810(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFCSPLOWO202FULL3810 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifcsplowo202full3810", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_55_25 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5525Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaHofstadiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia hofstadii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaHofstadiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraInfestansT304Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora infestans T30-4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraInfestansT304Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloracidobacteriumThermophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloracidobacterium thermophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloracidobacteriumThermophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusTerasakiellaMagneticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Terasakiella magnetica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTerasakiellaMagneticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpK4410mgs306Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. K4410MGS306 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpK4410mgs306Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusBrasiliensisCbs101740Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus brasiliensis CBS 101740 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusBrasiliensisCbs101740Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlagellimonasFlava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas flava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasFlava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusEpidermidisRp62aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis RP62A Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisRp62aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArabidopsisThaliana(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arabidopsis thaliana graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArabidopsisThaliana", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpA47(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. A47 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpA47", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpYr216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. YR216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpYr216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IxodesScapularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ixodes scapularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IxodesScapularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PilodermaCroceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Piloderma croceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PilodermaCroceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpiroforme(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium spiroforme graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpiroforme", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpCf299Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF299 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf299Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacterium4787Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium 4787 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacterium4787Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpIso899(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Frankia sp. Iso899 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrankiaSpIso899", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchromobacterSpRoot83Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Achromobacter sp. Root83 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AchromobacterSpRoot83Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpRit357Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. RIT357 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpRit357Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProteiniphilumSaccharofermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Proteiniphilum saccharofermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProteiniphilumSaccharofermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumIndicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium indicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumIndicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusSpG1w1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus sp. G1w1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "GeobacillusSpG1w1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MartelellaMediterraneaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Martelella mediterranea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MartelellaMediterraneaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusGriffiniaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus griffiniae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusGriffiniaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSpDmb20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. DMB20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpDmb20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacterium2w06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 2W06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium2w06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumMizutaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacterium mizutaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacteriumMizutaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoclostridiumAcidaminophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoclostridium acidaminophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoclostridiumAcidaminophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFOXYB1_FULL_54_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifoxyb1Full5412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvoviolaceusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fulvoviolaceus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFulvoviolaceusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChelonoidisAbingdoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chelonoidis abingdonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChelonoidisAbingdoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpHmsc067h01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HMSC067H01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHmsc067h01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SolimonasAquatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Solimonas aquatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SolimonasAquatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProtochlamydiaNaegleriophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Protochlamydia naegleriophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ProtochlamydiaNaegleriophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfatiglansAniliniDsm4660Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfatiglans anilini DSM 4660 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfatiglansAniliniDsm4660Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumBotulinumBkt015925Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium botulinum BKT015925 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBotulinumBkt015925Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RobiginitomaculumAntarcticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Robiginitomaculum antarcticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RobiginitomaculumAntarcticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusOrisratti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus orisratti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusOrisratti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumGw2011gwa24315Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium GW2011GWA24315 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumGw2011gwa24315Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusViolaceofuscusCbs115571(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus violaceofuscus CBS 115571 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusViolaceofuscusCbs115571", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasRupellensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Megamonas rupellensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MegamonasRupellensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwe24214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWE24214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwe24214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanoplasmaTermitum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoplasma termitum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoplasmaTermitum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GramellaPortivictoriaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gramella portivictoriae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GramellaPortivictoriaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSzegedienseO12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense O-12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylocaldumSzegedienseO12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelotrichaceaeBacteriumNyuble8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelotrichaceae bacterium NYUBLE8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelotrichaceaeBacteriumNyuble8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWb2n11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Wb2n-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWb2n11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaSpFb8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. FB8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpFb8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BubalusBubalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bubalus bubalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BubalusBubalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSmithiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus smithii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSmithiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaSativaIndicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Indica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaIndicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrondihabitansSpLeaf304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frondihabitans sp. Leaf304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrondihabitansSpLeaf304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErwiniaTracheiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia tracheiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaTracheiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusFascians(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus fascians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusFascians", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MannheimiaVarigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mannheimia varigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MannheimiaVarigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumSpRc3bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Rc3b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpRc3bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OrrellaDioscoreaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orrella dioscoreae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrrellaDioscoreaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaerobiumKushneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium kushneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumKushneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaccaAcetoxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacca acetoxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobaccaAcetoxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobiospirillumSucciniciproducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerobiospirillum succiniciproducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerobiospirillumSucciniciproducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusCompetibacterDenitrificansRunAD11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Competibacter denitrificans Run_A_D11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCompetibacterDenitrificansRunAD11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumTaiwanense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taiwanense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaiwanense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DechloromonasAromaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dechloromonas aromatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DechloromonasAromaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobulbusPropionicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus propionicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusPropionicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxSpLeaf191Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Leaf191 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpLeaf191Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KlenkiaSoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Klenkia soli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KlenkiaSoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichomalopsisSarcophagaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichomalopsis sarcophagae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichomalopsisSarcophagaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopirellulaEuropaeaSh398(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodopirellula europaea SH398 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodopirellulaEuropaeaSh398", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LechevalieriaFradiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lechevalieria fradiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LechevalieriaFradiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSeropedicae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum seropedicae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSeropedicae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGa0077533Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium Ga0077533 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGa0077533Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuegeriaMarisrubri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ruegeria marisrubri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RuegeriaMarisrubri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomaduraOligospora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura oligospora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraOligospora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudorhodoferaxSpLeaf267Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudorhodoferax sp. Leaf267 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudorhodoferaxSpLeaf267Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CardiniumEndosymbiontCeper1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cardinium endosymbiont cEper1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CardiniumEndosymbiontCeper1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpAntimn1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. AntiMn-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpAntimn1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusManganicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus manganicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusManganicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel131208Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_31_208 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel131208Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioAlcoholivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio alcoholivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioAlcoholivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurvibacterLanceolatusAtcc14669(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Curvibacter lanceolatus ATCC 14669 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CurvibacterLanceolatusAtcc14669", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxHongdengensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax hongdengensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxHongdengensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaCepaciaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia cepacia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaCepaciaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaFeeleiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella feeleii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaFeeleiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisValliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis valliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisValliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterSp6223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter sp. 62-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrobacterSp6223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlphaProteobacteriumScgcAaa015n04Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA015N04 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa015n04Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PragiaFontiumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pragia fontium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PragiaFontiumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho212full4422bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4422b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4422bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChrysemysPictaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chrysemys picta Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChrysemysPictaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProfftellaArmaturaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Profftella armatura Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProfftellaArmaturaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterBizzozeroniiCiii1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter bizzozeronii CIII1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterBizzozeroniiCiii1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBrumae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium brumae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBrumae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSaccharolyticaF0055Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica F0055 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSaccharolyticaF0055Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumDg743Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium DG_74_3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumDg743Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerriglobusSaanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus saanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSaanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCereusAtcc14579Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cereus ATCC 14579 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCereusAtcc14579Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexusSpMsgEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexus sp. MSG Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexusSpMsgEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusReticulitermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus reticulitermitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusReticulitermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSphaeroidesAtcc17025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sphaeroides ATCC17025 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSphaeroidesAtcc17025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpF0263(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. F0263 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpF0263", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NigeriumMassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nigerium massiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NigeriumMassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwb26316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWB2_63_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwb26316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensNz007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NZ007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNz007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AhrensiaSpR2a130(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ahrensia sp. R2A130 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AhrensiaSpR2a130", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4210Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4210 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4210Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LawsonellaClevelandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lawsonella clevelandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LawsonellaClevelandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GloeobacterViolaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gloeobacter violaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GloeobacterViolaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GottesmanbacteriaBacteriumRifcsplowo201full4910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPLOWO201FULL4910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsplowo201full4910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg1024923Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_49_23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg1024923Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpSirexaae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. SirexAAE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpSirexaae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ScheffersomycesStipitisCbs6054Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Scheffersomyces stipitis CBS 6054 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ScheffersomycesStipitisCbs6054Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpL77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. L77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpL77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Buchananbacteria bacterium RIFCSPHIGHO2_01_FULL_39_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBuchananbacteriaBacteriumRifcsphigho201Full3914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EutypaLataUcrel1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eutypa lata UCREL1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EutypaLataUcrel1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumC6a11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium C6A11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumC6a11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarisediminitaleaAggregataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marisediminitalea aggregata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarisediminitaleaAggregataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinitogaPiezophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinitoga piezophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinitogaPiezophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536g10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536G10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536g10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumLeguminosarumTrifoliiWsm2304Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum trifolii WSM2304 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumTrifoliiWsm2304Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatalinimonasAlkaloidigenaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Catalinimonas alkaloidigena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CatalinimonasAlkaloidigenaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AscoideaRubescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ascoidea rubescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AscoideaRubescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd335Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD335 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd335Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZambryskibacteriaBacteriumRifoxyd1full3935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zambryskibacteria bacterium RIFOXYD1FULL3935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZambryskibacteriaBacteriumRifoxyd1full3935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KordiaAlgicida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kordia algicida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KordiaAlgicida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Adlerbacteria bacterium RIFCSPLOWO2_01_FULL_54_21b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAdlerbacteriaBacteriumRifcsplowo201Full5421bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AidingimonasHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aidingimonas halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AidingimonasHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaPalleroniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga palleronii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaPalleroniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonJ07hb67Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon J07HB67 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonJ07hb67Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumGw2011Gwf24332(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium GW2011_GWF2_43_32 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumGw2011Gwf24332", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_40_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full4013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyclobacteriumQasimii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyclobacterium qasimii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyclobacteriumQasimii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaDenitrificansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella denitrificans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaDenitrificansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusMitisSk597Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus mitis SK597 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusMitisSk597Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumCg1024326(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium CG1_02_43_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumCg1024326", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumGa0074130Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium Ga0074130 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumGa0074130Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumEzzemoulense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum ezzemoulense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumEzzemoulense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusUdagawaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus udagawae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusUdagawaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaSpRoot685Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Devosia sp. Root685 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DevosiaSpRoot685Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShapirobacteriaBacteriumCg2303520Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shapirobacteria bacterium CG2303520 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShapirobacteriaBacteriumCg2303520Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaseolibacterFlectensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaseolibacter flectens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaseolibacterFlectensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpMit016451(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT016451 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HelicobacterSpMit016451", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CapraHircus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Capra hircus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CapraHircus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpA4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pantoea sp. A4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PantoeaSpA4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaDejecticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella dejecticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KwoniellaDejecticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumAcapulenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium acapulense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAcapulenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParacoccusSpN5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paracoccus sp. N5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ParacoccusSpN5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DrosophilaMelanogasterEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Drosophila melanogaster Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DrosophilaMelanogasterEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag356(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:356 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag356", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFlorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus florum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusFlorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterSp4425Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. 44-25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSp4425Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxSpP2s70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alcanivorax sp. P2S70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlcanivoraxSpP2s70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AminicenantesBacteriumRbg19ftcombo5817(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO5817 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo5817", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaVinsoniiSubspArupensisOk94513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bartonella vinsonii subsp. arupensis OK-94-513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BartonellaVinsoniiSubspArupensisOk94513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDesantisbacteriaBacteriumCg2304021Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Desantisbacteria bacterium CG2_30_40_21 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDesantisbacteriaBacteriumCg2304021Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesViridosporus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces viridosporus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesViridosporus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFCSPLOWO2_01_FULL_35_13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifcsplowo201Full3513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusCaballi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus caballi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCaballi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella disiens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDisiens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusClarkii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Bacillus] clarkii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusClarkii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BosGrunniens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bos grunniens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BosGrunniens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaGummosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Derxia gummosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DerxiaGummosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesPaurosaccharolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides paurosaccharolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPaurosaccharolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumRbg165411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioPutealisDsm16056(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis DSM 16056 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPutealisDsm16056", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusHaemolyticusM19501Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M19501 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM19501Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumDigitatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Penicillium digitatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PenicilliumDigitatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaumarchaeotaSpScgcAb629i23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota sp. SCGC AB629I23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaSpScgcAb629i23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasCoronafaciensPvPorri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas coronafaciens pv. porri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasCoronafaciensPvPorri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusSpFs40622(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus sp. FS40622 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusSpFs40622", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPLOWO2_01_FULL_42_22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsplowo201Full4222Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaElizabethaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella elizabethae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaElizabethaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillalesBacteriumRifcsplowo202full5816(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillales bacterium RIFCSPLOWO202FULL5816 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillalesBacteriumRifcsplowo202full5816", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full5114Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL5114 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full5114Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiomicrorhabdusChilensisDsm12352Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrorhabdus chilensis DSM 12352 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ThiomicrorhabdusChilensisDsm12352Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaUliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Olsenella uli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpR575(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. R57-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpR575", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfBathymodiolusHeckeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus heckerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusHeckeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumGw2011Gwc2459Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium GW2011_GWC2_45_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumGw2011Gwc2459Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SlackiaExiguaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Slackia exigua Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SlackiaExiguaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaceaeBacteriumHun156(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotellaceae bacterium HUN156 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaceaeBacteriumHun156", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacterium3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium 33-17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacterium3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaCoriaceaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia coriaceae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaCoriaceaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterSpDsm44400Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter sp. DSM 44400 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ModestobacterSpDsm44400Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogulbenkianiaSubflavaDsm22618Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudogulbenkiania subflava DSM 22618 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudogulbenkianiaSubflavaDsm22618Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SecondaryEndosymbiontOfTrabutinaManniparaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina mannipara Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaManniparaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6423Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6423 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6423Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmorphusCoralliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amorphus coralli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmorphusCoralliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LewinellaSp4g2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lewinella sp. 4G2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LewinellaSp4g2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrachymonasDenitrificansDsm15123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brachymonas denitrificans DSM 15123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrachymonasDenitrificansDsm15123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusariumSpAf8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusarium sp. AF-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusariumSpAf8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumSpLeaf183Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. Leaf183 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpLeaf183Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusLicheniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus licheniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusLicheniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusYunnanensisNbrc103083Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus yunnanensis NBRC 103083 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusYunnanensisNbrc103083Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumRubiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium rubi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumRubiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesDentalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces dentalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesDentalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermobacillusCompostiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermobacillus composti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermobacillusCompostiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Lloydbacteria bacterium RIFCSPLOWO2_01_FULL_50_20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusLloydbacteriaBacteriumRifcsplowo201Full5020Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeoalkalibacterSubterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geoalkalibacter subterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeoalkalibacterSubterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinomicrobiumOceaniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sinomicrobium oceani Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SinomicrobiumOceaniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKunkeeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kunkeei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKunkeeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasSpMed121(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas sp. MED121 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinomonasSpMed121", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AfipiaSpOhsuic4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Afipia sp. OHSUIC4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AfipiaSpOhsuic4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusIshikawaellaCapsulataMpkobeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ishikawaella capsulata Mpkobe Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusIshikawaellaCapsulataMpkobeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaGinsengiterraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paraburkholderia ginsengiterrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParaburkholderiaGinsengiterraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpHgb0020(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. HGB0020 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpHgb0020", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomarinaGelatinilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomarina gelatinilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomarinaGelatinilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HungateiclostridiumStraminisolvensJcm21531(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Hungateiclostridium straminisolvens JCM 21531 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HungateiclostridiumStraminisolvensJcm21531", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaGinsengi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea ginsengi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaGinsengi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanctomycetesBacteriumRbg135024(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RBG_13_50_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRbg135024", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TilletiariaAnomalaUbc951Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tilletiaria anomala UBC 951 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TilletiariaAnomalaUbc951Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wildermuthbacteria bacterium RIFCSPHIGHO2_01_FULL_49_22b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWildermuthbacteriaBacteriumRifcsphigho201Full4922b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CloacimonetesBacteriumWwei01(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cloacimonetes bacterium WWEI_01 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CloacimonetesBacteriumWwei01", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterEquiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter equi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterEquiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanofollisLiminatansDsm4140(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanofollis liminatans DSM 4140 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanofollisLiminatansDsm4140", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumPaludis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium paludis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumPaludis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSwuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus swuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSwuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClavisporaLusitaniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clavispora lusitaniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClavisporaLusitaniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpCnh287Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. CNH287 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpCnh287Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseomonasAerilataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseomonas aerilata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseomonasAerilataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpD5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium sp. D5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumSpD5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeosynechococcusSphagnicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neosynechococcus sphagnicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeosynechococcusSphagnicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterLwoffiiSh145(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter lwoffii SH145 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterLwoffiiSh145", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodotorulaGraminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodotorula graminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodotorulaGraminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptotrichiaSpW9775(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia sp. W9775 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaSpW9775", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterCrescentusCb15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Caulobacter crescentus CB15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CaulobacterCrescentusCb15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LevybacteriaBacteriumRifcsplowo202full4018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPLOWO202FULL4018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsplowo202full4018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudonajaTextilisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonaja textilis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonajaTextilisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxyb2full4235Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYB2FULL4235 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxyb2full4235Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSp17376Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 17376 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSp17376Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterExcellens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter excellens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterExcellens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BellilineaCaldifistulae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bellilinea caldifistulae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BellilineaCaldifistulae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_44_16 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaSpBmg512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Frankia sp. BMG512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrankiaSpBmg512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParafilimonasTerrae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parafilimonas terrae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParafilimonasTerrae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def InquilinusLimosusDsm16000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Inquilinus limosus DSM 16000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "InquilinusLimosusDsm16000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSp9145Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. 9145 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSp9145Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaSp4847faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Collinsella sp. 4847FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CollinsellaSp4847faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotionigerCbs115572Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus sclerotioniger CBS 115572 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AspergillusSclerotionigerCbs115572Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpKnhs205Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. KNHs205 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpKnhs205Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferSpHz11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer sp. HZ11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferSpHz11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SungbacteriaBacteriumRifcsplowo201full5916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sungbacteria bacterium RIFCSPLOWO201FULL5916 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SungbacteriaBacteriumRifcsplowo201full5916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusJurassicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusJurassicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaSpG5847Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. G5847 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpG5847Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPaucisporeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces paucisporeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesPaucisporeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharopolysporaRectivirgula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharopolyspora rectivirgula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharopolysporaRectivirgula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermofilumAdornatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermofilum adornatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermofilumAdornatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterovibrioCalviensisDsm14347Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Enterovibrio calviensis DSM 14347 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "EnterovibrioCalviensisDsm14347Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpB7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. B7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpB7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusCytotoxicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cytotoxicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusCytotoxicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusHaemolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus haemolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusHaemolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgoriphagusAquimarinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus aquimarinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusAquimarinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalomonasSpSoapLake7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halomonas sp. Soap Lake #7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalomonasSpSoapLake7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPruniNbrc15498(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas pruni NBRC 15498 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingomonasPruniNbrc15498", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacteriaBacteriumCg10238174(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacteria bacterium CG10238174 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacteriaBacteriumCg10238174", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpOk909Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. ok909 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpOk909Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LonsdaleaPopuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lonsdalea populi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LonsdaleaPopuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoplanusPetroleariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methanoplanus petrolearius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethanoplanusPetroleariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaromonasJejuensisNbrc106434Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polaromonas jejuensis NBRC 106434 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolaromonasJejuensisNbrc106434Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusLitoralisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus litoralis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PontibacillusLitoralisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNidulansFgscA4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nidulans FGSC A4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusNidulansFgscA4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetesBacteriumGwf1518(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirochaetes bacterium GWF1_51_8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirochaetesBacteriumGwf1518", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm6137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM6137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm6137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonBenhamiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichophyton benhamiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichophytonBenhamiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaColumbinumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma columbinum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaColumbinumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBathyarchaeotaArchaeonB24(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon B24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonB24", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SuillusLuteusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Suillus luteus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SuillusLuteusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KalmanozymaBrasiliensisGhg001Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kalmanozyma brasiliensis GHG001 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KalmanozymaBrasiliensisGhg001Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionCpr3Bacterium4484211Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division CPR3 bacterium 4484_211 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionCpr3Bacterium4484211Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpIbvss2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. IBVSS2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpIbvss2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TectomicrobiaBacteriumRifcsplowo202full7019(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tectomicrobia bacterium RIFCSPLOWO202FULL7019 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TectomicrobiaBacteriumRifcsplowo202full7019", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinimonasKoreensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinimonas koreensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinimonasKoreensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfomicrobiumBaculatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfomicrobium baculatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfomicrobiumBaculatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraWolbachiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptospira wolbachii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptospiraWolbachiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusOrientisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus orientis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusOrientisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpNiph973(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. NIPH973 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpNiph973", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCoryniformisSubspCoryniformisCect5711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis subsp. coryniformis CECT 5711 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisSubspCoryniformisCect5711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumArsenijeviciiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium arsenijevicii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumArsenijeviciiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaBicolor(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaBicolor", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PleurocapsaSpPcc7319(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7319 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7319", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcobacterButzleriRm4018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Arcobacter butzleri RM4018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ArcobacterButzleriRm4018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonomuraeaCandidaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea candida Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaCandidaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSpJdfr37Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr37Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlautiaSpCag52Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Blautia sp. CAG:52 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BlautiaSpCag52Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerbacteriaBacteriumRbg13378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fischerbacteria bacterium RBG13378 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FischerbacteriaBacteriumRbg13378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesLongwoodensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces longwoodensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesLongwoodensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpHmsc08h08Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. HMSC08H08 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpHmsc08h08Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DoudnabacteriaBacteriumRifcsphigho202full4924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Doudnabacteria bacterium RIFCSPHIGHO202FULL4924 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DoudnabacteriaBacteriumRifcsphigho202full4924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSpRoot1257(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides sp. Root1257 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSpRoot1257", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSp103mf(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. 103mf graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSp103mf", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarboxydothermusIslandicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carboxydothermus islandicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarboxydothermusIslandicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumVe20218Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridiales bacterium VE20218 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridialesBacteriumVe20218Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusAmoebophilusSp3638Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amoebophilus sp. 36-38 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmoebophilusSp3638Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusYonginensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus yonginensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusYonginensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSanguinisSk36Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sanguinis SK36 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSanguinisSk36Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LysinibacillusMacroidesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus macroides Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusMacroidesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full3317Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3317 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3317Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaKoreensisDs123Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella koreensis DS-123 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DokdonellaKoreensisDs123Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSiamensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus siamensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSiamensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasZinciduransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas zincidurans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasZinciduransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGastranaerophilalesBacteriumHum9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium HUM_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumHum9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsSpRao2017Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps sp. RAO-2017 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CordycepsSpRao2017Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DickeyaSp2b12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dickeya sp. 2B12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DickeyaSp2b12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyaloscyphaBicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hyaloscypha bicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HyaloscyphaBicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlcanivoraxPacificusW115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Alcanivorax pacificus W11-5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AlcanivoraxPacificusW115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlaciibacterSuperstesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glaciibacter superstes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlaciibacterSuperstesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PenicilliumFreiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium freii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumFreiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionKsb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division KSB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionKsb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifcsphigho202full349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPHIGHO202FULL349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsphigho202full349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevibacillusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevibacillus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevibacillusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CitreicellaSpSe45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citreicella sp. SE45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitreicellaSpSe45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumGwf24212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium GWF2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumGwf24212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumCatenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium catena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumCatenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLundenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium lundense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLundenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomaduraRifamyciniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinomadura rifamycini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinomaduraRifamyciniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaulobacterSpUnc279mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. UNC279MFTsu5.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUnc279mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerroplasmaAcidiphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ferroplasma acidiphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FerroplasmaAcidiphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrobacterHamburgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter hamburgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrobacterHamburgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacterMarinusA45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter marinus A45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacterMarinusA45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMarisflavi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus marisflavi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMarisflavi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermodesulfobacteriumHveragerdenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermodesulfobacterium hveragerdense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermodesulfobacteriumHveragerdenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrionalesBacteriumGa0074137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrionales bacterium Ga0074137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrionalesBacteriumGa0074137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseibiumSpTrichskd4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseibium sp. TrichSKD4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseibiumSpTrichskd4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraArctica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomicrospira arctica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomicrospiraArctica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitriliruptorAlkaliphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitriliruptor alkaliphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitriliruptorAlkaliphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydophilaAbortus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila abortus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaAbortus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlochmanniaEndosymbiontOfPolyrhachis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blochmannia endosymbiont of Polyrhachis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlochmanniaEndosymbiontOfPolyrhachis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaCrassostreaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga crassostreae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaCrassostreaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosaetaHarundinaceaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanosaeta harundinacea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanosaetaHarundinaceaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KinetoplastibacteriumOncopeltiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium oncopeltii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumOncopeltiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ModestobacterCaceresii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Modestobacter caceresii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ModestobacterCaceresii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaStercoraria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla stercoraria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaStercoraria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumNk4a144Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NK4A144 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNk4a144Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Melainabacteria bacterium RIFCSPHIGHO2_02_FULL_34_12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMelainabacteriaBacteriumRifcsphigho202Full3412Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRedseas03b5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium REDSEAS03B5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRedseas03b5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeniophoraSpCont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peniophora sp. CONT graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeniophoraSpCont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpJcm19062Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. JCM 19062 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpJcm19062Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SnodgrassellaSpCfcc13594Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Snodgrassella sp. CFCC 13594 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SnodgrassellaSpCfcc13594Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusTurcosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus turcosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusTurcosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacteriovorax marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacteriovoraxMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FervidicellaMetallireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fervidicella metallireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FervidicellaMetallireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerococcusTetradiusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus tetradius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusTetradiusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhytophthoraSojaeStrainP6497Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Phytophthora sojae strain P6497 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PhytophthoraSojaeStrainP6497Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaGariniiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Borrelia garinii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BorreliaGariniiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacterium1747faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium 1747FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacterium1747faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumScrofulaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium scrofulaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumScrofulaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeitlerinemaSpBbd19919Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geitlerinema sp. BBD 1991-9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeitlerinemaSpBbd19919Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterCanadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter canadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterCanadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr27(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-27 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr27", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonB262Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon B262 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonB262Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OctodonDegusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Octodon degus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OctodonDegusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AphanomycesAstaciEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aphanomyces astaci Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AphanomycesAstaciEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpHph0090Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. HPH0090 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpHph0090Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaSpF(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia sp. F graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaSpF", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaPleuritidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella pleuritidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaPleuritidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinimicrobiumMangroviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysinimicrobium mangrovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysinimicrobiumMangroviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumOceanicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium oceanicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumOceanicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsplowo201full4112(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL4112 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full4112", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumOlb9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium OLB9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumOlb9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudooceanicolaFlagellatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudooceanicola flagellatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudooceanicolaFlagellatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumSpWp30Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. WP30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumSpWp30Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AustrofundulusLimnaeus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Austrofundulus limnaeus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AustrofundulusLimnaeus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4716(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4716 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4716", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpRoot568Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. Root568 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpRoot568Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktothrixTepidaPcc9214Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix tepida PCC 9214 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PlanktothrixTepidaPcc9214Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerolineaeBacteriumCg2305767Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium CG2_30_57_67 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumCg2305767Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSocranskiiVpidr56br1116Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema socranskii VPIDR56BR1116 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSocranskiiVpidr56br1116Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XylariaFlabelliformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xylaria flabelliformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XylariaFlabelliformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gottesmanbacteria bacterium RIFCSPHIGHO2_02_FULL_40_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGottesmanbacteriaBacteriumRifcsphigho202Full4013", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumFragaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium fragae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFragaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VerrucomicrobiaBacteriumImcc26134Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium IMCC26134 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumImcc26134Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GolovinomycesCichoracearumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Golovinomyces cichoracearum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GolovinomycesCichoracearumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxHalotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax halotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxHalotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParvularculaBermudensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parvularcula bermudensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParvularculaBermudensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpTkpEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. TKP Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpTkpEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumTuberculosisH37raEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium tuberculosis H37Ra Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumTuberculosisH37raEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaJaponicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma japonicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SchistosomaJaponicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasSpLeaf324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas sp. Leaf324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasSpLeaf324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerratiaProteamaculans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serratia proteamaculans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerratiaProteamaculans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusDarwinianusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus darwinianus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDarwinianusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusInfantisSk970Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus infantis SK970 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusInfantisSk970Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudospirillumJaponicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudospirillum japonicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudospirillumJaponicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterNanhaisediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erythrobacter nanhaisediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErythrobacterNanhaisediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumCv2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium cv2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumCv2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumRubiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium rubi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumRubiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def UnculturedClostridiumSp(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return uncultured Clostridium sp. graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "UnculturedClostridiumSp", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BisonBisonBisonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bison bison bison Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BisonBisonBisonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HydrogenophagaFlavaNbrc102514Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hydrogenophaga flava NBRC 102514 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HydrogenophagaFlavaNbrc102514Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnicoccusIslandicusDsm13165Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ignicoccus islandicus DSM 13165 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "IgnicoccusIslandicusDsm13165Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LoaLoa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Loa loa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LoaLoa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaTaiwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicroplitisDemolitorCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microplitis demolitor Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicroplitisDemolitorCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VignaRadiataVarRadiataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Vigna radiata var. radiata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "VignaRadiataVarRadiataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChloroflexiBacteriumRifcsplowo202full7116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RIFCSPLOWO202FULL7116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRifcsplowo202full7116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumOculiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium oculi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumOculiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumSp1m11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 1M-11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp1m11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumUc511d2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium UC5.1-1D2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumUc511d2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechocystisSpPcc6803(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechocystis sp. PCC6803 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechocystisSpPcc6803", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSydowiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sydowii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusSydowiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusTimonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus timonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusTimonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivirgaTractuosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marivirga tractuosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarivirgaTractuosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfamplusMagnetovallimortisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfamplus magnetovallimortis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfamplusMagnetovallimortisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusTriatomae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus triatomae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusTriatomae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsplowo201full4816Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO201FULL4816 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo201full4816Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpJ56Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J56 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ56Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArchaeoglobusSpJdfr37(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sp. JdFR-37 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSpJdfr37", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusibacterSp3d3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusibacter sp. 3D3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusibacterSp3d3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurococcusAmylolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfurococcus amylolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfurococcusAmylolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpicheriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus spicheri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSpicheriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogemmatisporaCarboxidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermogemmatispora carboxidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermogemmatisporaCarboxidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1321Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1321 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1321Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HeterocephalusGlaber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Heterocephalus glaber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HeterocephalusGlaber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiyogibacteriaBacteriumRifcsplowo202full4513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niyogibacteria bacterium RIFCSPLOWO202FULL4513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiyogibacteriaBacteriumRifcsplowo202full4513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaMoravica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella moravica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaMoravica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesIsraeliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces israelii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesIsraeliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusUrinalisFb127cna2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis FB127CNA2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalisFb127cna2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodospirillaceaeBacteriumBrhc57(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillaceae bacterium BRHc57 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodospirillaceaeBacteriumBrhc57", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PararhodospirillumPhotometricum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pararhodospirillum photometricum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PararhodospirillumPhotometricum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvoviolaceus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fulvoviolaceus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFulvoviolaceus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UnidentifiedEubacteriumScb49Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return unidentified eubacterium SCB49 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UnidentifiedEubacteriumScb49Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerococcusPrevotiiAcs065vcol13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerococcus prevotii ACS065VCol13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerococcusPrevotiiAcs065vcol13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrogenomatesGroupBacteriumGw2011gwf2479(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microgenomates group bacterium GW2011GWF2479 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrogenomatesGroupBacteriumGw2011gwf2479", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EwingellaAmericanaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ewingella americana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EwingellaAmericanaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PectobacteriumCarotovorumOdoriferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pectobacterium carotovorum odoriferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PectobacteriumCarotovorumOdoriferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MorganellaPsychrotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Morganella psychrotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MorganellaPsychrotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAmesbacteriaBacteriumGw2011Gwa24212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Amesbacteria bacterium GW2011_GWA2_42_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusAmesbacteriaBacteriumGw2011Gwa24212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteipulveratusMongoliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus mongoliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusMongoliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMargulisbacteriaBacteriumGwf2359(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Margulisbacteria bacterium GWF2_35_9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMargulisbacteriaBacteriumGwf2359", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeefgeaRivuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deefgea rivuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeefgeaRivuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRokubacteriaBacterium13220cm27011Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_70_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm27011Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumRussii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium russii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumRussii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterArupensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter arupensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterArupensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusSpCag324Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Staphylococcus sp. CAG:324 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StaphylococcusSpCag324Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasHortorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas hortorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XanthomonasHortorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAg109o510Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. Ag109O510 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpAg109o510Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusEllipticusCbs70779(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus ellipticus CBS 707.79 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusEllipticusCbs70779", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RunellaLimosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Runella limosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RunellaLimosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfosporosinusAcidiphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfosporosinus acidiphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfosporosinusAcidiphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KapabacteriaThiocyanatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kapabacteria thiocyanatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KapabacteriaThiocyanatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolisilvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solisilvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSolisilvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumPhaeovibrioidesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlorobium phaeovibrioides Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlorobiumPhaeovibrioidesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMurinusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus murinus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMurinusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinivibrioAlkaliphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chitinivibrio alkaliphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChitinivibrioAlkaliphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBifidumPrl2010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium bifidum PRL2010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumBifidumPrl2010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumCg1023721Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium CG1_02_37_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumCg1023721Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeeuwenhoekiellaMarinoflava(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leeuwenhoekiella marinoflava graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeeuwenhoekiellaMarinoflava", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumYsb2008(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium YSB2008 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumYsb2008", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumGw2011gwb1378Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium GW2011GWB1378 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumGw2011gwb1378Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumUsda124Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum USDA124 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumUsda124Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TenacibaculumMaritimum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum maritimum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumMaritimum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacrophominaPhaseolinaMs6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Macrophomina phaseolina MS6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MacrophominaPhaseolinaMs6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusPyridinivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus pyridinivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhodococcusPyridinivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasArboricola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas arboricola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasArboricola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpSm9913(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. SM9913 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpSm9913", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumSpScn6914Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium sp. SCN 69-14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumSpScn6914Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VavraiaCulicis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vavraia culicis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VavraiaCulicis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSaudiphocaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas saudiphocaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSaudiphocaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasRubraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas rubra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasRubraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SulfurimonasSpRifoxyd12full3339(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulfurimonas sp. RIFOXYD12FULL3339 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulfurimonasSpRifoxyd12full3339", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NevskiaRamosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nevskia ramosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NevskiaRamosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoplasmaAcidophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoplasma acidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoplasmaAcidophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseburiaSpCag309(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseburia sp. CAG:309 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseburiaSpCag309", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SciscionellaMarina(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sciscionella marina graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SciscionellaMarina", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtissbacteriaBacteriumRifcsphigho202full4215Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFCSPHIGHO202FULL4215 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifcsphigho202full4215Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PasteurellaMultocidaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pasteurella multocida Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PasteurellaMultocidaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CalothrixSpPcc7507(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. PCC7507 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpPcc7507", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesWedmorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces wedmorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesWedmorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ListeriaFloridensisFslS101187Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Listeria floridensis FSL S10-1187 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ListeriaFloridensisFslS101187Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioCrossotusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio crossotus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioCrossotusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsphigho202full6720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPHIGHO202FULL6720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsphigho202full6720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPLOWO2_02_FULL_39_26 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsplowo202Full3926Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlteromonadaceaeBacteriumBs31Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadaceae bacterium Bs31 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonadaceaeBacteriumBs31Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagnetospirillumSpXm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum sp. XM-1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumSpXm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg166432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_64_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg166432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NioellaSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nioella sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NioellaSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaematobacterMissouriensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haematobacter missouriensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaematobacterMissouriensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAutolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces autolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAutolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiplorickettsiaMassiliensis20bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Diplorickettsia massiliensis 20B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DiplorickettsiaMassiliensis20bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpUnc451mfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. UNC451MF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpUnc451mfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanotorrisFormicicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanotorrisFormicicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaskawiczbacteriaBacteriumRifoxyc1full3818Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFOXYC1FULL3818 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifoxyc1full3818Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BorreliaMiyamotoiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia miyamotoi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaMiyamotoiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseinatronobacterThiooxidansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseinatronobacter thiooxidans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseinatronobacterThiooxidansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConexibacterWoeseiIso977nEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Conexibacter woesei Iso977N Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConexibacterWoeseiIso977nEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WildermuthbacteriaBacteriumRifcsplowo202full4710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wildermuthbacteria bacterium RIFCSPLOWO202FULL4710 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WildermuthbacteriaBacteriumRifcsplowo202full4710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsterYellowsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aster yellows Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsterYellowsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesSpN902109Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes sp. N902109 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesSpN902109Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CohnellaPanacarviGsoil349Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Gsoil 349 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CohnellaPanacarviGsoil349Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogladiusCalderae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermogladius calderae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermogladiusCalderae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifoxyd2full3512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFOXYD2FULL3512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifoxyd2full3512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpHmsc078h07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC078H07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc078h07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioSpAlj11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaBiviaJcvihmp010Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella bivia JCVIHMP010 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaBiviaJcvihmp010Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalosimplexCarlsbadenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halosimplex carlsbadense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalosimplexCarlsbadenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrococcusMobilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrococcus mobilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrococcusMobilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaHalophytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora halophytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaHalophytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterSpS60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter sp. S60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterSpS60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusRhodochrousCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus rhodochrous Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusRhodochrousCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterRuberEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter ruber Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterRuberEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalobacillusMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LuteipulveratusHalotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Luteipulveratus halotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LuteipulveratusHalotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DyadobacterSoliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dyadobacter soli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DyadobacterSoliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesMirabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces mirabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesMirabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElysiaChlorotica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elysia chlorotica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElysiaChlorotica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumMerycicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium merycicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumMerycicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg135152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_13_51_52 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg135152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterUreolyticusRigs9880(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus RIGS 9880 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterUreolyticusRigs9880", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BoseaSpLc85Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bosea sp. LC85 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BoseaSpLc85Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydophilaPneumoniaeTw183(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydophila pneumoniae TW183 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydophilaPneumoniaeTw183", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpScn6718Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SCN 67-18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpScn6718Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHominis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hominis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHominis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterFetus8240Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter fetus 8240 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CampylobacterFetus8240Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasTaetrolensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas taetrolens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasTaetrolensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpKpl1989(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1989 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1989", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifoxyc1full4826Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFOXYC1FULL4826 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifoxyc1full4826Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StaphylococcusLugdunensisN920143(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis N920143 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisN920143", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JiangellaAlbaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jiangella alba Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JiangellaAlbaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureimonasUreilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureimonas ureilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureimonasUreilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomascusLeucogenysCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nomascus leucogenys Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NomascusLeucogenysCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumCfEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium CF Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumCfEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaSpRubis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia sp. Rubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaSpRubis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MuribacterMurisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Muribacter muris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MuribacterMurisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Berkelbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBerkelbacteriaBacteriumRifcsplowo201Full5028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SynechococcusSpMits9509Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. MITS9509 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpMits9509Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaSpOk004(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dyella sp. OK004 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DyellaSpOk004", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4332bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4332b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4332bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwb13912Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWB13912 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwb13912Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferYueqingensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer yueqingensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferYueqingensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasMaliNbrc15500Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingomonas mali NBRC 15500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingomonasMaliNbrc15500Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaBcc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchnera aphidicola BCc graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchneraAphidicolaBcc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfolunaSpongiiphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfoluna spongiiphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfolunaSpongiiphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusHeteromorphusCbs11755(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus heteromorphus CBS 117.55 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusHeteromorphusCbs11755", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StarkeyaNovella(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Starkeya novella graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StarkeyaNovella", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioQuintilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio quintilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioQuintilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaMelliferumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spiroplasma melliferum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpiroplasmaMelliferumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaemophilusHaemolyticusM21639Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haemophilus haemolyticus M21639 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaemophilusHaemolyticusM21639Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraSpBv3c161Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. BV3C161 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpBv3c161Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaucisalibacillusSpEb02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paucisalibacillus sp. EB02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaucisalibacillusSpEb02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAcidurici(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium acidurici graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAcidurici", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveraIntermediaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera intermedia Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KluyveraIntermediaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumGw2011gwa24416(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium GW2011GWA24416 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumGw2011gwa24416", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumOrbiscindens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium orbiscindens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumOrbiscindens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GrifolaFrondosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Grifola frondosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GrifolaFrondosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinimicrobiumXinjiangenseDsm19287Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Salinimicrobium xinjiangense DSM 19287 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SalinimicrobiumXinjiangenseDsm19287Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentibacillusAmyloliquefaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentibacillus amyloliquefaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentibacillusAmyloliquefaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiscatorii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piscatorii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiscatorii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAcs4331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. ACS4331 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAcs4331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlicyclobacillusTengchongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus tengchongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusTengchongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiaceaeBacteriumSg6cEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobiaceae bacterium SG6C Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiaceaeBacteriumSg6cEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusHoronobensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoculleus horonobensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoculleusHoronobensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd308(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD308 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd308", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucobacterCelerSubspAstrifaciensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Leucobacter celer subsp. astrifaciens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LeucobacterCelerSubspAstrifaciensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaTrachomatisDUw3CxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chlamydia trachomatis D/UW-3/CX Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChlamydiaTrachomatisDUw3CxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpAli22iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. ALI22I Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpAli22iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TypebSymbiontEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return TypeB symbiont Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TypebSymbiontEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CohnellaPanacarviGsoil349(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cohnella panacarvi Gsoil 349 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CohnellaPanacarviGsoil349", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannospalaxGaliliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nannospalax galili Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NannospalaxGaliliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwc246850Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWC2_46_850 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwc246850Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNitrosopelagicusBrevisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nitrosopelagicus brevis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNitrosopelagicusBrevisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMethanoplasmaTermitumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanoplasma termitum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanoplasmaTermitumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FundulusHeteroclitusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fundulus heteroclitus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FundulusHeteroclitusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacteraceaeBacteriumSb2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacteraceae bacterium SB2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodobacteraceaeBacteriumSb2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpLeaf399Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium sp. Leaf399 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumSpLeaf399Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiellaGrylliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella grylli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaGrylliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaPiezotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella piezotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaPiezotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAnc4558Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4558 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4558Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfococcusOleovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus oleovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusOleovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesOvatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides ovatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesOvatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrchesellaCincta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Orchesella cincta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OrchesellaCincta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasProtegensPf5(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas protegens Pf5 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasProtegensPf5", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumRifcsphigho201full4114Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium RIFCSPHIGHO201FULL4114 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumRifcsphigho201full4114Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaBurgdorferi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella burgdorferi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaBurgdorferi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrlb24720(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLB24720 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlb24720", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusNomiusNrrl13137(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus nomius NRRL 13137 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AspergillusNomiusNrrl13137", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumRbg166422(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium RBG_16_64_22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumRbg166422", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusDelbrueckiiBulgaricus2038Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus delbrueckii bulgaricus 2038 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusDelbrueckiiBulgaricus2038Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPHIGHO2_01_FULL_45_23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsphigho201Full4523", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusVietnamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus vietnamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusVietnamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinopolymorphaCephalotaxiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinopolymorpha cephalotaxi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinopolymorphaCephalotaxiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumMinutulumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum minutulum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumMinutulumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMacrosporangiidus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus macrosporangiidus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMacrosporangiidus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaShayeganiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria shayeganii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaShayeganiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def Sar92BacteriumBacl16Mag120619Bin48Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return SAR92 bacterium BACL16 MAG-120619-bin48 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "Sar92BacteriumBacl16Mag120619Bin48Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCellulolyticumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cellulolyticum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCellulolyticumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumCochleariumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium cochlearium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumCochleariumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp2817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 28_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp2817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusParalimentariusDsm19674Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus paralimentarius DSM 19674 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusParalimentariusDsm19674Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioSalexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio salexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioSalexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaPertussisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella pertussis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaPertussisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FriedmanniomycesEndolithicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniomyces endolithicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FriedmanniomycesEndolithicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PythiumIrregulare(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pythium irregulare graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PythiumIrregulare", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusDispar(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus dispar graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusDispar", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpMrmd2014(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. MRMD2014 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpMrmd2014", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UncinocarpusReesii1704(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Uncinocarpus reesii 1704 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "UncinocarpusReesii1704", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumRifoxyc1full3814(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium RIFOXYC1FULL3814 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumRifoxyc1full3814", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbidiferaxSpOv413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Albidiferax sp. OV413 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlbidiferaxSpOv413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasGingeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas gingeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasGingeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSoliNbrc102451Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus soli NBRC 102451 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSoliNbrc102451Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumLactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium lactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumLactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KlenkiaTaihuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Klenkia taihuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KlenkiaTaihuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NaemateliaEncephalaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Naematelia encephala Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NaemateliaEncephalaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpLeaf339Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf339 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf339Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisNigoniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis nigoni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisNigoniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlasmodiumVivaxSal1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Plasmodium vivax Sal-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlasmodiumVivaxSal1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpBmaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Bma Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpBmaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymomonasMobilisZm4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zymomonas mobilis ZM4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZymomonasMobilisZm4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioBreoganii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio breoganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioBreoganii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full4120(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL4120 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full4120", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioParadoxusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio paradoxus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioParadoxusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusLuminyensisB10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis B10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensisB10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusPatagoniensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus patagoniensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusPatagoniensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumArborisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium arboris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumArborisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaballeroniaTelluris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caballeronia telluris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaballeroniaTelluris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu075Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU075 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu075Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CatenulisporaAcidiphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catenulispora acidiphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatenulisporaAcidiphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CatagonusWagneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Catagonus wagneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CatagonusWagneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumGw2011gwa24413bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium GW2011GWA24413b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumGw2011gwa24413bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MortierellaElongataAg77Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mortierella elongata AG-77 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MortierellaElongataAg77Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NecropsobacterRosorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Necropsobacter rosorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NecropsobacterRosorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusOmnitrophicaBacteriumCg1024015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Omnitrophica bacterium CG1_02_40_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusOmnitrophicaBacteriumCg1024015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpAtcc27244Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ATCC27244 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcinetobacterSpAtcc27244Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrococcalesBacterium7315Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Micrococcales bacterium 73-15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrococcalesBacterium7315Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeglectaTimonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neglecta timonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeglectaTimonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GelidibacterMesophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gelidibacter mesophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GelidibacterMesophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaJamestowniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella jamestowniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaJamestowniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusAurantiacusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus aurantiacus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusAurantiacusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpWh8016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. WH 8016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpWh8016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenimonasMetalliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arenimonas metalli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArenimonasMetalliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirulinaMajorPcc6313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Spirulina major PCC 6313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SpirulinaMajorPcc6313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeisingeraSpAngvpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leisingera sp. ANGVp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeisingeraSpAngvpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodobacterCapsulatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter capsulatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodobacterCapsulatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusSpF0407(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0407 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0407", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpUcdkl21Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. UCDKL21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpUcdkl21Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusSuryakundensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus suryakundensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusSuryakundensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusThailandensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusThailandensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanktothricoidesSpSr001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planktothricoides sp. SR001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanktothricoidesSpSr001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPelagibacterSpRs40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pelagibacter sp. RS40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPelagibacterSpRs40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSp2136faaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus sp. 2136FAA Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusSp2136faaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria mucosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMucosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumGwb24920(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium GWB2_49_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumGwb24920", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwa24611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWA2_46_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwa24611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobialesBacterium6217Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobiales bacterium 62-17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobialesBacterium6217Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasFluorescensNcimb11764(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas fluorescens NCIMB11764 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasFluorescensNcimb11764", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpP32eEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. P32E Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpP32eEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VulgatibacterIncomptusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vulgatibacter incomptus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VulgatibacterIncomptusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptolyngbyaSpNies2104Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-2104 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies2104Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVeteranaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia veterana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaVeteranaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyc2full3825Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3825 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3825Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisSpH115(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis sp. H115 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisSpH115", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeefgeaRivuliDsm18356Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Deefgea rivuli DSM 18356 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DeefgeaRivuliDsm18356Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UhrbacteriaBacteriumRifcsplowo201full4717Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Uhrbacteria bacterium RIFCSPLOWO201FULL4717 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "UhrbacteriaBacteriumRifcsplowo201full4717Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalidrisPugnax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Calidris pugnax graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CalidrisPugnax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBgeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bge Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBgeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesNeuiiBvs029a5Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii BVS029A5 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiBvs029a5Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LabrenziaSpOb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Labrenzia sp. OB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LabrenziaSpOb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraSpGa0074138Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospira sp. Ga0074138 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraSpGa0074138Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfofundulusThermocisternus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfofundulus thermocisternus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfofundulusThermocisternus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyangiaceaeBacteriumUtpro1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polyangiaceae bacterium UTPRO1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolyangiaceaeBacteriumUtpro1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EscherichiaAlbertiiKf1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Escherichia albertii KF1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EscherichiaAlbertiiKf1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Giovannonibacteria bacterium RIFCSPLOWO2_12_FULL_44_32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusGiovannonibacteriaBacteriumRifcsplowo212Full4432Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpX13sy08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. X13SY08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpX13sy08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanthinobacteriumSpB98(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Janthinobacterium sp. B9-8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JanthinobacteriumSpB98", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonadalesBacteriumEhc05Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonadales bacterium EhC05 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonadalesBacteriumEhc05Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusPasteurii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus pasteurii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichococcusPasteurii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterIndonesiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter indonesiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterIndonesiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAutotrophicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia autotrophica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAutotrophicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZunongwangiaAtlantica22ii1410f7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Zunongwangia atlantica 22II14-10F7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ZunongwangiaAtlantica22ii1410f7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaritaleaMyrionectaeDsm19524Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Maritalea myrionectae DSM 19524 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MaritaleaMyrionectaeDsm19524Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woykebacteria bacterium RIFCSPLOWO2_01_FULL_43_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoykebacteriaBacteriumRifcsplowo201Full4314Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LimnothrixRoseaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnothrix rosea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnothrixRoseaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanococcoidesMethylutensMm1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanococcoides methylutens MM1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanococcoidesMethylutensMm1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumDtu058Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU058 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu058Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSp1m11Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. 1M-11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSp1m11Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnoanaerobaculumSpObrc55Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnoanaerobaculum sp. OBRC5-5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnoanaerobaculumSpObrc55Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraCactorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora cactorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraCactorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProteobacteriaBacteriumSgbin4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Proteobacteria bacterium SGbin4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ProteobacteriaBacteriumSgbin4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SchistosomaMargrebowiei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Schistosoma margrebowiei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SchistosomaMargrebowiei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioSpFobeg1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio sp. FOBEG1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioSpFobeg1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VitreoscillaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vitreoscilla massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VitreoscillaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMaliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus mali Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMaliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudobutyrivibrioSpLb2011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. LB2011 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpLb2011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaProteobacteriumScgcAaa536k22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return alpha proteobacterium SCGC AAA536K22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlphaProteobacteriumScgcAaa536k22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenibacterElegansDsm3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Eisenibacter elegans DSM 3317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EisenibacterElegansDsm3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ReichenbachiellaAgariperforansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Reichenbachiella agariperforans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ReichenbachiellaAgariperforansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumMalmoenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium malmoense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumMalmoenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoagulans36d1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coagulans 36D1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusCoagulans36d1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptospiraMeyeriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira meyeri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraMeyeriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoprobacterFastidiosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coprobacter fastidiosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoprobacterFastidiosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThecamonasTrahensAtcc50062Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Thecamonas trahens ATCC 50062 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ThecamonasTrahensAtcc50062Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogeometricumRufum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum rufum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumRufum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumSp68310Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. 68-3-10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSp68310Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterNecessariusAsymbioticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius asymbioticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusAsymbioticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldisericumExileEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldisericum exile Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldisericumExileEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichinellaBritoviCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella britovi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaBritoviCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllosalinactinosporaLopnorensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allosalinactinospora lopnorensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllosalinactinosporaLopnorensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptobacillusRattiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptobacillus ratti Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptobacillusRattiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWA2_38_36 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwa23836", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKwashiorkoriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus kwashiorkori Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusKwashiorkoriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Peregrinibacteria bacterium GW2011_GWF2_39_17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusPeregrinibacteriaBacteriumGw2011Gwf23917Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesPurpeofuscus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces purpeofuscus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesPurpeofuscus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag628(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:628 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag628", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumGwf24014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium GWF2_40_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumGwf24014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterCloacaeEcwsu1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Enterobacter cloacae EcWSU1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EnterobacterCloacaeEcwsu1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSpRoot4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAobensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nocardia aobensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NocardiaAobensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HymenobacterSwuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hymenobacter swuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HymenobacterSwuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaSpMxaz02Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidocella sp. MXAZ02 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidocellaSpMxaz02Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanococcusMaripaludisC6Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanococcus maripaludis C6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanococcusMaripaludisC6Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhormidiumTenueNies30(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Phormidium tenue NIES-30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PhormidiumTenueNies30", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FischerellaSpPcc9431Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fischerella sp. PCC9431 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FischerellaSpPcc9431Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisGanjiahuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis ganjiahuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisGanjiahuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumDiphtheriaeNctc13129Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium diphtheriae NCTC 13129 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumDiphtheriaeNctc13129Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPLOWO2_01_FULL_54_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsplowo201Full5413Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanocaldococcusSpFs40622Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanocaldococcus sp. FS40622 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanocaldococcusSpFs40622Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiopsisAlba(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis alba graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisAlba", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterLariEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter lari Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterLariEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalanaeroarchaeumSulfurireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halanaeroarchaeum sulfurireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalanaeroarchaeumSulfurireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterInsulaenigraeNctc12927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Campylobacter insulaenigrae NCTC 12927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CampylobacterInsulaenigraeNctc12927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavihumibacterSpCaciam22h1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavihumibacter sp. CACIAM 22H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavihumibacterSpCaciam22h1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PochoniaChlamydosporia123Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pochonia chlamydosporia 123 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PochoniaChlamydosporia123Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusGottheiliiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gottheilii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusGottheiliiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinilabiliaSalmonicolorEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinilabilia salmonicolor Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinilabiliaSalmonicolorEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPasteurianus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPasteurianus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaSanticrucis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Legionella santicrucis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LegionellaSanticrucis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermogladiusCellulolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermogladius cellulolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermogladiusCellulolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFulvissimus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces fulvissimus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesFulvissimus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsplowo201full5121Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPLOWO201FULL5121 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsplowo201full5121Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlysiellaCrassaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alysiella crassa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlysiellaCrassaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldilineaAerophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldilinea aerophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldilineaAerophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HerbaspirillumSpGw103Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum sp. GW103 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSpGw103Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoesebacteriaBacteriumRifcsphigho201full4110Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium RIFCSPHIGHO201FULL4110 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumRifcsphigho201full4110Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaGlabrataCbs138Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return [Candida] glabrata CBS 138 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidaGlabrataCbs138Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadetesBacterium13220cm2657Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium 13_2_20CM_2_65_7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacterium13220cm2657Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasTaxi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas taxi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasTaxi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSinesaloumensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sinesaloumensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSinesaloumensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GymnopilusDilepisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gymnopilus dilepis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GymnopilusDilepisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtissbacteriaBacteriumRifoxya1full4114(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtissbacteria bacterium RIFOXYA1FULL4114 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtissbacteriaBacteriumRifoxya1full4114", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumNeworleansense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium neworleansense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumNeworleansense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoranbacteriaBacteriumGw2011gwe23640(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Moranbacteria bacterium GW2011GWE23640 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MoranbacteriaBacteriumGw2011gwe23640", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MariniblastusFucicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mariniblastus fucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MariniblastusFucicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaeniglutamicibacterGangotriensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paeniglutamicibacter gangotriensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaeniglutamicibacterGangotriensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaKoreensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dokdonella koreensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DokdonellaKoreensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterAilurogastricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter ailurogastricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HelicobacterAilurogastricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CommensalibacterSpMx01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter sp. MX01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterSpMx01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumAkiainvivensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium akiainvivens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumAkiainvivensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeferribacteralesBacteriumDeferri01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Deferribacterales bacterium Deferri_01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DeferribacteralesBacteriumDeferri01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThalassobiumSpR2a62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thalassobium sp. R2A62 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThalassobiumSpR2a62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SciscionellaMarinaDsm45152(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sciscionella marina DSM 45152 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SciscionellaMarinaDsm45152", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PediococcusStilesiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pediococcus stilesii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PediococcusStilesiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VignaRadiataVarRadiata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vigna radiata var. radiata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VignaRadiataVarRadiata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumPusillum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium pusillum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumPusillum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenisporosarcinaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenisporosarcina indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenisporosarcinaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpWmmb714Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. WMMB 714 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpWmmb714Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpOk091Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. OK091 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpOk091Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FilifactorAlocisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Filifactor alocis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FilifactorAlocisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MassiliaSpNr41(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. NR 4-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpNr41", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasFuniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megamonas funiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegamonasFuniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BranchiostomaFloridae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Branchiostoma floridae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BranchiostomaFloridae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaSourekiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Facklamia sourekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FacklamiaSourekiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacteriumRavenspurgenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brevibacterium ravenspurgense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrevibacteriumRavenspurgenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FacklamiaSourekiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Facklamia sourekii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FacklamiaSourekiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaPeanutWitchesbroomCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma peanut witchesbroom Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaPeanutWitchesbroomCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSpF0407Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. F0407 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSpF0407Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CommensalibacterSpMx01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Commensalibacter sp. MX01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CommensalibacterSpMx01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPoaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas poae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPoaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWor1BacteriumRifoxya2full3621Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFOXYA2FULL3621 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifoxya2full3621Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NicotianaAttenuata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nicotiana attenuata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NicotianaAttenuata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpF0209Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0209 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0209Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFCSPLOWO2_02_FULL_45_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifcsplowo202Full4515Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenophilusAzovorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xenophilus azovorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XenophilusAzovorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbaspirillumSeropedicaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Herbaspirillum seropedicae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HerbaspirillumSeropedicaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusHarenaeDsm16969Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus harenae DSM 16969 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusHarenaeDsm16969Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSyringaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix syringae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSyringaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesSpCag702Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:702 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag702Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4127Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4127 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4127Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpSt2l12Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. ST2L12 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpSt2l12Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoizmanbacteriaBacteriumGw2011gwa23418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roizmanbacteria bacterium GW2011GWA23418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoizmanbacteriaBacteriumGw2011gwa23418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpSjs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. SJS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpSjs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumSpCp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium sp. CP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumSpCp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RudanellaLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rudanella lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RudanellaLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TrichinellaPatagoniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichinella patagoniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichinellaPatagoniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumNe2001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium NE2001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumNe2001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarnobacteriumGallinarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Carnobacterium gallinarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CarnobacteriumGallinarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RIFCSPLOWO2_01_FULL_39_21 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRifcsplowo201Full3921Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanobacteriumCongolense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobacterium congolense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobacteriumCongolense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DialisterSuccinatiphilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Dialister succinatiphilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DialisterSuccinatiphilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaBacteriumBbfl7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteria bacterium BBFL7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaBacteriumBbfl7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacteriumSubtropicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacterium subtropicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkalibacteriumSubtropicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OmnitrophicaBacteriumRifcsplowo201full4510(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO201FULL4510 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo201full4510", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMundtiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus mundtii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMundtiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAngulatumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium angulatum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAngulatumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPinihumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus pinihumi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusPinihumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhanerochaeteCarnosaHhb10118SpCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Phanerochaete carnosa HHB-10118-sp Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PhanerochaeteCarnosaHhb10118SpCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusAcidominimusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus acidominimus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusAcidominimusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MagasanikbacteriaBacteriumRifcsphigho202full4135Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPHIGHO202FULL4135 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsphigho202full4135Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophoarchaeumButanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophoarchaeum butanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophoarchaeumButanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodoferaxFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodoferax ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodoferaxFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaGallisepticumFCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma gallisepticum F Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaGallisepticumFCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RenibacteriumSalmoninarumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Renibacterium salmoninarum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RenibacteriumSalmoninarumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSp263sspc(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus sp. 263SSPC graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSp263sspc", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_12_FULL_60_25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho212Full6025Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilusObscurusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus obscurus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusObscurusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaErythraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella erythra Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaErythraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllochromatiumWarmingiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium warmingii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumWarmingiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPseudoalcaligenesAd6(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas pseudoalcaligenes AD6 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasPseudoalcaligenesAd6", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasOceanitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas oceanitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasOceanitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpechtbacteriaBacteriumRifcsplowo201full4610Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPLOWO201FULL4610 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsplowo201full4610Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollierbacteriaBacteriumGw2011gwb1446(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Collierbacteria bacterium GW2011GWB1446 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CollierbacteriaBacteriumGw2011gwb1446", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpAb57Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. AB57 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpAb57Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusUliginisN3975(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus uliginis N3/975 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusUliginisN3975", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPLOWO2_01_FULL_37_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsplowo201Full3710", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaeroarcusBurkinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaeroarcus burkinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaeroarcusBurkinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag273(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:273 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag273", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DaucusCarotaSubspSativusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Daucus carota subsp. sativus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DaucusCarotaSubspSativusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumAc2028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC2028 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc2028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriumCg2304012(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return bacterium CG2_30_40_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriumCg2304012", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CordycepsSpRao2017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps sp. RAO-2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CordycepsSpRao2017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanibulbusIndolifexCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oceanibulbus indolifex Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OceanibulbusIndolifexCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudarthrobacterSulfonivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudarthrobacter sulfonivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudarthrobacterSulfonivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HadesarchaeaArchaeonYnp45Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon YNP_45 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeonYnp45Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptotrichiaShahiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptotrichia shahii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptotrichiaShahiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapilioMachaon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Papilio machaon graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PapilioMachaon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaEndosymbiontOfOrnithodorosMoubataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Francisella endosymbiont of Ornithodoros moubata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FrancisellaEndosymbiontOfOrnithodorosMoubataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusSp2gbenrich(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanohalophilus sp. 2GBenrich graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanohalophilusSp2gbenrich", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktotaleaArcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planktotalea arctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanktotaleaArcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesNeuiiBvs029a5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii BVS029A5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiBvs029a5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumGwa25511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium GWA2_55_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumGwa25511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumShinjukuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium shinjukuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumShinjukuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFCSPLOWO2_01_FULL_39_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifcsplowo201Full3917", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquidulcibacterPaucihalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aquidulcibacter paucihalophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AquidulcibacterPaucihalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumJannaschii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium jannaschii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumJannaschii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusCanisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus canis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusCanisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WinogradskyellaSpJ142Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella sp. J14-2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaSpJ142Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusPaucihalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus paucihalophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusPaucihalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlossinaAusteniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Glossina austeni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GlossinaAusteniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodovulumSpPh10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sp. PH10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSpPh10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiPvEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii PV Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiPvEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterHeilmanniiAsb14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter heilmannii ASB1.4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterHeilmanniiAsb14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConidiobolusCoronatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ConidiobolusCoronatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpOrs278(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. ORS278 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpOrs278", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TersicoccusSpBi70Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tersicoccus sp. Bi-70 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TersicoccusSpBi70Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusFrumentiDsm13145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus frumenti DSM 13145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFrumentiDsm13145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumRifcsplowo202full5016(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPLOWO202FULL5016 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsplowo202full5016", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaHermsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hermsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BorreliaHermsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDsm4029(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DSM 4029 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDsm4029", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevyellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Levyella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LevyellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosotenuisUzonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosotenuis uzonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosotenuisUzonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRhodobacterLobularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rhodobacter lobularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRhodobacterLobularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OreochromisAureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oreochromis aureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OreochromisAureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriKos6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri KOS6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriKos6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpHys(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. HYS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpHys", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoregulaFormicica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanoregula formicica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanoregulaFormicica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusFirmusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus firmus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusFirmusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BilophilaWadsworthia316(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bilophila wadsworthia 316 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BilophilaWadsworthia316", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArmadillidiumVulgareEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Armadillidium vulgare Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArmadillidiumVulgareEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoxanthomonasSpGw2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoxanthomonas sp. GW2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoxanthomonasSpGw2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPopuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium populi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumPopuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusSpTolsr(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus sp. TolSR graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusSpTolsr", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NannizziaGypseaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nannizzia gypsea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NannizziaGypseaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpGhvi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. Ghvi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpGhvi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaVacciniiNbrc15922(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia vaccinii NBRC 15922 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaVacciniiNbrc15922", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TepidibacterThalassicusDsm15285Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Tepidibacter thalassicus DSM 15285 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "TepidibacterThalassicusDsm15285Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarineGroupIThaumarchaeoteEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marine Group I thaumarchaeote Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIThaumarchaeoteEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusSp7f3div0205(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus sp. 7F3DIV0205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusSp7f3div0205", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesToyocaensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces toyocaensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesToyocaensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasPanacihumiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas panacihumi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasPanacihumiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaladaptatusSpR4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haladaptatus sp. R4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaladaptatusSpR4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerminephrobacterEiseniae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Verminephrobacter eiseniae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VerminephrobacterEiseniae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMegateriumQmB1551(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus megaterium QM B1551 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusMegateriumQmB1551", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AquimarinaLaterculaDsm2041(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Aquimarina latercula DSM 2041 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AquimarinaLaterculaDsm2041", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NosocomiicoccusAmpullae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nosocomiicoccus ampullae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NosocomiicoccusAmpullae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumIndicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum indicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumIndicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobaccaAcetoxidansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacca acetoxidans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobaccaAcetoxidansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardioidesSzechwanensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nocardioides szechwanensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NocardioidesSzechwanensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumSpSd626r(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum sp. SD626R graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumSpSd626r", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioOxyclinaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio oxyclinae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioOxyclinaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldimonasTaiwanensisNbrc104434Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Caldimonas taiwanensis NBRC 104434 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CaldimonasTaiwanensisNbrc104434Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IdiomarinaSpMd25aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Idiomarina sp. MD25a Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IdiomarinaSpMd25aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AltererythrobacterNamhicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Altererythrobacter namhicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AltererythrobacterNamhicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumChlorophenolicumL1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium chlorophenolicum L-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SphingobiumChlorophenolicumL1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetobacterMalorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acetobacter malorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcetobacterMalorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaAgarivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina agarivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAgarivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaSpSoil729(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Knoellia sp. Soil729 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KnoelliaSpSoil729", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MerdibacterMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Merdibacter massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MerdibacterMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoselliniaNecatrixEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rosellinia necatrix Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoselliniaNecatrixEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4432(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4432 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4432", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasVesicatoriaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas vesicatoria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasVesicatoriaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerobaculumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Anaerobaculum mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AnaerobaculumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesRoseoverticillatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces roseoverticillatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesRoseoverticillatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumBoenickeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium boenickei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumBoenickeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpRu36dCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. RU36D Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRu36dCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NitrobacterVulgaris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrobacter vulgaris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrobacterVulgaris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesCoprophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides coprophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidesCoprophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpC561Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. C561 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpC561Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusSucicolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus sucicola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSucicolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodospirillumSpUnkmgs17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodospirillum sp. UNKMGS17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodospirillumSpUnkmgs17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusHominickiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus hominickii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusHominickiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CavenderiaFasciculataSh3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cavenderia fasciculata SH3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CavenderiaFasciculataSh3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaGlabrataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Candida glabrata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidaGlabrataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnsiferSojae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ensifer sojae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnsiferSojae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeobacterGallaeciensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter gallaeciensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterGallaeciensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterSpRm8964(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter sp. RM8964 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterSpRm8964", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SecondaryEndosymbiontOfTrabutinaManniparaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return secondary endosymbiont of Trabutina mannipara Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SecondaryEndosymbiontOfTrabutinaManniparaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaBirtlesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella birtlesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaBirtlesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaumarchaeotaArchaeonScgcAaa007o23Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thaumarchaeota archaeon SCGC AAA007O23 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThaumarchaeotaArchaeonScgcAaa007o23Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TamlanaNanhaiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tamlana nanhaiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TamlanaNanhaiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PelagibacterUbiqueHtcc7214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC7214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc7214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterBrisouiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter brisouii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterBrisouiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FirmicutesBacteriumAsf500Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium ASF500 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumAsf500Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LipomycesStarkeyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lipomyces starkeyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LipomycesStarkeyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanomicrobiumMobileCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methanomicrobium mobile Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethanomicrobiumMobileCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraMicronuciformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera micronuciformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMicronuciformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasSpGpe39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas sp. GPE 39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasSpGpe39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdhazardiaAedisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Edhazardia aedis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EdhazardiaAedisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumSpUmwgj(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. UMWGJ graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpUmwgj", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FriedmanniellaSagamiharensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Friedmanniella sagamiharensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FriedmanniellaSagamiharensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizopusStoloniferEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizopus stolonifer Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizopusStoloniferEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChloroflexiBacteriumRbg165711Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chloroflexi bacterium RBG_16_57_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChloroflexiBacteriumRbg165711Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaEquiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Theileria equi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TheileriaEquiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfoplanesFormicivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfoplanes formicivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfoplanesFormicivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSpMwhadlerw8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sp. MWHAdlerW8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSpMwhadlerw8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacteriumRhizophilumDsm18822(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum DSM 18822 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilumDsm18822", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaPohangensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia pohangensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaPohangensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaMexicanaNbrc108244(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nocardia mexicana NBRC 108244 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NocardiaMexicanaNbrc108244", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_01_FULL_45_15b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo201Full4515b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobiformaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobiforma nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobiformaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanotorrisFormicicusMcS70Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanotorris formicicus Mc-S-70 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanotorrisFormicicusMcS70Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaHarzianumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma harzianum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichodermaHarzianumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeltaproteobacteriaBacteriumCg2304315(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium CG2_30_43_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumCg2304315", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptococcaceaeBacteriumBica17Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Peptococcaceae bacterium BICA1-7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PeptococcaceaeBacteriumBica17Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNele67bin005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nele67Bin005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNele67bin005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SinorhizobiumSpCcbau05631Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sinorhizobium sp. CCBAU05631 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SinorhizobiumSpCcbau05631Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerobiumAcetethylicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerobium acetethylicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerobiumAcetethylicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OwenweeksiaHongkongensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Owenweeksia hongkongensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OwenweeksiaHongkongensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloarculaJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloarcula japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloarculaJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpirosomaRigui(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma rigui graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRigui", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_41_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4113", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesPosadasiiStrSilveiraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Coccidioides posadasii str. Silveira Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CoccidioidesPosadasiiStrSilveiraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeifsoniaSp719(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. 71-9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSp719", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrovirgaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microvirga massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrovirgaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaAvium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia avium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaAvium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpRoot604(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. Root604 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpRoot604", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodohalobacterHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodohalobacter halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodohalobacterHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusSpKgw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus sp. KGW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusSpKgw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OleispiraAntarcticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oleispira antarctica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OleispiraAntarcticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidianusCopahuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidianus copahuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidianusCopahuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusSuisEa183292(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus suis EA183292 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusSuisEa183292", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrenochaetaSpDs3say3aCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrenochaeta sp. DS3sAY3a Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrenochaetaSpDs3say3aCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumStellenboschenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium stellenboschense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumStellenboschenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MeiothermusCerbereusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Meiothermus cerbereus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MeiothermusCerbereusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioPutealisDsm16056Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio putealis DSM 16056 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioPutealisDsm16056Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClohesyomycesAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clohesyomyces aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClohesyomycesAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylosarcinaLacusLw14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methylosarcina lacus LW14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethylosarcinaLacusLw14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidocellaAminolytica101Dsm11237Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Acidocella aminolytica 101 DSM 11237 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AcidocellaAminolytica101Dsm11237Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumRifoxyb1full4423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium RIFOXYB1FULL4423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumRifoxyb1full4423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyricimonasVirosaDsm23226Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Butyricimonas virosa DSM 23226 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ButyricimonasVirosaDsm23226Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichodermaArundinaceum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichoderma arundinaceum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichodermaArundinaceum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacterialesBacterium4461Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 44-61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium4461Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpL294(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. L294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpL294", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumOrchidophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orchidophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrchidophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1859Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1859 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1859Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusHorneckiaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus horneckiae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusHorneckiaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VerrucomicrobiaBacteriumGwf25119Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Verrucomicrobia bacterium GWF2_51_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VerrucomicrobiaBacteriumGwf25119Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSp12Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. 12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSp12Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpBchEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Bch Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpBchEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArcanobacteriumUrinimassilienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arcanobacterium urinimassiliense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArcanobacteriumUrinimassilienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterShowaeCsunswcd(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae CSUNSWCD graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeCsunswcd", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaArizonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica arizonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaArizonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EffusibacillusPohliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Effusibacillus pohliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EffusibacillusPohliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumNodatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium nodatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EubacteriumNodatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaWheatBlueCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Phytoplasma wheat blue Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "PhytoplasmaWheatBlueCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAccumulibacterSpSk11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Accumulibacter sp. SK-11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAccumulibacterSpSk11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaedibacterSp3749Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caedibacter sp. 37-49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaedibacterSp3749Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphaerochaetaPleomorphaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphaerochaeta pleomorpha Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphaerochaetaPleomorphaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasSpS2151Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halomonas sp. S2151 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalomonasSpS2151Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalopigerXanaduensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopiger xanaduensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopigerXanaduensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RiesiaSpGbbu(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riesia sp. GBBU graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiesiaSpGbbu", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus alvei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAlveiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterTowneriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter towneri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTowneriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpX15166b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. X15-166B graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpX15166b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TetrasphaeraElongata(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tetrasphaera elongata graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TetrasphaeraElongata", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaimiriBoliviensisBoliviensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saimiri boliviensis boliviensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaimiriBoliviensisBoliviensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full3910Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL3910 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full3910Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraPaucivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera paucivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraPaucivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusGastricusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus gastricus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusGastricusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioBrasiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio brasiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioBrasiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GlaciibacterSuperstes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glaciibacter superstes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlaciibacterSuperstes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomicrospiraMicroaerophilaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiomicrospira microaerophila Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiomicrospiraMicroaerophilaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlammeovirgaceaeBacteriumBbd199112Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flammeovirgaceae bacterium BBD 1991-12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlammeovirgaceaeBacteriumBbd199112Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryptococcusAmylolentusCbs6039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cryptococcus amylolentus CBS 6039 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CryptococcusAmylolentusCbs6039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalobacillusAidingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalobacillusAidingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RodentolepisNanaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rodentolepis nana Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RodentolepisNanaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirestonebacteriaBacteriumRifoxya2full408Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firestonebacteria bacterium RIFOXYA2FULL408 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirestonebacteriaBacteriumRifoxya2full408Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PezolomaEricaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pezoloma ericae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PezolomaEricaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_02_FULL_45_11c Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo202Full4511cCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DefluviitaleaPhaphyphila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Defluviitalea phaphyphila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DefluviitaleaPhaphyphila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThorarchaeotaArchaeonAb25Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thorarchaeota archaeon AB25 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThorarchaeotaArchaeonAb25Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KutzneriaAlbida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kutzneria albida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KutzneriaAlbida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SclerodermaCitrinumFougA(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Scleroderma citrinum Foug A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SclerodermaCitrinumFougA", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterSpSfb93Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter sp. SFB93 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PelobacterSpSfb93Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfitibacterAlkalitoleransDsm16504Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfitibacter alkalitolerans DSM 16504 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfitibacterAlkalitoleransDsm16504Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusSwuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus swuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DeinococcusSwuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionivibrioDicarboxylicusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Propionivibrio dicarboxylicus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PropionivibrioDicarboxylicusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DethiosulfovibrioSalsuginisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dethiosulfovibrio salsuginis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DethiosulfovibrioSalsuginisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldithrixSpRbg13449Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caldithrix sp. RBG_13_44_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaldithrixSpRbg13449Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DietziaMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dietzia maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DietziaMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpEs333(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. ES3-33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpEs333", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpYr485Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. YR485 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpYr485Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronococcusJeotgaliDsm18795(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali DSM 18795 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NatronococcusJeotgaliDsm18795", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumGwa24611(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium GWA2_46_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumGwa24611", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesAcidiscabies(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces acidiscabies graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesAcidiscabies", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasHelleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas helleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasHelleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasAlienaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas aliena Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasAlienaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MaribacterForsetiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maribacter forsetii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaribacterForsetiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusPolymyxaM1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus polymyxa M1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusPolymyxaM1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacterVibrioformisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpRoot268Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Root268 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpRoot268Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusTermitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus termitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTermitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoaglandellaEndobiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoaglandella endobia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoaglandellaEndobiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldicellulosiruptorMorganii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caldicellulosiruptor morganii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaldicellulosiruptorMorganii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegamonasFuniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megamonas funiformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegamonasFuniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AsticcacaulisSpYbe204Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis sp. YBE204 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisSpYbe204Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodococcusSpRd62Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. RD6.2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpRd62Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMidichloriaMitochondriiIricva(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Midichloria mitochondrii IricVA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMidichloriaMitochondriiIricva", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfonauticusSp384375(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfonauticus sp. 38_4375 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfonauticusSp384375", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumTepidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium tepidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumTepidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusSpTaa43Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus sp. TAA 43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSpTaa43Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilusPhascolarctosicola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilus phascolarctosicola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilusPhascolarctosicola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterAdhaerensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter adhaerens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterAdhaerensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRbg133914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RBG_13_39_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRbg133914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetarhiziumRileyiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metarhizium rileyi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetarhiziumRileyiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaMuscariaKoideBx008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Amanita muscaria Koide BX008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AmanitaMuscariaKoideBx008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusSpDsm45219Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus sp. DSM 45219 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusSpDsm45219Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasKuykendalliiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas kuykendallii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasKuykendalliiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaSpH567(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. H567 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpH567", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaAerolatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma aerolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaAerolatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseovariusMucosusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius mucosus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseovariusMucosusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCoryniformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCoryniformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Ryanbacteria bacterium RIFCSPLOWO2_01_FULL_48_26 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRyanbacteriaBacteriumRifcsplowo201Full4826", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonquetellaAnthropiDsm22815Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Jonquetella anthropi DSM22815 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "JonquetellaAnthropiDsm22815Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapsellaGrandifloraCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Capsella grandiflora Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CapsellaGrandifloraCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusCoryniformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus coryniformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCoryniformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenomonasRuminantiumAb3002Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas ruminantium AB3002 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SelenomonasRuminantiumAb3002Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinomonasPosidonicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas posidonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPosidonicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaJordanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella jordanis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaJordanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterPsychrophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter psychrophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterPsychrophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KushneriaSpYcwa18Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kushneria sp. YCWA18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KushneriaSpYcwa18Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EdwardsiellaIctaluriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Edwardsiella ictaluri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EdwardsiellaIctaluriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterGerneriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter gerneri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterGerneriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_54_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CeleribacterNeptuniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter neptunius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CeleribacterNeptuniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesArizonensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces arizonensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycomycesArizonensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterAlimentariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter alimentarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterAlimentariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YamadazymaTenuisAtcc10573(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis ATCC 10573 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "YamadazymaTenuisAtcc10573", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylacidiphilumFumariolicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylacidiphilum fumariolicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylacidiphilumFumariolicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf20Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf20Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CurtobacteriumSpBh211Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium sp. BH-2-1-1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumSpBh211Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidateDivisionWwe3BacteriumRifoxyb1full4324Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division WWE3 bacterium RIFOXYB1FULL4324 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWwe3BacteriumRifoxyb1full4324Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumIhumiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium ihumii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumIhumiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WoykebacteriaBacteriumRbg16399bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG16399b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg16399bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodopseudomonasPalustrisDx1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodopseudomonas palustris DX1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodopseudomonasPalustrisDx1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaSativaJaponicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oryza sativa Japonica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OryzaSativaJaponicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanosalsumZhilinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanosalsum zhilinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanosalsumZhilinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgibacterAquaticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algibacter aquaticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgibacterAquaticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnabasTestudineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anabas testudineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnabasTestudineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusBasilensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus basilensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CupriavidusBasilensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacillusSubterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Geobacillus subterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GeobacillusSubterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinokineosporaBangkokensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora bangkokensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaBangkokensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo202full4716Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO202FULL4716 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo202full4716Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumJcvitm6sc1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium JCVITM6SC1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumJcvitm6sc1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusCoprophilusNbrc100603Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus coprophilus NBRC 100603 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodococcusCoprophilusNbrc100603Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterobacterSpKpr6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter sp. kpr-6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterobacterSpKpr6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucilaginibacterMallensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter mallensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterMallensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PanicumVirgatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Panicum virgatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PanicumVirgatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls340Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS340 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls340Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhaeospirillumMolischianumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeospirillum molischianum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeospirillumMolischianumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactococcusPlantarum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactococcus plantarum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactococcusPlantarum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpAa0539Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces sp. AA0539 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptomycesSpAa0539Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaSubsalsa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirulina subsalsa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirulinaSubsalsa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaAfzelii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Borrelia afzelii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BorreliaAfzelii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegasphaeraMicronuciformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera micronuciformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraMicronuciformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaSpFb8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella sp. FB8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaSpFb8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PropionimicrobiumSpBv2f7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Propionimicrobium sp. BV2F7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PropionimicrobiumSpBv2f7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerorhabdusFurcosaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaerorhabdus furcosa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaerorhabdusFurcosaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpLeaf336Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Leaf336 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpLeaf336Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusMindensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus mindensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusMindensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpYqh10Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Shewanella sp. YQH10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ShewanellaSpYqh10Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFCSPLOWO2_12_FULL_47_20 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifcsplowo212Full4720Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CytophagaAurantiacaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cytophaga aurantiaca Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CytophagaAurantiacaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KineococcusRadiotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kineococcus radiotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KineococcusRadiotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterNecessariusStir1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Polynucleobacter necessarius STIR1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PolynucleobacterNecessariusStir1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorobiumTepidum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chlorobium tepidum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChlorobiumTepidum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliellaGarinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Borreliella garinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BorreliellaGarinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterCalcoaceticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter calcoaceticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterCalcoaceticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUpsaliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter upsaliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUpsaliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ButyrivibrioSpLc3010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. LC3010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpLc3010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XenorhabdusSzentirmaiiDsm16338Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Xenorhabdus szentirmaii DSM 16338 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "XenorhabdusSzentirmaiiDsm16338Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_01_FULL_34_15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudobutyrivibrioSpAcv2(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudobutyrivibrio sp. ACV-2 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudobutyrivibrioSpAcv2", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobacteriumAutotrophicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacterium autotrophicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobacteriumAutotrophicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaeniopygiaGuttataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Taeniopygia guttata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TaeniopygiaGuttataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BuchananbacteriaBacteriumRifcsphigho201full4411(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Buchananbacteria bacterium RIFCSPHIGHO201FULL4411 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BuchananbacteriaBacteriumRifcsphigho201full4411", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MegaseliaScalarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Megaselia scalaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MegaseliaScalarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinomonasPolarisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinomonas polaris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinomonasPolarisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3734Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3734 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3734Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSpCf097(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF097 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf097", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMagnum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium magnum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumMagnum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharothrixSpCb00851Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. CB00851 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpCb00851Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacillusIheyensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacillus iheyensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacillusIheyensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpiroplasmaCitri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spiroplasma citri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpiroplasmaCitri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaMahii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena mahii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaMahii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwb24422Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWB2_44_22 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwb24422Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSpHr7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. HR7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpHr7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnoxybacillusFlavithermusAk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus AK1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusAk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Legionella massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LegionellaMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeucoagaricusSpSymccosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leucoagaricus sp. SymCcos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeucoagaricusSpSymccosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentzeaGuizhouensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lentzea guizhouensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LentzeaGuizhouensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusPohliaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pohliae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusPohliaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WinogradskyellaPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Winogradskyella psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WinogradskyellaPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoprococcusCatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coprococcus catus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoprococcusCatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumCrudilactisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium crudilactis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCrudilactisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumRutilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium rutilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumRutilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusPasteurianusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus pasteurianus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPasteurianusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumMortiferum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium mortiferum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumMortiferum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSiciliae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina siciliae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSiciliae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicumIn8p8Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum in8p8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicumIn8p8Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MurdochiellaVaginalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Murdochiella vaginalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MurdochiellaVaginalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusPanisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus panis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusPanisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_41_18 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full4118Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermusFiliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermus filiformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermusFiliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiovulumSpEsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thiovulum sp. ES Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThiovulumSpEsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrocoleusVaginatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microcoleus vaginatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrocoleusVaginatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpChol1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Chol1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpChol1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DomibacillusIocasaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Domibacillus iocasae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DomibacillusIocasaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasFloridensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas floridensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasFloridensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NosemaBombycisCq1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nosema bombycis CQ1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NosemaBombycisCq1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaskawiczbacteriaBacteriumRifcsplowo201full4317b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Staskawiczbacteria bacterium RIFCSPLOWO201FULL4317b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StaskawiczbacteriaBacteriumRifcsplowo201full4317b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotoleransDsm19514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans DSM 19514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FerrithrixThermotoleransDsm19514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumFournieriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium fournierii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumFournieriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacteriumC7867001Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium C7867-001 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacteriumC7867001Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ElusimicrobiaBacteriumGwa26618Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Elusimicrobia bacterium GWA2_66_18 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ElusimicrobiaBacteriumGwa26618Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanolineaTardaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolinea tarda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolineaTardaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KluyveraCryocrescensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kluyvera cryocrescens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KluyveraCryocrescensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermoproteusSpJchs4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermoproteus sp. JCHS_4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermoproteusSpJchs4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhocaeicolaAbscessus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phocaeicola abscessus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhocaeicolaAbscessus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumGlobosumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium globosum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumGlobosumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerolineaeBacteriumUtcfx1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Anaerolineae bacterium UTCFX1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AnaerolineaeBacteriumUtcfx1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulicatellaBalaenopteraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulicatella balaenopterae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulicatellaBalaenopteraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCoahuilensisP1143Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus coahuilensis p1.1.43 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusCoahuilensisP1143Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeotaArchaeonEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeonEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiomonasArsenitoxydans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thiomonas arsenitoxydans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThiomonasArsenitoxydans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumGloeosporioidesCg14Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Colletotrichum gloeosporioides Cg-14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ColletotrichumGloeosporioidesCg14Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnisphaeraAggregansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ignisphaera aggregans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "IgnisphaeraAggregansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CordycepsFumosorosea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cordyceps fumosorosea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CordycepsFumosorosea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktothrixTepidaPcc9214Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Planktothrix tepida PCC 9214 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PlanktothrixTepidaPcc9214Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ShinellaSpHzn7Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shinella sp. HZN7 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShinellaSpHzn7Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporosarcinaSpZbg7a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina sp. ZBG7A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaSpZbg7a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp9Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp9Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAviariusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus aviarius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAviariusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PsychrobacterSpAntimn1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter sp. AntiMn-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterSpAntimn1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusSpScb245a518a17Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. scB245a_518A17 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpScb245a518a17Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumEtliMimosaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium etli mimosae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhizobiumEtliMimosaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterAnaerophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter anaerophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArcobacterAnaerophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConidiobolusCoronatusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Conidiobolus coronatus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ConidiobolusCoronatusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlastochlorisViridis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastochloris viridis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastochlorisViridis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumParaoxydansDh1bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium paraoxydans DH1b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumParaoxydansDh1bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MyroidesInjenensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Myroides injenensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MyroidesInjenensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisGranuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis granuli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisGranuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PlanctomycetesBacteriumRifcsphigho202full4012Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planctomycetes bacterium RIFCSPHIGHO202FULL4012 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanctomycetesBacteriumRifcsphigho202full4012Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpCh12iCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. CH12i Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpCh12iCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioGracilisDsm16080Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis DSM 16080 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioGracilisDsm16080Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCassavaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas cassavae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthomonasCassavaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaceaeBacteriumFsla50281(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeriaceae bacterium FSLA50281 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaceaeBacteriumFsla50281", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EhrlichiaMurisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ehrlichia muris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EhrlichiaMurisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterSinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter sinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterSinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumLablabi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium lablabi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumLablabi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryobacteriumPsychrotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium psychrotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumPsychrotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OrientiaTsutsugamushiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Orientia tsutsugamushi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OrientiaTsutsugamushiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenophagaSpRac07Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenophaga sp. RAC07 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HydrogenophagaSpRac07Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinosynnemaMirum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinosynnema mirum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinosynnemaMirum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobotryumSilenesdioicaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbotryum silenesdioicae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobotryumSilenesdioicaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StenotrophomonasMaltophiliaS028Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia S028 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaS028Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumRifcsphigho201full4921(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium RIFCSPHIGHO201FULL4921 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumRifcsphigho201full4921", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumMangenotii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium mangenotii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumMangenotii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlamydiaCaviaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chlamydia caviae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaCaviaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MucorCircinelloidesFCircinelloides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mucor circinelloides f. circinelloides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MucorCircinelloidesFCircinelloides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionTm6BacteriumGw2011gwe24260Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division TM6 bacterium GW2011GWE24260 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionTm6BacteriumGw2011gwe24260Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NovosphingobiumSpNdb2meth1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. NDB2Meth1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpNdb2meth1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FragariaVesca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Fragaria vesca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FragariaVesca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalonotiusSpJ07hn4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Halonotius sp. J07HN4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HalonotiusSpJ07hn4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfocapsaSulfexigens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfocapsa sulfexigens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfocapsaSulfexigens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterBorealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pedobacter borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PedobacterBorealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ApteryxOwenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Apteryx owenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ApteryxOwenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TemnothoraxLongispinosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Temnothorax longispinosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TemnothoraxLongispinosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar324ClusterBacteriumRedseas27b3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium REDSEAS27B3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumRedseas27b3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GracilariopsisChordaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilariopsis chorda Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilariopsisChordaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasByunsanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas byunsanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasByunsanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMethanolicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis methanolica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMethanolicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NematocidaSp1Ertm2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nematocida sp. 1 ERTm2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NematocidaSp1Ertm2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VanderwaltozymaPolyspora(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vanderwaltozyma polyspora graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VanderwaltozymaPolyspora", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PapillibacterCinnamivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Papillibacter cinnamivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PapillibacterCinnamivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp22311(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2231.1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp22311", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpTca20(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus sp. TCA20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusSpTca20", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251057sch5723018(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251057SCH5723018 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251057sch5723018", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacterialesBacteriumBrhc54(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriales bacterium BRHc54 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacterialesBacteriumBrhc54", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SelenihalanaerobacterShriftiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Selenihalanaerobacter shriftii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SelenihalanaerobacterShriftiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CladophialophoraPsammophilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cladophialophora psammophila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CladophialophoraPsammophilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioZosteraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio zosterae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioZosteraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarineGroupIiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marine Group III Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarineGroupIiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LimnobacterSpMed105Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Limnobacter sp. MED105 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LimnobacterSpMed105Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeptuniibacterMarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neptuniibacter marinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeptuniibacterMarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CoccidioidesImmitisRsCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Coccidioides immitis RS Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CoccidioidesImmitisRsCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LamprocystisPurpureaDsm4197Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lamprocystis purpurea DSM 4197 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LamprocystisPurpureaDsm4197Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumGwa1448(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium GWA1448 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumGwa1448", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMd335Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MD335 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMd335Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonlabensSpHel13355Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens sp. Hel1_33_55 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonlabensSpHel13355Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesNeuiiDsm8576(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces neuii DSM8576 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ActinomycesNeuiiDsm8576", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSolaniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus solani Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSolaniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpCcge1001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia sp. CCGE1001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaSpCcge1001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZunongwangiaProfunda(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zunongwangia profunda graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZunongwangiaProfunda", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaElongataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria elongata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaElongataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaDisiensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella disiens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaDisiensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusOligofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus oligofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusOligofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpJha19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. JHA19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpJha19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FibrobacterSpUwp2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWP2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwp2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def VibrioFluvialis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio fluvialis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioFluvialis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFCSPHIGHO2_02_FULL_53_13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifcsphigho202Full5313", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TardibacterChloracetimidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tardibacter chloracetimidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TardibacterChloracetimidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasSpLm091Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas sp. LM091 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasSpLm091Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusCacaonum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus cacaonum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusCacaonum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KitasatosporaArboriphilaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kitasatospora arboriphila Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KitasatosporaArboriphilaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumRifcsplowo202full4516(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium RIFCSPLOWO202FULL4516 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumRifcsplowo202full4516", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGelatiniCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Bacillus gelatini Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BacillusGelatiniCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptomycesSpNrrlwc3742(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLWC3742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrlwc3742", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterUreolyticusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter ureolyticus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterUreolyticusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BordetellaPetriiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bordetella petrii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BordetellaPetriiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyphellophoraEuropaeaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyphellophora europaea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyphellophoraEuropaeaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaBacterium4484255Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria bacterium 4484255 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaBacterium4484255Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlagellimonasFlavaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flagellimonas flava Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlagellimonasFlavaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumScophthalmumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium scophthalmum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumScophthalmumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacteriumRbg16439Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium RBG_16_43_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacteriumRbg16439Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusGinsengihumiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus ginsengihumi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusGinsengihumiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasResinovoransNbrc106553Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas resinovorans NBRC106553 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasResinovoransNbrc106553Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoffeaCanephoraEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coffea canephora Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CoffeaCanephoraEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AminicenantesBacteriumRbg19ftcombo5817Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aminicenantes bacterium RBG19FTCOMBO5817 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AminicenantesBacteriumRbg19ftcombo5817Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasAgariciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas agarici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudomonasAgariciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrancisellaUliginis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Francisella uliginis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FrancisellaUliginis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobiumCzechenseLl01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sphingobium czechense LL01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SphingobiumCzechenseLl01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cynara cardunculus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CynaraCardunculusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaAobensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia aobensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaAobensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinicolaSpMit1003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicola sp. MIT1003 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicolaSpMit1003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacteriumGwa27023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium GWA2_70_23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacteriumGwa27023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnophelesColuzzii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anopheles coluzzii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnophelesColuzzii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13220cm27011(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_2_20CM_2_70_11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13220cm27011", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumBombiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium bombi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumBombiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PacebacteriaBacteriumCg1024331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pacebacteria bacterium CG1024331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PacebacteriaBacteriumCg1024331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfobacillusAcidophilusDsm10332Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Sulfobacillus acidophilus DSM 10332 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "SulfobacillusAcidophilusDsm10332Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolyporusArculariusHhb13444(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Polyporus arcularius HHB13444 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PolyporusArculariusHhb13444", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterSpS77Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter sp. S77 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CitrobacterSpS77Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesorhizobiumHuakuiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium huakuii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumHuakuiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSaccharophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saccharophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaccharophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumCg2304417(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium CG2304417 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumCg2304417", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EubacteriumRuminantiumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium ruminantium Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EubacteriumRuminantiumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidesDorei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bacteroides dorei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BacteroidesDorei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpL1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bacillus sp. L1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BacillusSpL1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterPiechaudii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacter piechaudii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacterPiechaudii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusMassilionigeriensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus massilionigeriensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusMassilionigeriensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpP6wCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Novosphingobium sp. P6W Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NovosphingobiumSpP6wCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MesoflavibacterZeaxanthDsm18436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanth. DSM18436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthDsm18436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHarbinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus harbinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHarbinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusNovofumigatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus novofumigatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AspergillusNovofumigatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaNitratireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola nitratireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrincolaNitratireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium RIFOXYB1_FULL_39_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumRifoxyb1Full3916Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SutterellaWadsworthensisHga0223Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sutterella wadsworthensis HGA0223 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SutterellaWadsworthensisHga0223Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidimicrobiiaBacteriumBacl6Mag120910Bin40(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Acidimicrobiia bacterium BACL6 MAG-120910-bin40 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AcidimicrobiiaBacteriumBacl6Mag120910Bin40", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonasStellipolarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alteromonas stellipolaris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlteromonasStellipolarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaPestisCo92Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pestis CO92 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaPestisCo92Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycineMax(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Glycine max graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GlycineMax", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumHylemonaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium hylemonae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumHylemonaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacterSpJcm18900(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Psychrobacter sp. JCM18900 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PsychrobacterSpJcm18900", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmmonifexDegensii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ammonifex degensii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AmmonifexDegensii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacillusEquuliSubspEquuliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Actinobacillus equuli subsp. equuli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ActinobacillusEquuliSubspEquuliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanibaculumNanhaienseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oceanibaculum nanhaiense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OceanibaculumNanhaienseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OstreococcusTauri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ostreococcus tauri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OstreococcusTauri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeorickettsiaHelminthoeca(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neorickettsia helminthoeca graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeorickettsiaHelminthoeca", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Yanofskybacteria bacterium RIFCSPLOWO2_02_FULL_45_10 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusYanofskybacteriaBacteriumRifcsplowo202Full4510Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingopyxisFribergensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis fribergensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisFribergensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwf23566Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWF2_35_66 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwf23566Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrincolaLacisaponensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrincola lacisaponensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrincolaLacisaponensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterTerraeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter terrae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterTerraeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiellaGrylliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella grylli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaGrylliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumSpCf284Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. CF284 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpCf284Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RasamsoniaEmersoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rasamsonia emersonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RasamsoniaEmersoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoclavibacterSoli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudoclavibacter soli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudoclavibacterSoli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumCarboxydivoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfotomaculum carboxydivorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfotomaculumCarboxydivoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AspergillusWelwitschiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus welwitschiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AspergillusWelwitschiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfonatronumThioautotrophicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfonatronum thioautotrophicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfonatronumThioautotrophicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HelicobacterSpMit016451Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter sp. MIT016451 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HelicobacterSpMit016451Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TalaromycesAmestolkiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Talaromyces amestolkiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TalaromycesAmestolkiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LentibacillusJuripiscariusJcm12147Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lentibacillus juripiscarius JCM 12147 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LentibacillusJuripiscariusJcm12147Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TenacibaculumSpMar201089Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Tenacibaculum sp. MAR_2010_89 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TenacibaculumSpMar201089Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcetothermiaBacteriumJdfr48(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetothermia bacterium JdFR48 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetothermiaBacteriumJdfr48", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpDsm44205(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. DSM 44205 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpDsm44205", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FilomicrobiumInsigneEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Filomicrobium insigne Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FilomicrobiumInsigneEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusPhocaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus phocae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptococcusPhocaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Curtissbacteria bacterium RIFCSPLOWO2_01_FULL_37_9 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCurtissbacteriaBacteriumRifcsplowo201Full379Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterAsymbioticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter asymbioticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterAsymbioticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaAerolataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Knoellia aerolata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KnoelliaAerolataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidovoraxSpJs42(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acidovorax sp. JS42 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcidovoraxSpJs42", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumSpNk2b42Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Oribacterium sp. NK2B42 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "OribacteriumSpNk2b42Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsplowo201full3317(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPLOWO201FULL3317 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsplowo201full3317", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasHaloplanktisTb64Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas haloplanktis TB64 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasHaloplanktisTb64Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AureispiraSpCcbqb1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aureispira sp. CCBQB1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AureispiraSpCcbqb1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ConiellaLustricolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Coniella lustricola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ConiellaLustricolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwb14014Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWB14014 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwb14014Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioHongkongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio hongkongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioHongkongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusSpJ39Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus sp. J39 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusSpJ39Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminiclostridiumThermocellum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Ruminiclostridium thermocellum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RuminiclostridiumThermocellum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SynechococcusSpCb0205Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Synechococcus sp. CB0205 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SynechococcusSpCb0205Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedobacterInsulaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter insulae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterInsulaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisMediterraneiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis mediterranei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisMediterraneiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacterEngbaekiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter engbaekii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterEngbaekiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsplowo202full4511(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPLOWO202FULL4511 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsplowo202full4511", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtopobiumSpBv3ac4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Atopobium sp. BV3Ac4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "AtopobiumSpBv3ac4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusAmylolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronococcus amylolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronococcusAmylolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytoplasmaSpVc33(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytoplasma sp. Vc33 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytoplasmaSpVc33", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPLOWO2_12_FULL_47_12 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsplowo212Full4712Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusSwuensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus swuensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSwuensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesParvulusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces parvulus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesParvulusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VeillonellaAtypicaKon(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Veillonella atypica KON graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VeillonellaAtypicaKon", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNatriegens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Vibrio natriegens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "VibrioNatriegens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumGelidilacusDsm15343(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium gelidilacus DSM 15343 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumGelidilacusDsm15343", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogranumRubrumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halogranum rubrum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalogranumRubrumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaBenthicaKt99(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Shewanella benthica KT99 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ShewanellaBenthicaKt99", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcremoniumChrysogenum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acremonium chrysogenum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcremoniumChrysogenum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HerbidosporaMongoliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Herbidospora mongoliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HerbidosporaMongoliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeri3(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri 3 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeri3", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobacteriumEndosymbiontCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return cyanobacterium endosymbiont Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanobacteriumEndosymbiontCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerfeziaBoudieriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terfezia boudieri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerfeziaBoudieriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumGilvumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium gilvum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumGilvumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterTjernbergiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter tjernbergiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterTjernbergiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumMarinumDsm44953Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium marinum DSM 44953 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumMarinumDsm44953Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobotrysOligosporaAtcc24927(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobotrys oligospora ATCC 24927 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobotrysOligosporaAtcc24927", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XenorhabdusDoucetiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Xenorhabdus doucetiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "XenorhabdusDoucetiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WolbachiaSpOocCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Ooc Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpOocCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LeptolyngbyaSpNies3755Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Leptolyngbya sp. NIES-3755 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LeptolyngbyaSpNies3755Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumAc3007Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium AC3007 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumAc3007Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium3146faaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 3146FAA Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium3146faaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaplasmaPhagocytophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anaplasma phagocytophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnaplasmaPhagocytophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FusobacteriumVariumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium varium Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumVariumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkalibacterSaccharofermentansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alkalibacter saccharofermentans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlkalibacterSaccharofermentansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaJaponica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella japonica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaJaponica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaDisparEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma dispar Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaDisparEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidaMaltosaXu316Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candida maltosa Xu316 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidaMaltosaXu316Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMucidolens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas mucidolens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasMucidolens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StruthioCamelusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Struthio camelus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StruthioCamelusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumSpGxf4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Methylobacterium sp. GXF4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MethylobacteriumSpGxf4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethanobrevibacterCuticularis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanobrevibacter cuticularis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanobrevibacterCuticularis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WohlfahrtiimonasLarvae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas larvae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasLarvae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMoranbacteriaBacteriumCg2304514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Moranbacteria bacterium CG2_30_45_14 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMoranbacteriaBacteriumCg2304514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HaloferaxMediterranei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferax mediterranei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferaxMediterranei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KuraishiaCapsulataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Kuraishia capsulata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "KuraishiaCapsulataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParabacteroidesSpMarseillep3160(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides sp. MarseilleP3160 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesSpMarseillep3160", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdlerbacteriaBacteriumRifcsplowo201full5116Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Adlerbacteria bacterium RIFCSPLOWO201FULL5116 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AdlerbacteriaBacteriumRifcsplowo201full5116Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriaceaeBacteriumT5br10b2g0(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium T5Br10B2g0 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumT5br10b2g0", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumOligotrophicumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium oligotrophicum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumOligotrophicumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMalodoratus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus malodoratus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMalodoratus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfarculusBaarsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfarculus baarsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfarculusBaarsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasMoraviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas moraviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasMoraviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumKoreense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium koreense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumKoreense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SerendipitaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Serendipita indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SerendipitaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelagibacterUbiqueHtcc8051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelagibacter ubique HTCC8051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelagibacterUbiqueHtcc8051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BartonellaSpWd121Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. WD12.1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpWd121Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalothiobacillusSpXi15Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halothiobacillus sp. XI15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalothiobacillusSpXi15Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TheileriaEquiStrainWa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Theileria equi strain WA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TheileriaEquiStrainWa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_01_FULL_46_24 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho201Full4624", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusXylanexedensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus xylanexedens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusXylanexedensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EpulopisciumSpNuni2hmbin001(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Epulopiscium sp. Nuni2HMBin001 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EpulopisciumSpNuni2hmbin001", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParamaledivibacterCaminithermalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paramaledivibacter caminithermalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParamaledivibacterCaminithermalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSediminisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sediminis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSediminisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AtopobiumSpF0209Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atopobium sp. F0209 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtopobiumSpF0209Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SyntrophusGentianaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Syntrophus gentianae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SyntrophusGentianaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PorphyrobacterSanguineusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Porphyrobacter sanguineus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PorphyrobacterSanguineusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MobiluncusMulierisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mobiluncus mulieris Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MobiluncusMulierisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PostiaPlacentaMad698rsb12(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Postia placenta MAD698RSB12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PostiaPlacentaMad698rsb12", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJicamaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium jicamae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumJicamaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusAminicenantesBacteriumRbg166630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Aminicenantes bacterium RBG_16_66_30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusAminicenantesBacteriumRbg166630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRbg163414(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RBG_16_34_14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRbg163414", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KocuriaRhizophilaDc2201Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Kocuria rhizophila DC2201 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "KocuriaRhizophilaDc2201Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PanTroglodytes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pan troglodytes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PanTroglodytes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumLuteum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium luteum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumLuteum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionZixibacteriaBacterium448495Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division Zixibacteria bacterium 4484_95 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionZixibacteriaBacterium448495Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronorubrumSulfidifaciens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum sulfidifaciens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumSulfidifaciens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumAmycolatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Corynebacterium amycolatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CorynebacteriumAmycolatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZobelliaGalactanivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Zobellia galactanivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ZobelliaGalactanivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxElongans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Haloferax elongans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HaloferaxElongans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MaricaulisMarisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Maricaulis maris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MaricaulisMarisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaldicoprobacterOshimai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Caldicoprobacter oshimai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CaldicoprobacterOshimai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DermacoccusSpPe3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dermacoccus sp. PE3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DermacoccusSpPe3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumCg1024416Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium CG1024416 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumCg1024416Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaGrenadensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nocardia grenadensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NocardiaGrenadensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParabacteroidesMassiliensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parabacteroides massiliensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParabacteroidesMassiliensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusOryzaeRib40Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Aspergillus oryzae RIB40 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AspergillusOryzaeRib40Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusSenegalensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus senegalensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusSenegalensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCollierbacteriaBacteriumGw2011Gwf24415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Collierbacteria bacterium GW2011_GWF2_44_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCollierbacteriaBacteriumGw2011Gwf24415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPLOWO2_01_FULL_50_28 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsplowo201Full5028Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaBarkeriMs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina barkeri MS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaBarkeriMs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasMaltophiliaR5513(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas maltophilia R5513 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasMaltophiliaR5513", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpDlviiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. DLVIII Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpDlviiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumSpUnccl10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Microbacterium sp. UNCCL10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MicrobacteriumSpUnccl10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaPipientis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia pipientis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaPipientis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumMarinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium marinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumMarinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSelangorensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus selangorensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusSelangorensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg134015Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG134015 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg134015Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpJs23(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. JS23 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpJs23", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanktomarinaTemperataEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Planktomarina temperata Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PlanktomarinaTemperataEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoesebacteriaBacteriumGw2011gwc2459Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Woesebacteria bacterium GW2011GWC2459 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WoesebacteriaBacteriumGw2011gwc2459Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpYr096Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. yr096 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpYr096Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCarsonellaRuddiiHcIsolateThao2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Carsonella ruddii HC isolate Thao2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusCarsonellaRuddiiHcIsolateThao2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichophytonEquinum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Trichophyton equinum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TrichophytonEquinum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSp32ow(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. 32OW graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSp32ow", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAssamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus assamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusAssamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadetesBacteriumScn7022(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium SCN 70-22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumScn7022", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GillisiaSpJm1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gillisia sp. JM1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GillisiaSpJm1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DickeyaDadantii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dickeya dadantii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DickeyaDadantii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterAlpinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter alpinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterAlpinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumSpWsm1743(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium sp. WSM1743 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumSpWsm1743", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DadabacteriaBacteriumRifcsphigho212full5321(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Dadabacteria bacterium RIFCSPHIGHO212FULL5321 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DadabacteriaBacteriumRifcsphigho212full5321", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterCapsiciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter capsici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterCapsiciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlr1721(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALR1721 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlr1721", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptobacteriumCurtumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium curtum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumCurtumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumKht7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium KHT7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumKht7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonasSpRcc299Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Micromonas sp. RCC299 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MicromonasSpRcc299Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodohalobacterHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodohalobacter halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodohalobacterHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TerribacillusAidingensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Terribacillus aidingensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TerribacillusAidingensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfitobacteriumDichloroeliminans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfitobacterium dichloroeliminans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfitobacteriumDichloroeliminans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSyringaePvTagetisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas syringae pv. tagetis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSyringaePvTagetisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalanaerobiumHydrogeniformansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halanaerobium hydrogeniformans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalanaerobiumHydrogeniformansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriaceaeBacteriumS85(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacteriaceae bacterium S85 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriaceaeBacteriumS85", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CollinsellaStercorisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Collinsella stercoris Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CollinsellaStercorisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FuchsiellaAlkaliacetigenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fuchsiella alkaliacetigena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FuchsiellaAlkaliacetigenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusMacrosporangiidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alicyclobacillus macrosporangiidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlicyclobacillusMacrosporangiidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumLevicorallinumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium levicorallinum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumLevicorallinumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AquimarinaAtlanticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Aquimarina atlantica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AquimarinaAtlanticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeoglobusSulfaticallidusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Archaeoglobus sulfaticallidus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArchaeoglobusSulfaticallidusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def IsoptericolaVariabilis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Isoptericola variabilis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "IsoptericolaVariabilis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophomonasWolfeiMethylbutyratica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophomonas wolfei methylbutyratica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophomonasWolfeiMethylbutyratica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FraserbacteriaBacteriumRbg16559(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fraserbacteria bacterium RBG16559 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FraserbacteriaBacteriumRbg16559", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AchlyaHypogyna(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Achlya hypogyna graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AchlyaHypogyna", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KingellaDenitrificansAtcc33394(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Kingella denitrificans ATCC 33394 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KingellaDenitrificansAtcc33394", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WoykebacteriaBacteriumRbg134015(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Woykebacteria bacterium RBG134015 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WoykebacteriaBacteriumRbg134015", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FungalSpNo11243Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return fungal sp. No.11243 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FungalSpNo11243Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycoplasmaYeatsiiGm274bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii GM274B Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaYeatsiiGm274bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumPhragmitis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium phragmitis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumPhragmitis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumYanniciiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium yannicii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumYanniciiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfotomaculumSp46296Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum sp. 46_296 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumSp46296Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomassiliicoccusLuminyensisB10(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanomassiliicoccus luminyensis B10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanomassiliicoccusLuminyensisB10", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanomethylophilusAlvus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanomethylophilus alvus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanomethylophilusAlvus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Citrobacter koseri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CitrobacterKoseri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudogymnoascusSpVkmf4513Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4513 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4513Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LegionellaFalloniiLlap10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Legionella fallonii LLAP-10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LegionellaFalloniiLlap10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronorubrumTibetense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronorubrum tibetense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronorubrumTibetense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporosarcinaNewyorkensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sporosarcina newyorkensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SporosarcinaNewyorkensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterArupensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter arupensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterArupensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirosomaRadiotolerans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spirosoma radiotolerans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpirosomaRadiotolerans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenibacterElegansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eisenibacter elegans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EisenibacterElegansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MetallosphaeraHakonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Metallosphaera hakonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MetallosphaeraHakonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharibacteriaBacteriumGw2011gwc2489Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium GW2011GWC2489 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumGw2011gwc2489Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CercosporaBerteroae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cercospora berteroae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CercosporaBerteroae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriumScgcAaa278o22(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return actinobacterium SCGC AAA278O22 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriumScgcAaa278o22", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLsjc280b00Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LSJC280B00 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLsjc280b00Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudogymnoascusSpVkmf4281Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudogymnoascus sp. VKMF4281 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudogymnoascusSpVkmf4281Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumMarseillep2935Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium MarseilleP2935 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumMarseillep2935Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychromonasOssibalaenae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychromonas ossibalaenae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychromonasOssibalaenae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf262Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf262 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf262Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHelveticusCnrz32Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus helveticus CNRZ32 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusHelveticusCnrz32Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonadaceaeBacteriumBrhc29(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonadaceae bacterium BRHc29 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HyphomonadaceaeBacteriumBrhc29", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesoflavibacterZeaxanthinifaciensDsm18436Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mesoflavibacter zeaxanthinifaciens DSM 18436 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MesoflavibacterZeaxanthinifaciensDsm18436Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusHydrothermaeBacteriumJdfr72Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Hydrothermae bacterium JdFR-72 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusHydrothermaeBacteriumJdfr72Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodomicrobiumUdaipurenseJa643Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rhodomicrobium udaipurense JA643 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RhodomicrobiumUdaipurenseJa643Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusLugdunensisHku0901(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus lugdunensis HKU0901 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusLugdunensisHku0901", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaBergeriaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Gemella bergeriae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GemellaBergeriaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaBacteriumGwa24115Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica bacterium GWA2_41_15 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaBacteriumGwa24115Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitansEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeumEquitansEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusThailandensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus thailandensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusThailandensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioRuberDsm16370(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Vibrio ruber DSM 16370 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "VibrioRuberDsm16370", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArenibacterNanhaiticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arenibacter nanhaiticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArenibacterNanhaiticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSp21331Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. 2133.1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSp21331Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FusobacteriumNucleatumAtcc25586Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fusobacterium nucleatum ATCC25586 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FusobacteriumNucleatumAtcc25586Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BombyxMoriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bombyx mori Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BombyxMoriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiaBrevicatenaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardia brevicatena Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiaBrevicatenaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CryptobacteriumCurtumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cryptobacterium curtum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CryptobacteriumCurtumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Blackburnbacteria bacterium RIFCSPHIGHO2_02_FULL_44_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusBlackburnbacteriaBacteriumRifcsphigho202Full4420", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def IgnavibacteriaBacteriumRifoxyc2full3825Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ignavibacteria bacterium RIFOXYC2FULL3825 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "IgnavibacteriaBacteriumRifoxyc2full3825Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeumEquitansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeum equitans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeumEquitansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Falkowbacteria bacterium RIFOXYC12_FULL_34_55 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusFalkowbacteriaBacteriumRifoxyc12Full3455Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EuryarchaeotaArchaeonRbg166727Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Euryarchaeota archaeon RBG_16_67_27 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EuryarchaeotaArchaeonRbg166727Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FictibacillusMacauensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fictibacillus macauensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FictibacillusMacauensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RuminococcusFlavefaciensMa2007Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Ruminococcus flavefaciens MA2007 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RuminococcusFlavefaciensMa2007Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumSpHmsc28b08(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. HMSC28B08 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpHmsc28b08", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LentzeaAerocolonigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lentzea aerocolonigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LentzeaAerocolonigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraInfestans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora infestans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraInfestans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OscillatoriaSpPcc10802Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoria sp. PCC10802 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatoriaSpPcc10802Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusUrinalis228597Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus urinalis 228597 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StreptococcusUrinalis228597Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JannaschiaSeosinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia seosinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JannaschiaSeosinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumPropinquumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium propinquum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumPropinquumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfohalotomaculumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfohalotomaculum alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfohalotomaculumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosarchaeumKoreenseMy1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Nitrosarchaeum koreense MY1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NitrosarchaeumKoreenseMy1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumViride(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium viride graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumViride", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumBrachiatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium brachiatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumBrachiatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiaBacteriumDtu030(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridia bacterium DTU030 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiaBacteriumDtu030", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusGottheilii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus gottheilii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusGottheilii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesocestoidesCortiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mesocestoides corti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MesocestoidesCortiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThermincolaPotensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermincola potens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermincolaPotensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PorphyromonasCangingivalis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Porphyromonas cangingivalis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PorphyromonasCangingivalis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcaceaeBacteriumD5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcaceae bacterium D5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcaceaeBacteriumD5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TropilaelapsMercedesaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tropilaelaps mercedesae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TropilaelapsMercedesaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AuxenochlorellaProtothecoides(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Auxenochlorella protothecoides graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AuxenochlorellaProtothecoides", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHokkaidonensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hokkaidonensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHokkaidonensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PericoniaMacrospinosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Periconia macrospinosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PericoniaMacrospinosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaBirminghamensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella birminghamensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaBirminghamensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SclerotiniaBorealis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sclerotinia borealis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SclerotiniaBorealis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFloricolaDsm23037Jcm16512Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus floricola DSM 23037 JCM 16512 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFloricolaDsm23037Jcm16512Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylocaldumSzegedienseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocaldum szegediense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocaldumSzegedienseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerriglobusSaanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Terriglobus saanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TerriglobusSaanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PontibacterSpS108Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pontibacter sp. S10-8 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PontibacterSpS108Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArthrobacterSpUnc362mftsu51(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Arthrobacter sp. UNC362MFTsu51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ArthrobacterSpUnc362mftsu51", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpChol1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas sp. Chol1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasSpChol1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NocardiaYamanashiensisNbrc100130Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Nocardia yamanashiensis NBRC 100130 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NocardiaYamanashiensisNbrc100130Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BlattabacteriumSpMadarCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. MADAR Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpMadarCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EscherichiaColiK12Mg1655Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.0", **kwargs
) -> Graph:
    """Return Escherichia coli K12 MG1655 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
    """
    return RetrievedGraph(
        "EscherichiaColiK12Mg1655Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusAmylolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Anoxybacillus amylolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AnoxybacillusAmylolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BhargavaeaCecembensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bhargavaea cecembensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BhargavaeaCecembensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylothermaceaeBacteria(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylothermaceae bacteria graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylothermaceaeBacteria", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcidobacteriaBacteriumRifcsplowo202full6415Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium RIFCSPLOWO202FULL6415 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumRifcsplowo202full6415Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaEnzanensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinokineospora enzanensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinokineosporaEnzanensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolynucleobacterSinensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sinensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSinensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumGwe23716Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium GWE2_37_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumGwe23716Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumErythrophlei(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bradyrhizobium erythrophlei graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BradyrhizobiumErythrophlei", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlattabacteriumSpBge(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Blattabacterium sp. Bge graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BlattabacteriumSpBge", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumTaibaishanenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium taibaishanense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTaibaishanenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChitinophagaNiabensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chitinophaga niabensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChitinophagaNiabensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusContaminansCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus contaminans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParacoccusContaminansCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumSelenitireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium selenitireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSelenitireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirochaetaLuteaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spirochaeta lutea Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpirochaetaLuteaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaSpBma(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.0", **kwargs
) -> Graph:
    """Return Wolbachia sp. Bma graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
    """
    return RetrievedGraph(
        "WolbachiaSpBma", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChlorellaVariabilisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlorella variabilis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlorellaVariabilisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpUrhd0024Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. URHD0024 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpUrhd0024Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteroidesFrankliniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacteroides franklinii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteroidesFrankliniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YarrowiaLipolyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Yarrowia lipolytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "YarrowiaLipolyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhytophthoraNicotianaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Phytophthora nicotianae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhytophthoraNicotianaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudocercosporaMusae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudocercospora musae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudocercosporaMusae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DerxiaLacustris(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Derxia lacustris graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DerxiaLacustris", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArchaeonGw2011ar5Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return archaeon GW2011AR5 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArchaeonGw2011ar5Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VogelbacteriaBacteriumRifoxyb1full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vogelbacteria bacterium RIFOXYB1FULL4216 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VogelbacteriaBacteriumRifoxyb1full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OryzaGlumipatula(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza glumipatula graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaGlumipatula", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpUrha0033Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. URHA0033 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpUrha0033Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FrankiaAsymbioticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia asymbiotica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaAsymbioticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasSpGr602(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. GR 6-02 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpGr602", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaPtyseosCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tatumella ptyseos Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TatumellaPtyseosCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiaSibirica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia sibirica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaSibirica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FerrithrixThermotoleransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Ferrithrix thermotolerans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FerrithrixThermotoleransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterSchindleriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter schindleri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSchindleriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodobacterSpCacia14h1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodobacter sp. CACIA14H1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodobacterSpCacia14h1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Levybacteria bacterium RIFCSPHIGHO2_01_FULL_40_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusLevybacteriaBacteriumRifcsphigho201Full4016Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFf9(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FF9 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFf9", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterobacterTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Enterobacter timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EnterobacterTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastococcusSpUrhd0036Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Blastococcus sp. URHD0036 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BlastococcusSpUrhd0036Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GranulibacterBethesdensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Granulibacter bethesdensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GranulibacterBethesdensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaCoronataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Puccinia coronata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PucciniaCoronataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XylariaFlabelliformis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xylaria flabelliformis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XylariaFlabelliformis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TarenayaHasslerianaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Tarenaya hassleriana Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "TarenayaHasslerianaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumCallunae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium callunae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumCallunae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrotetrasporaMalaysiensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microtetraspora malaysiensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrotetrasporaMalaysiensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FirmicutesBacteriumCag65Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Firmicutes bacterium CAG:65 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FirmicutesBacteriumCag65Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StenotrophomonasNitritireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stenotrophomonas nitritireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StenotrophomonasNitritireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HortaeaWerneckiiExf2000Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Hortaea werneckii EXF-2000 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HortaeaWerneckiiExf2000Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseiflexusCastenholziiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Roseiflexus castenholzii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RoseiflexusCastenholziiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChlamydiaeBacteriumRifcsplowo212full4520Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chlamydiae bacterium RIFCSPLOWO212FULL4520 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChlamydiaeBacteriumRifcsplowo212full4520Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HoefleaSpBrhc9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hoeflea sp. BRHc9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HoefleaSpBrhc9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGilvosporeusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces gilvosporeus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGilvosporeusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AuraticoccusMonumenti(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Auraticoccus monumenti graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AuraticoccusMonumenti", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycolicibacteriumChubuenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium chubuense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumChubuenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfurisphaeraTokodaiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sulfurisphaera tokodaii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SulfurisphaeraTokodaiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GordoniaEffusaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gordonia effusa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GordoniaEffusaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhenylobacteriumZucineum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Phenylobacterium zucineum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhenylobacteriumZucineum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterVadiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter vadi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PolaribacterVadiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacteriumVacuolatumDsm3385Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacterium vacuolatum DSM 3385 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobacteriumVacuolatumDsm3385Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusHordeiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hordei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHordeiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumTibeticumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium tibeticum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumTibeticumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SpiribacterSalinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Spiribacter salinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SpiribacterSalinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlphaproteobacteriaBacteriumGwf25820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alphaproteobacteria bacterium GWF2_58_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlphaproteobacteriaBacteriumGwf25820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusAlveiTs15Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Paenibacillus alvei TS15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PaenibacillusAlveiTs15Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6423(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6423 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6423", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMeningitidisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Neisseria meningitidis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMeningitidisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalogeometricumBorinquenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halogeometricum borinquense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalogeometricumBorinquenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarininemaMesophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marininema mesophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarininemaMesophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MetschnikowiaSpJcm33374Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Metschnikowia sp. JCM 33374 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MetschnikowiaSpJcm33374Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharibacteriaBacteriumCg2304152Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Saccharibacteria bacterium CG2304152 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SaccharibacteriaBacteriumCg2304152Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TaylorbacteriaBacteriumRifcsphigho202full4412Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Taylorbacteria bacterium RIFCSPHIGHO202FULL4412 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TaylorbacteriaBacteriumRifcsphigho202full4412Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacteriumAurumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacterium aurum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycolicibacteriumAurumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusSaccharimonasAalborgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Saccharimonas aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSaccharimonasAalborgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumXenopiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium xenopi Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumXenopiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GordoniaMalaquae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gordonia malaquae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GordoniaMalaquae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PlanomonosporaSphaericaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Planomonospora sphaerica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PlanomonosporaSphaericaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CryobacteriumFlavumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cryobacterium flavum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CryobacteriumFlavumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CaproniaEpimycesEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capronia epimyces Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaproniaEpimycesEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KinetoplastibacteriumDesouzaii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kinetoplastibacterium desouzaii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KinetoplastibacteriumDesouzaii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumRifcsphigho201full5436Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium RIFCSPHIGHO201FULL5436 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumRifcsphigho201full5436Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PropionimicrobiumLymphophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Propionimicrobium lymphophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PropionimicrobiumLymphophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeodermatophilusRuber(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilus ruber graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilusRuber", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumRufum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Mycobacterium rufum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MycobacteriumRufum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusSpJcm19058(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. JCM 19058 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusSpJcm19058", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacteriumMc2017Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium MC2017 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumMc2017Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BartonellaSpRaccoon60(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bartonella sp. Raccoon60 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BartonellaSpRaccoon60", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenobacterThermophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenobacter thermophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrogenobacterThermophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumKashiwanohense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium kashiwanohense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumKashiwanohense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RuminococcusSpCag382Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Ruminococcus sp. CAG:382 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RuminococcusSpCag382Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FaecalibacteriumPrausnitziiSl33Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Faecalibacterium prausnitzii SL33 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "FaecalibacteriumPrausnitziiSl33Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumBaratiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium baratii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumBaratiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidovoraxRadicisN35Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acidovorax radicis N35 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcidovoraxRadicisN35Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NatronincolaPeptidivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Natronincola peptidivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NatronincolaPeptidivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MesorhizobiumSpLnhc252b00(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mesorhizobium sp. LNHC252B00 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MesorhizobiumSpLnhc252b00", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumGa0077560(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium Ga0077560 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumGa0077560", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NanoarchaeotaArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleurotusOstreatusPc15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pleurotus ostreatus PC15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PleurotusOstreatusPc15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NomurabacteriaBacteriumRifcsphigho201full37110(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO201FULL37110 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho201full37110", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlicyclobacillusPohliaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Alicyclobacillus pohliae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AlicyclobacillusPohliaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusMethanomethylicusMesodigestumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Methanomethylicus mesodigestum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusMethanomethylicusMesodigestumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DaphniaPulex(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Daphnia pulex graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DaphniaPulex", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParacoccusChinensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paracoccus chinensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParacoccusChinensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpSw1Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. SW1 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpSw1Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylomicrobiumAlcaliphilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylomicrobium alcaliphilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylomicrobiumAlcaliphilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinokineosporaSpEg49Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinokineospora sp. EG49 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinokineosporaSpEg49Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AgrobacteriumVitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium vitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumVitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBathyarchaeotaArchaeonBa1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Bathyarchaeota archaeon BA1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusBathyarchaeotaArchaeonBa1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YamadazymaTenuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yamadazyma tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YamadazymaTenuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSpF0234Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0234 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0234Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SilvibacteriumBohemicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Silvibacterium bohemicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SilvibacteriumBohemicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermosyntrophaLipolyticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thermosyntropha lipolytica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThermosyntrophaLipolyticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OlsenellaUliEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella uli Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaUliEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def UrinicoccusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Urinicoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "UrinicoccusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NomurabacteriaBacteriumRifcsphigho212full4219(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nomurabacteria bacterium RIFCSPHIGHO212FULL4219 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NomurabacteriaBacteriumRifcsphigho212full4219", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeinococcusSpRlEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Deinococcus sp. RL Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DeinococcusSpRlEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc5600Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 5600 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc5600Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfurispirillumIndicum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurispirillum indicum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurispirillumIndicum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MastigocladopsisRepensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Mastigocladopsis repens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MastigocladopsisRepensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasByunsanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas byunsanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasByunsanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PacificibacterMarinusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pacificibacter marinus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PacificibacterMarinusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YonathbacteriaBacteriumRifcsphigho201full4441Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yonathbacteria bacterium RIFCSPHIGHO201FULL4441 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YonathbacteriaBacteriumRifcsphigho201full4441Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellaBurnetii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coxiella burnetii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoxiellaBurnetii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MolaMola(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mola mola graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MolaMola", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronomonasPharaonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natronomonas pharaonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatronomonasPharaonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ZymobacterPalmaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Zymobacter palmae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ZymobacterPalmaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ImhoffiellaPurpureaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Imhoffiella purpurea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ImhoffiellaPurpureaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumAurum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium aurum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumAurum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ProchlorococcusMarinusMit9313Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prochlorococcus marinus MIT9313 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ProchlorococcusMarinusMit9313Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteriovoraxSpMedpeswde(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteriovorax sp. MedPESWde graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteriovoraxSpMedpeswde", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpIhbB17019Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. IHB B 17019 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ChryseobacteriumSpIhbB17019Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DongiaSpUrhe0060Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dongia sp. URHE0060 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DongiaSpUrhe0060Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CoxiellalikeEndosymbiont(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Coxiellalike endosymbiont graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CoxiellalikeEndosymbiont", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaWadsworthiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella wadsworthii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaWadsworthiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OceanobacterKriegiiDsm6294(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii DSM 6294 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "OceanobacterKriegiiDsm6294", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtelocyanobacteriumThalassaSio64986(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Atelocyanobacterium thalassa SIO64986 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AtelocyanobacteriumThalassaSio64986", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PenicilliumExpansumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Penicillium expansum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PenicilliumExpansumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTremblayaPhenacolaPaveEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Tremblaya phenacola PAVE Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTremblayaPhenacolaPaveEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsilocybeCyanescens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psilocybe cyanescens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsilocybeCyanescens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium RIFCSPLOWO2_01_FULL_45_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumRifcsplowo201Full4519", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalophilicArchaeonDl31(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return halophilic archaeon DL31 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalophilicArchaeonDl31", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaSp9145Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Erwinia sp. 9145 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ErwiniaSp9145Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusHoagii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus hoagii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodococcusHoagii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NematocidaDisplodereEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nematocida displodere Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NematocidaDisplodereEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Chisholmbacteria bacterium RIFCSPHIGHO2_01_FULL_48_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusChisholmbacteriaBacteriumRifcsphigho201Full4812", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioAzureusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Vibrio azureus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "VibrioAzureusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NanoarchaeotaArchaeonScgcAaa011G17(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Nanoarchaeota archaeon SCGC AAA011-G17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NanoarchaeotaArchaeonScgcAaa011G17", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JuglansRegiaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Juglans regia Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JuglansRegiaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusGhanensisDsm18630Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus ghanensis DSM 18630 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "LactobacillusGhanensisDsm18630Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ExiguobacteriumSpZwu0009(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Exiguobacterium sp. ZWU0009 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ExiguobacteriumSpZwu0009", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotorhabdusHeterorhabditis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Photorhabdus heterorhabditis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PhotorhabdusHeterorhabditis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumLavalenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] lavalense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumLavalenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylobacterLuteusImvB3098(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methylobacter luteus IMV-B-3098 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethylobacterLuteusImvB3098", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrospiraeBacteriumJdfr86Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrospirae bacterium JdFR-86 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrospiraeBacteriumJdfr86Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusAcetotoleransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus acetotolerans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusAcetotoleransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChristensenellaceaeBacteriumPhil7Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Christensenellaceae bacterium Phil7 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChristensenellaceaeBacteriumPhil7Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesVaccimaxillaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces vaccimaxillae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesVaccimaxillaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OscillatorialesCyanobacteriumCg2304061Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Oscillatoriales cyanobacterium CG2_30_40_61 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OscillatorialesCyanobacteriumCg2304061Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GottesmanbacteriaBacteriumRifcsphigho201full3910(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gottesmanbacteria bacterium RIFCSPHIGHO201FULL3910 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GottesmanbacteriaBacteriumRifcsphigho201full3910", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrobaculumAerophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum aerophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumAerophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BeauveriaBassianaArsef2860Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Beauveria bassiana ARSEF 2860 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BeauveriaBassianaArsef2860Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RickettsiellaGrylli(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella grylli graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaGrylli", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Campbellbacteria bacterium RIFCSPLOWO2_01_FULL_34_15 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusCampbellbacteriaBacteriumRifcsplowo201Full3415Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrocadiaCaroliniensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Brocadia caroliniensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BrocadiaCaroliniensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfurobacteriumThermolithotrophum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfurobacterium thermolithotrophum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfurobacteriumThermolithotrophum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusTimonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus timonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusTimonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThioalkalivibrioThiocyanodenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio thiocyanodenitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioThiocyanodenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaHyopneumoniae232Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma hyopneumoniae 232 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaHyopneumoniae232Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusRubiinfantisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus rubiinfantis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusRubiinfantisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrancisellaPersicaAtccVr331(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Francisella persica ATCC VR-331 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FrancisellaPersicaAtccVr331", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Taylorbacteria bacterium RIFOXYD2_FULL_36_9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusTaylorbacteriaBacteriumRifoxyd2Full369Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesSpCag1060(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides sp. CAG:1060 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacteroidesSpCag1060", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MacacaFascicularisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Macaca fascicularis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MacacaFascicularisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TatumellaSpUcddsuzukii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tatumella sp. UCDDsuzukii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TatumellaSpUcddsuzukii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterSpClo3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Helicobacter sp. CLO-3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HelicobacterSpClo3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulophagaLytica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cellulophaga lytica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CellulophagaLytica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BifidobacteriumCatenulatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bifidobacterium catenulatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BifidobacteriumCatenulatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusSpFjat26967(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus sp. FJAT-26967 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusSpFjat26967", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelioribacterRoseusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melioribacter roseus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelioribacterRoseusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PaenibacillusDurusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus durus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusDurusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetanaerobacteriumElongatum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acetanaerobacterium elongatum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcetanaerobacteriumElongatum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpHn41Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. HN-41 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpHn41Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudodesulfovibrioIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudodesulfovibrio indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudodesulfovibrioIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GallibacteriumSalpingitidisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gallibacterium salpingitidis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GallibacteriumSalpingitidisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsinibacteriumSpOr53Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Asinibacterium sp. OR53 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AsinibacteriumSpOr53Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BrevibacillusBorstelensisAk1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Brevibacillus borstelensis AK1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BrevibacillusBorstelensisAk1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosarchaeumLimnium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Nitrosarchaeum limnium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NitrosarchaeumLimnium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SyntrophaceaeBacteriumCg2304912(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Syntrophaceae bacterium CG2_30_49_12 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SyntrophaceaeBacteriumCg2304912", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfovibrioGracilisDsm16080Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfovibrio gracilis DSM 16080 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfovibrioGracilisDsm16080Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SaccharothrixSpNrrlb16314Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Saccharothrix sp. NRRLB16314 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SaccharothrixSpNrrlb16314Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MucilaginibacterSpPpcgb2223Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mucilaginibacter sp. PPCGB 2223 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MucilaginibacterSpPpcgb2223Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacteroidalesBacteriumBact19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidales bacterium Bact_19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidalesBacteriumBact19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumXbb2008Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium XBB2008 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumXbb2008Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriaBacteriumScn6937Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acidobacteria bacterium SCN 69-37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriaBacteriumScn6937Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlobisporangiumUltimumDaomBr144(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Globisporangium ultimum DAOM BR144 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GlobisporangiumUltimumDaomBr144", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseivivaxLentusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Roseivivax lentus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RoseivivaxLentusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterLipolyticusSm19Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter lipolyticus SM19 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterLipolyticusSm19Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusPseudintermediusHku1003Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus pseudintermedius HKU10-03 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusPseudintermediusHku1003Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlkaliphilusOremlandiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus oremlandii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusOremlandiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpUnc23mfcrub11(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rhodococcus sp. UNC23MFCrub11 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RhodococcusSpUnc23mfcrub11", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinospirillumAlkaliphilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinospirillum alkaliphilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinospirillumAlkaliphilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalinicoccusHaloduransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinicoccus halodurans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinicoccusHaloduransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylobacteriumPlatani(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylobacterium platani graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethylobacteriumPlatani", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AccumulibacterAalborgensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter aalborgensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterAalborgensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SagittulaStellataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sagittula stellata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SagittulaStellataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def OmnitrophicaWor2BacteriumRifcsplowo212full6316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Omnitrophica WOR2 bacterium RIFCSPLOWO212FULL6316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "OmnitrophicaWor2BacteriumRifcsplowo212full6316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GiovannonibacteriaBacteriumRifcsplowo212full4432Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Giovannonibacteria bacterium RIFCSPLOWO212FULL4432 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GiovannonibacteriaBacteriumRifcsplowo212full4432Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeregrinibacteriaBacteriumGw2011gwa2447(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peregrinibacteria bacterium GW2011GWA2447 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeregrinibacteriaBacteriumGw2011gwa2447", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferacaceaeArchaeonCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haloferacaceae archaeon Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaloferacaceaeArchaeonCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FulvivirgaImtechensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Fulvivirga imtechensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FulvivirgaImtechensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThiobacillusSpScn65179Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thiobacillus sp. SCN 65-179 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThiobacillusSpScn65179Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacteraceaeBacterium501bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacteraceae bacterium 501b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "XanthobacteraceaeBacterium501bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusHammesii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus hammesii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LactobacillusHammesii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StappiaIndica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Stappia indica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StappiaIndica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Roizmanbacteria bacterium RIFOXYC1_FULL_38_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRoizmanbacteriaBacteriumRifoxyc1Full3814Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar86ClusterBacteriumSar86a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return SAR86 cluster bacterium SAR86A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "Sar86ClusterBacteriumSar86a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrososphaeraGargensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nitrososphaera gargensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NitrososphaeraGargensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpCetp13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. CETP13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpCetp13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NiastellaViciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Niastella vici Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NiastellaViciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CampylobacterHyointestinalisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter hyointestinalis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterHyointestinalisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24721Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24721 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24721Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WilliamwhitmaniaTaraxaciCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Williamwhitmania taraxaci Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WilliamwhitmaniaTaraxaciCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TreponemaBrennaborenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Treponema brennaborense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TreponemaBrennaborenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfovibrioLongusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfovibrio longus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfovibrioLongusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterSpR2019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter sp. R2019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PedobacterSpR2019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingobacterialesBacterium5039Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingobacteriales bacterium 50-39 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingobacterialesBacterium5039Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CurtobacteriumAmmoniigenesCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Curtobacterium ammoniigenes Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CurtobacteriumAmmoniigenesCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasPoae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas poae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudomonasPoae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasBalearicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas balearica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasBalearicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanopyrusKandleriAv19(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanopyrus kandleri AV19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanopyrusKandleriAv19", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CroceitaleaDokdonensisDokdo023Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Croceitalea dokdonensis DOKDO 023 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CroceitaleaDokdonensisDokdo023Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NesterenkoniaMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nesterenkonia massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NesterenkoniaMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesBouchesdurhonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces bouchesdurhonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinomycesBouchesdurhonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthobacterSp126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthobacter sp. 126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthobacterSp126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ZetaproteobacteriaBacteriumCg10255237(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Zetaproteobacteria bacterium CG1_02_55_237 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ZetaproteobacteriaBacteriumCg10255237", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalorubrumAidingense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halorubrum aidingense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalorubrumAidingense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpSrs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. SRS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpSrs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaSaccharolyticaF0055Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Prevotella saccharolytica F0055 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PrevotellaSaccharolyticaF0055Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumMedpe(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium MedPE graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumMedpe", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitrobacterKoseriAtccBaa895(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Citrobacter koseri ATCC BAA-895 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CitrobacterKoseriAtccBaa895", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Salmonella enterica subsp. salamae serovar 56:z10:e,n,x str. 1369-73 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SalmonellaEntericaSubspSalamaeSerovar56Z10ENXStr136973", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AerococcusViridansAtcc11563Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aerococcus viridans ATCC11563 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AerococcusViridansAtcc11563Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethyloteneraMobilisJlw8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methylotenera mobilis JLW8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethyloteneraMobilisJlw8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErwiniaPersicinaNbrc102418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Erwinia persicina NBRC 102418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ErwiniaPersicinaNbrc102418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAnginosusC1051(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus anginosus C1051 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAnginosusC1051", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumSpFh1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium sp. FH1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumSpFh1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfPoeciloscleridaSpNCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Poecilosclerida sp. N Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfPoeciloscleridaSpNCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ProchlorococcusSpRs01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prochlorococcus sp. RS01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ProchlorococcusSpRs01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FervidobacteriumThailandenseEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Fervidobacterium thailandense Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FervidobacteriumThailandenseEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpNfr07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. NFR07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpNfr07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ImhoffiellaPurpurea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Imhoffiella purpurea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ImhoffiellaPurpurea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricibacterSanguinisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Turicibacter sanguinis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TuricibacterSanguinisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycolicibacterMinnesotensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycolicibacter minnesotensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycolicibacterMinnesotensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FrankiaElaeagniEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Frankia elaeagni Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FrankiaElaeagniEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingobacteriumSpAccc05744Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Sphingobacterium sp. ACCC05744 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SphingobacteriumSpAccc05744Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudonocardiaAutotrophica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudonocardia autotrophica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudonocardiaAutotrophica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumRhizophilum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SporanaerobacterAcetigenes(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sporanaerobacter acetigenes graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SporanaerobacterAcetigenes", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylophagaFrappieriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Methylophaga frappieri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MethylophagaFrappieriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MelainabacteriaBacterium3541(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Melainabacteria bacterium 3541 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MelainabacteriaBacterium3541", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichurisTrichiura(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Trichuris trichiura graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TrichurisTrichiura", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CycloclasticusSpSymbiontOfBathymodiolusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cycloclasticus sp. symbiont of Bathymodiolus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CycloclasticusSpSymbiontOfBathymodiolusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaliangiumOchraceumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Haliangium ochraceum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HaliangiumOchraceumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SelenomonasArtemidisF0399(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Selenomonas artemidis F0399 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SelenomonasArtemidisF0399", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThaueraButanivoransNbrc103042(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thauera butanivorans NBRC 103042 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThaueraButanivoransNbrc103042", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParapedobacterIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parapedobacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParapedobacterIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BathyarchaeotaArchaeonRbg135212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bathyarchaeota archaeon RBG135212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BathyarchaeotaArchaeonRbg135212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CapnocytophagaSpF0087Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Capnocytophaga sp. F0087 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CapnocytophagaSpF0087Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LachnospiraceaeBacterium2146faa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium 2146FAA graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacterium2146faa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LegionellaRubrilucensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Legionella rubrilucens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LegionellaRubrilucensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MethylocystisSpSc2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylocystis sp. SC2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylocystisSpSc2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusKoreensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus koreensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusKoreensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AtribacteriaBacterium34128Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Atribacteria bacterium 34_128 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AtribacteriaBacterium34128Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinobacteriaBacteriumCg23050142Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium CG2_30_50_142 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumCg23050142Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusBrocadiaSpUtamx2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Brocadia sp. UTAMX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusBrocadiaSpUtamx2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumCavendishiiDsm21758(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium cavendishii DSM 21758 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumCavendishiiDsm21758", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DipodomysOrdiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dipodomys ordii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DipodomysOrdiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StappiaStellulataDsm5886Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Stappia stellulata DSM 5886 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "StappiaStellulataDsm5886Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacteriumRhizophilumDsm18822Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacterium rhizophilum DSM 18822 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacteriumRhizophilumDsm18822Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterCorcagiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter corcagiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CampylobacterCorcagiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KaiserbacteriaBacteriumGw2011gwa25212Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Kaiserbacteria bacterium GW2011GWA25212 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KaiserbacteriaBacteriumGw2011gwa25212Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinovumAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Marinovum algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MarinovumAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpOralTaxon807Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Olsenella sp. oral taxon 807 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "OlsenellaSpOralTaxon807Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DevosiaGeojensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Devosia geojensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DevosiaGeojensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HahellaChejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hahella chejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HahellaChejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Doudnabacteria bacterium RIFCSPHIGHO2_02_FULL_46_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDoudnabacteriaBacteriumRifcsphigho202Full4611Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PaenibacillusOryzaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Paenibacillus oryzae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PaenibacillusOryzaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OceanobacterKriegii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oceanobacter kriegii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OceanobacterKriegii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusRokubacteriaBacterium13140cm6927Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Rokubacteria bacterium 13_1_40CM_69_27 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusRokubacteriaBacterium13140cm6927Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusOleiagriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus oleiagri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusOleiagriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumKetosireducensCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ketosireducens Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumKetosireducensCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterMedellinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Komagataeibacter medellinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KomagataeibacterMedellinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinomycesCardiffensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces cardiffensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesCardiffensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def FlavobacteriumSaccharophilumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Flavobacterium saccharophilum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FlavobacteriumSaccharophilumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GammaproteobacteriaBacteriumSg830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium SG8_30 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumSg830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kaiserbacteria bacterium RIFCSPHIGHO2_02_FULL_55_20 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusKaiserbacteriaBacteriumRifcsphigho202Full5520", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls1777Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1777 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1777Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpKc8(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. KC8 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpKc8", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FelisCatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Felis catus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FelisCatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CruoricaptorIgnavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cruoricaptor ignavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CruoricaptorIgnavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TessaracoccusMassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus massiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusMassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TepidiphilusMargaritifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tepidiphilus margaritifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TepidiphilusMargaritifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HelicobacterPyloriSa213aEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Helicobacter pylori SA213A Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HelicobacterPyloriSa213aEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpEs1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. ES1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpEs1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusNomurabacteriaBacteriumGw2011Gwc23941(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Nomurabacteria bacterium GW2011_GWC2_39_41 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusNomurabacteriaBacteriumGw2011Gwc23941", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsticcacaulisExcentricusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asticcacaulis excentricus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsticcacaulisExcentricusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WenyingzhuangiaFucanilyticaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Wenyingzhuangia fucanilytica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "WenyingzhuangiaFucanilyticaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls1777Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS1777 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls1777Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VariovoraxSpCf079Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Variovorax sp. CF079 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VariovoraxSpCf079Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel131208Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_31_208 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel131208Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatronococcusJeotgaliDsm18795Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Natronococcus jeotgali DSM 18795 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NatronococcusJeotgaliDsm18795Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LiptonbacteriaBacteriumRifcsphigho201full5728Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Liptonbacteria bacterium RIFCSPHIGHO201FULL5728 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LiptonbacteriaBacteriumRifcsphigho201full5728Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpCag1185Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. CAG:1185 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpCag1185Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuberMelanosporum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Tuber melanosporum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TuberMelanosporum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CorynebacteriumSpKpl1995Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium sp. KPL1995 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumSpKpl1995Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gemella Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GemellaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NitrosococcusHalophilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nitrosococcus halophilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NitrosococcusHalophilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NocardiopsisListeriEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nocardiopsis listeri Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NocardiopsisListeriEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnoxybacillusFlavithermusTno09006Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Anoxybacillus flavithermus TNO09006 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "AnoxybacillusFlavithermusTno09006Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlgoriphagusSpA40Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Algoriphagus sp. A40 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlgoriphagusSpA40Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StaphylococcusEpidermidisAtcc12228(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Staphylococcus epidermidis ATCC12228 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StaphylococcusEpidermidisAtcc12228", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiromycesFinnis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Piromyces finnis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PiromycesFinnis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeobacillusJurassicusNbrc107829Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Geobacillus jurassicus NBRC 107829 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "GeobacillusJurassicusNbrc107829Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GeobacterLovleyi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Geobacter lovleyi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GeobacterLovleyi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KwoniellaMangroviensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Kwoniella mangroviensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "KwoniellaMangroviensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusVarians(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysinibacillus varians graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysinibacillusVarians", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WolbachiaEndosymbiontOfDactylopius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Wolbachia endosymbiont of Dactylopius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "WolbachiaEndosymbiontOfDactylopius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpongiibacterTropicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Spongiibacter tropicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SpongiibacterTropicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGuanduensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces guanduensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesGuanduensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EremococcusColeocolaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Eremococcus coleocola Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EremococcusColeocolaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MassiliaSpRoot418Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Massilia sp. Root418 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MassiliaSpRoot418Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSp85200251057sch5723018Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. 85200251057SCH5723018 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSp85200251057sch5723018Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusSaccharolyticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Halococcus saccharolyticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HalococcusSaccharolyticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpAnc4999Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. ANC 4999 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpAnc4999Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridialesBacteriumFirm13Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium Firm_13 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumFirm13Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrevundimonasSpGw460121014lb2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Brevundimonas sp. GW460121014LB2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BrevundimonasSpGw460121014lb2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CorynebacteriumAtypicumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Corynebacterium atypicum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CorynebacteriumAtypicumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ElizabethkingiaAnophelis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Elizabethkingia anophelis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ElizabethkingiaAnophelis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalospiraHalophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiohalospira halophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiohalospiraHalophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpNrrls646Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. NRRLS646 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpNrrls646Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanidioschyzonMerolaeStrain10d(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Cyanidioschyzon merolae strain 10D graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CyanidioschyzonMerolaeStrain10d", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalogranumRubrum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halogranum rubrum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalogranumRubrum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PantoeaSpSc1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pantoea sp. Sc1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PantoeaSpSc1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpCf394Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. CF394 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpCf394Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EubacteriumSpCag786Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Eubacterium sp. CAG:786 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "EubacteriumSpCag786Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichoplaxSpH2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trichoplax sp. H2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrichoplaxSpH2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcinetobacterHaemolyticus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter haemolyticus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterHaemolyticus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaShayeganiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria shayeganii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaShayeganiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudovibrioAxinellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio axinellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAxinellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArachidicoccusSpBs20Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Arachidicoccus sp. BS20 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ArachidicoccusSpBs20Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasStutzeriNf13Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri NF13 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriNf13Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MicrobacteriumGinsengisoliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium ginsengisoli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumGinsengisoliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DiaphorobacterSpJ551(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Diaphorobacter sp. J5-51 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DiaphorobacterSpJ551", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BavariicoccusSeileriCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bavariicoccus seileri Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BavariicoccusSeileriCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StreptococcusThoraltensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus thoraltensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusThoraltensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusSpWkb10Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus sp. wkB10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusSpWkb10Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MegasphaeraSpBv3c161(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Megasphaera sp. BV3C161 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MegasphaeraSpBv3c161", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LevybacteriaBacteriumRifcsphigho202full4212(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Levybacteria bacterium RIFCSPHIGHO202FULL4212 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LevybacteriaBacteriumRifcsphigho202full4212", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumFimetarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return [Clostridium] fimetarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumFimetarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BurkholderiaMalleiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Burkholderia mallei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BurkholderiaMalleiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlgiphilusAromaticivoransEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Algiphilus aromaticivorans Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlgiphilusAromaticivoransEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidesPropionicifaciensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacteroides propionicifaciens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacteroidesPropionicifaciensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermacetogeniumPhaeum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thermacetogenium phaeum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThermacetogeniumPhaeum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PelobacterCarbinolicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pelobacter carbinolicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PelobacterCarbinolicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YanofskybacteriaBacteriumRifcsphigho201full4126(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yanofskybacteria bacterium RIFCSPHIGHO201FULL4126 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YanofskybacteriaBacteriumRifcsphigho201full4126", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanolobusSpT824Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methanolobus sp. T82-4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethanolobusSpT824Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def KnoelliaFlavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Knoellia flava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "KnoelliaFlavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Jorgensenbacteria bacterium GW2011_GWB1_50_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusJorgensenbacteriaBacteriumGw2011Gwb15010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PontibacillusChungwhensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pontibacillus chungwhensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PontibacillusChungwhensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MollicutesBacteriumHr2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Mollicutes bacterium HR2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "MollicutesBacteriumHr2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudomonasSpLfm046Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudomonas sp. LFM046 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudomonasSpLfm046Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumCauenseR2a7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium cauense R2A-7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumCauenseR2a7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemmatirosaKalamazoonesisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gemmatirosa kalamazoonesis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GemmatirosaKalamazoonesisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AnaerocolumnaAminovalerica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerocolumna aminovalerica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerocolumnaAminovalerica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpUrha0019Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. URHA0019 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpUrha0019Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ColwellbacteriaBacteriumRifcsphigho212full4417Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colwellbacteria bacterium RIFCSPHIGHO212FULL4417 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColwellbacteriaBacteriumRifcsphigho212full4417Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeokomagataeaThailandicaNbrc106555Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neokomagataea thailandica NBRC 106555 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeokomagataeaThailandicaNbrc106555Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DemequinaSediminicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Demequina sediminicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DemequinaSediminicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusAquimarinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus aquimarinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "EnterococcusAquimarinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarivitaCryptomonadis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Marivita cryptomonadis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MarivitaCryptomonadis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpBciso3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. Bciso3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpBciso3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagasanikbacteriaBacteriumRifcsplowo212full4312Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magasanikbacteria bacterium RIFCSPLOWO212FULL4312 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagasanikbacteriaBacteriumRifcsplowo212full4312Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfococcusMultivorans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfococcus multivorans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfococcusMultivorans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloterrigenaTurkmenicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Haloterrigena turkmenica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HaloterrigenaTurkmenicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BrugiaTimori(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Brugia timori graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BrugiaTimori", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CupriavidusNantongensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cupriavidus nantongensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CupriavidusNantongensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumSpEm1321Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium sp. EM1321 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumSpEm1321Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JannaschiaDonghaensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jannaschia donghaensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JannaschiaDonghaensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FormosaSpHel133131Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Formosa sp. Hel1_33_131 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "FormosaSpHel133131Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BradyrhizobiumElkaniiUsda76(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium elkanii USDA76 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumElkaniiUsda76", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DonghicolaXiamenensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Donghicola xiamenensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DonghicolaXiamenensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JonesiaQuinghaiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Jonesia quinghaiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "JonesiaQuinghaiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaYeatsiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mycoplasma yeatsii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MycoplasmaYeatsiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingopyxisMacrogoltabida(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingopyxis macrogoltabida graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingopyxisMacrogoltabida", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RheinheimeraPacificaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rheinheimera pacifica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RheinheimeraPacificaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSpIs1742(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium sp. IS-1742 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSpIs1742", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CynaraCardunculus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cynara cardunculus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CynaraCardunculus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ActinobacteriaBacteriumRbg166821(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinobacteria bacterium RBG_16_68_21 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinobacteriaBacteriumRbg166821", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PucciniaGraminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Puccinia graminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PucciniaGraminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Spechtbacteria bacterium RIFCSPHIGHO2_12_FULL_38_30 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusSpechtbacteriaBacteriumRifcsphigho212Full3830", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpEcsmb14101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. ECSMB14101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpEcsmb14101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DuganellaSpCf458Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Duganella sp. CF458 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DuganellaSpCf458Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NonlabensDokdonensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Nonlabens dokdonensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NonlabensDokdonensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFOXYD2_FULL_43_10 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifoxyd2Full4310", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusDysgalactiae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptococcus dysgalactiae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptococcusDysgalactiae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BlastomycesGilchristiiSlh14081Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Blastomyces gilchristii SLH14081 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "BlastomycesGilchristiiSlh14081Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderiaSpWp9Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Burkholderia sp. WP9 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BurkholderiaSpWp9Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PedosphaeraParvulaEllin514Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pedosphaera parvula Ellin514 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PedosphaeraParvulaEllin514Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CeleribacterIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Celeribacter indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CeleribacterIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyphomyrmexCostatusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cyphomyrmex costatus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CyphomyrmexCostatusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def WuchereriaBancroftiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wuchereria bancrofti Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WuchereriaBancroftiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HadesarchaeaArchaeonYnp45Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Hadesarchaea archaeon YNP_45 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "HadesarchaeaArchaeonYnp45Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeisseriaShayeganii871(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Neisseria shayeganii 871 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "NeisseriaShayeganii871", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TreponemaSpC6a8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Treponema sp. C6A8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TreponemaSpC6a8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DehalobacterSpFth1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Dehalobacter sp. FTH1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "DehalobacterSpFth1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BorreliaHispanicaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Borrelia hispanica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BorreliaHispanicaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridialesBacteriumDtu070Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridiales bacterium DTU070 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridialesBacteriumDtu070Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysobacterSpA03(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Lysobacter sp. A03 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "LysobacterSpA03", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusHalophilusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus halophilus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusHalophilusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusCihuensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bacillus cihuensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BacillusCihuensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaSpTs(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacula sp. TS graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DesulfobaculaSpTs", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusFlorumDsm22689Jcm16035(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus florum DSM 22689 JCM 16035 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LactobacillusFlorumDsm22689Jcm16035", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TerrisporobacterOthiniensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Terrisporobacter othiniensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TerrisporobacterOthiniensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSubtilisInaquosorumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus subtilis inaquosorum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusSubtilisInaquosorumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YangiaPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Yangia pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "YangiaPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinoplanesGlobisporusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Actinoplanes globisporus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ActinoplanesGlobisporusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaSpCnq490Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Saccharomonospora sp. CNQ490 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "SaccharomonosporaSpCnq490Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmanitaMuscariaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amanita muscaria Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmanitaMuscariaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaAquaticaFslS101188(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Listeria aquatica FSL S10-1188 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ListeriaAquaticaFslS101188", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OryzaGlaberrima(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oryza glaberrima graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OryzaGlaberrima", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycobacteriumSzulgai(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium szulgai graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumSzulgai", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeifsoniaSpRoot60Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leifsonia sp. Root60 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeifsoniaSpRoot60Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BifidobacteriumAngulatumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bifidobacterium angulatum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BifidobacteriumAngulatumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptococcusAgalactiaeNem316Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Streptococcus agalactiae NEM316 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "StreptococcusAgalactiaeNem316Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcidobacteriumAilaauiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acidobacterium ailaaui Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcidobacteriumAilaauiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusPoribacteriaBacteriumWga3gEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Poribacteria bacterium WGA-3G Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPoribacteriaBacteriumWga3gEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PolaribacterSpKt25b(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter sp. KT25b graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolaribacterSpKt25b", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AnaerostipesHadrus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Anaerostipes hadrus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AnaerostipesHadrus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ColletotrichumOrbiculareCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Colletotrichum orbiculare Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ColletotrichumOrbiculareCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SorangiumCellulosumSo01572Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sorangium cellulosum So01572 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SorangiumCellulosumSo01572Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudoalteromonasSpOcn003(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudoalteromonas sp. OCN003 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudoalteromonasSpOcn003", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpirulinaSubsalsaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spirulina subsalsa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpirulinaSubsalsaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LachnospiraceaeBacteriumA4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lachnospiraceae bacterium A4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LachnospiraceaeBacteriumA4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSediminis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sediminis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSediminis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Magasanikbacteria bacterium GW2011_GWC2_40_17 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusMagasanikbacteriaBacteriumGw2011Gwc24017", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LitomosoidesSigmodontisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Litomosoides sigmodontis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LitomosoidesSigmodontisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GemmatimonadetesBacteriumKbs708(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemmatimonadetes bacterium KBS708 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemmatimonadetesBacteriumKbs708", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VirgibacillusSenegalensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Virgibacillus senegalensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VirgibacillusSenegalensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LeptospiraAlstoniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Leptospira alstonii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "LeptospiraAlstoniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudoalteromonasPhenolicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pseudoalteromonas phenolica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PseudoalteromonasPhenolicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalidrisPugnaxEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calidris pugnax Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalidrisPugnaxEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThiohalomonasDenitrificans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thiohalomonas denitrificans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThiohalomonasDenitrificans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BetaproteobacteriaBacteriumRifcsplowo212full6820(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Betaproteobacteria bacterium RIFCSPLOWO212FULL6820 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BetaproteobacteriaBacteriumRifcsplowo212full6820", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PsychrobacillusSpOk028(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Psychrobacillus sp. OK028 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PsychrobacillusSpOk028", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrachymyrmexZetekiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Trachymyrmex zeteki Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TrachymyrmexZetekiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ErythrobacterCitreusLama915Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Erythrobacter citreus LAMA 915 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ErythrobacterCitreusLama915Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodovulumSulfidophilumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Rhodovulum sulfidophilum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "RhodovulumSulfidophilumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusGastranaerophilalesBacteriumZag111(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Gastranaerophilales bacterium Zag_111 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusGastranaerophilalesBacteriumZag111", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumSpCag273Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:273 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag273Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulomonasSpLeaf334Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Cellulomonas sp. Leaf334 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CellulomonasSpLeaf334Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhizobiumSpLeaf384(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhizobium sp. Leaf384 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhizobiumSpLeaf384", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethylosinusSpLw4Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Methylosinus sp. LW4 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MethylosinusSpLw4Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarmoricolaAequoreusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marmoricola aequoreus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarmoricolaAequoreusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AlkaliphilusPeptidifermentans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alkaliphilus peptidifermentans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlkaliphilusPeptidifermentans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanosarcinaSpMtp4(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Methanosarcina sp. MTP4 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MethanosarcinaSpMtp4", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArsenicicoccusBolidensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arsenicicoccus bolidensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArsenicicoccusBolidensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CrocinitomixAlgicolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Crocinitomix algicola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CrocinitomixAlgicolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanohalophilusPortucalensisFdf1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Methanohalophilus portucalensis FDF-1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MethanohalophilusPortucalensisFdf1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasStutzeriNf13(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas stutzeri NF13 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasStutzeriNf13", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfosporosinusLacusDsm15449Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfosporosinus lacus DSM 15449 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfosporosinusLacusDsm15449Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NeptunicoccusSediminisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neptunicoccus sediminis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeptunicoccusSediminisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DyellaJiangningensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Dyella jiangningensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DyellaJiangningensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TachikawaeaGelatinosaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tachikawaea gelatinosa Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TachikawaeaGelatinosaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesSpHpa0247Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Actinomyces sp. HPA0247 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "ActinomycesSpHpa0247Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def XanthomonasBromi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Xanthomonas bromi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "XanthomonasBromi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfotomaculumFerrireducensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Desulfotomaculum ferrireducens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DesulfotomaculumFerrireducensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWoesebacteriaBacteriumRbg164224Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Woesebacteria bacterium RBG_16_42_24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusWoesebacteriaBacteriumRbg164224Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Kuenenbacteria bacterium RIFCSPLOWO2_02_FULL_42_16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusKuenenbacteriaBacteriumRifcsplowo202Full4216Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AzospiraOryzaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Azospira oryzae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AzospiraOryzaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CyanistesCaeruleusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Cyanistes caeruleus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CyanistesCaeruleusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def KomagataeibacterXylinus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Komagataeibacter xylinus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "KomagataeibacterXylinus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CampylobacterShowaeRm3277Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Campylobacter showae RM3277 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CampylobacterShowaeRm3277Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CandidatusLatescibacterAnaerobiusScgcAaa252E07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Latescibacter anaerobius SCGC AAA252-E07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "CandidatusLatescibacterAnaerobiusScgcAaa252E07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LactobacillusKimchiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Lactobacillus kimchiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "LactobacillusKimchiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidateDivisionWor1BacteriumRifcsphigho202full5326Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return candidate division WOR1 bacterium RIFCSPHIGHO202FULL5326 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CandidateDivisionWor1BacteriumRifcsphigho202full5326Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlbimonasPacificaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Albimonas pacifica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AlbimonasPacificaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def GluconobacterMorbifer(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gluconobacter morbifer graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GluconobacterMorbifer", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlteromonadalesBacteriumBs08Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alteromonadales bacterium BS08 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlteromonadalesBacteriumBs08Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OlsenellaSpHmsc062g07Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Olsenella sp. HMSC062G07 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "OlsenellaSpHmsc062g07Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ShewanellaSpHn41Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Shewanella sp. HN-41 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ShewanellaSpHn41Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PyrococcusHorikoshiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus horikoshii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusHorikoshiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Daviesbacteria bacterium RIFCSPHIGHO2_01_FULL_36_37 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusDaviesbacteriaBacteriumRifcsphigho201Full3637Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumRifcsplowo212full4010Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium RIFCSPLOWO212FULL4010 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumRifcsplowo212full4010Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusSpBjeddCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus sp. Bjedd Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusSpBjeddCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalococcusHamelinensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Halococcus hamelinensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "HalococcusHamelinensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NonomuraeaJiangxiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nonomuraea jiangxiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NonomuraeaJiangxiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MycobacteriumFragae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mycobacterium fragae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MycobacteriumFragae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasWittichiiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas wittichii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasWittichiiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DesulfobacterVibrioformisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobacter vibrioformis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobacterVibrioformisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SinorhizobiumSaheliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sinorhizobium saheli Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SinorhizobiumSaheliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def DeinococcusWulumuqiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deinococcus wulumuqiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeinococcusWulumuqiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsplowo2124711Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPLOWO2_12_47_11 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsplowo2124711Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BdellovibrioBacteriovorusHd100Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bdellovibrio bacteriovorus HD100 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BdellovibrioBacteriovorusHd100Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Uhrbacteria bacterium RIFOXYB12_FULL_58_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusUhrbacteriaBacteriumRifoxyb12Full5810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ActinomycesTangfeifanii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Actinomyces tangfeifanii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ActinomycesTangfeifanii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PiscibacillusSalipiscariusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Piscibacillus salipiscarius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PiscibacillusSalipiscariusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RahnellaAquatilisHx2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Rahnella aquatilis HX2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "RahnellaAquatilisHx2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MarinobacterSpMctg268(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Marinobacter sp. MCTG268 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "MarinobacterSpMctg268", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Pacebacteria bacterium RIFCSPHIGHO2_01_FULL_46_16 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusPacebacteriaBacteriumRifcsphigho201Full4616Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PneumocystisJiroveciiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Pneumocystis jirovecii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "PneumocystisJiroveciiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaenorhabditisBrenneri(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Caenorhabditis brenneri graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CaenorhabditisBrenneri", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MangrovimonasSpTpbh4Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Mangrovimonas sp. TPBH4 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MangrovimonasSpTpbh4Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag964Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:964 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag964Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def MitsuariaSp7(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuaria sp. 7 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuariaSp7", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PhotobacteriumJeaniiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Photobacterium jeanii Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PhotobacteriumJeaniiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CupriavidusGilardiiCr3Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Cupriavidus gilardii CR3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CupriavidusGilardiiCr3Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusEiseniaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus eiseniae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusEiseniaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloactinosynnemaSpL07(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Alloactinosynnema sp. L-07 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AlloactinosynnemaSpL07", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JanibacterLimosusNbrc16128(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Janibacter limosus NBRC 16128 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "JanibacterLimosusNbrc16128", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErpetoichthysCalabaricus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Erpetoichthys calabaricus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ErpetoichthysCalabaricus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TuricellaOtitidis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Turicella otitidis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "TuricellaOtitidis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicromonosporaRhizosphaeraeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Micromonospora rhizosphaerae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicromonosporaRhizosphaeraeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MelissococcusPlutoniusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Melissococcus plutonius Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MelissococcusPlutoniusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlj24Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALJ24 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlj24Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AphanizomenonFlosAquaeUkl13PbCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Aphanizomenon flos-aquae UKL13-PB Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AphanizomenonFlosAquaeUkl13PbCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag710Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:710 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag710Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PrevotellaSpKh2c16Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Prevotella sp. KH2C16 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PrevotellaSpKh2c16Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinarchaeumSpHarchtbsk1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinarchaeum sp. HarchtBsk1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinarchaeumSpHarchtbsk1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RoseobacterSpGai101(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseobacter sp. GAI101 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseobacterSpGai101", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FlavobacteriumDenitrificansDsm15936Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Flavobacterium denitrificans DSM 15936 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "FlavobacteriumDenitrificansDsm15936Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BacillusTuaregiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacillus tuaregi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacillusTuaregiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PhaeobacterPorticolaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Phaeobacter porticola Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PhaeobacterPorticolaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChryseobacteriumGregarium(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium gregarium graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumGregarium", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobacteriumSpRoot61Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Microbacterium sp. Root61 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MicrobacteriumSpRoot61Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DeltaproteobacteriaBacteriumRbg165817Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Deltaproteobacteria bacterium RBG_16_58_17 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "DeltaproteobacteriaBacteriumRbg165817Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CarlitoSyrichta(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Carlito syrichta graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CarlitoSyrichta", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacterium13220cm6619(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium 13_2_20CM_66_19 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacterium13220cm6619", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AspergillusSclerotiicarbonarius(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Aspergillus sclerotiicarbonarius graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AspergillusSclerotiicarbonarius", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MoraxellaCatarrhalisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Moraxella catarrhalis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "MoraxellaCatarrhalisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DokdonellaKoreensisDs123(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Dokdonella koreensis DS-123 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "DokdonellaKoreensisDs123", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaHolmesiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella holmesii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaHolmesiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TaeniaAsiatica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Taenia asiatica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "TaeniaAsiatica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusItalicusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus italicus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusItalicusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def WohlfahrtiimonasPopuliCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Wohlfahrtiimonas populi Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "WohlfahrtiimonasPopuliCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PapioAnubisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Papio anubis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PapioAnubisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrobacterPenzbergensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Hydrobacter penzbergensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HydrobacterPenzbergensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AsaiaPrunellaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Asaia prunellae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AsaiaPrunellaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GammaproteobacteriaBacteriumRifcsphigho212full3924Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Gammaproteobacteria bacterium RIFCSPHIGHO212FULL3924 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GammaproteobacteriaBacteriumRifcsphigho212full3924Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def LactobacillusAmylophilusDsm20533Jcm1125Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Lactobacillus amylophilus DSM 20533 JCM 1125 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "LactobacillusAmylophilusDsm20533Jcm1125Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SporothrixSchenckiiAtcc58251(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Sporothrix schenckii ATCC 58251 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "SporothrixSchenckiiAtcc58251", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TrichococcusCollinsiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Trichococcus collinsii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "TrichococcusCollinsiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalothrixSpHk06Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Calothrix sp. HK-06 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CalothrixSpHk06Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf32Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf32 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf32Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def TessaracoccusSpZs01Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tessaracoccus sp. ZS01 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TessaracoccusSpZs01Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolaribacterAtrinaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Polaribacter atrinae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PolaribacterAtrinaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AlloscardoviaOmnicolensEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Alloscardovia omnicolens Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AlloscardoviaOmnicolensEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PeromyscusManiculatus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobulbusMediterraneusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Desulfobulbus mediterraneus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DesulfobulbusMediterraneusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NovosphingobiumSpRr217Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Novosphingobium sp. Rr 217 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
    """
    return RetrievedGraph(
        "NovosphingobiumSpRr217Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PalaeococcusPacificus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Palaeococcus pacificus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PalaeococcusPacificus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalobacillusDabanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halobacillus dabanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalobacillusDabanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnhydrobacterAerosaccusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enhydrobacter aerosaccus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnhydrobacterAerosaccusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def CroceicoccusNaphthovoransCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Croceicoccus naphthovorans Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CroceicoccusNaphthovoransCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def HalopenitusMalekzadehii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Halopenitus malekzadehii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "HalopenitusMalekzadehii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaWadsworthii9715Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Neisseria wadsworthii 9715 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "NeisseriaWadsworthii9715Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JohnsonellaIgnavaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Johnsonella ignava Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JohnsonellaIgnavaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumSpCag167(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Clostridium sp. CAG:167 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ClostridiumSpCag167", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MicrobulbiferAggregans(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Microbulbifer aggregans graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MicrobulbiferAggregans", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiaRickettsii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Rickettsia rickettsii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "RickettsiaRickettsii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GossypiumRaimondiiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Gossypium raimondii Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GossypiumRaimondiiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ErysipelothrixLarvaeEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Erysipelothrix larvae Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ErysipelothrixLarvaeEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def VibrioNeptuniusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Vibrio neptunius Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "VibrioNeptuniusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PseudomonasNitroreducensHbp1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Pseudomonas nitroreducens HBP1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PseudomonasNitroreducensHbp1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HydrogenovibrioSpMa26Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Hydrogenovibrio sp. MA2-6 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "HydrogenovibrioSpMa26Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesGriseorubens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Streptomyces griseorubens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "StreptomycesGriseorubens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SkermanellaAerolataCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Skermanella aerolata Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SkermanellaAerolataCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def StarkeyaNovellaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Starkeya novella Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StarkeyaNovellaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PseudovibrioAxinellae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pseudovibrio axinellae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PseudovibrioAxinellae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def LysinibacillusMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Lysinibacillus massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "LysinibacillusMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def TatumellaMorbiroseiCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Tatumella morbirosei Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "TatumellaMorbiroseiCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChitinophagaTerraeKimAndJung2007(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Chitinophaga terrae Kim and Jung 2007 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ChitinophagaTerraeKimAndJung2007", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusUrinimassiliensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Peptoniphilus urinimassiliensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PeptoniphilusUrinimassiliensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ClostridiumDrakeiEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Clostridium drakei Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ClostridiumDrakeiEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesHumi(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces humi graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "StreptomycesHumi", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PrevotellaMelaninogenica(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Prevotella melaninogenica graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PrevotellaMelaninogenica", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GracilibacillusHalophilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Gracilibacillus halophilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "GracilibacillusHalophilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def JatrophaCurcas(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Jatropha curcas graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "JatrophaCurcas", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ThermotogaProfundaAzm34c06(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Thermotoga profunda AZM34c06 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ThermotogaProfundaAzm34c06", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def FibrobacterSpUwb15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Fibrobacter sp. UWB15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "FibrobacterSpUwb15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSubrutilusCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces subrutilus Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSubrutilusCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PopulusTrichocarpaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Populus trichocarpa Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PopulusTrichocarpaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RickettsiellaIsopodorumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rickettsiella isopodorum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RickettsiellaIsopodorumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PachysolenTannophilusNrrlY2460Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Pachysolen tannophilus NRRL Y-2460 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "PachysolenTannophilusNrrlY2460Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinarimonadaceaeBacteriumHl109Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salinarimonadaceae bacterium HL-109 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalinarimonadaceaeBacteriumHl109Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulfitobacterMediterraneusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sulfitobacter mediterraneus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SulfitobacterMediterraneusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CalescamantesBacteriumScgcAaa471m6Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Calescamantes bacterium SCGC AAA471M6 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CalescamantesBacteriumScgcAaa471m6Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def NostocSpMbr210Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Nostoc sp. MBR 210 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NostocSpMbr210Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ArcobacterSpLpb0137Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Arcobacter sp. LPB0137 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ArcobacterSpLpb0137Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChroogloeocystisSiderophila(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chroogloeocystis siderophila graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChroogloeocystisSiderophila", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaulobacterSpRoot656Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Caulobacter sp. Root656 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CaulobacterSpRoot656Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PolynucleobacterSphagniphilus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Polynucleobacter sphagniphilus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PolynucleobacterSphagniphilus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EisenibacterElegansDsm3317Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Eisenibacter elegans DSM 3317 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "EisenibacterElegansDsm3317Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrobaculumSpWp30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrobaculum sp. WP30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrobaculumSpWp30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ButyrivibrioSpCag318Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Butyrivibrio sp. CAG:318 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ButyrivibrioSpCag318Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterKyonggiensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter kyonggiensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterKyonggiensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MitsuokellaJalaludinii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Mitsuokella jalaludinii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "MitsuokellaJalaludinii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SpechtbacteriaBacteriumRifcsphigho212full3830Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Spechtbacteria bacterium RIFCSPHIGHO212FULL3830 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SpechtbacteriaBacteriumRifcsphigho212full3830Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumJejuense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium jejuense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumJejuense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Zambryskibacteria bacterium RIFCSPHIGHO2_12_FULL_44_12b Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusZambryskibacteriaBacteriumRifcsphigho212Full4412bEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def OribacteriumParvum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Oribacterium parvum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "OribacteriumParvum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CitreimonasSalinariaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Citreimonas salinaria Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "CitreimonasSalinariaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AllochromatiumVinosum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Allochromatium vinosum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AllochromatiumVinosum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaAquaticaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Listeria aquatica Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ListeriaAquaticaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ParcubacteriaGroupBacteriumCg2304411Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium CG2_30_44_11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumCg2304411Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ListeriaInnocua(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Listeria innocua graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ListeriaInnocua", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasSpLeaf343Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. Leaf343 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpLeaf343Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesSpTpa0874Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces sp. TPA0874 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "StreptomycesSpTpa0874Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ClostridiumAnorexicamassiliense(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Clostridium anorexicamassiliense graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "ClostridiumAnorexicamassiliense", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacteroidetesBacteriumUkl133Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Bacteroidetes bacterium UKL13-3 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "BacteroidetesBacteriumUkl133Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AcetobacterOrientalis21f2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Acetobacter orientalis 21F-2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "AcetobacterOrientalis21f2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PleurocapsaSpPcc7319Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Pleurocapsa sp. PCC7319 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "PleurocapsaSpPcc7319Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BurkholderialesBacteriumRifoxyd12full5919(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Burkholderiales bacterium RIFOXYD12FULL5919 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BurkholderialesBacteriumRifoxyd12full5919", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PirellulaSpShsr6a(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Pirellula sp. SHSr6A graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "PirellulaSpShsr6a", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParcubacteriaGroupBacteriumGw2011gwa24726(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Parcubacteria group bacterium GW2011GWA24726 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ParcubacteriaGroupBacteriumGw2011gwa24726", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def YersiniaPseudotuberculosisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Yersinia pseudotuberculosis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "YersiniaPseudotuberculosisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaMucosa(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neisseria mucosa graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeisseriaMucosa", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HalomonasLuteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Halomonas lutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HalomonasLuteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PedobacterLusitanusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pedobacter lusitanus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PedobacterLusitanusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HyphomonasChukchiensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Hyphomonas chukchiensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "HyphomonasChukchiensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThioalkalivibrioSpAlmg11Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Thioalkalivibrio sp. ALMg11 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ThioalkalivibrioSpAlmg11Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusNiameyensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus niameyensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusNiameyensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeromyscusManiculatusBairdii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peromyscus maniculatus bairdii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeromyscusManiculatusBairdii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AgrobacteriumArsenijevicii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Agrobacterium arsenijevicii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "AgrobacteriumArsenijevicii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GlycomycesTenuisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Glycomyces tenuis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "GlycomycesTenuisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AmphriteaJaponicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Amphritea japonica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AmphriteaJaponicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def HaloferaxElongansAtccBaa1513Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Haloferax elongans ATCC BAA-1513 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "HaloferaxElongansAtccBaa1513Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeolentinusLepideus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Neolentinus lepideus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "NeolentinusLepideus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CyanobiumSpCaciam14(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Cyanobium sp. CACIAM14 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "CyanobiumSpCaciam14", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def PeptoniphilusObesiPh1(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Peptoniphilus obesi ph1 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "PeptoniphilusObesiPh1", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MyroidesGuanonisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Myroides guanonis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MyroidesGuanonisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def JejuiaPallidiluteaCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Jejuia pallidilutea Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "JejuiaPallidiluteaCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def BuchneraAphidicolaAphisGlycines(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Buchnera aphidicola (Aphis glycines) graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "BuchneraAphidicolaAphisGlycines", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ArthrobacterSpLeaf234(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Arthrobacter sp. Leaf234 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ArthrobacterSpLeaf234", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Colwellbacteria bacterium RIFCSPLOWO2_01_FULL_48_10 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "CandidatusColwellbacteriaBacteriumRifcsplowo201Full4810Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SphingomonasSpNfr15(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas sp. NFR15 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SphingomonasSpNfr15", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BradyrhizobiumJaponicum22Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Bradyrhizobium japonicum 22 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "BradyrhizobiumJaponicum22Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SphingomonasPanacisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Sphingomonas panacis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SphingomonasPanacisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def YersiniaFrederiksenii(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Yersinia frederiksenii graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "YersiniaFrederiksenii", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CandidatusWolfebacteriaBacteriumGw2011Gwa14424Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Candidatus Wolfebacteria bacterium GW2011_GWA1_44_24 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CandidatusWolfebacteriaBacteriumGw2011Gwa14424Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CellulosimicrobiumCellulansJ1Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Cellulosimicrobium cellulans J1 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "CellulosimicrobiumCellulansJ1Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BauldiaLitoralis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Bauldia litoralis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "BauldiaLitoralis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def Sar324ClusterBacteriumRedseas27b3Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return SAR324 cluster bacterium REDSEAS27B3 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "Sar324ClusterBacteriumRedseas27b3Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NatrialbaTaiwanensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Natrialba taiwanensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "NatrialbaTaiwanensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ChryseobacteriumTaeanenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Chryseobacterium taeanense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "ChryseobacteriumTaeanenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def PyrococcusFuriosusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Pyrococcus furiosus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "PyrococcusFuriosusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BordetellaGenomosp8Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bordetella genomosp. 8 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BordetellaGenomosp8Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DelphinapterusLeucasCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Delphinapterus leucas Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "DelphinapterusLeucasCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhodococcusSpB7740Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Rhodococcus sp. B7740 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "RhodococcusSpB7740Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def AccumulibacterAalborgensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Accumulibacter aalborgensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AccumulibacterAalborgensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AcinetobacterSpDsm11652Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Acinetobacter sp. DSM 11652 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AcinetobacterSpDsm11652Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RhizobiumLeguminosarumViciaeGb30Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Rhizobium leguminosarum viciae GB30 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "RhizobiumLeguminosarumViciaeGb30Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MethanoculleusBourgensisMs2Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Methanoculleus bourgensis MS2 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MethanoculleusBourgensisMs2Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChamaesiphonMinutusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chamaesiphon minutus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChamaesiphonMinutusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AdhaeribacterAquaticusEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Adhaeribacter aquaticus Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "AdhaeribacterAquaticusEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def CaldivirgaMaquilingensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Caldivirga maquilingensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "CaldivirgaMaquilingensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def StreptomycesFradiaeCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Streptomyces fradiae Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "StreptomycesFradiaeCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def EnterococcusTermitisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Enterococcus termitis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "EnterococcusTermitisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SoleaferreaMassiliensis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Soleaferrea massiliensis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SoleaferreaMassiliensis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def RhodanobacterSpRoot480(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Rhodanobacter sp. Root480 graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RhodanobacterSpRoot480", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ParaburkholderiaSprentiaeWsm5005Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Paraburkholderia sprentiae WSM5005 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "ParaburkholderiaSprentiaeWsm5005Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def NeisseriaSpHmsc064e01Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Neisseria sp. HMSC064E01 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "NeisseriaSpHmsc064e01Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DesulfobaculaToluolicaTol2Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v11.5", **kwargs
) -> Graph:
    """Return Desulfobacula toluolica Tol2 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v11.5"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
    """
    return RetrievedGraph(
        "DesulfobaculaToluolicaTol2Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaElarraichensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solemya elarraichensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolemyaElarraichensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RiesiaPthiripubis(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Riesia pthiripubis graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RiesiaPthiripubis", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MycoplasmaSpG5847Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v11.5", **kwargs
) -> Graph:
    """Return Mycoplasma sp. G5847 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v11.5"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
    """
    return RetrievedGraph(
        "MycoplasmaSpG5847Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GemellaBergeriae(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Gemella bergeriae graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "GemellaBergeriae", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def BacillusDrentensisEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Bacillus drentensis Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "BacillusDrentensisEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SulciaMuelleriSmdsem(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Sulcia muelleri SMDSEM graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SulciaMuelleriSmdsem", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MarinobacterSpAc23Cluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Marinobacter sp. AC-23 Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MarinobacterSpAc23Cluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SolemyaVelumCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Solemya velum Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "SolemyaVelumCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SideroxydansSpGwf25914Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Sideroxydans sp. GWF2_59_14 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SideroxydansSpGwf25914Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def GeodermatophilaceaeBacteriumUrha0031Enrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Geodermatophilaceae bacterium URHA0031 Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "GeodermatophilaceaeBacteriumUrha0031Enrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def DraconibacteriumOrientale(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Draconibacterium orientale graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "DraconibacteriumOrientale", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def ChaetomiumGlobosumEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Chaetomium globosum Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v11.0
			- enrichment.terms.v11.5
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "ChaetomiumGlobosumEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def MagnetospirillumGryphiswaldenseCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Magnetospirillum gryphiswaldense Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "MagnetospirillumGryphiswaldenseCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def RoseovariusIndicus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Roseovarius indicus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "RoseovariusIndicus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def XanthomonasCampestrisMusacearum(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Xanthomonas campestris musacearum graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "XanthomonasCampestrisMusacearum", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SaccharomonosporaCyanea(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Saccharomonospora cyanea graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SaccharomonosporaCyanea", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmycolatopsisJejuensisCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amycolatopsis jejuensis Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v11.0
			- cluster.v11.5
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmycolatopsisJejuensisCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def ThaueraHumireducens(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Thauera humireducens graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "ThaueraHumireducens", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def EnterococcusCasseliflavus(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v11.5", **kwargs
) -> Graph:
    """Return Enterococcus casseliflavus graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v11.5"
        Version to retrieve	
		The available versions are:
			- homology.v11.0
			- physical.links.v11.0
			- links.v11.0
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
    """
    return RetrievedGraph(
        "EnterococcusCasseliflavus", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def SalmonellaEntericaIndicaEnrichment(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="enrichment.terms.v12.0", **kwargs
) -> Graph:
    """Return Salmonella enterica indica Enrichment graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "enrichment.terms.v12.0"
        Version to retrieve	
		The available versions are:
			- enrichment.terms.v12.0
    """
    return RetrievedGraph(
        "SalmonellaEntericaIndicaEnrichment", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
def AmesbacteriaBacteriumGw2011gwa24711bCluster(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="cluster.v12.0", **kwargs
) -> Graph:
    """Return Amesbacteria bacterium GW2011GWA24711b Cluster graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "cluster.v12.0"
        Version to retrieve	
		The available versions are:
			- cluster.v12.0
    """
    return RetrievedGraph(
        "AmesbacteriaBacteriumGw2011gwa24711bCluster", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs,
		callbacks=[
			build_string_cluster_graph_node_and_edge_list
		],
		callbacks_arguments=[
		    {
		        "cluster_info_path": "clusters.info.tsv",
		        "cluster_tree_path": "clusters.tree.tsv",
		        "cluster_to_proteins_path": "clusters.proteins.tsv",
		        "node_list_path": "nodes.tsv",
		        "edge_list_path": "edges.tsv"
		    }
		]
    )()
def SalinimicrobiumCatena(
    directed=False, preprocess="auto", bioregistry=False, load_nodes=True, load_node_types=True,
    load_edge_types=True, load_edge_weights=True, auto_enable_tradeoffs=True,
    sort_tmp_dir=None, verbose=2, ring_bell=False, cache=True, cache_path=None,
    cache_sys_var="GRAPH_CACHE_DIR", version="links.v12.0", **kwargs
) -> Graph:
    """Return Salinimicrobium catena graph	

    Parameters
    ----------
    directed = False
    preprocess = "auto"
        Preprocess for optimal load time & memory peak.
        Will preprocess in Linux/macOS but not Windows.
    bioregistry=False
    load_nodes = True
        Load node names or use numeric range
    load_node_types = True
    load_edge_types = True
    auto_enable_tradeoffs = True
        Enable when graph has < 50M edges
    cache_path = None
        Path to store graphs
        Defaults either to `GRAPH_CACHE_DIR` sys var or `graphs`
    cache_sys_var = "GRAPH_CACHE_DIR"
    version = "links.v12.0"
        Version to retrieve	
		The available versions are:
			- homology.v11.5
			- physical.links.v11.5
			- links.v11.5
			- homology.v12.0
			- physical.links.v12.0
			- links.v12.0
    """
    return RetrievedGraph(
        "SalinimicrobiumCatena", version, "string", directed, preprocess, bioregistry, load_nodes,
        load_node_types, load_edge_types, load_edge_weights, auto_enable_tradeoffs, sort_tmp_dir,
        verbose, ring_bell, cache, cache_path, cache_sys_var, kwargs
    )()
"""Submodule with methods to parse and standardize STRING graphs."""
import pandas as pd


def create_species_tree_node_and_edge_list(
    tree_path: str, tree_metadata_path: str, node_list_path: str, edge_list_path: str
):
    """Create the node and edge lists for the species tree at given path.

    Parameters
    -------------------
    tree_path: str
        The path from where to load the tree data.
    tree_metadata_path: str
        The path from where to load the tree metadata.
    node_list_path: str
        The path where to store the tree node list.
    edge_list_path: str
        The path where to store the tree edge list.
    """
    tree = pd.read_csv(tree_path, sep="\t", index_col=0)
    metadata = pd.read_csv(tree_metadata_path, sep="\t", index_col=0)

    # Imputing the missing domains in the Species Tree.
    tree.loc[metadata.index, "domain"] = metadata.domain
    tree.loc[tree.parent_taxon_id == 1, "domain"] = "Ancestral"
    tree.loc[tree.domain == "Eukaryotes", "domain"] = "Eukaryota"

    while tree.domain.isna().any():
        child_nodes = tree[
            tree.loc[tree.parent_taxon_id].domain.isna().values
            & tree.domain.notna().values
        ]
        tree.loc[child_nodes.parent_taxon_id, "domain"] = child_nodes.domain.values

    # We drop the temporary node index 1
    tree.drop(index=1, inplace=True)

    # Making taxon names unique, so that corner cases
    # such as `Drosophila Drosophila` can be handled.
    tree.loc[tree.duplicated("taxon_name"), "taxon_name"] = [
        f"{taxon_name}.{index}"
        for index, taxon_name in tree.loc[
            tree.duplicated("taxon_name"), "taxon_name"
        ].iteritems()
    ]

    # Writing the node list
    node_list = tree[["taxon_name", "domain"]]
    node_list.to_csv(node_list_path, sep="\t", index=False)

    # We drop edges from the root node to LUCA
    tree.drop(index=tree[tree.parent_taxon_id == 1].index[0], inplace=True)

    # Writing the edge list
    pd.DataFrame(
        {
            "sources": node_list.loc[tree.parent_taxon_id].taxon_name.values,
            "destinations": node_list.loc[tree.index].taxon_name.values,
            "domain": tree.domain.values,
        }
    ).to_csv(edge_list_path, sep="\t", index=False)


def build_string_cluster_graph_node_and_edge_list(
    cluster_info_path: str,
    cluster_tree_path: str,
    cluster_to_proteins_path: str,
    node_list_path: str,
    edge_list_path: str,
):
    """Build labeled edge and node list for cluster graphs.

    Parameters
    -----------------------
    cluster_info_path: str
        Path from where to load the cluster node list informations.
    cluster_tree_path: str
        Path from where to load the cluster to cluster edge list.
    cluster_to_proteins_path: str
        Path from where to load the cluster to protein edge list.
    target_path: str
        Path where to write the resulting node list TSV.
    """
    cluster_only_node_list = pd.read_csv(cluster_info_path, sep="\t")
    cluster_only_node_list["term"] = "Cluster"
    cluster_only_node_list.rename(
        columns={"best_described_by": "description", "cluster_id": "node_name"},
        inplace=True,
    )
    string_only_node_list = pd.read_csv(node_list_path, sep="\t")
    string_only_node_list.rename(
        columns={"#string_protein_id": "node_name"}, inplace=True
    )
    node_list = pd.concat((cluster_only_node_list, string_only_node_list), axis=0)
    node_list.to_csv(node_list_path, sep="\t")

    cluster_tree_df = pd.read_csv(cluster_tree_path, sep="\t")
    cluster_to_proteins_df = pd.read_csv(cluster_to_proteins_path, sep="\t")

    cluster_tree_df.rename(
        columns={
            "child_cluster_id": "source",
            "parent_cluster_id": "destination",
        },
        inplace=True,
    )

    cluster_to_proteins_df.rename(
        columns={
            "cluster_id": "source",
            "protein_id": "destination",
        },
        inplace=True,
    )

    edge_list = pd.concat(
        (
            cluster_tree_df[["source", "destination"]],
            cluster_to_proteins_df[["source", "destination"]],
        ),
        axis=0,
    )

    edge_list.to_csv(edge_list_path, sep="\t", index=False)
